(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     59230,       2142]*)
(*NotebookOutlinePosition[     60149,       2174]*)
(*  CellTagsIndexPosition[     60105,       2170]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["INTRODUCTION"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Remove["\<Global`*\>"]\)], "Input"],

Cell[CellGroupData[{

Cell[TextData["General Comments "], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Style"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(case = {a \[Rule] 1, b \[Rule] 2}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({a \[Rule] 1, b \[Rule] 2}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Preparation"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Off[General::"\<spell\>", General::"\<spell1\>"]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Needs["\<Graphics`Arrow`\>"]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Needs["\<Graphics`PlotField`\>"]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Units and Constants"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Units"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(tera = 10\^12; micro = 1\/10\^6; \), 
    \(giga = 10\^9; nano = 1\/10\^9; \), 
    \(mega = 10\^6; pico = 1\/10\^12; \), 
    \(kilo = 10\^3; femto = 1\/10\^15; \), 
    \(milli = 1\/10.\^3; atto = 1\/10\^18; \)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Physical Constants"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(NSub
       = {c \[Rule] 2.99792458\ 10\^8, e \[Rule] 1.6021773\/10\^19, 
        h \[Rule] 6.6260755\/10.\^34, hbar \[Rule] 1.05457\/10.\^34, 
        K \[Rule] 1.380658\/10\^23, me \[Rule] 9.109389\/10\^31, 
        mu0 \[Rule] \(4.\ \[Pi]\)\/10\^7, eps0 \[Rule] 8.85419\/10\^12}; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Materials Constants"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ESi = 0.179\ tera; rhoSi = 2330; nuSi = 0.28; \), 
    \(ESiO2 = 0.06\ tera; rhoSiO2 = 2200; nuSiO2 = 0.25; \), 
    \(ESi3N4 = 0.15\ tera; rhoSi3N4 = 3100; nuSi3N4 = 0.25; \), 
    \(EAu = 0.08\ tera; rhoAu = 19300; nuAu = 0.42; \), 
    \(ENi = 0.207\ tera; rhoNi = 8900; nuNi = 0.41; \), 
    \(EW = 0.345\ tera; rhoW = 19300; nuW = 0.28; \), 
    \(EPt = 0.17\ tera; rhoPt = 21400; nuPt = 0.39; \), 
    \(EIr = 0.52\ tera; rhoIr = 22500; nuIr = 0.3; \), 
    \(EHOPG = 0.2\ tera; rhoHOPG = 2250; nuHOPG = 0.3; \), 
    \(EPol = 0.001\ tera; rhoPol = 1000; nuPol = 0.3; \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(x = 0.8; \)\), 
    \(\(EPtIr = x\ EPt + \((1 - x)\)\ EIr; \)\), 
    \(\(rhoPtIr = x\ rhoPt + \((1 - x)\)\ rhoIr; \)\), 
    \(\(nuPtIr = 0.3; \)\), 
    \(\(Clear[x]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Figures"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Figure Options"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(opt
       = {PlotRange \[Rule] All, AxesOrigin \[Rule] {0, 0}, 
        Frame \[Rule] True, GridLines \[Rule] Automatic, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        PlotStyle 
          \[Rule] {Dashing[{.0001}], Dashing[{.0200}], Dashing[{.0200}], 
            Dashing[{.0200}], Dashing[{.0200}], Dashing[{.0001}]}}; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(opt1
       = {PlotRange \[Rule] All, AxesOrigin \[Rule] {0, 0}, 
        Frame \[Rule] True, GridLines \[Rule] Automatic, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}}; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Figure Examples"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig1x1 = 
      Plot[{Sin[x], Cos[x]}, {x, 0, \[Pi]}, 
        FrameLabel \[Rule] {"\<x in rad\>", "\<Sin & Cos\>"}, Evaluate[opt]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.023809 0.303152 0.309017 0.294302 [
[.02381 -0.0125 -4 -12 ]
[.02381 -0.0125 4 0 ]
[.17539 -0.0125 -7 -12 ]
[.17539 -0.0125 7 0 ]
[.32696 -0.0125 -4 -12 ]
[.32696 -0.0125 4 0 ]
[.47854 -0.0125 -7 -12 ]
[.47854 -0.0125 7 0 ]
[.63011 -0.0125 -4 -12 ]
[.63011 -0.0125 4 0 ]
[.78169 -0.0125 -7 -12 ]
[.78169 -0.0125 7 0 ]
[.93327 -0.0125 -4 -12 ]
[.93327 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14.5 -24 ]
[.5 -0.0125 14.5 -12 ]
[-0.0125 .01472 -14 -6 ]
[-0.0125 .01472 0 6 ]
[-0.0125 .16187 -20 -6 ]
[-0.0125 .16187 0 6 ]
[-0.0125 .30902 -8 -6 ]
[-0.0125 .30902 0 6 ]
[-0.0125 .45617 -14 -6 ]
[-0.0125 .45617 0 6 ]
[-0.0125 .60332 -8 -6 ]
[-0.0125 .60332 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -32 -19 ]
[-0.01875 .30902 -20 19 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .61803 L
s
.32696 0 m
.32696 .61803 L
s
.47854 0 m
.47854 .61803 L
s
.63011 0 m
.63011 .61803 L
s
.78169 0 m
.78169 .61803 L
s
.93327 0 m
.93327 .61803 L
s
0 .16187 m
1 .16187 L
s
0 .30902 m
1 .30902 L
s
0 .45617 m
1 .45617 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.17539 0 m
.17539 .00625 L
s
gsave
.17539 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.32696 0 m
.32696 .00625 L
s
gsave
.32696 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.47854 0 m
.47854 .00625 L
s
gsave
.47854 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.63011 0 m
.63011 .00625 L
s
gsave
.63011 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.78169 0 m
.78169 .00625 L
s
gsave
.78169 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.93327 0 m
.93327 .00625 L
s
gsave
.93327 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75137 0 m
.75137 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(rad) show
87.312500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .16187 m
.00625 .16187 L
s
gsave
-0.0125 .16187 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .45617 m
.00625 .45617 L
s
gsave
-0.0125 .45617 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -106 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
80 10 translate
90 rotate
-80 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Sin) show
75.625000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(&) show
83.812500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Cos) show
96.187500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.17539 .61178 m
.17539 .61803 L
s
.32696 .61178 m
.32696 .61803 L
s
.47854 .61178 m
.47854 .61803 L
s
.63011 .61178 m
.63011 .61803 L
s
.78169 .61178 m
.78169 .61803 L
s
.93327 .61178 m
.93327 .61803 L
s
.125 Mabswid
.05412 .61428 m
.05412 .61803 L
s
.08444 .61428 m
.08444 .61803 L
s
.11476 .61428 m
.11476 .61803 L
s
.14507 .61428 m
.14507 .61803 L
s
.2057 .61428 m
.2057 .61803 L
s
.23602 .61428 m
.23602 .61803 L
s
.26633 .61428 m
.26633 .61803 L
s
.29665 .61428 m
.29665 .61803 L
s
.35728 .61428 m
.35728 .61803 L
s
.38759 .61428 m
.38759 .61803 L
s
.41791 .61428 m
.41791 .61803 L
s
.44822 .61428 m
.44822 .61803 L
s
.50885 .61428 m
.50885 .61803 L
s
.53917 .61428 m
.53917 .61803 L
s
.56948 .61428 m
.56948 .61803 L
s
.5998 .61428 m
.5998 .61803 L
s
.66043 .61428 m
.66043 .61803 L
s
.69074 .61428 m
.69074 .61803 L
s
.72106 .61428 m
.72106 .61803 L
s
.75137 .61428 m
.75137 .61803 L
s
.81201 .61428 m
.81201 .61803 L
s
.84232 .61428 m
.84232 .61803 L
s
.87264 .61428 m
.87264 .61803 L
s
.90295 .61428 m
.90295 .61803 L
s
.96358 .61428 m
.96358 .61803 L
s
.9939 .61428 m
.9939 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .30902 m
.06244 .34642 L
.10458 .3865 L
.14415 .4228 L
.18221 .45589 L
.22272 .48856 L
.26171 .51699 L
.30316 .54343 L
.34309 .56477 L
.3815 .58112 L
.40095 .58775 L
.42237 .59372 L
.44268 .59807 L
.45178 .5996 L
.46172 .60098 L
.4671 .60159 L
.4721 .60207 L
.47727 .60249 L
.48196 .6028 L
.48658 .60303 L
.4887 .60311 L
.49093 .60319 L
.49332 .60325 L
.49438 .60327 L
.49552 .60329 L
.49675 .6033 L
.49789 .60331 L
.49859 .60332 L
.49925 .60332 L
.50049 .60332 L
.50163 .60331 L
.50286 .60331 L
.50401 .60329 L
.50508 .60328 L
.50754 .60323 L
.51014 .60315 L
.51268 .60306 L
.51504 .60296 L
.5204 .60265 L
.5293 .60195 L
.53882 .60091 L
.54906 .59947 L
.56016 .59754 L
.58032 .59305 L
.62123 .5801 L
.66064 .56296 L
.69852 .54244 L
.73886 .51659 L
.77769 .48825 L
.81897 .4549 L
Mistroke
.85873 .42022 L
.89697 .38505 L
.93767 .34631 L
.97619 .30902 L
Mfstroke
[ .02 ] 0 setdash
.02381 .60332 m
.02499 .60332 L
.02605 .60331 L
.02729 .6033 L
.02846 .60328 L
.03053 .60325 L
.03279 .60319 L
.03527 .60311 L
.0379 .603 L
.04262 .60275 L
.04749 .60242 L
.05205 .60204 L
.06244 .60093 L
.07305 .59945 L
.08274 .59778 L
.10458 .59293 L
.12357 .58753 L
.14429 .58038 L
.18493 .56272 L
.22406 .54141 L
.26565 .51454 L
.30571 .48498 L
.34426 .45364 L
.38527 .41776 L
.42475 .38132 L
.46273 .34511 L
.50315 .30596 L
.54206 .26832 L
.58342 .22905 L
.62326 .19262 L
.66159 .15946 L
.70238 .12682 L
.74164 .09849 L
.77939 .07458 L
.8196 .05311 L
.85828 .0367 L
.87793 .03004 L
.89942 .0241 L
.91995 .01977 L
.92911 .01826 L
.93905 .01692 L
.94426 .01635 L
.94906 .01589 L
.95356 .01553 L
.95851 .01522 L
.96295 .015 L
.9671 .01485 L
.96939 .01479 L
.97148 .01475 L
.97264 .01474 L
Mistroke
.9739 .01472 L
.97509 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{126, 77},
  ImageMargins->{{123, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002N0000HA000`40l00?003`W_oo002Nool009ko
o`00W_oo001Cool00`0?ool03`03ool01@0?ool03ooo00l00ooo00H03oooool03ooo00l2ool200lc
ool005Coo`0300oooooo00;oo`0500ooo`0?ool03`03ool00`0?ooooo`0200l2ool00`0?ool03`0c
ool005Coo`0300oooooo00;oo`0500ooo`0?ool03`03ool200l2ool01P0?ooooo`0?ool03c?oo`00
Dooo00<03ooo00l00ooo00@03ooo00l03`Coo`0300ooo`0?00803`?oo`803c?oo`00J_oo00<03ooo
ool0<Ooo001Iool00`0?ooooo`12ool009koo`00W_oo002Nool009koo`00W_oo002Nool002_oo`03
00oooooo00_oo`0500oooooo00ooo`0200l;ool300l:ool300l00ooo00ooo`0200l<ool300l:ool3
00l00ooo00ooo`0200l;ool200l@ool002[oo`0300ooo`0?00_oo`0300ooo`0?00Goo`0300oooooo
00Woo`0300oooooo00[oo`0300oooooo00Coo`0300oooooo00Woo`0300oooooo00[oo`0300oooooo
00Goo`0300oooooo00[oo`0300oooooo00goo`00:_oo00<03ooo00l02ooo00<03ooo00l00ooo0P0?
3?oo00<03oooool02_oo00<03oooool00_oo0P0?3Ooo00<03oooool02_oo00<03oooool00_oo0P0?
3?oo00<03oooool03_oo000Zool00`0?ool03`0;ool00`0?ool03`03ool00`0?ooooo`0;ool00`0?
ooooo`0:ool00`0?ooooo`02ool00`0?ooooo`0;ool00`0?ool03`0:ool00`0?ool03`03ool00`0?
ooooo`0<ool00`0?ooooo`0=ool002_oo`0300oooooo00_oo`0300oooooo00;oo`<03`[oo`803`_o
o`803`Coo`<03`coo`803`_oo`803`?oo`<03`[oo`803a3oo`00W_oo002Nool009koo`00W_oo000R
ool300miool002?oo`0300oooooo00?oofd03`Soo`007_oo0`0?0_oo00<03oooool00ooo0P0?4Ooo
00<0Ooooool03_oo00<0Soooool03Ooo00<0Soooool03Ooo00<0Soooool03_oo00<0Ooooool03Ooo
00<0O`0?00l00P0?00?oo`0?00l02?oo000Sool00`0?ooooo`03ool00`0?ooooo`0@ool00`2?oooo
o`0>ool00`1oooooo`0=ool00`1oooooo`0=ool00`1oooooo`0>ool00`2?ooooo`08ool00`0?ool0
3`0200l00`2?ooooo`04ool00`0?ooooo`06ool002;oo`803`Goo`0300oooooo013oo`0307oooooo
00koo`0308oooooo00goo`0308oooooo00goo`0308oooooo00koo`0307oooooo00Koo`<03`Coo`03
07oooooo00Coo`0300oooooo00Koo`00:Ooo0P0?4Ooo00<0Soooool03_oo00<0Ooooool03Ooo00<0
Ooooool03Ooo00<0Ooooool03_oo00<0Soooool00ooo0P0?2?oo00<0Soooool01?oo00<03oooool0
1_oo000Yool00`0?ooooo`0@ool00`1oooooo`0>ool00`2?ooooo`0=ool00`2?ooooo`0=ool00`2?
ooooo`0>ool00`1oooooo`02ool00`0?ooooo`08ool00`1oooooo`04ool00`0?ooooo`06ool002Wo
o`0300oooooo013oo`0308oooooo00koo`0307oooooo00goo`0307oooooo00goo`0307oooooo00ko
o`0408ooo`0?00l<ool00`2?ooooo`04ool00`0?ooooo`06ool002Woo`0300oooooo013oo`0307oo
oooo00koo`0308oooooo00goo`0308oooooo00goo`0308oooooo00koo`0307l03ooo00goo`0307oo
oooo00Coo`0300oooooo00Koo`00:Ooo0P0?4Ooo00<0Soooool03_oo00<0Ooooool03Ooo00<0Oooo
ool03Ooo00<0Ooooool03?oo0P0?00<0Soooool03Ooo00<0Soooool01?oo00<03oooool01_oo000Y
ool00`0?ooooo`0@ool00`1oooooo`0>ool00`2?ooooo`0=ool00`2?ooooo`0=ool00`2?ooooo`0;
ool0100?ooooo`1o3ooo00<0Ooooool01?oo00<03oooool01_oo000Yool00`0?ooooo`0@ool00`2?
ooooo`0>ool00`1oooooo`0=ool00`1oooooo`0=ool00`1oooooo`09ool200l3ool00`2?ooooo`0=
ool00`2?ooooo`04ool00`0?ooooo`06ool002Woo`803a7oo`0307oooooo00koo`0308oooooo00go
o`0308oooooo00goo`0308oooooo00Soo`0300oooooo00?oo`0307oooooo00goo`0307oooooo00Co
o`0300oooooo00Koo`00:Ooo00<03oooool04?oo00<0Soooool03_oo00<0Ooooool03Ooo00<0Oooo
ool03Ooo00<0Ooooool01_oo00<03oooool01Ooo00<0Soooool03Ooo00<0Soooool01?oo00<03ooo
ool01_oo000Yool00`0?ooooo`0@ool00`1oooooo`0>ool00`2?ooooo`0=ool00`2?ooooo`0=ool0
0`2?ooooo`05ool00`0?ooooo`06ool00`1oooooo`0=ool00`1oooooo`04ool00`0?ooooo`06ool0
02Woo`803a7oo`0308oooooo00koo`0307oooooo00goo`0307oooooo00goo`0307oooooo00Coo`03
00oooooo00Ooo`0308oooooo00goo`0308oooooo00Coo`0300oooooo00Koo`007Ooo00D03oooool0
3ooo00803`Goo`0300oooooo013oo`0307oooooo00koo`0308oooooo00goo`0308oooooo00goo`03
08oooooo00?oo`0300oooooo00Soo`0307oooooo00goo`0307oooooo00Coo`0300oooooo00Koo`00
3?oo00<03oooool00P0?2ooo00<03ooo00l01Ooo00<03oooool00_oo00<03oooool04?oo00<0Sooo
ool03_oo00<0Ooooool03Ooo00<0Ooooool03Ooo00@0Ooooooooo`803`_oo`0308oooooo00goo`03
08oooooo00Coo`0300oooooo00Koo`002ooo00<03ooo00l00_oo00<03oooool01Ooo0`0?00Coo`0?
ool03`?oo`803`Goo`803`1Y08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00803`Soo`002ooo
00H03oooool03ooo00l;ool00`0?ool03`03ool00`0?ooooo`04ool00`0?ooooo`0@ool00`2?oooo
o`0>ool00`1oooooo`0=ool00`1oooooo`0=ool00`1oool03`0>ool00`2?ooooo`0=ool00`2?oooo
o`04ool00`0?ooooo`06ool000_oo`803`;oo`0300oooooo00_oo`0300oooooo00;oo`<03`Coo`03
00oooooo013oo`0307oooooo00koo`0308oooooo00goo`0308oooooo00goo`0308l03ooo00koo`03
07oooooo00goo`0307oooooo00Coo`0300oooooo00Koo`00:Ooo0P0?4Ooo00<0Soooool03_oo00<0
Ooooool03Ooo00<0Ooooool03Ooo00<0Ooooool03_oo00<0Soooool03Ooo00<0Soooool01?oo00<0
3oooool01_oo000>ool00`0?ool03`0Hool00`0?ooooo`0@ool00`1oooooo`0>ool00`2?ooooo`0=
ool00`2?ooooo`0<ool00`0?08ooo`0?ool00`1oooooo`0=ool00`1oooooo`04ool00`0?ooooo`06
ool000_oo`0300ooo`0?00<03aSoo`0300oooooo013oo`0308oooooo00koo`0307oooooo00goo`03
07oooooo00_oo`0300ooo`1o013oo`0308oooooo00goo`0308oooooo00Coo`0300oooooo00Koo`00
3Ooo100?6?oo0P0?4Ooo00<0Ooooool03_oo00<0Soooool03Ooo00<0Soooool02Ooo00D03ooooooo
o`2?013oo`0307oooooo00goo`0307oooooo00Coo`0300oooooo00Koo`003Ooo00@03oooool03aSo
o`0300oooooo013oo`0308oooooo00koo`0307oooooo00goo`0307oooooo00Soo`0300oooooo00;o
o`0307oooooo00koo`0308oooooo00goo`0308oooooo00Coo`0300oooooo00Koo`003Ooo00<03ooo
ool06Ooo00<03oooool04?oo00<0Ooooool03_oo00<0Soooool03Ooo00<0Soooool01ooo00<03ooo
ool00ooo00<0Soooool03_oo00<0Ooooool03Ooo00<0Ooooool01?oo00<03oooool01_oo000>ool3
00lHool00`0?ooooo`0@ool00`2?ooooo`0>ool00`1oooooo`0=ool00`1oooooo`06ool00`0?oooo
o`04ool00`1oooooo`0>ool00`2?ooooo`0=ool00`2?ooooo`04ool00`0?ooooo`06ool002Woo`80
3a7oo`0307oooooo00koo`0308oooooo00goo`0308oooooo00Goo`0300oooooo00Goo`0308oooooo
00koo`0307oooooo00goo`0307oooooo00Coo`0300oooooo00Koo`00:Ooo00<03oooool04?oo00<0
Soooool03_oo00<0Ooooool03Ooo00<0Ooooool01?oo00<03oooool01_oo00<0Ooooool03_oo00<0
Soooool03Ooo00<0Soooool01?oo00<03oooool01_oo000>ool200lIool00`0?ooooo`0@ool00`1o
ooooo`0>ool00`2?ooooo`0=ool00`2?ooooo`03ool00`0?ooooo`07ool00`2?ooooo`0>ool00`1o
ooooo`0=ool00`1oooooo`04ool00`0?ooooo`06ool000coo`803`;oo`0300oooooo017oo`0300oo
oooo00;oo`803a7oo`0308oooooo00koo`0307oooooo00goo`0307oooooo00;oo`0300oooooo00So
o`0307oooooo00koo`0308oooooo00goo`0308oooooo00Coo`0300oooooo00Koo`002ooo00H03ooo
00l03ooo00lBool00`0?ool03`03ool00`0?ooooo`0@ool00`1oooooo`0>ool00`2?ooooo`0=ool0
1@2?oooooooo00l02ooo00<0Soooool03_oo00<0Ooooool03Ooo00<0Ooooool01?oo00<03oooool0
1_oo000<ool0100?ooooo`0?4ooo00<03ooo00l00ooo00<03oooool04?oo00<0Soooool03_oo00<0
Ooooool03Ooo00@0Ooooool03`coo`0307oooooo00koo`0308oooooo00goo`0308oooooo00Coo`03
00oooooo00Koo`003_oo00<03ooo00l04_oo00<03ooo00l00oooK@0?2?oo000=ool0100?ooooo`0?
4ooo00<03oooool00_oo00@03oooooooo`803`goo`0308oooooo00koo`0307oooooo00goo`0307l0
3ooo00goo`0307oooooo00koo`0308oooooo00goo`0308oooooo00803`;oo`0300oooooo00Koo`00
:Ooo00<03oooool00_oo0P0?3?oo00<0Ooooool03_oo00<0Soooool03Ooo00<03oooool03Ooo00<0
Soooool03_oo00<0Ooooool03Ooo00@0Oooo00l03`?oo`0300oooooo00Koo`00:Ooo0P0?1?oo0P0?
2ooo00<0Soooool03_oo00<0Ooooool03?oo00<03`1oool03_oo00<0Ooooool03_oo00<0Soooool0
3Ooo00<0S`0?00l01?oo00<03oooool01_oo000=ool300lIool00`0?ooooo`04ool200l:ool00`1o
ooooo`0>ool00`2?ooooo`0;ool00`0?ool0S`0?ool00`2?ooooo`0>ool00`1oooooo`0=ool200l5
ool00`0?ooooo`06ool000_oo`803`?oo`0300oooooo01Koo`0300oooooo00Goo`803`Woo`0308oo
oooo00koo`0307oooooo00Woo`0500ooooooool0O`0?ool00`1oooooo`0>ool00`2?ooooo`0<ool2
00l6ool00`0?ooooo`06ool000_oo`0300oooooo00;oo`0300oooooo01Koo`803`Ooo`803`Soo`03
07oooooo00koo`0308oooooo00Woo`0500ooooooool0S`0?ool00`2?ooooo`0>ool00`1oooooo`0;
ool200l00`1oooooo`04ool00`0?ooooo`06ool000_oo`0300oooooo00;oo`0300oooooo01Koo`03
00oooooo00Ooo`803`Ooo`0308oooooo00koo`0307oooooo00Soo`0300oooooo00;oo`0307oooooo
00goo`0307oooooo00koo`0308oooooo00Woo`803`;oo`0308oooooo00Coo`0300oooooo00Koo`00
2ooo0P0?0_oo00<03oooool05ooo00<03oooool02?oo0P0?1_oo00<0Ooooool03_oo00<0Soooool0
1_oo00<03oooool01?oo00<0Soooool03Ooo00<0Soooool03_oo00<0Ooooool02?oo0P0?0ooo00<0
Ooooool01?oo00<03oooool01_oo000>ool200lIool200l:ool200l5ool00`2?ooooo`0>ool00`1o
ooooo`06ool00`0?ooooo`04ool00`1oooooo`0=ool00`1oooooo`0>ool00`2?ooooo`07ool200l4
ool00`2?ooooo`04ool00`0?ooooo`06ool000goo`0400oooooo00lHool00`0?ooooo`0:ool200l4
ool00`1oooooo`0>ool00`2?ooooo`05ool00`0?ooooo`05ool00`2?ooooo`0=ool00`2?ooooo`0>
ool00`1oooooo`06ool200l5ool00`1oooooo`04ool00`0?ooooo`06ool000goo`0400oooooo00lH
ool00`0?ooooo`0;ool200l3ool00`2?ooooo`0>ool00`1oooooo`03ool00`0?ooooo`07ool00`1o
ooooo`0=ool00`1oooooo`0>ool00`2?ooooo`05ool200l6ool00`2?ooooo`04ool00`0?ooooo`06
ool000koo`803aWoo`0300oooooo00coo`803`;oo`0307oooooo00koo`0308oooooo00;oo`803`Wo
o`0308oooooo00goo`0308oooooo00koo`0307oooooo00Coo`803`Ooo`0307oooooo00Coo`0300oo
oooo00Koo`003_oo00<03ooo00l03Ooo00D03oooool03ooo00803`Coo`803`koo`<03`0308oooooo
00koo`0307oooooo00;oo`0300oooooo00Soo`0307oooooo00goo`0307oooooo00koo`0308oooooo
00?oo`803`Soo`0308oooooo00Coo`0300oooooo00Koo`003Ooo0P0?00?oo`0?ool02ooo00<03ooo
00l01Ooo00D03oooooooo`0?017oo`803a3oo`0408oooooo00l<ool00`2?ooooo`0=ool00`2?oooo
o`0>ool00`1oooooo`02ool200l9ool00`1oooooo`04ool00`0?ooooo`06ool000goo`0300ooo`0?
00goo`0300ooo`0?00?oo`803`Coo`0300oooooo013oo`803`ooo`0307l03`0?00goo`0307oooooo
00goo`0307oooooo00koo`0408ooooooool200l:ool00`2?ooooo`04ool00`0?ooooo`06ool001go
o`0300ooo`0?00?oo`0300oooooo00?oo`803`0B08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o0P0?0440S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?00<03`0A08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`0200l8ool001koo`0300oooooo00;oo`<03`?oo`0300oooooo013oo`0408ooo`0?00l<ool200l?
ool00`1oooooo`0=ool00`1oooooo`0>ool00`2?00l03`0=ool00`2?ooooo`04ool00`0?ooooo`06
ool002Woo`0300oooooo013oo`0307oooooo00<03`Woo`0300ooo`2?00ooo`0308oooooo00goo`03
08oooooo00koo`803`koo`0307oooooo00Coo`0300oooooo00Koo`00:Ooo0P0?4Ooo00<0Soooool0
0_oo0P0?2_oo00<0Ooooool03Ooo00<0Ooooool03Ooo00<0Ooooool03Ooo0P0?3ooo00<0Soooool0
1?oo00<03oooool01_oo000Yool00`0?ooooo`0@ool00`1oooooo`03ool200l4ool200l3ool00`2?
ooooo`0=ool00`2?ooooo`0=ool00`2?ooooo`0;ool300l00`1oooooo`0=ool00`1oooooo`04ool0
0`0?ooooo`06ool002Woo`0300oooooo013oo`0308oooooo00Coo`<03`;oo`0300oooooo00;oo`03
07oooooo00goo`0307oooooo00goo`0307oooooo00[oo`803`;oo`0308oooooo00goo`0308oooooo
00Coo`0300oooooo00Koo`00:Ooo0P0?4Ooo00<0Ooooool01_oo0P0?1_oo00<0Soooool03Ooo00<0
Soooool03Ooo00<0Soooool02?oo0`0?0ooo00<0Ooooool03Ooo00<0Ooooool01?oo00<03oooool0
1_oo000Yool00`0?ooooo`0@ool00`2?ooooo`05ool500l4ool00`1oooooo`0=ool00`1oooooo`0=
ool00`1oooooo`07ool200l5ool00`2?ooooo`0=ool00`2?ooooo`04ool00`0?ooooo`06ool002Wo
o`0300oooooo013oo`0307oooooo00?oo`0300oooooo00?oo`803`?oo`0308oooooo00goo`0308oo
oooo00goo`0308oooooo00Goo`<03`Koo`0307oooooo00goo`0307oooooo00Coo`0300oooooo00Ko
o`00:Ooo0P0?4Ooo00@0Soooooooo`<03`Koo`<03`03ool0Oooo00koo`0307oooooo00goo`0307oo
oooo00Coo`803`Soo`0308oooooo00goo`0308oooooo00Coo`0300oooooo00Koo`00:Ooo00<03ooo
ool04?oo00<0Oooo00l03?oo0`0?3ooo00<0Soooool03Ooo00<0Soooool00_oo0`0?2Ooo00<0Oooo
ool03Ooo00<0Ooooool01?oo00<03oooool01_oo000Yool00`0?ooooo`0@ool00`2?00l03`0>ool3
00l=ool00`1oooooo`0=ool00`1oooooo`0300l;ool00`2?ooooo`0=ool00`2?ooooo`04ool00`0?
ooooo`06ool002Woo`803a3oo`0300l0Oooo00ooo`0308ooo`0?00803`_oo`0308oooooo00goo`@0
3`goo`0307oooooo00goo`0307oooooo00Coo`0300oooooo00Koo`008ooo0`0?0ooo00<03oooool0
3Ooo0P0?00?oo`2?ool03ooo00@0Ooooooooo`@03`Soo`0307oooooo00_oo`<03a3oo`0308oooooo
00goo`0308oooooo00Coo`0300oooooo00Koo`009?oo00<03oooool00_oo00<03oooool02?oo100?
1?oo00<0Ooooool03_oo00<0Soooool01?oo100?1Ooo00<0Soooool01ooo1@0?00?oo`2?ool03ooo
00<0Ooooool03Ooo00<0Ooooool01?oo00<03oooool01_oo000Tool00`0?ooooo`02ool200l01Ooo
00l03`0?ool00`0?2Ooo00<0Soooool03_oo00<0Ooooool01ooo4@0?1Ooo00<0Ooooool03_oo00<0
Soooool03Ooo00<0Soooool00ooo0P0?2?oo000Tool00`0?ooooo`02ool0100?ooooo`0?3ooo00<0
3oooool03_oo00<03oooool03Ooo00<03oooool03Ooo00<03oooool03_oo00<03oooool03Ooo00<0
3oooool01?oo00<03oooool01_oo000Sool200l4oom]00l8ool009koo`00W_oo002Nool009koo`00
\
\>"],
  ImageRangeCache->{{{0, 156.5}, {95.25, 0}} -> {-1.363509, -1.818936, 
  0.038328, 0.039481}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig1x2 = 
      Show[Graphics[Circle[{0, 0}, 1], AspectRatio \[Rule] Automatic, 
          FrameLabel \[Rule] {"\<x in a.u.\>", "\<y in a.u.\>"}, opt1]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[.02381 -0.0125 -7 -12 ]
[.02381 -0.0125 7 0 ]
[.2619 -0.0125 -10 -12 ]
[.2619 -0.0125 10 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.7381 -0.0125 -7 -12 ]
[.7381 -0.0125 7 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -15 -24 ]
[.5 -0.0125 15 -12 ]
[-0.0125 .02381 -14 -6 ]
[-0.0125 .02381 0 6 ]
[-0.0125 .2619 -20 -6 ]
[-0.0125 .2619 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .7381 -14 -6 ]
[-0.0125 .7381 0 6 ]
[-0.0125 .97619 -8 -6 ]
[-0.0125 .97619 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -32 -15 ]
[-0.01875 .5 -20 15 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 1 L
s
.5 0 m
.5 1 L
s
.7381 0 m
.7381 1 L
s
0 .2619 m
1 .2619 L
s
0 .5 m
1 .5 L
s
0 .7381 m
1 .7381 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -76 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
82.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
86.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
88.687500 13.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .2619 m
.00625 .2619 L
s
gsave
-0.0125 .2619 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .7381 m
.00625 .7381 L
s
gsave
-0.0125 .7381 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .97619 m
.00625 .97619 L
s
gsave
-0.0125 .97619 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .21429 m
.00375 .21429 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .40476 m
.00375 .40476 L
s
0 .45238 m
.00375 .45238 L
s
0 .54762 m
.00375 .54762 L
s
0 .59524 m
.00375 .59524 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .78571 m
.00375 .78571 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -102 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
76 10 translate
90 rotate
-76 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
82.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
86.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
88.687500 13.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .99375 m
.02381 1 L
s
.2619 .99375 m
.2619 1 L
s
.5 .99375 m
.5 1 L
s
.7381 .99375 m
.7381 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.07143 .99625 m
.07143 1 L
s
.11905 .99625 m
.11905 1 L
s
.16667 .99625 m
.16667 1 L
s
.21429 .99625 m
.21429 1 L
s
.30952 .99625 m
.30952 1 L
s
.35714 .99625 m
.35714 1 L
s
.40476 .99625 m
.40476 1 L
s
.45238 .99625 m
.45238 1 L
s
.54762 .99625 m
.54762 1 L
s
.59524 .99625 m
.59524 1 L
s
.64286 .99625 m
.64286 1 L
s
.69048 .99625 m
.69048 1 L
s
.78571 .99625 m
.78571 1 L
s
.83333 .99625 m
.83333 1 L
s
.88095 .99625 m
.88095 1 L
s
.92857 .99625 m
.92857 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .2619 m
1 .2619 L
s
.99375 .5 m
1 .5 L
s
.99375 .7381 m
1 .7381 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .40476 m
1 .40476 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .59524 m
1 .59524 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .78571 m
1 .78571 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
.5 Mabswid
newpath
.5 .5 .47619 0 365.72958 arc
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{99, 99},
  ImageMargins->{{123, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001l0000O1000`40l00?003`O?oo001lool007co
o`00O?oo001lool007coo`00O?oo0011ool00`0?ool03`03ool01@0?ool03ooo00l00ooo00@03ooo
00l03`;oo`803`03ool03ooo02;oo`00@_oo00<03oooool00_oo00D03ooo00ooo`0?00?oo`803`?o
o`0300ooo`0?02Goo`00@_oo00<03oooool00_oo00D03ooo00ooo`0?00Coo`0700ooooooool03ooo
00l09Ooo0011ool00`0?ool03`03ool0100?ool03`0?1?oo0P0?0ooo00<03ooo00l09Ooo001lool0
04Ooo`0300oooooo03;oo`00O?oo001lool007coo`00O?oo001lool007coo`009?oo0`0?4?oo00D0
3oooool03ooo00803`ooo`0300oooooo00ooo`0500oooooo00ooo`0200l@ool300l3ool002Goo`03
00oooooo00koo`0300ooo`0?00Goo`0300oooooo00_oo`0300ooo`0?00ooo`0300ooo`0?00Goo`03
00oooooo00koo`0300oooooo00;oo`008?oo0`0?0_oo00<03oooool02_oo0`0?00Coo`0?ool03`?o
o`803`koo`0300ooo`0?00ooo`0300ooo`0?00?oo`803a7oo`0300oooooo00;oo`009Ooo00<03ooo
ool03_oo00<03ooo00l00ooo00<03oooool03Ooo00<03ooo00l03ooo00<03ooo00l00ooo00<03ooo
ool04?oo00<03oooool00_oo000Tool200lAool00`0?ooooo`02ool300l>ool00`0?ooooo`0?ool0
0`0?ooooo`02ool300l?ool200l4ool007coo`00O?oo001lool007coo`006_oo0`0?1?ooF@0?0_oo
000Kool00`0?ooooo`03ool00`0?ool03`0Dool00`0?ooooo`0Bool00`0?ooooo`0Bool00`0?oooo
o`0Bool00`0?ool03`02ool001Koo`<03`;oo`0300oooooo00?oo`803aGoo`0307oooooo013oo`D0
3a;oo`0307oooooo01Coo`403`7oo`7oo`006ooo00<03oooool00ooo00<03oooool05?oo00<0Sooo
ool02Ooo1`0?0_oo00<0Ooooool0200?2_oo00<0Soooool05?oo0@0?0Ooo0Ooo000Jool200l5ool0
0`0?ooooo`0Dool00`1oooooo`06ool300l9ool00`2?ooooo`08ool300l7ool00`1oooooo`0Dool1
00l1ool1ool0027oo`0300oooooo01Coo`0308oooooo00?oo`<03`coo`0307oooooo00_oo`<03`Co
o`0308oooooo01Coo`403`7oo`7oo`008Ooo00<03oooool05?oo00@0Ooooooooo`803`ooo`0308oo
oooo00koo`803`;oo`0307oooooo01Coo`403`7oo`7oo`008Ooo00<03oooool05?oo00@0Sooo00l0
3a7oo`0307oooooo013oo`803`0308oooooo01Coo`403`7oo`7oo`008Ooo00<03oooool05?oo0P0?
4ooo00<0Soooool04_oo0P0?5Ooo0@0?0Ooo0Ooo000Qool00`0?ooooo`0Bool200l00`2?ooooo`0B
ool00`1oooooo`0Bool0102?ool03`0?4ooo0@0?0Ooo0Ooo000Qool00`0?ooooo`0Aool0100?oooo
o`1o5?oo00<0Soooool04_oo00<0Ooooool00P0?4_oo0@0?0Ooo0Ooo000Qool00`0?ooooo`0@ool0
1@0?oooooooo08l05?oo00<0Ooooool04_oo00<0Soooool00_oo00<03oooool03ooo0@0?0Ooo0Ooo
000Qool00`0?ooooo`0?ool00`0?ooooo`02ool00`1oooooo`0Bool00`2?ooooo`0Bool00`1ooooo
o`03ool00`0?ooooo`0>ool100l1ool1ool0027oo`0300oooooo00goo`803`Goo`0308oooooo01;o
o`0307oooooo01;oo`0308oooooo00Coo`0300oooooo00goo`403`7oo`7oo`008Ooo00<03oooool0
3?oo00<03oooool01Ooo00<0Ooooool04_oo00<0Soooool04_oo00<0Ooooool01Ooo00<03oooool0
3?oo0@0?0Ooo0Ooo000Qool00`0?ooooo`0;ool200l7ool00`2?ooooo`0Bool00`1oooooo`0Bool0
0`2?ooooo`06ool00`0?ooooo`0;ool100l1ool1ool0027oo`0300oooooo00[oo`0300oooooo00Oo
o`0307oooooo01;oo`0308oooooo01;oo`0307oooooo00Ooo`0300oooooo00[oo`403`7oo`7oo`00
8Ooo00<03oooool02_oo00<03oooool01ooo00<0Soooool04_oo00<0Ooooool04_oo00<0Soooool0
2?oo00<03oooool02Ooo0@0?0Ooo0Ooo000Qool00`0?ooooo`09ool00`0?ooooo`08ool00`1ooooo
o`0Bool00`2?ooooo`0Bool00`1oooooo`09ool00`0?ooooo`08ool100l1ool1ool0027oo`0300oo
oooo00Soo`0300oooooo00Woo`0308oooooo01;oo`0307oooooo01;oo`0308oooooo00[oo`0300oo
oooo00Ooo`403`7oo`7oo`008Ooo00<03oooool01ooo00<03oooool02_oo00<0Ooooool04_oo00<0
Soooool04_oo00<0Ooooool02_oo00<03oooool01ooo0@0?0Ooo0Ooo000Eool01@0?ooooo`0?ool0
0P0?1Ooo00<03oooool01_oo00<03oooool02ooo00<0Soooool04_oo00<0Ooooool04_oo00<0Sooo
ool02ooo00<03oooool01_oo0@0?0Ooo0Ooo000Dool00`0?ool03`05ool00`0?ooooo`02ool00`0?
ooooo`06ool00`0?ooooo`0;ool00`1oooooo`0Bool00`2?ooooo`0Bool00`1oooooo`0<ool00`0?
ooooo`05ool100l1ool1ool0013oo`<03`04ool03ooo00l3ool200l5ool200l0E`1o08l0O`2?07l0
S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l03`02ool001Coo`0300ooo`0?
00?oo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo00coo`0307oooooo01;oo`0308oooooo
01;oo`0307oooooo00goo`0300oooooo00Coo`403`7oo`7oo`005Ooo00<03oooool00_oo0`0?1?oo
00<03oooool01?oo00<03oooool03Ooo00<0Soooool04_oo00<0Ooooool04_oo00<0Soooool03Ooo
00<03oooool01?oo0@0?0Ooo0Ooo000Qool00`0?ooooo`04ool00`0?ooooo`0=ool00`1oooooo`0B
ool00`2?ooooo`0Bool00`1oooooo`0>ool00`0?ooooo`03ool100l1ool1ool0027oo`0300oooooo
00?oo`0300oooooo00koo`0308oooooo01;oo`0307oooooo01;oo`0308oooooo00koo`0300oooooo
00?oo`403`7oo`7oo`008Ooo00<03oooool00ooo00<03oooool03_oo00<0Ooooool04_oo00<0Sooo
ool04_oo00<0Ooooool03ooo00<03oooool00_oo0@0?0Ooo0Ooo000Qool00`0?ooooo`02ool00`0?
ooooo`0?ool00`2?ooooo`0Bool00`1oooooo`0Bool00`2?ooooo`0?ool00`0?ooooo`02ool100l1
ool1ool0027oo`0300oooooo00;oo`0300oooooo00ooo`0307oooooo01;oo`0308oooooo01;oo`03
07oooooo013oo`0500ooooooool03`02ool0027oo`0300oooooo00;oo`0300oooooo00ooo`0308oo
oooo01;oo`0307oooooo01;oo`0308oooooo013oo`0500ooooooool03`02ool000Goo`0300oooooo
00;oo`0300oooooo01Coo`0500ooooooool03`0Bool00`1oooooo`0Bool00`2?ooooo`0Bool00`1o
ooooo`0@ool01@0?oooooooo00l00_oo0005ool300l00ooo00l03`0Fool01@0?oooooooo00l04_oo
00<0Soooool04_oo00<0Ooooool04_oo00<0Soooool04Ooo00@03oooool03`;oo`001ooo0P0?6?oo
00D03oooooooo`0?01;oo`0307oooooo01;oo`0308oooooo01;oo`0307oooooo017oo`0400oooooo
00l2ool000Goo`803a[oo`0400oooooo00lCool00`2?ooooo`0Bool00`1oooooo`0Bool00`2?oooo
o`0Aool0100?ooooo`0?0_oo000Qool0100?ooooo`0?4ooo00<0Ooooool04_oo00<0Soooool04_oo
00<0Ooooool04Ooo00@03oooool03`;oo`008Ooo00@03oooool03a?oo`0308oooooo01;oo`0307oo
oooo01;oo`0308oooooo01;oo`0300ooo`0?00;oo`001_oo00<03ooo00l06?oo00@03oooool03a?o
o`0307oooooo01;oo`0308oooooo01;oo`0307oooooo01;oo`0300ooo`0?00;oo`000ooo00<03ooo
00l00`0?6?oo00@03oooool03a?oo`0308oooooo01;oo`0307oooooo01;oo`0308oooooo01;oo`03
00ooo`0?00;oo`001Ooo100?6?oo00@03oooool03a?oo`0307oooooo01;oo`0308oooooo01;oo`03
07oooooo01;oo`0300ooo`0?00;oo`001Ooo00@03oooool03aSoo`0400oooooo00lCool00`2?oooo
o`0Bool00`1oooooo`0Bool00`2?ooooo`0Bool00`0?ool03`02ool000Goo`0300oooooo01Coo`03
00oooooo00;oo`0300ooo`0?01Coo`0307oooooo01;oo`0308oooooo01;oo`0307oooooo01;oo`03
00ooo`0?00;oo`001_oo0`0?4_oo00<03ooo00l00ooo00<03ooo00l05?oo00<0Soooool04_oo00<0
Ooooool04_oo00<0Soooool04_oo00<03ooo00l00_oo000Kool00`0?ool03`03ool300l0EP1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o00l2ool001_oo`0300oo
o`0?00?oo`0300ooo`0?01Coo`0308oooooo01;oo`0307oooooo01;oo`0308oooooo01;oo`0300oo
o`0?00;oo`001Ooo00<03ooo00l05?oo00<03oooool00_oo00<03ooo00l05?oo00<0Ooooool04_oo
00<0Soooool04_oo00<0Ooooool04_oo00<03ooo00l00_oo0005ool200l00ooo00ooo`0Gool0100?
ooooo`0?4ooo00<0Soooool04_oo00<0Ooooool04_oo00<0Soooool04_oo00<03ooo00l00_oo0006
ool300lHool0100?ooooo`0?4ooo00<0Ooooool04_oo00<0Soooool04_oo00<0Ooooool04_oo00<0
3ooo00l00_oo0008ool00`0?ooooo`0Fool0100?ooooo`0?4ooo00<0Soooool04_oo00<0Ooooool0
4_oo00<0Soooool04_oo00<03ooo00l00_oo0008ool00`0?ooooo`0Fool0100?ooooo`0?4ooo00<0
Ooooool04_oo00<0Soooool04_oo00<0Ooooool04_oo00<03ooo00l00_oo0005ool300lIool0100?
ooooo`0?4ooo00<0Soooool04_oo00<0Ooooool04_oo00<0Soooool04_oo00<03ooo00l00_oo0008
ool00`0?ooooo`0Fool0100?ooooo`0?4ooo00<0Ooooool04_oo00<0Soooool04_oo00<0Ooooool0
4Ooo00@03oooool03`;oo`001Ooo100?6?oo00@03oooool03a?oo`0308oooooo01;oo`0307oooooo
01;oo`0308oooooo017oo`0400oooooo00l2ool0027oo`0500ooooooool03`0Bool00`1oooooo`0B
ool00`2?ooooo`0Bool00`1oooooo`0Aool0100?ooooo`0?0_oo000Qool01@0?oooooooo00l04_oo
00<0Soooool04_oo00<0Ooooool04_oo00<0Soooool04Ooo00@03oooool03`;oo`002?oo00<03ooo
ool05_oo00D03oooooooo`0?01;oo`0307oooooo01;oo`0308oooooo01;oo`0307oooooo013oo`05
00ooooooool03`02ool0027oo`0500ooooooool03`0Bool00`2?ooooo`0Bool00`1oooooo`0Bool0
0`2?ooooo`0@ool01@0?oooooooo00l00_oo000Qool00`0?ooooo`02ool00`0?ooooo`0?ool00`1o
ooooo`0Bool00`2?ooooo`0Bool00`1oooooo`0@ool01@0?oooooooo00l00_oo000Qool00`0?oooo
o`02ool00`0?ooooo`0?ool00`2?ooooo`0Bool00`1oooooo`0Bool00`2?ooooo`0?ool00`0?oooo
o`02ool100l1ool1ool0027oo`0300oooooo00;oo`0300oooooo00ooo`0307oooooo01;oo`0308oo
oooo01;oo`0307oooooo00ooo`0300oooooo00;oo`403`7oo`7oo`008Ooo00<03oooool00ooo00<0
3oooool03_oo00<0Soooool04_oo00<0Ooooool04_oo00<0Soooool03ooo00<03oooool00_oo0@0?
0Ooo0Ooo000Qool00`0?ooooo`03ool00`0?ooooo`0>ool00`1oooooo`0Bool00`2?ooooo`0Bool0
0`1oooooo`0>ool00`0?ooooo`03ool100l1ool1ool001Koo`0500oooooo00ooo`0200l4ool00`0?
ooooo`04ool00`0?ooooo`0=ool00`2?ooooo`0Bool00`1oooooo`0Bool00`2?ooooo`0>ool00`0?
ooooo`03ool100l1ool1ool001Goo`0300ooo`0?00Goo`0500ooooooool03`06ool00`0?ooooo`0=
ool00`1oooooo`0Bool00`2?ooooo`0Bool00`1oooooo`0=ool00`0?ooooo`04ool100l1ool1ool0
01Goo`0300ooo`0?00?oo`803`Coo`803`1G07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l03`1o08l0O`2?07l0S`0?00;oo`005Ooo00<03ooo00l00ooo00<03oooool00ooo00<03ooo
ool01Ooo00<03oooool03?oo00<0Ooooool04_oo00<0Soooool04_oo00<0Ooooool03?oo00<03ooo
ool01Ooo0@0?0Ooo0Ooo000Fool00`0?ooooo`02ool300l3ool00`0?ooooo`06ool00`0?ooooo`0;
ool00`2?ooooo`0Bool00`1oooooo`0Bool00`2?ooooo`0;ool00`0?ooooo`06ool100l1ool1ool0
027oo`0300oooooo00Koo`803`coo`0307oooooo01;oo`0308oooooo01;oo`0307oooooo00_oo`03
00oooooo00Koo`403`7oo`7oo`008Ooo00<03oooool01ooo00<03oooool02_oo00<0Soooool04_oo
00<0Ooooool04_oo00<0Soooool02_oo00<03oooool01ooo0@0?0Ooo0Ooo000Qool00`0?ooooo`08
ool00`0?ooooo`09ool00`1oooooo`0Bool00`2?ooooo`0Bool00`1oooooo`09ool00`0?ooooo`08
ool100l1ool1ool0027oo`0300oooooo00Woo`0300oooooo00Soo`0308oooooo01;oo`0307oooooo
01;oo`0308oooooo00Soo`0300oooooo00Woo`403`7oo`7oo`008Ooo00<03oooool02_oo00<03ooo
ool01ooo00<0Ooooool04_oo00<0Soooool04_oo00<0Ooooool02?oo00<03oooool02Ooo0@0?0Ooo
0Ooo000Qool00`0?ooooo`0;ool00`0?ooooo`06ool00`2?ooooo`0Bool00`1oooooo`0Bool00`2?
ooooo`07ool00`0?ooooo`0:ool100l1ool1ool0027oo`0300oooooo00coo`0300oooooo00Goo`03
07oooooo01;oo`0308oooooo01;oo`0307oooooo00Koo`0300oooooo00_oo`403`7oo`7oo`008Ooo
00<03oooool03Ooo00<03oooool01?oo00<0Soooool04_oo00<0Ooooool04_oo00<0Soooool01Ooo
00<03oooool03?oo0@0?0Ooo0Ooo000Qool00`0?ooooo`0>ool00`0?ooooo`03ool00`1oooooo`0B
ool00`2?ooooo`0Bool00`1oooooo`03ool200l?ool100l1ool1ool0027oo`0300oooooo00ooo`03
00oooooo00;oo`0308oooooo01;oo`0307oooooo01;oo`0308oooooo00;oo`0300oooooo00ooo`40
3`7oo`7oo`008Ooo00<03oooool04?oo0P0?0_oo00<0Ooooool04_oo00<0Soooool04_oo00D0Oooo
ooooo`0?01;oo`403`7oo`7oo`008Ooo00<03oooool04_oo00<03ooo08l05?oo00<0Ooooool04_oo
00@0Sooo00l03a?oo`403`7oo`7oo`008Ooo00<03oooool04ooo0P0?5?oo00<0Soooool04_oo00<0
O`0?ool05?oo0@0?0Ooo0Ooo000Qool00`0?ooooo`0Dool00`2?00l03`0Bool00`1oooooo`0Aool2
00lFool100l1ool1ool0027oo`0300oooooo01Coo`0307oooooo00803a3oo`0308oooooo00ooo`80
3`03ool0Oooo01Goo`403`7oo`7oo`008Ooo00<03oooool05?oo00<0Soooool00_oo0P0?3_oo00<0
Ooooool03?oo0`0?0ooo00<0Soooool05?oo0@0?0Ooo0Ooo000Kool300l3ool00`0?ooooo`0Dool0
0`1oooooo`04ool300l;ool00`2?ooooo`09ool300l6ool00`1oooooo`0Dool100l1ool1ool001co
o`0300oooooo00;oo`0300oooooo01Coo`0308oooooo00Ooo`D03`Koo`0307oooooo00Goo`@03`Wo
o`0308oooooo01Coo`403`7oo`7oo`007?oo00<03oooool00_oo0P0?5Ooo00<0Ooooool03?oo3P0?
3Ooo00<0Ooooool05?oo0@0?0Ooo0Ooo000Lool00`0?ooooo`02ool00`0?ooooo`0Dool00`2?oooo
o`0Bool00`1oooooo`0Bool00`2?ooooo`0Dool100l1ool1ool001_oo`803`CooeT03`;oo`00O?oo
001lool007coo`00O?oo001lool007coo`00O?oo0000\
\>"],
  ImageRangeCache->{{{0, 122.75}, {122.75, 0}} -> {-1.851332, -1.701905, 
  0.029763, 0.029763}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Recommended Books"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["$\\it Mathematica$ Programming Language"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Scanning Probe Microscopy"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"NeXT 3.0",
ScreenRectangle->{{0, 957}, {0, 768}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{607, 326},
WindowMargins->{{117, Automatic}, {Automatic, 7}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"NeXTAutomaticEncoding",
Magnification->1.25
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 87, 2, 122, "Title"],
Cell[1821, 55, 55, 1, 31, "Input"],

Cell[CellGroupData[{
Cell[1901, 60, 94, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[2020, 66, 85, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[2130, 72, 92, 2, 31, "Input"],
Cell[2225, 76, 60, 1, 32, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2334, 83, 91, 2, 54, "Subsection"],
Cell[2428, 87, 113, 2, 31, "Input"],
Cell[2544, 91, 93, 2, 31, "Input"],
Cell[2640, 95, 97, 2, 31, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2786, 103, 96, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[2907, 109, 85, 2, 54, "Subsection"],
Cell[2995, 113, 271, 6, 239, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3303, 124, 98, 2, 54, "Subsection"],
Cell[3404, 128, 351, 7, 147, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3792, 140, 99, 2, 54, "Subsection"],
Cell[3894, 144, 635, 11, 184, "Input"],
Cell[4532, 157, 234, 6, 99, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4815, 169, 84, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[4924, 175, 94, 2, 54, "Subsection"],
Cell[5021, 179, 403, 9, 116, "Input"],
Cell[5427, 190, 240, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5704, 200, 95, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[5824, 206, 201, 5, 65, "Input"],
Cell[6028, 213, 28127, 1050, 107, 15933, 893, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34192, 1268, 222, 5, 65, "Input"],
Cell[34417, 1275, 24400, 846, 134, 12971, 699, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58878, 2128, 94, 2, 64, "Section"],
Cell[58975, 2132, 119, 2, 54, "Subsection"],
Cell[59097, 2136, 105, 2, 54, "Subsection"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

