(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    197289,       6200]*)
(*NotebookOutlinePosition[    198207,       6232]*)
(*  CellTagsIndexPosition[    198163,       6228]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["FOWLER-NORDHEIM TUNNELING"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Remove["\<Global`*\>"]\)], "Input"],

Cell[BoxData[
    \(Remove::"rmnsm" \( : \ \) 
      "There are no symbols matching \"\!\(\"Global`*\"\)\"."\)], "Message"]
}, Open  ]],

Cell[TextData["Highlights"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Abstract"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Introduction"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Off[General::"\<spell\>", General::"\<spell1\>"]; \)\), 
    \(\(Needs["\<Graphics`Arrow`\>"]; \)\), 
    \(tera = 10\^12; micro = 1\/10\^6; \), 
    \(giga = 10\^9; nano = 1\/10\^9; \), 
    \(mega = 10\^6; pico = 1\/10\^12; \), 
    \(kilo = 10\^3; femto = 1\/10\^15; \), 
    \(milli = 1\/10.\^3; atto = 1\/10\^18; \), 
    \(\(NSub
       = {c \[Rule] 2.99792458\ 10\^8, e \[Rule] 1.6021773\/10\^19, 
        h \[Rule] 6.6260755\/10.\^34, hbar \[Rule] 1.05457\/10.\^34, 
        K \[Rule] 1.380658\/10\^23, me \[Rule] 9.109389\/10\^31, 
        mu0 \[Rule] \(4.\ \[Pi]\)\/10\^7, eps0 \[Rule] 8.85419\/10\^12}; \)\),
   
    \(ESi = 0.179\ tera; rhoSi = 2330; nuSi = 0.28; \), 
    \(ESiO2 = 0.06\ tera; rhoSiO2 = 2200; nuSiO2 = 0.3; \), 
    \(ESi3N4 = 0.15\ tera; rhoSi3N4 = 3100; nuSi3N4 = 0.24; \), 
    \(EAu = 0.08\ tera; rhoAu = 19300; nuAu = 0.42; \), 
    \(ENi = 0.207\ tera; rhoNi = 8900; nuNi = 0.41; \), 
    \(EW = 0.345\ tera; rhoW = 19300; nuW = 0.28; \), 
    \(EPt = 0.17\ tera; rhoPt = 21400; nuPt = 0.39; \), 
    \(EIr = 0.52\ tera; rhoIr = 22500; nuIr = 0.3; \), 
    \(EHOPG = 0.2\ tera; rhoHOPG = 2250; nuHOPG = 0.3; \), 
    \(EPol = 0.001\ tera; rhoPol = 1000; nuPol = 0.3; \), 
    \(\(xx = 0.8; \)\), 
    \(\(EPtIr = xx\ 0.8\ EPt + \((1 - xx)\)\ EIr; \)\), 
    \(\(rhoPtIr = xx\ rhoPt + \((1 - xx)\)\ rhoIr; \)\), 
    \(\(nuPtIr = 0.3; \)\), 
    \(opt = {PlotRange \[Rule] All, AxesOrigin \[Rule] {0, 0}, 
        Frame \[Rule] True, GridLines \[Rule] Automatic, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        PlotStyle 
          \[Rule] {Dashing[{.0001}], Dashing[{.0200}], Dashing[{.0200}], 
            Dashing[{.0200}], Dashing[{.0200}], Dashing[{.0001}]}}; \n
    \(opt1 = {PlotRange \[Rule] All, AxesOrigin \[Rule] {0, 0}, 
        Frame \[Rule] True, GridLines \[Rule] Automatic, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}}; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Operating Conditions"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(caseA
       = {phiAu \[Rule] 4.2\ e, phiW \[Rule] 3.5\ e, phiAl \[Rule] 3.17\ e, 
          phiMg \[Rule] 2.3\ e, phiSi \[Rule] 4.2\ e, phiCr \[Rule] 3.51\ e, 
          phiPt \[Rule] 3.01\ e, Ecb \[Rule] 3.2\ e} /. NSub; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(case = Join[NSub, caseA]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Fowler-Nordheim Current Density"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[kappa]; \)\), 
    \(\(kappa[phi_, meff_] := \(2\ \[Pi]\ \@\(2\ meff\ phi\)\)\/h; \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[C0]; \)\), 
    \(C0[phi_, meff_] := 
      \(2\ \(\[Integral]\_0\%phi kappa[x, meff] \[DifferentialD]x\)\)\/e\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Print["\<C0 = \>", C0[phi, meff]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("C0 = "\[InvisibleSpace]\(8\ \@2\ phi\ \@\(meff\ phi\)\ \[Pi]\)\/\(3\ 
            e\ h\)\),
      SequenceForm[ "C0 = ", 
        Times[ 
          Rational[ 8, 3], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ e, -1], 
          Power[ h, -1], phi, 
          Power[ 
            Times[ meff, phi], 
            Rational[ 1, 2]], Pi]],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[{
    \(\(Clear[B0]; \)\), 
    \(\(B0[phi_] := e\^3\/\(8\ \[Pi]\ h\ phi\); \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[J]; \)\), 
    \(\(J[v_, phi_, meff_, d_] = 
      B0[phi]\ \((v\/d)\)\^2\ Exp[\(-\(\(C0[phi, meff]\ d\)\/v\)\)] /. case; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Numerical Example"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Jx, phi]; \)\), 
    \(Jx[phi_] := J[8, phi, 0.8\ me, 3\ nano] /. case\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(phix = 
      \(FindRoot[Jx[phi] == 10\^5, {phi, 4\ e /. NSub}]
          \)\[LeftDoubleBracket]1, 2\[RightDoubleBracket]; \)\), 
    \(Print["\<experimental phi = \>", phix\/e /. NSub, "\< [eV]\>"]\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("experimental phi = "\[InvisibleSpace]3.82948322626522141`
        \[InvisibleSpace]" [eV]"\),
      SequenceForm[ "experimental phi = ", 3.82948322626522142, " [eV]"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(caseB = {phi \[Rule] phix, meff \[Rule] 0.8\ me, d \[Rule] 3\ nano}; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(case1 = Join[caseB, case]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(B1 = B0[phi] /. case1; \)\), 
    \(\(C1 = C0[phi, meff] /. case1; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[J]; \)\), 
    \(\(J[v_] := B1\ \((v\/d)\)\^2\ Exp[\(-\(\(C1\ d\)\/v\)\)] /. case1; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig11x2 = 
      Plot[J[v]\/10\^4, {v, 5, 8}, 
        FrameLabel \[Rule] {"\<v in V\>", "\<J in pA over 100 nm^2\>"}, 
        Evaluate[opt]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
-1.563492 0.31746 0.014707 0.058861 [
[.02381 -0.0125 -4 -12 ]
[.02381 -0.0125 4 0 ]
[.18254 -0.0125 -7 -12 ]
[.18254 -0.0125 7 0 ]
[.34127 -0.0125 -4 -12 ]
[.34127 -0.0125 4 0 ]
[.5 -0.0125 -7 -12 ]
[.5 -0.0125 7 0 ]
[.65873 -0.0125 -4 -12 ]
[.65873 -0.0125 4 0 ]
[.81746 -0.0125 -7 -12 ]
[.81746 -0.0125 7 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12 -24 ]
[.5 -0.0125 12 -12 ]
[-0.0125 .01471 -8 -6 ]
[-0.0125 .01471 0 6 ]
[-0.0125 .13243 -8 -6 ]
[-0.0125 .13243 0 6 ]
[-0.0125 .25015 -8 -6 ]
[-0.0125 .25015 0 6 ]
[-0.0125 .36787 -8 -6 ]
[-0.0125 .36787 0 6 ]
[-0.0125 .4856 -8 -6 ]
[-0.0125 .4856 0 6 ]
[-0.0125 .60332 -12 -6 ]
[-0.0125 .60332 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24 -39 ]
[-0.01875 .30902 -12 39 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .13243 m
1 .13243 L
s
0 .25015 m
1 .25015 L
s
0 .36787 m
1 .36787 L
s
0 .4856 m
1 .4856 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -73 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(V) show
82.937500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01471 m
.00625 .01471 L
s
gsave
-0.0125 .01471 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .13243 m
.00625 .13243 L
s
gsave
-0.0125 .13243 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .25015 m
.00625 .25015 L
s
gsave
-0.0125 .25015 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .36787 m
.00625 .36787 L
s
gsave
-0.0125 .36787 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07357 m
.00375 .07357 L
s
0 .103 m
.00375 .103 L
s
0 .16186 m
.00375 .16186 L
s
0 .19129 m
.00375 .19129 L
s
0 .22072 m
.00375 .22072 L
s
0 .27958 m
.00375 .27958 L
s
0 .30901 m
.00375 .30901 L
s
0 .33844 m
.00375 .33844 L
s
0 .3973 m
.00375 .3973 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -118 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
100 10 translate
90 rotate
-100 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(J) show
68.062500 13.000000 moveto
(in) show
76.250000 13.000000 moveto
(pA) show
88.000000 13.000000 moveto
(over) show
104.125000 13.000000 moveto
(100) show
118.125000 13.000000 moveto
(nm) show
128.312500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(^) show
132.062500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
136.062500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .13243 m
1 .13243 L
s
.99375 .25015 m
1 .25015 L
s
.99375 .36787 m
1 .36787 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07357 m
1 .07357 L
s
.99625 .103 m
1 .103 L
s
.99625 .16186 m
1 .16186 L
s
.99625 .19129 m
1 .19129 L
s
.99625 .22072 m
1 .22072 L
s
.99625 .27958 m
1 .27958 L
s
.99625 .30901 m
1 .30901 L
s
.99625 .33844 m
1 .33844 L
s
.99625 .3973 m
1 .3973 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .01472 m
.04262 .01472 L
.06244 .01472 L
.08255 .01473 L
.10458 .01474 L
.12415 .01475 L
.14509 .01477 L
.16639 .0148 L
.18653 .01483 L
.20651 .01487 L
.22495 .01492 L
.24367 .01499 L
.2643 .01509 L
.28371 .01521 L
.30459 .01537 L
.32572 .01559 L
.34581 .01586 L
.36562 .01619 L
.384 .01658 L
.42313 .01773 L
.44454 .01861 L
.46472 .01965 L
.50327 .02237 L
.52321 .02427 L
.54427 .02673 L
.58224 .03267 L
.60175 .03667 L
.62267 .04186 L
.64248 .04778 L
.66403 .05553 L
.70387 .07437 L
.74465 .10156 L
.78392 .13793 L
.82167 .18541 L
.86187 .25369 L
.90056 .34182 L
.9417 .46687 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.9375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000ga000`40l00?003`ooooJOoo003ooomY
ool00?ooofWoo`00ooooJOoo002jool00`0?ooooo`02ool01@0?ool03ooo00l01?oo0P0?W_oo002j
ool00`0?ooooo`02ool01@0?ool03ooo00l01?oo0P0?W_oo002iool00`0?ool03`03ool01@0?ool0
3ooo00l00ooo00@03oooool03igoo`00^Ooo00<03ooo00l00ooo00@03ooo00l03`Coo`0400oooooo
00nMool00<Ooo`0400oooooo00nMool00;ooo`0300oooooo0:Koo`00ooooJOoo003ooomYool00?oo
ofWoo`00ooooJOoo003ooomYool00?ooofWoo`00;?oo0P0?;Ooo0P0?0_oo00@03ooo00l03bgoo`03
00oooooo02coo`0500oooooo00ooo`0200l]ool00`0?ooooo`0/ool01@0?ooooo`0?ool00P0?;_oo
00<03oooool03_oo000^ool00`0?ooooo`0/ool00`0?ooooo`03ool00`0?ooooo`0Yool00`0?ool0
3`0/ool00`0?ool03`05ool00`0?ooooo`0Zool00`0?ooooo`0/ool00`0?ooooo`04ool00`0?oooo
o`0Zool00`0?ool03`0?ool002coo`803bgoo`803`Coo`803bcoo`803bgoo`803`Coo`803bkoo`03
00oooooo02coo`0400ooooooool200l^ool00`0?ooooo`0>ool002coo`0300oooooo02coo`0300oo
oooo00?oo`0300oooooo02_oo`0300oooooo02coo`0300oooooo00?oo`0300oooooo02goo`0300oo
oooo02coo`0500ooooooool03`0^ool00`0?ool03`0?ool002coo`<03bcoo`<03`?oo`<03bcoo`80
3bgoo`803`?oo`<03b_oo`<03bcoo`<03`?oo`<03bgoo`0300oooooo00koo`00ooooJOoo003ooomY
ool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo000Voooo00lk00l8ool002Ko
o`0300oooooo00Goo`0300oooooo00Ooo`0300oooooo00Koo`0300oooooo00Ooo`0300oooooo00Oo
o`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Oo
o`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ko
o`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Oo
o`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Oo
o`0300oooooo00Ooo`0300oooooo00Koo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Oo
o`0300oooooo00Ooo`0300oooooo00Goo`0300oooooo00Koo`007_oo00<03oooool01Ooo00<03ooo
ool01Ooo00<03oooool0;_oo00<03oooool0;ooo00<03oooool0;_oo00<03oooool0;ooo00<03ooo
ool0;ooo00<03oooool0;_oo00<03oooool01Ooo00<03oooool01_oo000Mool00`0?ool03`06ool0
0`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool0
0`1oooooo`0fool00`0?ooooo`06ool001goo`0300ooo`0?00Koo`0300oooooo03Koo`0307oooooo
02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo03Koo`0300oooooo
00Koo`007Ooo00<03ooo00l01_oo0`0?1OooN`0?6Ooo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0
Ooooool0=?oo0`0?2?oo000Nool00`0?ooooo`05ool00`0?ooooo`0fool00`1oooooo`0_ool00`1o
ooooo`0DoolE00l5ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0fool00`0?ooooo`06
ool002Koo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02Soo`d03b_oo`0307oooooo02oo
o`0307oooooo03Koo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Ooooool0;ooo00<0Oooo
ool0;_oo00<0Soooool00ooo2P0?8_oo00<0Soooool0;ooo00<0Soooool0=_oo00<03oooool01_oo
000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0<ool700lLool0
0`1oooooo`0_ool00`1oooooo`0fool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0307oooooo
02ooo`0307oooooo02koo`0308oooooo01;oo`L03aKoo`0308oooooo02ooo`0308oooooo03Koo`03
00oooooo00Koo`009_oo00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0
6?oo1P0?4Ooo00<0Ooooool0;ooo00<0Ooooool0=_oo00<03oooool01_oo000Vool00`0?ooooo`0f
ool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0Mool500l=ool00`2?ooooo`0_ool00`2?
ooooo`0fool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02ko
o`0307oooooo027oo`D03`Woo`0307oooooo02ooo`0307oooooo03Koo`0300oooooo00Koo`009_oo
0P0?=ooo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool09Ooo100?1_oo00<0Soooool0;ooo
00<0Soooool0=?oo0`0?2?oo000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool0
0`1oooooo`0Xool400l3ool00`1oooooo`0_ool00`1oooooo`0fool00`0?ooooo`06ool002Koo`03
00oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02_oo`@03`0308oooooo02oo
o`0308oooooo03Koo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Soooool0;ooo00<0Sooo
ool0;_oo00<0Ooooool0;_oo100?;ooo00<0Ooooool0=_oo00<03oooool01_oo000Vool00`0?oooo
o`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ool03`0200l]ool00`2?
ooooo`0fool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02ko
o`0307oooooo02ooo`0407ooooooool300l[ool00`1oooooo`0fool00`0?ooooo`06ool002Koo`03
00oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo00?oo`<0
3bWoo`0308oooooo03Koo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Soooool0;ooo00<0
Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool01Ooo0`0?9ooo00<0Ooooool0=_oo00<03oooool0
1_oo000Vool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?
ooooo`07ool300lUool00`2?ooooo`0fool00`0?ooooo`06ool002Koo`803cOoo`0308oooooo02oo
o`0308oooooo02koo`0307oooooo02ooo`0307oooooo00Woo`<03b?oo`0307oooooo03Coo`<03`So
o`009_oo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Sooo
ool02ooo0`0?8Ooo00<0Soooool0=_oo00<03oooool01_oo000Vool00`0?ooooo`0fool00`2?oooo
o`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0=ool200lPool00`1oooooo`0fool0
0`0?ooooo`06ool002Koo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo
02ooo`0308oooooo00koo`<03akoo`0308oooooo03Koo`0300oooooo00Koo`009_oo00<03oooool0
=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool04?oo0P0?7Ooo00<0
Ooooool0=_oo00<03oooool01_oo000Vool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^
ool00`2?ooooo`0_ool00`2?ooooo`0Aool300lKool00`2?ooooo`0fool00`0?ooooo`06ool002Ko
o`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`0307oooooo01?o
o`803a[oo`0307oooooo03Koo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Ooooool0;ooo
00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool05?oo0`0?6?oo00<0Soooool0=_oo00<03ooo
ool01_oo000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool0
0`1oooooo`0Fool200lGool00`1oooooo`0fool00`0?ooooo`06ool002Koo`803cOoo`0307oooooo
02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo01Ooo`<03aGoo`0308oooooo03Coo`<0
3`Soo`009_oo00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0
Ooooool06Ooo0P0?5?oo00<0Ooooool0=_oo00<03oooool01_oo000Vool00`0?ooooo`0fool00`1o
ooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0Jool200lCool00`2?ooooo`0f
ool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oo
oooo02ooo`0307oooooo01_oo`803a;oo`0307oooooo03Koo`0300oooooo00Koo`009_oo00<03ooo
ool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool07?oo0P0?4Ooo
00<0Soooool0=_oo00<03oooool01_oo000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?oooo
o`0^ool00`1oooooo`0_ool00`1oooooo`0Mool200l@ool00`1oooooo`0fool00`0?ooooo`06ool0
02Koo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo
01koo`803`ooo`0308oooooo03Koo`0300oooooo00Koo`007Ooo0`0?1_oo00<03oooool0=_oo00<0
Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool07ooo0P0?3_oo00<0Ooooool0
=_oo00<03oooool01_oo000Mool00`0?ooooo`06ool00`0?ooooo`0fool00`1oooooo`0_ool00`1o
ooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0Pool200l=ool00`2?ooooo`0fool00`0?ooooo`06
ool001koo`0300oooooo00Goo`<03`3_08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`0200l0@`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00<03`Soo`007Ooo00<03ooo
00l01_oo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Sooo
ool08_oo0P0?2ooo00<0Soooool0=_oo00<03oooool01_oo000Nool200l6ool00`0?ooooo`0fool0
0`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0Sool200l:ool00`1ooooo
o`0fool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`03
08oooooo02ooo`0308oooooo02Coo`803`Woo`0308oooooo03Koo`0300oooooo00Koo`009_oo00<0
3oooool0=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool09Ooo0P0?
2?oo00<0Ooooool0=_oo00<03oooool01_oo000Vool00`0?ooooo`0fool00`1oooooo`0_ool00`1o
ooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0Vool200l7ool00`2?ooooo`0fool00`0?ooooo`06
ool002Koo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`0307oo
oooo02Ooo`803`Koo`0307oooooo03Koo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Oooo
ool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0:?oo00<03oooool01?oo00<0Sooo
ool0=_oo00<03oooool01_oo000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool0
0`1oooooo`0_ool00`1oooooo`0Xool200l5ool00`1oooooo`0fool00`0?ooooo`06ool002Koo`03
00oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02Woo`80
3`Coo`0308oooooo03Koo`0300oooooo00Koo`009_oo0P0?=ooo00<0Soooool0;ooo00<0Soooool0
;_oo00<0Ooooool0;ooo00<0Ooooool0:_oo0P0?0ooo00<0Ooooool0=?oo0`0?2?oo000Vool00`0?
ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0[ool200l2
ool00`2?ooooo`0fool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0308oooooo02ooo`0308oo
oooo02koo`0307oooooo02ooo`0307oooooo02coo`0400oooooo07lhool00`0?ooooo`06ool002Ko
o`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02co
o`803`03ool0Sooo03Ooo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Soooool0;ooo00<0
Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;Ooo0P0?00<0Ooooool0=_oo00<03oooool01_oo
000Vool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?oooo
o`0^ool200lhool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo
02koo`0307oooooo02ooo`0307oooooo02ooo`0300oooooo03Koo`0300oooooo00Koo`009_oo00<0
3oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo0P0?
=ooo00<03oooool01_oo000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1o
ooooo`0_ool00`1oooooo`0_ool00`1o00l03`0fool00`0?ooooo`06ool000coo`0300oooooo00;o
o`0300oooooo01;oo`803cOoo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oo
oooo02ooo`0308ooo`0?03Coo`<03`Soo`003?oo1@0?5Ooo00<03oooool0=_oo00<0Soooool0;ooo
00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00@0Oooo00l03cGoo`0300oooooo00Ko
o`003?oo00<03oooool05ooo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Sooo
ool0;ooo00<0Soooool0;ooo00<0Soooool00P0?=?oo00<03oooool01_oo000Vool00`0?ooooo`0f
ool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool01@1ooooooooo
00l0=?oo00<03oooool01_oo000Vool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool0
0`2?ooooo`0_ool00`2?ooooo`0_ool0102?oooooooo0P0?<ooo00<03oooool01_oo000?ool00`0?
ool03`0Dool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1o
ooooo`0_ool00`1oooooo`02ool00`0?ooooo`0aool00`0?ooooo`06ool000coo`0300ooo`0?00<0
3aCoo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo
02ooo`0308oooooo00;oo`803c;oo`0300oooooo00Koo`003_oo100?5?oo00<03oooool0=_oo00<0
Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool00ooo00<0
3oooool0<?oo00<03oooool01_oo000>ool0100?ooooo`0?5?oo00<03oooool0=_oo00<0Ooooool0
;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool00ooo0P0?<Ooo00<0
3oooool01_oo000>ool00`0?ooooo`0Eool200lgool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1o
ooooo`0_ool00`1oooooo`0_ool00`1oooooo`04ool200l^ool300l8ool000ooo`<03aCoo`0300oo
oooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oo
oooo00Goo`0300oooooo02koo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Soooool0;ooo
00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool01Ooo0P0?;ooo00<03ooo
ool01_oo000Vool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool0
0`2?ooooo`0_ool00`2?ooooo`06ool00`0?ooooo`0]ool00`0?ooooo`06ool000koo`H03a;oo`03
00oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`03
07oooooo00Koo`803bkoo`0300oooooo00Koo`003_oo00H03oooool03ooo00lBool00`0?ooooo`0f
ool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`07
ool200l]ool00`0?ooooo`06ool000koo`0400oooooo00lDool00`0?ooooo`0fool00`2?ooooo`0_
ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`08ool00`0?ooooo`0[
ool00`0?ooooo`06ool000ooo`803`koo`0300oooooo00Coo`0300oooooo03Koo`0307oooooo02oo
o`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo00Soo`803bcoo`0300oo
oooo00Koo`004Ooo00<03oooool02Ooo0`0?1_oo00<03oooool0=_oo00<0Soooool0;ooo00<0Sooo
ool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool02Ooo00<03oooool0:_oo00<03ooo
ool01_oo000?ool300l;ool00`0?ool03`06ool300l0o`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`002P1o08l0O`2?07l0S`1o08l0O`2?0P0?02T0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00<03`So
o`003?oo100?3_oo0P0?1_oo00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Oooo
ool0;ooo00<0Ooooool0;ooo00<0Ooooool02_oo0P0?:_oo00<03oooool01_oo000=ool300l?ool0
0`0?ooooo`04ool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool0
0`2?ooooo`0_ool00`2?ooooo`0;ool00`0?ooooo`0Xool00`0?ooooo`06ool0013oo`803aCoo`03
00oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`03
07oooooo00_oo`0300oooooo02Soo`0300oooooo00Koo`004Ooo00<03oooool04_oo00<03oooool0
=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0
2ooo0P0?:Ooo00<03oooool01_oo000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^
ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0<ool00`0?ooooo`0Wool00`0?ooooo`06
ool002Koo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oo
oooo02ooo`0308oooooo00coo`803bSoo`0300oooooo00Koo`003ooo0P0?5Ooo00<03oooool0=_oo
00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool03Ooo
00<03oooool09_oo00<03oooool01_oo000>ool0100?ooooo`0?5?oo00<03oooool0=_oo00<0Oooo
ool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool03Ooo0P0?9ooo
00<03oooool01_oo000>ool0100?ooooo`0?5?oo0P0?=ooo00<0Soooool0;ooo00<0Soooool0;_oo
00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool03_oo00<03oooool08ooo0`0?2?oo000?ool2
00lEool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?oooo
o`0_ool00`2?ooooo`0>ool00`0?ooooo`0Uool00`0?ooooo`06ool000koo`0300oooooo01Goo`03
00oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`03
07oooooo00koo`803bKoo`0300oooooo00Koo`003_oo0P0?5_oo00<03oooool0=_oo00<0Ooooool0
;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool03ooo00<03oooool0
9?oo00<03oooool01_oo000@ool200lDool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^
ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0?ool200lUool00`0?ooooo`06ool000ko
o`803aKoo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oo
oooo02ooo`0308oooooo013oo`0300oooooo02?oo`0300oooooo00Koo`003ooo0P0?5Ooo00<03ooo
ool0=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Oooo
ool04?oo0P0?9?oo00<03oooool01_oo000>ool200l00ooo00ooo`0Cool00`0?ooooo`0fool00`1o
ooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0Aool00`0?
ooooo`0Rool00`0?ooooo`06ool000koo`803`03ool03ooo01?oo`0300oooooo03Koo`0308oooooo
02ooo`0308oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo017oo`803b?oo`03
00oooooo00Koo`004?oo0P0?5?oo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0
Soooool0;ooo00<0Soooool0;ooo00<0Soooool04_oo00<03oooool08Ooo00<03oooool01_oo000>
ool400lDool200lgool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_
ool00`1oooooo`0Bool00`0?ooooo`0Oool300l8ool000koo`0400oooooo00lDool00`0?ooooo`0f
ool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0B
ool200lRool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02ko
o`0307oooooo02ooo`0307oooooo02ooo`0307oooooo01?oo`0300oooooo023oo`0300oooooo00Ko
o`009_oo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Sooo
ool0;ooo00<0Soooool04ooo0P0?8Ooo00<03oooool01_oo000Vool00`0?ooooo`0fool00`2?oooo
o`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0Dool00`0?oooo
o`0Oool00`0?ooooo`06ool000goo`0500ooooooool03`0Dool00`0?ooooo`0fool00`1oooooo`0_
ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0Dool200lPool00`0?
ooooo`06ool000coo`H03aCoo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oo
oooo02ooo`0307oooooo02ooo`0307oooooo01Goo`0300oooooo01koo`0300oooooo00Koo`004Ooo
00<03oooool04_oo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo
00<0Soooool0;ooo00<0Soooool05Ooo00<03oooool07_oo00<03oooool01_oo000=ool400lEool0
0`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool0
0`1oooooo`0Eool200lOool00`0?ooooo`06ool000coo`0300oooooo00;oo`0300oooooo01;oo`80
3cOoo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo
01Koo`0300oooooo01_oo`<03`Soo`003?oo00<03oooool00_oo00<03oooool04_oo00<03oooool0
=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0
5_oo0P0?7_oo00<03oooool01_oo000=ool400lEool00`0?ooooo`0fool00`1oooooo`0_ool00`1o
ooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0Gool00`0?ooooo`0Lool00`0?
ooooo`06ool000goo`@03aGoo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oo
oooo02ooo`0307oooooo02ooo`0307oooooo01Ooo`0300oooooo01coo`0300oooooo00Koo`003?oo
00<03oooool00_oo00<03oooool04_oo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo
00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool05ooo0P0?7Ooo00<03oooool01_oo000<ool0
0`0?ooooo`02ool00`0?ooooo`0Bool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool0
0`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0Hool00`0?ooooo`0Kool00`0?ooooo`06ool0
00goo`@03`goo`0300oooooo00Goo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`03
08oooooo02ooo`0308oooooo02ooo`0308oooooo01Soo`0300oooooo01_oo`0300oooooo00Koo`00
7Ooo00<03ooo00l01_oo00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0
;ooo00<0Ooooool0;ooo00<0Ooooool06?oo0P0?7?oo00<03oooool01_oo000Mool200l7ool00`0?
ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?
ooooo`0Iool00`0?ooooo`0Jool00`0?ooooo`06ool000koo`@03`_oo`0300oooooo00Koo`<03`3o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?000e08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`0300l8ool000koo`0400oooooo00l<ool200l6ool00`0?ooooo`0f
ool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0I
ool200lKool00`0?ooooo`06ool000koo`0300oooooo01Goo`0300oooooo03Koo`0308oooooo02oo
o`0308oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo01[oo`0300oooooo01Wo
o`0300oooooo00Koo`003ooo0`0?5?oo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo
00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool06_oo00<03oooool06Ooo00<03oooool01_oo
000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1ooooo
o`0_ool00`1oooooo`0Jool200lJool00`0?ooooo`06ool000koo`@03aCoo`0300oooooo03Koo`03
07oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo01_oo`03
00oooooo01Soo`0300oooooo00Koo`003_oo00<03oooool05Ooo00<03oooool0=_oo00<0Soooool0
;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool06ooo00<03oooool0
6?oo00<03oooool01_oo000?ool300lDool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^
ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0Kool200lIool00`0?ooooo`06ool000ko
o`0300oooooo01Goo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02oo
o`0307oooooo02ooo`0307oooooo01coo`0300oooooo01Ooo`0300oooooo00Koo`003ooo0`0?5?oo
0P0?=ooo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Sooo
ool07?oo00<03oooool05Ooo0`0?2?oo000=ool200lGool00`0?ooooo`0fool00`2?ooooo`0_ool0
0`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0Lool200lHool00`0?oooo
o`06ool000coo`0300oooooo01Ooo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`03
08oooooo02ooo`0308oooooo02ooo`0308oooooo01goo`0300oooooo01Koo`0300oooooo00Koo`00
3Ooo0P0?5ooo00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0
Ooooool0;ooo00<0Ooooool07Ooo00<03oooool05_oo00<03oooool01_oo000Vool00`0?ooooo`0f
ool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0M
ool200lGool00`0?ooooo`06ool000goo`0300oooooo01Koo`0300oooooo03Koo`0308oooooo02oo
o`0308oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo01koo`0300oooooo01Go
o`0300oooooo00Koo`003?oo00@03oooooooo`803aCoo`0300oooooo03Koo`0307oooooo02ooo`03
07oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo01koo`0300oooooo01Goo`03
00oooooo00Koo`003?oo00H03oooool03ooo00lDool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?
ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0Nool200lFool00`0?ooooo`06
ool000goo`803`;oo`0300oooooo01;oo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02ko
o`0308oooooo02ooo`0308oooooo02ooo`0308oooooo01ooo`0300oooooo01Coo`0300oooooo00Ko
o`009_oo0P0?=ooo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo
00<0Ooooool07ooo00<03oooool04_oo0`0?2?oo000Vool00`0?ooooo`0fool00`1oooooo`0_ool0
0`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0Oool200lEool00`0?oooo
o`06ool002Koo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`03
07oooooo02ooo`0307oooooo023oo`0300oooooo01?oo`0300oooooo00Koo`009_oo00<03oooool0
=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0
8?oo00<03oooool04ooo00<03oooool01_oo000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?
ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0Pool200lDool00`0?ooooo`06
ool002Koo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oo
oooo02ooo`0308oooooo027oo`0300oooooo01;oo`0300oooooo00Koo`009_oo00<03oooool0=_oo
00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool08Ooo
00<03oooool04_oo00<03oooool01_oo000Vool00`0?ooooo`0fool00`1oooooo`0_ool00`1ooooo
o`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0Qool200lCool00`0?ooooo`06ool0
02Koo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`0307oooooo
02ooo`0307oooooo02;oo`0300oooooo017oo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0
Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool08_oo00<0
3oooool04Ooo00<03oooool01_oo000Vool200lgool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1o
ooooo`0_ool00`1oooooo`0_ool00`1oooooo`0Rool200l@ool300l8ool002Koo`0300oooooo03Ko
o`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo02?o
o`0300oooooo013oo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Soooool0;ooo00<0Sooo
ool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool08ooo00<03oooool04?oo00<03ooo
ool01_oo000Vool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool0
0`2?ooooo`0_ool00`2?ooooo`0Sool200lAool00`0?ooooo`06ool002Koo`0300oooooo03Koo`03
08oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo02Coo`03
00oooooo00ooo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0
;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool09?oo00<03oooool03ooo00<03oooool0
1_oo000Nool00`0?ooooo`05ool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1o
ooooo`0_ool00`1oooooo`0_ool00`1oooooo`0Tool00`0?ooooo`0?ool00`0?ooooo`06ool001go
o`0300ooo`0?00Koo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02oo
o`0308oooooo02ooo`0308oooooo02Coo`803a3oo`0300oooooo00Koo`007_oo00<03oooool01Ooo
00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo
00<0Ooooool09Ooo00<03oooool03_oo00<03oooool01_oo000Mool00`0?ool03`06ool300l0o`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`00=@1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l00`0?2?oo000Nool00`0?ooooo`05ool00`0?ooooo`0fool00`2?oooo
o`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0Uool00`0?oooo
o`0>ool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`03
08oooooo02ooo`0308oooooo02ooo`0308oooooo02Goo`803`ooo`0300oooooo00Koo`009_oo00<0
3oooool0=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0
Ooooool09_oo00<03oooool03Ooo00<03oooool01_oo000Vool00`0?ooooo`0fool00`1oooooo`0_
ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0Vool00`0?ooooo`0=
ool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oo
oooo02ooo`0307oooooo02ooo`0307oooooo02Koo`0300oooooo00goo`0300oooooo00Koo`009_oo
00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo
00<0Soooool09_oo0P0?3_oo00<03oooool01_oo000Vool00`0?ooooo`0fool00`2?ooooo`0_ool0
0`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0Wool00`0?ooooo`0<ool0
0`0?ooooo`06ool002Koo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo
02ooo`0308oooooo02ooo`0308oooooo02Ooo`0300oooooo00coo`0300oooooo00Koo`009_oo0P0?
=ooo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0
9ooo00<03oooool02_oo0`0?2?oo000Vool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^
ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0Wool200l=ool00`0?ooooo`06ool002Ko
o`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`0307oooooo02oo
o`0307oooooo02Soo`0300oooooo00_oo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Oooo
ool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0:?oo00<03ooo
ool02ooo00<03oooool01_oo000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool0
0`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0Xool00`0?ooooo`0;ool00`0?ooooo`06ool0
02Koo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo
02ooo`0308oooooo02Soo`803`coo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Soooool0
;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0:Ooo00<03oooool0
2_oo00<03oooool01_oo000Vool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?
ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0Yool00`0?ooooo`0:ool00`0?ooooo`06ool002Ko
o`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`0307oooooo02oo
o`0307oooooo02Woo`0300oooooo00[oo`0300oooooo00Koo`009_oo0P0?=ooo00<0Ooooool0;ooo
00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0:Ooo0P0?2Ooo0`0?2?oo
000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1ooooo
o`0_ool00`1oooooo`0Zool00`0?ooooo`09ool00`0?ooooo`06ool002Koo`0300oooooo03Koo`03
07oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo02[oo`03
00oooooo00Woo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool0
;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0:_oo00<03oooool02Ooo00<03oooool0
1_oo000Vool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?
ooooo`0_ool00`2?ooooo`0Zool200l:ool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0308oo
oooo02ooo`0308oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo02_oo`0300oo
oooo00Soo`0300oooooo00Koo`009_oo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo
00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0:ooo00<03oooool02?oo00<03oooool01_oo
000Vool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1ooooo
o`0_ool00`1oooooo`0[ool00`0?ooooo`08ool00`0?ooooo`06ool002Koo`0300oooooo03Koo`03
07oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo02_oo`80
3`Woo`0300oooooo00Koo`009_oo0P0?=ooo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0
;ooo00<0Ooooool0;ooo00<0Ooooool0;?oo00<03oooool01Ooo0`0?2?oo000Vool00`0?ooooo`0f
ool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0/
ool00`0?ooooo`07ool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0308oooooo02ooo`0308oo
oooo02koo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo02coo`0300oooooo00Ooo`0300oo
oooo00Koo`009_oo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool0;_oo00<0Soooool0;ooo
00<0Soooool0;ooo00<0Soooool0;?oo0P0?2?oo00<03oooool01_oo000Vool00`0?ooooo`0fool0
0`2?ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0]ool0
0`0?ooooo`06ool00`0?ooooo`06ool002Koo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo
02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo02goo`0300oooooo00Koo`0300oooooo
00Koo`009_oo00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0
Ooooool0;ooo00<0Ooooool0;Ooo00<03oooool01_oo00<03oooool01_oo000Iool300l2ool00`0?
ooooo`05ool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?
ooooo`0_ool00`2?ooooo`0]ool200l7ool00`0?ooooo`06ool001[oo`0600oooooo00ooo`0?1_oo
00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo
00<0Ooooool0;_oo00<03oooool01Ooo00<03oooool01_oo000Jool01P0?ooooo`0?ool03`Koo`<0
3cKoo`0307oooooo02ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo
02koo`0300oooooo00?oo`<03`Soo`006_oo00H03oooool03ooo00l6ool00`0?ooooo`0fool00`2?
ooooo`0_ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0fool00`0?
ooooo`06ool001Woo`803`?oo`0300oooooo00Goo`0300oooooo03Koo`0307oooooo02ooo`0307oo
oooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo03Koo`0300oooooo00Koo`009_oo
00<03oooool01Ooo00<03oooool0;_oo00<03oooool0;ooo00<03oooool0;_oo00<03oooool0;ooo
00<03oooool0;ooo00<03oooool0;_oo00<03oooool01Ooo00<03oooool01_oo000Vool00`0?oooo
o`05ool00`0?ooooo`07ool00`0?ooooo`06ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?oooo
o`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?oooo
o`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`06ool00`0?oooo
o`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?oooo
o`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?oooo
o`07ool00`0?ooooo`06ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?oooo
o`07ool00`0?ooooo`05ool00`0?ooooo`06ool002Koool03c/03`Soo`00ooooJOoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {4.535032, -1.71314, 0.012605,
   0.067982}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Oxide Field and Applied Field"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(delphi = \(phi - phiSi\)\/e; \)\), 
    \(Print["\<delphi = \>", \(delphi /. caseB\) /. case, "\< [V]\>"]\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("delphi = "\[InvisibleSpace]\( - 0.370516773734778936`
          \)\[InvisibleSpace]" [V]"\),
      SequenceForm[ "delphi = ", -0.37051677373477894, " [V]"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Oscillation Factor"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[k1]; \)\), 
    \(\(k1[v_] = \((\(2\ meff\ e\ v\)\/\(d\ hbar\^2\))\)\^\(1/3\); \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Print["\<k1[8] = \>", N[k1[8]]\ nano //. case1, "\< [1/nm]\>"]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("k1[8] = "\[InvisibleSpace]3.82571462157558883`
        \[InvisibleSpace]" [1/nm]"\),
      SequenceForm[ "k1[8] = ", 3.82571462157558884, " [1/nm]"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[{
    \(\(Clear[Lcb]; \)\), 
    \(\(Lcb[v_, En_] := d - \(\((phi + En)\)\ d\)\/\(e\ v\); \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Print["\<Lcb[8,0] = \>", N[Lcb[8, 0]]\/nano /. case1, "\< [nm]\>"]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("Lcb[8,0] = "\[InvisibleSpace]1.56394379015054223`
        \[InvisibleSpace]" [nm]"\),
      SequenceForm[ "Lcb[8,0] = ", 1.56394379015054223, " [nm]"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[{
    \(\(Clear[k]; \)\), 
    \(\(k[v_] = \@\(2\ meff\ \((phi + \((e\ v - Ecb)\))\)\)\/hbar; \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Print["\<k[8] = \>", N[k[8]\ nano] //. case1, "\< [1/nm]\>"]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("k[8] = "\[InvisibleSpace]13.4609863699345`
        \[InvisibleSpace]" [1/nm]"\),
      SequenceForm[ "k[8] = ", 13.46098636993449915, " [1/nm]"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[{
    \(\(b0 = .08; \)\), 
    \(\(Clear[b]; \)\), 
    \(\(b[v_, En_] := 
      b0\ N[1/\((
                AiryAi[\(-k1[v]\)\ Lcb[v, En]]\^2 + 
                  \((k1[v]\/k[v])\)\^2\ 
                    AiryAiPrime[\(-k1[v]\)\ Lcb[v, En]]\^2)\)] //. case1; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig11x3 = 
      Plot[Evaluate[{b[v, 0], b[v, .2\ e]}], {v, 5, 8}, 
        FrameLabel \[Rule] {"\<v in V\>", "\<b\>"}, Evaluate[opt]]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
-1.563492 0.31746 -0.182105 0.431957 [
[.02381 -0.0125 -4 -12 ]
[.02381 -0.0125 4 0 ]
[.18254 -0.0125 -7 -12 ]
[.18254 -0.0125 7 0 ]
[.34127 -0.0125 -4 -12 ]
[.34127 -0.0125 4 0 ]
[.5 -0.0125 -7 -12 ]
[.5 -0.0125 7 0 ]
[.65873 -0.0125 -4 -12 ]
[.65873 -0.0125 4 0 ]
[.81746 -0.0125 -7 -12 ]
[.81746 -0.0125 7 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12 -24 ]
[.5 -0.0125 12 -12 ]
[-0.0125 .07707 -14 -6 ]
[-0.0125 .07707 0 6 ]
[-0.0125 .16346 -14 -6 ]
[-0.0125 .16346 0 6 ]
[-0.0125 .24985 -8 -6 ]
[-0.0125 .24985 0 6 ]
[-0.0125 .33624 -14 -6 ]
[-0.0125 .33624 0 6 ]
[-0.0125 .42263 -14 -6 ]
[-0.0125 .42263 0 6 ]
[-0.0125 .50903 -14 -6 ]
[-0.0125 .50903 0 6 ]
[-0.0125 .59542 -14 -6 ]
[-0.0125 .59542 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26 -4 ]
[-0.01875 .30902 -14 4 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .07707 m
1 .07707 L
s
0 .16346 m
1 .16346 L
s
0 .24985 m
1 .24985 L
s
0 .33624 m
1 .33624 L
s
0 .42263 m
1 .42263 L
s
0 .50903 m
1 .50903 L
s
0 .59542 m
1 .59542 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -73 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(V) show
82.937500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .07707 m
.00625 .07707 L
s
gsave
-0.0125 .07707 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .16346 m
.00625 .16346 L
s
gsave
-0.0125 .16346 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .24985 m
.00625 .24985 L
s
gsave
-0.0125 .24985 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .33624 m
.00625 .33624 L
s
gsave
-0.0125 .33624 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .42263 m
.00625 .42263 L
s
gsave
-0.0125 .42263 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .50903 m
.00625 .50903 L
s
gsave
-0.0125 .50903 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .59542 m
.00625 .59542 L
s
gsave
-0.0125 .59542 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .09867 m
.00375 .09867 L
s
0 .12026 m
.00375 .12026 L
s
0 .14186 m
.00375 .14186 L
s
0 .18506 m
.00375 .18506 L
s
0 .20666 m
.00375 .20666 L
s
0 .22825 m
.00375 .22825 L
s
0 .27145 m
.00375 .27145 L
s
0 .29305 m
.00375 .29305 L
s
0 .31464 m
.00375 .31464 L
s
0 .35784 m
.00375 .35784 L
s
0 .37944 m
.00375 .37944 L
s
0 .40104 m
.00375 .40104 L
s
0 .44423 m
.00375 .44423 L
s
0 .46583 m
.00375 .46583 L
s
0 .48743 m
.00375 .48743 L
s
0 .53062 m
.00375 .53062 L
s
0 .55222 m
.00375 .55222 L
s
0 .57382 m
.00375 .57382 L
s
0 .05547 m
.00375 .05547 L
s
0 .03387 m
.00375 .03387 L
s
0 .01228 m
.00375 .01228 L
s
0 .61701 m
.00375 .61701 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -85 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
65 10 translate
90 rotate
-65 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07707 m
1 .07707 L
s
.99375 .16346 m
1 .16346 L
s
.99375 .24985 m
1 .24985 L
s
.99375 .33624 m
1 .33624 L
s
.99375 .42263 m
1 .42263 L
s
.99375 .50903 m
1 .50903 L
s
.99375 .59542 m
1 .59542 L
s
.125 Mabswid
.99625 .09867 m
1 .09867 L
s
.99625 .12026 m
1 .12026 L
s
.99625 .14186 m
1 .14186 L
s
.99625 .18506 m
1 .18506 L
s
.99625 .20666 m
1 .20666 L
s
.99625 .22825 m
1 .22825 L
s
.99625 .27145 m
1 .27145 L
s
.99625 .29305 m
1 .29305 L
s
.99625 .31464 m
1 .31464 L
s
.99625 .35784 m
1 .35784 L
s
.99625 .37944 m
1 .37944 L
s
.99625 .40104 m
1 .40104 L
s
.99625 .44423 m
1 .44423 L
s
.99625 .46583 m
1 .46583 L
s
.99625 .48743 m
1 .48743 L
s
.99625 .53062 m
1 .53062 L
s
.99625 .55222 m
1 .55222 L
s
.99625 .57382 m
1 .57382 L
s
.99625 .05547 m
1 .05547 L
s
.99625 .03387 m
1 .03387 L
s
.99625 .01228 m
1 .01228 L
s
.99625 .61701 m
1 .61701 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .5832 m
.02499 .58639 L
.02605 .58888 L
.02721 .5911 L
.02846 .59298 L
.02961 .59422 L
.03068 .59493 L
.0317 .59522 L
.03279 .59511 L
.03395 .59452 L
.0352 .59334 L
.03638 .59172 L
.03746 .58981 L
.04011 .58349 L
.04262 .57541 L
.04753 .55441 L
.0521 .52981 L
.06244 .46253 L
.08454 .31166 L
.10458 .20383 L
.11426 .16387 L
.12473 .12839 L
.14371 .08067 L
.15321 .06317 L
.16365 .04785 L
.17454 .03554 L
.18471 .02694 L
.18972 .02363 L
.19516 .02065 L
.19996 .01856 L
.20506 .01684 L
.20965 .01574 L
.21225 .01529 L
.21345 .01513 L
.2147 .01499 L
.21577 .01489 L
.21694 .01481 L
.21801 .01476 L
.21899 .01473 L
.22017 .01472 L
.22123 .01473 L
.22246 .01477 L
.22362 .01483 L
.22477 .01492 L
.22601 .01504 L
.22825 .01533 L
.23091 .01579 L
.23334 .01633 L
.23862 .01788 L
.24363 .01984 L
Mistroke
.25246 .02449 L
.26209 .03136 L
.27243 .04102 L
.2818 .05201 L
.29274 .06785 L
.30279 .0856 L
.32207 .1296 L
.3429 .1939 L
.36337 .2734 L
.38244 .35319 L
.39188 .38867 L
.40081 .41582 L
.40574 .4271 L
.40834 .4318 L
.4111 .43578 L
.41341 .4383 L
.41473 .43938 L
.41597 .44017 L
.4171 .44069 L
.41813 .44101 L
.41927 .44117 L
.42047 .44113 L
.42171 .44088 L
.42241 .44063 L
.42305 .44035 L
.42423 .43966 L
.42548 .43872 L
.42765 .43658 L
.43004 .43348 L
.43532 .42404 L
.44025 .41234 L
.45863 .35195 L
.4975 .21128 L
.51872 .15361 L
.52847 .1326 L
.53883 .11371 L
.54828 .09933 L
.55872 .08627 L
.56768 .07721 L
.57713 .06962 L
.58194 .06648 L
.58721 .06357 L
.59205 .06136 L
.59645 .05974 L
.60167 .05827 L
.60454 .05767 L
.60725 .05723 L
.60847 .05708 L
.60976 .05695 L
.61086 .05685 L
Mistroke
.61207 .05678 L
.61337 .05672 L
.6141 .0567 L
.61477 .0567 L
.61607 .0567 L
.6173 .05673 L
.61855 .05679 L
.61925 .05684 L
.61989 .05688 L
.62234 .05713 L
.62455 .05744 L
.6269 .05786 L
.63177 .05903 L
.63712 .06079 L
.64664 .06512 L
.65551 .07061 L
.66598 .07895 L
.67588 .08879 L
.69444 .1127 L
.71437 .147 L
.73279 .18694 L
.77208 .29111 L
.78168 .31644 L
.79179 .34042 L
.80115 .35872 L
.80571 .36588 L
.80985 .37123 L
.81432 .37569 L
.81678 .37753 L
.8191 .37885 L
.82033 .37939 L
.82162 .37984 L
.82273 .38012 L
.82395 .38033 L
.82526 .38042 L
.826 .38042 L
.82667 .38038 L
.82797 .38021 L
.82921 .37993 L
.83053 .3795 L
.83172 .37901 L
.83439 .37754 L
.83687 .37572 L
.83919 .37363 L
.84442 .36764 L
.85007 .35935 L
.87006 .31872 L
.89115 .26706 L
.92919 .18222 L
.94875 .14921 L
Mistroke
.96969 .12251 L
.97619 .11591 L
Mfstroke
[ .02 ] 0 setdash
.02381 .13147 m
.06244 .35679 L
.08255 .5069 L
.08806 .54213 L
.09109 .55892 L
.09396 .5727 L
.09662 .58345 L
.09952 .59265 L
.1008 .59583 L
.10215 .59861 L
.10331 .60047 L
.10458 .60199 L
.10584 .60293 L
.10655 .60322 L
.10721 .60332 L
.10843 .60311 L
.10972 .60231 L
.11099 .60097 L
.11219 .5992 L
.11442 .59461 L
.11707 .58712 L
.11951 .57839 L
.12501 .55303 L
.14415 .42943 L
.16457 .29501 L
.18364 .19782 L
.20197 .13111 L
.21224 .10301 L
.22161 .08207 L
.2407 .05048 L
.25148 .03791 L
.26146 .02904 L
.26609 .02572 L
.27108 .02268 L
.2754 .02047 L
.28012 .01848 L
.28536 .01678 L
.28821 .01607 L
.29087 .01555 L
.29336 .01517 L
.29563 .01493 L
.29689 .01483 L
.2976 .01479 L
.29825 .01476 L
.29945 .01473 L
.30072 .01472 L
.30193 .01473 L
.30325 .01478 L
.3045 .01485 L
.30565 .01494 L
Mistroke
.30784 .01518 L
.31016 .01553 L
.3129 .01606 L
.31548 .01668 L
.3203 .01816 L
.3291 .02195 L
.33861 .0277 L
.34814 .03529 L
.35859 .04592 L
.36962 .06004 L
.37967 .07581 L
.39921 .11575 L
.42014 .1744 L
.46004 .32932 L
.4783 .39962 L
.4833 .41505 L
.48868 .42878 L
.49116 .43395 L
.49377 .43855 L
.49621 .44203 L
.49842 .44447 L
.49956 .44546 L
.5008 .44632 L
.5021 .44699 L
.50333 .4474 L
.50448 .44759 L
.5057 .44758 L
.50675 .4474 L
.50789 .44702 L
.50858 .4467 L
.50924 .44634 L
.51047 .44549 L
.51324 .44283 L
.51563 .4397 L
.51823 .43547 L
.52352 .42442 L
.52915 .40953 L
.53926 .3767 L
.57697 .23773 L
.59792 .17518 L
.61714 .13165 L
.63597 .10051 L
.64543 .08853 L
.6558 .07791 L
.66606 .06972 L
.67539 .06411 L
.68055 .06171 L
.68615 .05965 L
.68872 .05889 L
.69145 .05821 L
Mistroke
.69378 .05773 L
.69633 .05731 L
.69764 .05714 L
.69885 .057 L
.70011 .05689 L
.70125 .05681 L
.70237 .05675 L
.70343 .05671 L
.70454 .0567 L
.70575 .0567 L
.70697 .05673 L
.70767 .05676 L
.70832 .05679 L
.70962 .05687 L
.71103 .057 L
.71356 .0573 L
.71588 .05768 L
.72038 .05865 L
.72528 .06009 L
.73418 .06372 L
.74359 .06902 L
.75397 .07667 L
.77499 .09839 L
.79435 .12649 L
.81521 .16625 L
.85637 .27045 L
.87691 .32547 L
.88692 .34868 L
.89601 .36588 L
.90057 .37274 L
.9055 .37866 L
.90776 .38082 L
.91016 .3827 L
.9122 .38399 L
.91445 .38504 L
.91577 .38549 L
.91702 .38579 L
.91814 .38596 L
.91936 .38604 L
.92005 .38604 L
.92068 .38601 L
.92141 .38593 L
.92209 .38583 L
.92331 .38555 L
.92463 .38513 L
.92578 .38466 L
.92704 .38404 L
.92959 .38244 L
.93414 .37846 L
.93941 .37221 L
Mistroke
.94438 .3648 L
.9537 .34768 L
.97464 .2994 L
.97619 .29555 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.9375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000ga000`40l00?003`ooooJOoo003ooomY
ool00?ooofWoo`00ooooJOoo002kool00`0?ooooo`02ool01@0?ool03ooo00l01?oo0P0?WOoo002k
ool00`0?ooooo`02ool01@0?ool03ooo00l01?oo0P0?WOoo002jool00`0?ool03`03ool01@0?ool0
3ooo00l00ooo00@03oooool03icoo`00^_oo00<03ooo00l00ooo00@03ooo00l03`Coo`0400oooooo
00nLool00<Soo`0400oooooo00nLool00<3oo`0300oooooo0:Goo`00ooooJOoo003ooomYool00?oo
ofWoo`00ooooJOoo003ooomYool00?ooofWoo`00;?oo0P0?;Ooo0P0?0_oo00@03ooo00l03bkoo`03
00oooooo02coo`0500oooooo00ooo`0200l^ool00`0?ooooo`0/ool01@0?ooooo`0?ool00P0?;_oo
00<03oooool03?oo000^ool00`0?ooooo`0/ool00`0?ooooo`03ool00`0?ooooo`0Zool00`0?ool0
3`0/ool00`0?ool03`05ool00`0?ooooo`0[ool00`0?ooooo`0/ool00`0?ooooo`04ool00`0?oooo
o`0Zool00`0?ool03`0=ool002coo`803bgoo`803`Coo`803bgoo`803bgoo`803`Coo`803booo`03
00oooooo02coo`0400ooooooool200l^ool00`0?ooooo`0<ool002coo`0300oooooo02coo`0300oo
oooo00?oo`0300oooooo02coo`0300oooooo02coo`0300oooooo00?oo`0300oooooo02koo`0300oo
oooo02coo`0500ooooooool03`0^ool00`0?ool03`0=ool002coo`<03bcoo`<03`?oo`<03bgoo`80
3bgoo`803`?oo`<03bcoo`<03bcoo`<03`?oo`<03bgoo`0300oooooo00coo`00ooooJOoo003ooomY
ool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo000Voooo00lm00l6ool002Ko
o`0300oooooo00Goo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Oo
o`0300oooooo00Ooo`0300oooooo00Koo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Oo
o`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Oo
o`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Oo
o`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Oo
o`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Oo
o`0300oooooo00Ooo`0300oooooo00Goo`0300oooooo00Coo`009_oo00<03oooool01Ooo00<03ooo
ool0;ooo00<03oooool0;_oo00<03oooool0;ooo00<03oooool0;ooo00<03oooool0;ooo00<03ooo
ool0;ooo00<03oooool01Ooo00<03oooool01?oo000Vool00`0?ooooo`0gool00`1oooooo`0^ool0
0`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0gool00`0?ooooo`04ool0
02Koo`803cSoo`0308oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo02ooo`03
07oooooo03Koo`803`Koo`009_oo00<03oooool0=ooo00<0Ooooool00ooo300?4?oo200?1ooo00<0
Soooool0;ooo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0=ooo00<03oooool01?oo000V
ool00`0?ooooo`0gool0102?oooooooo0`0?2_oo0`0?7Ooo00<0Ooooool0;ooo00<0Ooooool0;ooo
00<0Ooooool0;ooo00<0Ooooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0gool00`1oool0
3`0200l>ool300l5ool200lAool0100?ooooo`2?<Ooo00<0Soooool0;ooo00<0Soooool0;ooo00<0
Soooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0gool300lBool300l2ool00`0?ooooo`0B
ool200l00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0gool00`0?oooo
o`04ool002Koo`0300oooooo03Koo`803aKoo`<03aOoo`0300oooooo02ooo`0308oooooo02ooo`03
08oooooo02ooo`0308oooooo03Ooo`0300oooooo00Coo`009_oo00<03oooool0=Ooo0P0?00<0Sooo
ool05?oo0`0?5ooo00<0O`0?ool0;ooo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0=ooo
00<03oooool01?oo000Vool200leool200l00ooo07ooo`0Gool200lFool0102?ool03`0?;_oo00<0
Soooool0;ooo00<0Soooool0;ooo00<0Soooool0=_oo0P0?1_oo000Vool00`0?ooooo`0cool200l2
ool00`2?ooooo`0Gool200lEool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0_ool00`1o
ooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo03;oo`803`?oo`0307oooooo01Soo`803aCo
o`0308oooooo02ooo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo03Ooo`0300oooooo00Co
o`009_oo00<03oooool0<Ooo0P0?1?oo00<0Soooool06Ooo0P0?4ooo00<0Ooooool0;ooo00<0Oooo
ool0;ooo00<0Ooooool0;ooo00<0Ooooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0`ool2
00l5ool00`1oooooo`0@ool00`0?ooooo`07ool200lBool00`2?ooooo`0_ool00`2?ooooo`0_ool0
0`2?ooooo`0_ool00`2?ooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo033oo`0300oooooo
00Coo`0308oooooo00ooo`0300oooooo00Woo`803a7oo`0307oooooo00Coo`0300oooooo02Soo`03
07oooooo02ooo`0307oooooo02ooo`0307oooooo03Ooo`0300oooooo00Coo`009_oo00<03oooool0
;ooo0P0?1_oo00<0Ooooool03_oo00<03oooool02ooo00<03oooool03ooo00<0Soooool01Ooo00<0
3oooool09ooo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0=ooo00<03oooool01?oo000V
ool200l_ool200l7ool00`2?ooooo`0>ool00`0?ooooo`0;ool200l@ool00`1oooooo`06ool00`0?
ooooo`0Vool00`1oooooo`0Mool:00l8ool00`1oooooo`09ool800lNool00`1oooooo`0fool200l6
ool002Koo`0300oooooo02koo`0300oooooo00Koo`0307oooooo00goo`0300oooooo00goo`803`oo
o`0308oooooo00Koo`0300oooooo02Koo`0308oooooo01[oo`@03`Soo`@03`Goo`0308oooooo02oo
o`0308oooooo03Ooo`0300oooooo00Coo`009_oo00<03oooool0;Ooo0P0?2?oo00<0Soooool03?oo
00<03oooool03ooo0P0?3_oo00<0Ooooool01ooo00<03oooool09Ooo00<0Ooooool06?oo0`0?3_oo
0`0?0ooo00<0Ooooool00ooo00<03oooool03ooo00<03oooool05ooo00<0Ooooool0=ooo00<03ooo
ool01?oo000Vool00`0?ooooo`0/ool200l9ool00`1oooooo`0Oool00`0?ooooo`0<ool00`2?oooo
o`08ool00`0?ooooo`0Tool00`2?ooooo`0Fool300lBool300l00ooo08ooo`02ool200lCool200lG
ool00`2?ooooo`0gool00`0?ooooo`04ool001Soo`0400oooooo00l2ool00`0?ooooo`05ool00`0?
ooooo`0/ool00`0?ooooo`08ool00`2?ooooo`0Oool200l=ool00`1oooooo`0_ool00`1oooooo`0E
ool200lFool300l00ooo00l03`0Gool200lEool00`1oooooo`0gool00`0?ooooo`04ool001Ooo`03
00ooo`0?00?oo`0300ooo`0?00Koo`0300oooooo02_oo`803`[oo`0307oooooo023oo`0300oooooo
00_oo`0308oooooo02ooo`0308oooooo01Coo`803aWoo`803a_oo`0300oooooo01;oo`0308oooooo
03Ooo`0300oooooo00Coo`005ooo00<03ooo00l00ooo0P0?1ooo0`0?05X0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l200l0E01o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`803`0K07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00803`1W08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l00`0?1_oo000Gool00`0?ool03`03ool00`0?ooooo`06ool00`0?ooooo`0Zool200l;
ool00`1oooooo`09ool00`0?ooooo`0Eool00`0?ooooo`0:ool00`2?ooooo`0_ool00`2?ooooo`0B
ool200lKool0102?ool03`0?;_oo00<0Soooool0=ooo00<03oooool01?oo000Hool00`0?ooooo`03
ool200l6ool00`0?ooooo`0Zool00`0?ooooo`0:ool00`2?ooooo`09ool00`0?ooooo`0Fool00`0?
ooooo`09ool00`1oooooo`0;ool00`0?ooooo`0Qool00`1oooooo`0Aool200lLool00`1oooooo`02
00l]ool00`1oooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo02Woo`803`coo`0307oooooo
00Soo`0300oooooo01Ooo`803`[oo`0308oooooo00_oo`0300oooooo027oo`0308oooooo013oo`80
3agoo`0408ooooooool200l/ool00`2?ooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo02Wo
o`0300oooooo00_oo`0308oooooo00Soo`0300oooooo01Soo`0300oooooo00Soo`0307oooooo00co
o`0300oooooo023oo`0307oooooo00ooo`803a[oo`0500ooooooool0O`04ool200lKool00`0?oooo
o`0=ool00`1oooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo02Woo`0300oooooo00_oo`03
07oooooo00Ooo`0300oooooo01Woo`0300oooooo00Soo`0308oooooo00coo`0300oooooo023oo`03
08oooooo00koo`803a[oo`0300oooooo00;oo`0308oooooo00?oo`803a_oo`0300oooooo00coo`03
08oooooo03Ooo`0300oooooo00Coo`009_oo00<03oooool0:?oo0P0?3Ooo00<0Soooool01ooo00<0
3oooool06Ooo0P0?2Ooo00<0Ooooool03Ooo00<03oooool07ooo00<0Ooooool03Ooo0P0?6_oo00<0
3oooool00ooo00<0Ooooool01?oo0P0?6ooo00<03oooool02ooo00<0Ooooool0=ooo00<03oooool0
1?oo000Vool200lYool00`0?ooooo`0<ool00`1oooooo`06ool00`0?ooooo`0Kool00`0?ooooo`07
ool00`2?ooooo`0=ool00`0?ooooo`0Oool00`2?ooooo`0<ool200lKool00`0?ooooo`03ool00`2?
ooooo`05ool00`0?ooooo`0Jool00`0?ooooo`0:ool00`2?ooooo`0fool200l6ool002Koo`0300oo
oooo02Ooo`803`koo`0308oooooo02Coo`803`Soo`0307oooooo00goo`0300oooooo01ooo`0307oo
oooo00coo`0300oooooo01Woo`0300oooooo00Coo`0307oooooo00Goo`803acoo`0300oooooo00Wo
o`0307oooooo03Ooo`0300oooooo00Coo`009_oo00<03oooool09ooo00<03oooool03Ooo00<0Oooo
ool09Ooo00<03oooool01_oo00<0Soooool0;ooo00<0Soooool02ooo0P0?6ooo00<03oooool01?oo
00<0Soooool01_oo0P0?6ooo00<03oooool02Ooo00<0Soooool0=ooo00<03oooool01?oo000Vool0
0`0?ooooo`0Wool00`0?ooooo`0=ool00`2?ooooo`0Uool200l7ool00`1oooooo`0_ool00`1ooooo
o`0:ool200lSool00`1oooooo`07ool200lVool00`1oooooo`0gool00`0?ooooo`04ool002Koo`03
00oooooo02Koo`803`ooo`0307oooooo02Koo`0300oooooo00Goo`0308oooooo02ooo`0308oooooo
00[oo`0300oooooo02;oo`0308oooooo00Soo`803bGoo`0308oooooo03Ooo`0300oooooo00Coo`00
9_oo00<03oooool09_oo00<03oooool03_oo00<0Soooool09_oo0P0?1_oo00<0Ooooool0;ooo00<0
Ooooool02Ooo0P0?9?oo00<0Ooooool02Ooo00<03oooool08ooo00<0Ooooool0=ooo00<03oooool0
1?oo000Vool00`0?ooooo`0Vool00`0?ooooo`0>ool00`1oooooo`04ool00`0?ooooo`0Pool00`0?
ooooo`04ool00`2?ooooo`0_ool00`2?ooooo`09ool00`0?ooooo`0Sool00`2?ooooo`09ool200lT
ool00`2?ooooo`0^ool200l7ool00`0?ooooo`04ool002Koo`803bKoo`0300oooooo00ooo`0308oo
oooo00Coo`0300oooooo023oo`0300oooooo00Coo`0307oooooo013oo`0300oooooo01coo`0307oo
oooo00Soo`803a[oo`0300oooooo00Soo`0307oooooo00[oo`0300oooooo01[oo`0300oooooo00Go
o`0307oooooo02goo`803`Ooo`803`Koo`009_oo00<03oooool09Ooo00<03oooool03ooo00<0Oooo
ool00ooo00<03oooool08Ooo0P0?1Ooo00<0Soooool04Ooo00<03oooool06ooo00<0Soooool02?oo
00<03oooool06Ooo00<03oooool02?oo00<0Soooool02_oo0P0?6ooo00<03oooool01Ooo00<0Sooo
ool0;?oo0P0?2Ooo00<03oooool01?oo000Vool00`0?ooooo`0Tool200lAool00`2?ooooo`03ool0
0`0?ooooo`0Rool00`0?ooooo`03ool00`1oooooo`0Aool00`0?ooooo`0Kool00`1oooooo`07ool2
00lJool00`0?ooooo`09ool00`1oooooo`0;ool00`0?ooooo`0Jool00`0?ooooo`04ool00`1ooooo
o`0/ool00`0?ooooo`08ool00`0?ooooo`04ool002Koo`0300oooooo00Goo`0300oooooo01coo`03
00oooooo013oo`0307oooooo00?oo`0300oooooo02;oo`803`Coo`0308oooooo017oo`0300oooooo
01_oo`0308oooooo00Koo`803a[oo`0300oooooo00[oo`0308oooooo00_oo`803acoo`0300oooooo
00?oo`0308oooooo02_oo`803`[oo`0300oooooo00Coo`009_oo00<03oooool01Ooo00<03oooool0
7?oo00<03oooool04?oo00<0Soooool00_oo00<03oooool09?oo00<03oooool00_oo00<0Ooooool0
4_oo00<03oooool06_oo00<0Ooooool01_oo00<03oooool06Ooo00<03oooool02_oo00<0Ooooool0
3?oo0P0?6ooo00<03oooool00ooo00<0Ooooool0:_oo0P0?2ooo00<03oooool01?oo000Vool00`0?
ooooo`05ool00`0?ooooo`0Kool200lBool00`1oooooo`02ool00`0?ooooo`0Tool00`0?ooooo`02
ool00`2?ooooo`0Bool00`0?ooooo`0Jool00`2?ooooo`06ool00`0?ooooo`0Iool00`0?ooooo`0:
ool00`2?ooooo`0=ool00`0?ooooo`0Jool00`0?ooooo`02ool00`2?ooooo`0Yool200l<ool00`0?
ooooo`04ool002Koo`0300oooooo00Goo`0300oooooo01_oo`0300oooooo017oo`0308oooooo02Wo
o`803`?oo`0307oooooo02ooo`0307oooooo00Goo`803a[oo`0300oooooo00_oo`0307oooooo00go
o`803a_oo`0300oooooo00;oo`0307oooooo02Woo`0300oooooo00_oo`0300oooooo00Coo`009_oo
0P0?1_oo00<03oooool06ooo00<03oooool04Ooo00<0Ooooool0:_oo00D03oooooooo`2?037oo`03
08oooooo00Goo`0300oooooo02Ooo`0308oooooo00koo`0300oooooo01koo`0308oooooo02Soo`80
3`coo`803`Koo`009_oo00<03oooool01Ooo00<03oooool06ooo00<03oooool04Ooo00<0Soooool0
:_oo00D03oooooooo`1o037oo`0307oooooo00Coo`803bWoo`0307oooooo00koo`803aooo`0307oo
oooo02Ooo`803`koo`0300oooooo00Coo`009_oo00<03oooool01_oo00<03oooool06Ooo0P0?4ooo
00<0Ooooool0:_oo0P0?0_oo00<0Soooool0;ooo00<0Soooool01?oo00<03oooool0:?oo00<0Sooo
ool03ooo00<03oooool07Ooo00<0Soooool09_oo0P0?3ooo00<03oooool01?oo000Vool00`0?oooo
o`06ool00`0?ooooo`0Iool00`0?ooooo`0Bool00`2?ooooo`0[ool0100?ooooo`1o<Ooo00<0Oooo
ool00ooo0P0?:_oo00<0Ooooool03ooo0P0?7_oo00<0Ooooool09_oo00<03oooool03_oo00<03ooo
ool01?oo000Hool0100?ooooo`0?0_oo00<03oooool01Ooo00<03oooool08_oo00<03oooool04_oo
00D0Ooooooooo`0?02Woo`0400oooooo08lFool00`0?ooooo`0Hool00`2?ooooo`03ool00`0?oooo
o`0Iool00`0?ooooo`0=ool00`2?ooooo`0@ool00`0?ooooo`0Jool00`0?ool0S`0Wool200l@ool0
0`0?ooooo`04ool001Ooo`0300ooo`0?00?oo`0300ooo`0?00Koo`0300oooooo027oo`803aCoo`04
08oooooo00lZool200l00ooo07ooo`0Fool00`0?ooooo`0Gool00`1oooooo`03ool00`0?ooooo`0H
ool00`0?ooooo`0>ool00`1oooooo`0@ool200lKool00`0?ool0O`0Wool00`0?ooooo`0?ool00`0?
ooooo`04ool001Ooo`0300ooo`0?00Coo`0300oooooo00Goo`<03`3o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l03`2?000g08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l00`0?1_oo000Gool00`0?ool03`03ool00`0?ool03`06ool00`0?ooooo`0Qool00`0?oooo
o`0Cool0102?ooooo`0?:ooo00<03ooo07l05ooo00<03oooool05ooo00<0Ooooool00_oo00<03ooo
ool06Ooo00<03oooool03_oo00<0Ooooool04Ooo0P0?7?oo00<03oooool08ooo0P0?4_oo00<03ooo
ool01?oo000Hool00`0?ooooo`03ool00`0?ooooo`05ool00`0?ooooo`0Qool00`0?ooooo`0Cool0
0`1oool03`0/ool200l00`2?ooooo`0Fool00`0?ooooo`0Fool0102?oooooooo0P0?6_oo00<03ooo
ool03ooo00<0Soooool04_oo00<03oooool06_oo00<03oooool08ooo00<03oooool04Ooo00<03ooo
ool01?oo000Vool00`0?ooooo`07ool00`0?ooooo`0Fool200lEool00`2?ool03`0]ool00`0?07oo
o`0Gool00`0?ooooo`0Fool01@1ooooooooo00l06ooo00<03oooool03ooo00<0Ooooool04_oo0P0?
6ooo00<03oooool08_oo0P0?4ooo00<03oooool01?oo000Vool00`0?ooooo`07ool00`0?ooooo`0F
ool00`0?ooooo`0Dool00`1oool03`0]ool00`0?08ooo`0Gool00`0?ooooo`0Fool01@2?oooooooo
00l06_oo00<03oooool04?oo00<0Soooool04ooo00<03oooool06Ooo00<0S`0?ool08_oo00<03ooo
ool04_oo00<03oooool01?oo000Vool00`0?ooooo`07ool00`0?ooooo`0Fool00`0?ooooo`0Dool0
0`2?ooooo`0]ool00`0?07ooo`0`ool00`1oooooo`0200l]ool00`1oooooo`0Cool200lJool00`1o
ooooo`0Qool200lDool00`0?ooooo`04ool002Koo`0300oooooo00Ooo`0300oooooo01Koo`0300oo
oooo01Coo`0307oooooo02goo`803c7oo`0408oooooo00l^ool00`2?ooooo`0Dool00`0?ooooo`0H
ool00`2?ooooo`0Pool200lEool00`0?ooooo`04ool002Koo`803`Soo`0300oooooo01Goo`803aKo
o`0308oooooo02koo`0300oooooo02ooo`0407oooooo00l^ool00`1oooooo`0Dool00`0?ooooo`0H
ool00`1oooooo`0Pool00`0?ooooo`0Cool200l6ool002Koo`0300oooooo00Soo`0300oooooo01Co
o`0300oooooo01Goo`0307oooooo02koo`0300oooooo02ooo`0408ooo`0?00l^ool00`2?ooooo`0D
ool200lIool00`2?ooooo`0Oool200lFool00`0?ooooo`04ool002Koo`0300oooooo00Soo`0300oo
oooo01Coo`0300oooooo01Goo`0308oooooo02koo`803c3oo`0307ooo`0?02ooo`0307oooooo01Go
o`0300oooooo01Ooo`0307oooooo01ooo`0300oooooo01Goo`0300oooooo00Coo`009_oo00<03ooo
ool07ooo00<03oooool05Ooo00<03oooool0;_oo00<0S`0?ool06?oo00<03oooool05?oo00<0S`0?
00l06_oo00<03oooool04_oo00<0Soooool05Ooo0P0?6?oo00@0Soooool03akoo`0300oooooo01Go
o`0300oooooo00Coo`009_oo00<03oooool07_oo0P0?5ooo00<03oooool0;_oo00<0O`0?ool06?oo
00<03oooool05?oo00<0O`0?ool06_oo00<03oooool04_oo00<0Ooooool05_oo00<03oooool05_oo
00@0Ooooool03agoo`803aOoo`0300oooooo00Coo`009_oo00<03oooool07_oo00<03oooool05_oo
00<03oooool0;_oo00<0S`0?00l06?oo00<03oooool05?oo00<0S`0?ool06_oo00<03oooool04_oo
00<0Soooool05_oo00<03oooool05_oo00D0Soooooooo`0?01coo`0300oooooo01Koo`0300oooooo
00Coo`009_oo00<03oooool07_oo00<03oooool05_oo00<03oooool0;_oo00<0Oooo00l06Ooo00<0
3oooool04ooo0P0?6_oo00<03oooool04ooo00<0Ooooool05_oo0P0?5ooo00D0Ooooooooo`0?01_o
o`803aSoo`0300oooooo00Coo`009_oo0P0?7ooo00<03oooool05Ooo00<03`1oool0;ooo00<0Sooo
00l06Ooo00<03oooool04ooo00<03oooool06Ooo00<03oooool04ooo00<0Soooool05ooo00<03ooo
ool05Ooo00<0Soooool00_oo00<03oooool06?oo00<03oooool05_oo0P0?1_oo000Vool00`0?oooo
o`09ool00`0?ooooo`0Bool00`0?ooooo`0Eool00`0?08ooo`0_ool00`1oool03`0Iool00`0?oooo
o`0Cool00`0?ooooo`0Iool00`0?ooooo`0Cool00`1oooooo`0Gool00`0?ooooo`0Eool00`1ooooo
o`02ool00`0?ooooo`0Gool200lIool00`0?ooooo`04ool002Koo`0300oooooo00Woo`0300oooooo
017oo`803aOoo`0300l0Oooo02ooo`0408ooo`0?00lHool00`0?ooooo`0Bool200lJool00`0?oooo
o`0Dool00`2?ooooo`0Hool00`0?ooooo`0Dool00`2?ooooo`02ool00`0?ooooo`0Gool00`0?oooo
o`0Hool00`0?ooooo`04ool002Koo`0300oooooo00Woo`0300oooooo017oo`0300oooooo01Ooo`03
08oooooo02koo`0407oooooo00lIool00`0?ooooo`0Aool00`0?07ooo`0`ool00`1oooooo`0Hool0
0`0?ooooo`0Dool00`1oooooo`0Kool200lJool00`0?ooooo`04ool002Koo`0300oooooo00Woo`03
00oooooo017oo`0300oooooo01Ooo`0307oooooo02koo`0408oooooo00l]ool00`0?08ooo`0`ool0
0`2?ooooo`0Hool200lEool00`2?ooooo`0Kool00`0?ooooo`0Iool00`0?ooooo`04ool002Koo`03
00oooooo00Woo`0300oooooo017oo`0300oooooo01Ooo`0308oooooo02koo`0407oooooo00l]ool0
0`0?07ooo`0`ool00`1oooooo`0Iool00`0?ooooo`0Cool00`1oooooo`0Kool00`0?ooooo`0Iool0
0`0?ooooo`04ool002Koo`0300oooooo00[oo`0300oooooo013oo`0300oooooo01Ooo`0307oooooo
02koo`0308oooooo00803b_oo`0300ooo`2?037oo`0308oooooo01Woo`0300oooooo01?oo`0308oo
oooo01[oo`803a_oo`0300oooooo00Coo`009_oo0P0?2ooo00<03oooool03ooo0P0?6Ooo00<0Sooo
ool0;_oo00D0Ooooooooo`0?02_oo`0300ooo`1o037oo`0307oooooo01Woo`803aCoo`0307oooooo
00Coo`0300oooooo01?oo`0300oooooo01Woo`803`Koo`009_oo00<03oooool07?oo00<03oooool0
5_oo00<03ooo07l0<?oo00D0Soooooooo`0?02_oo`0300ooo`2?01Soo`0300oooooo01Koo`0308oo
oooo01[oo`0300oooooo01;oo`0308oooooo00Goo`0300oooooo017oo`803acoo`0300oooooo00Co
o`009_oo00<03oooool07?oo00<03oooool05_oo00<03ooo08l0<?oo00D0Ooooooooo`0?01Woo`03
00oooooo00koo`803`03ool0Oooo01Ooo`0300oooooo01Koo`0307oooooo01[oo`803a?oo`0307oo
oooo00Goo`0300oooooo017oo`0300oooooo01_oo`0300oooooo00Coo`009_oo00<03oooool07?oo
00<03oooool05Ooo00@03oooool0Oc3oo`0408ooooooool200lHool00`0?ooooo`0>ool0100?oooo
o`2?6?oo00<03oooool05_oo00<0Soooool06ooo00<03oooool04Ooo00<0Soooool01Ooo00<03ooo
ool04?oo0P0?7Ooo00<03oooool01?oo000Mool300l6ool00`0?ooooo`0Lool00`0?ooooo`0Eool0
100?ooooo`2?<?oo00<0Ooooool00_oo00<03oooool05ooo00<03oooool03Ooo00@03oooool0OaOo
o`0300oooooo01Ooo`0307oooooo01_oo`0300oooooo017oo`0307oooooo00Koo`0300oooooo00oo
o`0300oooooo01coo`0300oooooo00Coo`007_oo00<03oooool01Ooo00<03oooool07?oo00<03ooo
ool05Ooo00@03oooool0Oc3oo`0308oooooo00;oo`0300oooooo01Ooo`0300oooooo00goo`0400oo
oooo08lGool00`0?ooooo`0Gool00`2?ooooo`0Kool200lBool00`2?ooooo`06ool00`0?ooooo`0>
ool200lNool00`0?ooooo`04ool001koo`0300oooooo00Goo`0300oooooo01_oo`803aOoo`0400oo
oooo08l`ool00`1oooooo`02ool00`0?ooooo`0Gool00`0?ooooo`0<ool200l2ool00`1oooooo`0E
ool00`0?ooooo`0Gool00`1oooooo`0Lool00`0?ooooo`0@ool00`1oooooo`07ool00`0?ooooo`0=
ool00`0?ooooo`0Mool00`0?ooooo`04ool001koo`0300oooooo00Goo`<03`1]08l0O`2?07l0S`1o
08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l00P0?0<L0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`0300l6ool001goo`803`Ooo`0300oooooo00_oo`0300oooooo00goo`0300oooooo
01Goo`0500ooooooool0S`0`ool00`1oooooo`03ool00`0?ooooo`0Gool00`0?ooooo`0;ool01@0?
oooooooo07l0<Ooo00<0Ooooool07?oo0P0?4Ooo00<0Ooooool05_oo00<03oooool07_oo00<03ooo
ool01?oo000Vool00`0?ooooo`0;ool00`0?ooooo`0=ool00`0?ooooo`0Iool00`1oooooo`0^ool0
0`2?ooooo`03ool00`0?ooooo`0Tool200l3ool00`2?ooooo`0_ool00`2?ooooo`0Mool00`0?oooo
o`0?ool00`2?ooooo`0Fool00`0?ooooo`0Nool00`0?ooooo`04ool002Koo`0300oooooo00coo`03
00oooooo00coo`0300oooooo01Woo`0308oooooo02koo`0307oooooo00?oo`0300oooooo02Coo`03
00oooooo00;oo`0307oooooo02ooo`0307oooooo01goo`803a3oo`0307oooooo01Goo`803b3oo`03
00oooooo00Coo`009_oo00<03oooool03?oo00<03oooool02ooo0P0?6ooo00<0Ooooool0;_oo00<0
Soooool00ooo0P0?9Ooo00<03oooool00_oo00<0Soooool0;ooo00<0Soooool07_oo00<03oooool0
3_oo00<0Soooool05Ooo00<03oooool07ooo00<03oooool01?oo000Vool00`0?ooooo`0<ool00`0?
ooooo`0;ool00`0?ooooo`0Jool00`2?ooooo`0^ool00`1oooooo`04ool00`0?ooooo`0Sool00`0?
ooooo`02ool00`1oooooo`0_ool00`1oooooo`0Nool00`0?ooooo`0>ool00`1oooooo`09ool00`0?
ooooo`08ool200lQool00`0?ooooo`04ool002Koo`803`goo`0300oooooo00_oo`0300oooooo01[o
o`0307oooooo02koo`0308oooooo00Coo`0300oooooo02;oo`803`Coo`0308oooooo01?oo`0300oo
oooo01Woo`0308oooooo01koo`803`ooo`0308oooooo00[oo`0300oooooo00Ooo`0300oooooo01oo
o`803`Koo`009_oo00<03oooool06_oo00<03oooool05Ooo00<03oooool00_oo00<0Soooool0;_oo
00<0Ooooool01?oo00<03oooool05ooo00<03oooool02?oo00<03oooool00ooo00<0Ooooool04ooo
00<03oooool06Ooo00<0Ooooool07ooo00<03oooool03Ooo00<0Ooooool02_oo00<03oooool01_oo
0P0?8_oo00<03oooool01?oo000Vool00`0?ooooo`0Jool00`0?ooooo`0Eool00`0?ooooo`02ool0
0`1oooooo`0^ool00`2?ooooo`05ool00`0?ooooo`0Gool00`0?ooooo`07ool00`0?ooooo`03ool0
0`2?ooooo`0Bool00`0?ooooo`0Jool00`2?ooooo`0Oool00`0?ooooo`0=ool00`2?ooooo`0:ool0
0`0?ooooo`06ool00`0?ooooo`0Qool00`0?ooooo`04ool002Koo`0300oooooo01Woo`803aOoo`03
00oooooo00;oo`0308oooooo02koo`0307oooooo00Goo`0300oooooo01Ooo`0300oooooo00Ooo`03
00oooooo00?oo`0307oooooo01;oo`0300oooooo01[oo`0307oooooo01ooo`803`koo`0307oooooo
00_oo`0300oooooo00Goo`0300oooooo027oo`0300oooooo00Coo`009_oo00<03oooool06Ooo00<0
3oooool05_oo00<03oooool00_oo00<0Ooooool0;_oo00<0Soooool01Ooo00<03oooool05ooo00<0
3oooool01_oo0P0?1Ooo00<0Soooool04_oo00<03oooool06_oo00<0Soooool08?oo00<03oooool0
3?oo00<0Soooool02ooo00<03oooool01?oo0P0?8ooo00<03oooool01?oo000Vool00`0?ooooo`0I
ool00`0?ooooo`0Eool00`0?ooooo`03ool00`2?ooooo`0^ool00`1oooooo`05ool00`0?ooooo`0G
ool00`0?ooooo`06ool00`0?ooooo`04ool00`1oooooo`0Aool00`0?ooooo`0Kool00`1oooooo`0P
ool200l=ool00`1oooooo`0;ool00`0?ooooo`04ool00`0?ooooo`0Rool00`0?ooooo`04ool002Ko
o`0300oooooo00goo`0300oooooo00Woo`0300oooooo01Goo`0300oooooo00?oo`0307oooooo02ko
o`0308oooooo00Goo`803aWoo`0300oooooo00Goo`0300oooooo00Coo`0308oooooo017oo`0300oo
oooo01_oo`0308oooooo027oo`0300oooooo00_oo`0308oooooo017oo`803bCoo`0300oooooo00Co
o`009_oo0P0?3_oo00<03oooool02Ooo00<03oooool05Ooo00<03oooool00ooo00<0Soooool0;_oo
00<0Ooooool01_oo00<03oooool05ooo00<03oooool01?oo0P0?1_oo00<0Ooooool0;ooo00<0Oooo
ool08Ooo00<03oooool02ooo00<0Ooooool04Ooo00<03oooool08_oo0P0?1_oo000Vool00`0?oooo
o`0=ool00`0?ooooo`09ool00`0?ooooo`0Kool00`1oooooo`0^ool00`2?ooooo`06ool00`0?oooo
o`0Nool00`0?ooooo`05ool00`2?ooooo`0_ool00`2?ooooo`0Qool200l<ool00`2?ooooo`0Aool0
0`0?ooooo`0Kool00`0?ooooo`05ool00`0?ooooo`04ool002Koo`0300oooooo00koo`0300oooooo
00Ooo`803agoo`0308oooooo02koo`0307oooooo00Koo`0300oooooo01koo`0300oooooo00Goo`03
07oooooo02ooo`0307oooooo02;oo`0300oooooo00[oo`0307oooooo013oo`803agoo`0300oooooo
00Goo`0300oooooo00Coo`009_oo00<03oooool03_oo00<03oooool01ooo00<03oooool07?oo00<0
Ooooool0;_oo00<0Soooool01_oo0P0?7ooo00<03oooool01Ooo00<0Soooool0;ooo00<0Soooool0
8_oo00<03oooool02_oo00<0Soooool04?oo00<03oooool06ooo00<03oooool01_oo00<03oooool0
1?oo000:ool500lGool00`0?ooooo`0>ool00`0?ooooo`07ool00`0?ooooo`0Lool00`2?ooooo`0^
ool00`1oooooo`07ool00`0?ooooo`0Lool200l7ool00`1oooooo`0_ool00`1oooooo`0Rool200l;
ool00`1oooooo`0>ool300lMool00`0?ooooo`06ool00`0?ooooo`04ool000coo`0400oooooo00lF
ool00`0?ooooo`0>ool00`0?ooooo`07ool00`0?ooooo`0Lool00`1oooooo`0^ool00`2?ooooo`07
ool00`0?ooooo`0Lool00`0?ooooo`06ool00`2?ooooo`0@ool00`0?ooooo`0Lool00`2?ooooo`0S
ool00`0?ooooo`09ool00`2?ooooo`0>ool200lWool00`0?ooooo`04ool000coo`0400oooooo00lF
ool00`0?ooooo`0Hool00`0?ooooo`0Eool00`0?ooooo`04ool00`2?ooooo`0^ool00`1oooooo`07
ool00`0?ooooo`0Gool00`0?ooooo`02ool00`0?ooooo`06ool00`1oooooo`0?ool00`0?ooooo`0M
ool00`1oooooo`0Sool200l:ool00`1oooooo`0>ool200lWool00`0?ooooo`04ool000goo`803aOo
o`803aSoo`803aOoo`0300oooooo00Coo`0307oooooo02koo`0308oooooo00Ooo`803aWoo`0300oo
oooo00803`Soo`0308oooooo00ooo`0300oooooo01goo`0308oooooo02Coo`0300oooooo00Soo`03
08oooooo00koo`803bKoo`803`Koo`009_oo00<03oooool05ooo00<03oooool05_oo00<03oooool0
1?oo00<0Soooool0;_oo00<0Ooooool02?oo00<03oooool05ooo00@03oooool03`Woo`0307oooooo
00ooo`0300oooooo01goo`0307oooooo02Coo`0300oooooo00Soo`0307oooooo00koo`803bOoo`03
00oooooo00Coo`009_oo00<03oooool05ooo00<03oooool05_oo00<03oooool01?oo00<0Ooooool0
;_oo00<0Soooool02?oo00<03oooool05ooo00@03oooool03`Woo`0308oooooo00ooo`0300oooooo
01goo`0308oooooo02Coo`803`Woo`0308oooooo00goo`<03bOoo`0300oooooo00Coo`009_oo00<0
3oooool05ooo00<03oooool05Ooo00<03oooool01Ooo00<0Soooool0;_oo00<0Ooooool02?oo00<0
3oooool05ooo00@03oooool03`Woo`0307oooooo00koo`0300oooooo01koo`0307oooooo02Goo`03
00oooooo00Ooo`0307oooooo00goo`0400oooooo00lJool200l:ool00`0?ooooo`04ool001Ooo`<0
3`03ool03ooo00<03`Koo`0300oooooo00ooo`0300oooooo00Goo`0300oooooo01Goo`0300oooooo
00Goo`0307oooooo02koo`0308oooooo00Soo`803aWoo`<03`Woo`0308oooooo00koo`0300oooooo
01koo`0308oooooo02Goo`803`Soo`0308oooooo00coo`803agoo`0300oooooo00Woo`0300oooooo
00Coo`006?oo00<03oooool00_oo00<03oooool01_oo00<03oooool03ooo00<03oooool01Ooo00<0
3oooool05Ooo00<03oooool01Ooo00<0Soooool0;_oo00<0Ooooool02Ooo00<03oooool05ooo0P0?
2_oo00<0Ooooool0;ooo00<0Ooooool09_oo00<03oooool01_oo00<0Ooooool03?oo00<03oooool0
6ooo00<03oooool02_oo00<03oooool01?oo000Hool00`0?ooooo`03ool00`0?ooooo`05ool00`0?
ooooo`0?ool00`0?ooooo`05ool00`0?ooooo`0Mool00`1oooooo`0^ool00`2?ooooo`09ool00`0?
ooooo`0Hool00`0?ooooo`08ool00`2?ooooo`0_ool00`2?ooooo`0Vool00`0?ooooo`06ool00`2?
ooooo`0;ool200lMool00`0?ooooo`0:ool00`0?ooooo`04ool001Soo`0300oooooo00;oo`0300oo
o`0?00Koo`<03`0F07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l200l0
g@1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
3`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l00P0?03l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l00`0?1_oo000Gool200l5ool200l6ool0
0`0?ooooo`0@ool00`0?ooooo`03ool00`0?ooooo`0Nool00`1oooooo`0^ool00`2?ooooo`09ool2
00lHool200l:ool00`2?ooooo`0_ool00`2?ooooo`0Wool00`0?ooooo`05ool00`2?ooooo`0:ool2
00lMool00`0?ooooo`0;ool00`0?ooooo`04ool002Koo`0300oooooo013oo`0300oooooo00?oo`03
00oooooo01koo`0308oooooo02koo`0307oooooo00[oo`0300oooooo01Koo`0300oooooo00Woo`03
07oooooo02ooo`0307oooooo02Ooo`803`Koo`0307oooooo00[oo`0300oooooo00Goo`0300oooooo
02;oo`0300oooooo00Coo`009_oo00<03oooool04?oo00<03oooool00ooo00<03oooool07_oo00<0
Ooooool0;_oo00<0Soooool02_oo00<03oooool05_oo00<03oooool02Ooo00<0Soooool03?oo00<0
3oooool08?oo00<0Soooool0:?oo00<03oooool01?oo00<0Soooool02Ooo0P0?2?oo00<03oooool0
8Ooo00<03oooool01?oo000Vool00`0?ooooo`0@ool00`0?ooooo`03ool00`0?ooooo`0Nool00`2?
ooooo`0^ool00`1oooooo`0:ool00`0?ooooo`0Eool200l00ooo00ooo`08ool00`1oooooo`0<ool0
0`0?ooooo`0Pool00`1oooooo`0Xool200l5ool00`1oooooo`09ool00`0?ooooo`07ool00`0?oooo
o`0Qool00`0?ooooo`04ool002Koo`0300oooooo01Koo`0300oooooo01Goo`0300oooooo00Koo`03
07oooooo02koo`0308oooooo00[oo`0300oooooo01Goo`0400oooooo00l9ool00`2?ooooo`0<ool0
0`0?ooooo`0Pool00`2?ooooo`0Yool00`0?ooooo`03ool00`2?ooooo`08ool200l:ool00`0?oooo
o`0Pool00`0?ooooo`04ool002Koo`0300oooooo01Koo`0300oooooo01Goo`0300oooooo00Koo`03
08oooooo02koo`0307oooooo00[oo`803aKoo`0400oooooo00l9ool00`1oooooo`0<ool00`0?oooo
o`0Pool00`1oooooo`0Yool200l4ool00`1oooooo`08ool00`0?ooooo`09ool00`0?ooooo`0Pool0
0`0?ooooo`04ool002Koo`803aKoo`803aOoo`0300oooooo00Koo`0307oooooo02koo`0308oooooo
00_oo`0300oooooo01Coo`0400oooooo00l9ool00`2?ooooo`0;ool00`0?ooooo`0Qool00`2?oooo
o`0Zool00`0?ooooo`02ool00`2?ooooo`07ool200l<ool00`0?ooooo`0>ool00`0?ooooo`0=ool2
00l6ool002Koo`0300oooooo01Goo`0300oooooo01Koo`0300oooooo00Koo`0308oooooo02koo`03
07oooooo00_oo`0300oooooo01?oo`803`;oo`0300oooooo00Ooo`0307oooooo00_oo`0300oooooo
027oo`0307oooooo02_oo`0500ooooooool0O`09ool00`0?ooooo`0Lool00`0?ooooo`0>ool00`0?
ooooo`04ool002Koo`0300oooooo01Goo`0300oooooo01Goo`0300oooooo00Ooo`0307oooooo02ko
o`0308oooooo00_oo`803aCoo`0300oooooo00;oo`0300oooooo00Koo`0308oooooo00_oo`0300oo
oooo027oo`0308oooooo02_oo`803`;oo`0308oooooo00Koo`803agoo`0300oooooo00ooo`0300oo
oooo00Coo`009_oo00<03oooool04Ooo00D03oooooooo`0?01Ooo`0300oooooo00Ooo`0308oooooo
02koo`0307oooooo00coo`0300oooooo01;oo`0300oooooo00;oo`0300oooooo00Koo`0307oooooo
02ooo`0307oooooo02coo`803`03ool0Oooo00Koo`803agoo`0300oooooo013oo`0300oooooo00Co
o`009_oo00<03oooool04Ooo00D03oooooooo`0?01Ooo`0300oooooo00Ooo`0307oooooo02koo`03
08oooooo00coo`0300oooooo017oo`803`goo`0308oooooo02ooo`0308oooooo02goo`803`0308oo
oooo00Coo`803akoo`0300oooooo013oo`0300oooooo00Coo`009_oo00<03oooool04Ooo00D03ooo
ooooo`0?027oo`0308oooooo02koo`0307oooooo00coo`0300oooooo017oo`0300oooooo00coo`03
07oooooo02ooo`0307oooooo02koo`803`Goo`803a?oo`0300oooooo00Soo`0300oooooo017oo`03
00oooooo00Coo`009_oo0P0?4ooo00@03oooool03b7oo`0307oooooo02koo`0308oooooo00coo`80
3a;oo`0300oooooo00coo`0308oooooo02ooo`0308oooooo02ooo`803`;oo`<03aGoo`0300oooooo
01[oo`803`Koo`009_oo00<03oooool04_oo00@03ooo00l03b7oo`0308oooooo02koo`0307oooooo
00goo`0300oooooo00ooo`803`koo`0307oooooo02ooo`0307oooooo02ooo`0307l03`0?00803aSo
o`0300oooooo01[oo`0300oooooo00Coo`009_oo00<03oooool04_oo00<03ooo00l08_oo00<0Oooo
ool0;_oo00<0Soooool03Ooo00<03oooool03ooo00<03oooool03Ooo00<0Soooool02Ooo00<03ooo
ool08ooo00<0Soooool0;ooo00<0Soooool06ooo0`0?6Ooo00<03oooool01?oo000Vool00`0?oooo
o`0Bool00`0?ool03`0Rool00`2?ooooo`0^ool00`1oooooo`0=ool00`0?ooooo`0?ool00`0?oooo
o`06ool00`0?ooooo`04ool00`1oooooo`09ool00`0?ooooo`0Sool00`1oooooo`0_ool00`1ooooo
o`0Mool200lHool00`0?ooooo`04ool002Koo`0300oooooo01Coo`0300oooooo01Goo`0300oooooo
00Soo`0307oooooo02koo`0308oooooo00goo`803a3oo`0300oooooo00Koo`0300oooooo00Coo`03
08oooooo00Soo`0300oooooo02Coo`0308oooooo02ooo`0308oooooo03Ooo`0300oooooo00Coo`00
9_oo00<03oooool05?oo00<03oooool05Ooo00<03oooool02?oo00<0Soooool0;_oo00<0Ooooool0
3_oo00<03oooool03Ooo00<03oooool01ooo00<03oooool01?oo00<0Ooooool02?oo00<03oooool0
9?oo00<0Ooooool0;ooo00<0Ooooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0Dool00`0?
ooooo`0Eool00`0?ooooo`08ool00`1oooooo`0^ool00`2?ooooo`0>ool00`0?ooooo`0=ool00`0?
ooooo`07ool00`0?ooooo`04ool00`2?ooooo`08ool00`0?ooooo`0Tool00`2?ooooo`0_ool00`2?
ooooo`0gool00`0?ooooo`04ool002Koo`803aGoo`0300oooooo01Goo`0300oooooo00Soo`0308oo
oooo02koo`0307oooooo00koo`803`koo`0300oooooo00Soo`0300oooooo00?oo`0307oooooo00Oo
o`0300oooooo02Goo`0307oooooo02ooo`0307oooooo03Koo`803`Koo`009_oo00<03oooool04ooo
0P0?5ooo00<03oooool02?oo00<0Ooooool0;_oo00<0Soooool03ooo00<03oooool02ooo0P0?2_oo
00<03oooool00ooo00<0Soooool01ooo00<03oooool09Ooo00<0Soooool0;ooo00<0Soooool0=ooo
00<03oooool01?oo000Vool00`0?ooooo`0Cool00`0?ooooo`0Fool00`0?ooooo`08ool00`2?oooo
o`0^ool00`1oooooo`0?ool00`0?ooooo`0;ool00`0?ooooo`09ool00`0?ooooo`03ool00`1ooooo
o`0_ool00`1oooooo`0_ool00`1oooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo01?oo`03
00oooooo01Goo`0300oooooo00Woo`0307oooooo02koo`0308oooooo00ooo`803`coo`0300oooooo
00ooo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo03Ooo`0300oooooo00Coo`009_oo00<0
3oooool04ooo00<03oooool08Ooo00<0Soooool0;_oo00<0Ooooool04?oo00<03oooool02Ooo0P0?
4Ooo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0=ooo00<03oooool01?oo000Gool300l0
0ooo00ooo`02ool00`0?ooooo`04ool00`0?ooooo`0Cool00`0?ooooo`0Qool00`1oooooo`0^ool0
0`2?ooooo`0@ool00`0?ooooo`09ool00`0?ooooo`0@ool00`2?ooooo`0_ool00`2?ooooo`0_ool0
0`2?ooooo`0gool00`0?ooooo`04ool001Soo`0300oooooo00;oo`<03`Koo`0300oooooo01?oo`03
00oooooo027oo`0308oooooo02koo`0307oooooo013oo`803`Woo`803a;oo`0307oooooo02ooo`03
07oooooo02ooo`0307oooooo03Ooo`0300oooooo00Coo`006?oo00<03oooool00_oo00<03ooo00l0
1_oo0`0?0180S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l200l0o`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`008`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l00`0?1_oo000Hool00`0?ooooo`03ool200l6
ool00`0?ooooo`0Bool00`0?ool03`0Rool00`2?ooooo`0^ool00`1oooooo`0Aool200l7ool200l@
ool0100?ooooo`1o1ooo00<03oooool09ooo00<0Ooooool0;ooo00<0Ooooool0=ooo00<03oooool0
1?oo000Gool200l6ool00`0?ooooo`04ool00`0?ooooo`0Bool00`0?ool03`0Rool00`1oooooo`0^
ool00`2?ooooo`0Bool00`0?ooooo`05ool00`0?ooooo`0?ool0100?ooooo`2?1_oo00<03oooool0
:?oo00<0Soooool0;ooo00<0Soooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0Bool00`0?
ooooo`0Eool00`0?ooooo`0:ool00`2?ooooo`0^ool00`1oooooo`0Bool200l5ool200lAool0100?
ooooo`1o1_oo00<03oooool0:?oo00<0Ooooool0;ooo00<0Ooooool0=ooo00<03oooool01?oo000V
ool00`0?ooooo`0Bool00`0?ooooo`0Eool00`0?ooooo`0:ool00`1oooooo`0^ool00`2?ooooo`0C
ool200l4ool00`0?ooooo`0Aool00`0?ool0S`05ool00`0?ooooo`0Yool00`2?ooooo`0_ool00`2?
ooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo01;oo`0300oooooo01Goo`0300oooooo00[o
o`0308oooooo02koo`0307oooooo01Coo`803`04ool03`0?00lCool00`0?ool0O`04ool00`0?oooo
o`0Zool00`1oooooo`0_ool00`1oooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo01;oo`03
00oooooo01Goo`0300oooooo00[oo`0307oooooo02koo`0308oooooo01Goo`<03aKoo`0300l0Sooo
00?oo`0300oooooo02[oo`0308oooooo02ooo`0308oooooo03Ooo`0300oooooo00Coo`009_oo0P0?
4_oo0P0?5ooo00<03oooool02_oo00<0Soooool0;_oo00<0Ooooool0;ooo00<03oooool0;ooo00<0
Ooooool0;ooo00<0Ooooool0=_oo0P0?1_oo000Vool00`0?ooooo`0Aool01@0?oooooooo00l05?oo
00<03oooool02_oo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0;ooo
00<0Soooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0Aool01@0?oooooooo00l04ooo00<0
3oooool02ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0
Ooooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0Aool01@0?oooooooo00l08Ooo00<0Oooo
ool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0=ooo00<03ooo
ool01?oo000Vool00`0?ooooo`0Aool01@0?oooooooo00l08Ooo00<0Soooool0;_oo00<0Ooooool0
;ooo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0=ooo00<03oooool01?oo000Vool00`0?
ooooo`0Aool01@0?oooooooo00l08Ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo
00<0Soooool0;ooo00<0Soooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0Aool01@0?oooo
oooo00l08Ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0
Ooooool0=ooo00<03oooool01?oo000Vool200lAool200l3ool00`0?ooooo`0Oool00`1oooooo`0^
ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0fool200l6ool002Ko
o`0300oooooo013oo`0300oooooo01Goo`0300oooooo00coo`0308oooooo02koo`0307oooooo02oo
o`0307oooooo02ooo`0307oooooo02ooo`0307oooooo03Ooo`0300oooooo00Coo`009_oo00<03ooo
ool04?oo00<03oooool05Ooo00<03oooool03?oo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Sooo
ool0;ooo00<0Soooool0;ooo00<0Soooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0@ool0
0`0?ooooo`0Eool00`0?ooooo`0<ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool0
0`1oooooo`0_ool00`1oooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo013oo`0300oooooo
01Goo`0300oooooo00coo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo
02ooo`0308oooooo03Ooo`0300oooooo00Coo`009_oo00<03oooool04?oo00<03oooool05Ooo00<0
3oooool03?oo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0
Ooooool0=ooo00<03oooool01?oo000Vool200lAool00`0?ooooo`03ool00`0?ooooo`0?ool00`0?
ooooo`0<ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?
ooooo`0fool200l6ool002Koo`0300oooooo00ooo`803`Goo`0300oooooo00koo`0300oooooo00go
o`0308oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo03Oo
o`0300oooooo00Coo`009_oo00<03oooool03ooo00<03oooool01?oo00<03oooool07_oo00<0Oooo
ool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0=ooo00<03ooo
ool01?oo000Vool00`0?ooooo`0?ool00`0?ooooo`05ool00`0?ooooo`0Mool00`2?ooooo`0^ool0
0`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0gool00`0?ooooo`04ool0
02Koo`0300oooooo00ooo`0300oooooo00Goo`0300oooooo01goo`0307oooooo02koo`0308oooooo
02ooo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo03Ooo`0300oooooo00Coo`005ooo0`0?
00Goo`0?ooooo`0?00Ooo`0300oooooo00ooo`0300oooooo00Goo`0300oooooo01goo`0308oooooo
02koo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo03Ooo`0300oooooo
00Coo`006?oo00<03oooool00_oo00<03ooo00l01_oo00<03oooool03ooo00<03oooool01Ooo00<0
3oooool07Ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0;ooo00<0
Soooool0=ooo00<03oooool01?oo000Hool00`0?ooooo`02ool200l7ool300l03P1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l200l0o`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`009`1o08l0
O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`0300l6ool001Soo`0300oooooo00;oo`0300oooooo00Koo`0300oooooo00ko
o`0300oooooo01Goo`0300oooooo00koo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02oo
o`0308oooooo02ooo`0308oooooo03Ooo`0300oooooo00Coo`005ooo0P0?1Ooo0P0?1_oo00<03ooo
ool03_oo00<03oooool05Ooo00<03oooool03_oo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Oooo
ool0;ooo00<0Ooooool0;ooo00<0Ooooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0>ool0
0`0?ooooo`0Eool00`0?ooooo`0>ool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool0
0`2?ooooo`0_ool00`2?ooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo00koo`0300oooooo
01Goo`0300oooooo00koo`0308oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo
02ooo`0307oooooo03Ooo`0300oooooo00Coo`009_oo00<03oooool03_oo00<03oooool05Ooo00<0
3oooool03_oo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0;ooo00<0
Soooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0>ool00`0?ooooo`07ool00`0?ooooo`0;
ool00`0?ooooo`0>ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0_
ool00`1oooooo`0gool00`0?ooooo`04ool002Koo`803`koo`803`Woo`0300oooooo00_oo`0300oo
oooo00koo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo02ooo`0308oo
oooo03Koo`803`Koo`009_oo00<03oooool03Ooo00<03oooool02?oo00<03oooool07?oo00<0Sooo
ool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0=ooo00<03ooo
ool01?oo000Vool00`0?ooooo`0=ool00`0?ooooo`09ool00`0?ooooo`0Kool00`1oooooo`0^ool0
0`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0gool00`0?ooooo`04ool0
02Koo`0300oooooo00goo`0300oooooo00Woo`0300oooooo01_oo`0308oooooo02koo`0307oooooo
02ooo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo03Ooo`0300oooooo00Coo`009_oo00<0
3oooool03Ooo00<03oooool02Ooo00<03oooool06ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<0
Soooool0;ooo00<0Soooool0;ooo00<0Soooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0<
ool200l;ool00`0?ooooo`0Kool00`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1o
ooooo`0_ool00`1oooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo00coo`0300oooooo01Ko
o`0300oooooo00ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo02oo
o`0308oooooo03Ooo`0300oooooo00Coo`009_oo0P0?3Ooo00<03oooool05Ooo00<03oooool04?oo
00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0=_oo
0P0?1_oo000Vool00`0?ooooo`0<ool00`0?ooooo`0Eool00`0?ooooo`0@ool00`1oooooo`0^ool0
0`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0gool00`0?ooooo`04ool0
02Koo`0300oooooo00coo`0300oooooo01Goo`0300oooooo013oo`0308oooooo02koo`0307oooooo
02ooo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo03Ooo`0300oooooo00Coo`009_oo00<0
3oooool02ooo0P0?5ooo00<03oooool04?oo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0
;ooo00<0Soooool0;ooo00<0Soooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0;ool00`0?
ooooo`0<ool00`0?ooooo`07ool00`0?ooooo`0@ool00`2?ooooo`0^ool00`1oooooo`0_ool00`1o
ooooo`0_ool00`1oooooo`0_ool00`1oooooo`0gool00`0?ooooo`04ool002Koo`0300oooooo00_o
o`0300oooooo00coo`0300oooooo00Koo`0300oooooo017oo`0307oooooo02koo`0308oooooo02oo
o`0308oooooo02ooo`0308oooooo02ooo`0308oooooo03Ooo`0300oooooo00Coo`009_oo00<03ooo
ool02ooo00<03oooool03Ooo00<03oooool06Ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Oooo
ool0;ooo00<0Ooooool0;ooo00<0Ooooool0=ooo00<03oooool01?oo000Vool200l;ool200l?ool0
0`0?ooooo`0Iool00`1oooooo`0^ool00`2?ooooo`0_ool00`2?ooooo`0_ool00`2?ooooo`0_ool0
0`2?ooooo`0fool200l6ool002Koo`0300oooooo00[oo`0300oooooo00koo`0300oooooo01Woo`03
08oooooo02koo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo02ooo`0307oooooo03Ooo`03
00oooooo00Coo`009_oo00<03oooool02_oo00<03oooool03_oo00<03oooool06Ooo00<0Ooooool0
;_oo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0;ooo00<0Soooool0=ooo00<03oooool0
1?oo000Vool00`0?ooooo`05ool0100?oooooooo0P0?4?oo0P0?6_oo00<0Soooool0;_oo00<0Oooo
ool0;ooo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0=ooo00<03oooool01?oo000Gool3
00l01Ooo00oooooo00l01ooo00<03oooool01Ooo00D03oooooooo`0?01Soo`0300oooooo01;oo`03
07oooooo02koo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo02ooo`0308oooooo03Ooo`03
00oooooo00Coo`006?oo00<03oooool00_oo00<03ooo00l01_oo00<03oooool01Ooo0P0?00?oo`0?
00l05ooo00<03oooool04ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Oooo
ool0;ooo00<0Ooooool0=ooo00<03oooool01?oo000Hool00`0?ooooo`03ool00`0?ooooo`05ool3
00l01P2?07l0S`1o08l0O`<03`3o07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o000^07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l300l6ool001Soo`0300oooooo00;oo`0300ooo`0?00Ko
o`0300oooooo027oo`0300oooooo01?oo`0308oooooo02koo`0307oooooo02ooo`0307oooooo02oo
o`0307oooooo02ooo`0307oooooo03Ooo`0300oooooo00Coo`005ooo0P0?1Ooo00<03oooool01Ooo
00<03oooool08?oo00<03oooool05?oo00<0Ooooool0;_oo00<0Soooool0;ooo00<0Soooool0;ooo
00<0Soooool0;ooo00<0Soooool0=ooo00<03oooool01?oo000Vool00`0?ooooo`0Nool300lFool0
0`2?ooooo`0^ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0_ool00`1oooooo`0gool0
0`0?ooooo`04ool002Koo`0300oooooo03Ooo`0307oooooo02koo`0308oooooo02ooo`0308oooooo
02ooo`0308oooooo02ooo`0308oooooo03Ooo`0300oooooo00Coo`009_oo00<03oooool0=ooo00<0
Soooool0;_oo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0;ooo00<0Ooooool0=ooo00<0
3oooool01?oo000Vool00`0?ooooo`05ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07
ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`06ool00`0?ooooo`07ool00`0?ooooo`07
ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07
ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07
ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07
ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07
ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`05ool00`0?ooooo`04ool002Koool03cd0
3`Koo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {4.538725, 0.223393, 0.012515,
   0.009198}}]
}, Open  ]],

Cell[BoxData[{
    \(\(Clear[Josc]; \)\), 
    \(\(Josc[v_, En_] := b[v, En]\ J[v]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig11x4 = 
      Plot[Evaluate[{J[v]\/10\^4, Josc[v, 0]\/10\^4}], {v, 5, 8}, 
        FrameLabel \[Rule] {"\<v in V\>", "\<Josc in pA over 100 nm^2\>"}, 
        Evaluate[opt]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
-1.563492 0.31746 0.014707 0.058861 [
[.02381 -0.0125 -4 -12 ]
[.02381 -0.0125 4 0 ]
[.18254 -0.0125 -7 -12 ]
[.18254 -0.0125 7 0 ]
[.34127 -0.0125 -4 -12 ]
[.34127 -0.0125 4 0 ]
[.5 -0.0125 -7 -12 ]
[.5 -0.0125 7 0 ]
[.65873 -0.0125 -4 -12 ]
[.65873 -0.0125 4 0 ]
[.81746 -0.0125 -7 -12 ]
[.81746 -0.0125 7 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12 -24 ]
[.5 -0.0125 12 -12 ]
[-0.0125 .01471 -8 -6 ]
[-0.0125 .01471 0 6 ]
[-0.0125 .13243 -8 -6 ]
[-0.0125 .13243 0 6 ]
[-0.0125 .25015 -8 -6 ]
[-0.0125 .25015 0 6 ]
[-0.0125 .36787 -8 -6 ]
[-0.0125 .36787 0 6 ]
[-0.0125 .4856 -8 -6 ]
[-0.0125 .4856 0 6 ]
[-0.0125 .60332 -12 -6 ]
[-0.0125 .60332 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24 -44 ]
[-0.01875 .30902 -12 44 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .13243 m
1 .13243 L
s
0 .25015 m
1 .25015 L
s
0 .36787 m
1 .36787 L
s
0 .4856 m
1 .4856 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -73 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(V) show
82.937500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01471 m
.00625 .01471 L
s
gsave
-0.0125 .01471 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .13243 m
.00625 .13243 L
s
gsave
-0.0125 .13243 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .25015 m
.00625 .25015 L
s
gsave
-0.0125 .25015 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .36787 m
.00625 .36787 L
s
gsave
-0.0125 .36787 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07357 m
.00375 .07357 L
s
0 .103 m
.00375 .103 L
s
0 .16186 m
.00375 .16186 L
s
0 .19129 m
.00375 .19129 L
s
0 .22072 m
.00375 .22072 L
s
0 .27958 m
.00375 .27958 L
s
0 .30901 m
.00375 .30901 L
s
0 .33844 m
.00375 .33844 L
s
0 .3973 m
.00375 .3973 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10 translate
90 rotate
-105 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Josc) show
78.625000 13.000000 moveto
(in) show
86.812500 13.000000 moveto
(pA) show
98.562500 13.000000 moveto
(over) show
114.687500 13.000000 moveto
(100) show
128.687500 13.000000 moveto
(nm) show
138.875000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(^) show
142.625000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
146.625000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .13243 m
1 .13243 L
s
.99375 .25015 m
1 .25015 L
s
.99375 .36787 m
1 .36787 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07357 m
1 .07357 L
s
.99625 .103 m
1 .103 L
s
.99625 .16186 m
1 .16186 L
s
.99625 .19129 m
1 .19129 L
s
.99625 .22072 m
1 .22072 L
s
.99625 .27958 m
1 .27958 L
s
.99625 .30901 m
1 .30901 L
s
.99625 .33844 m
1 .33844 L
s
.99625 .3973 m
1 .3973 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .01472 m
.04262 .01472 L
.06244 .01472 L
.08255 .01473 L
.10458 .01474 L
.12415 .01475 L
.14509 .01477 L
.16639 .0148 L
.18653 .01483 L
.20651 .01487 L
.22495 .01492 L
.24367 .01499 L
.2643 .01509 L
.28371 .01521 L
.30459 .01537 L
.32572 .01559 L
.34581 .01586 L
.36562 .01619 L
.384 .01658 L
.42313 .01773 L
.44454 .01861 L
.46472 .01965 L
.50327 .02237 L
.52321 .02427 L
.54427 .02673 L
.58224 .03267 L
.60175 .03667 L
.62267 .04186 L
.64248 .04778 L
.66403 .05553 L
.70387 .07437 L
.74465 .10156 L
.78392 .13793 L
.82167 .18541 L
.86187 .25369 L
.90056 .34182 L
.9417 .46687 L
.97619 .60332 L
s
[ .02 ] 0 setdash
.02381 .01472 m
.04262 .01473 L
.0522 .01473 L
.06244 .01473 L
.07286 .01473 L
.08255 .01473 L
.10458 .01474 L
.1148 .01474 L
.12589 .01474 L
.13547 .01474 L
.14603 .01475 L
.16586 .01475 L
.17672 .01476 L
.18689 .01477 L
.19727 .01477 L
.20714 .01478 L
.22566 .01481 L
.23525 .01482 L
.24547 .01484 L
.26386 .0149 L
.27414 .01493 L
.28527 .01499 L
.29577 .01506 L
.30544 .01513 L
.32426 .01534 L
.33495 .01551 L
.34493 .01571 L
.35538 .01598 L
.36528 .01629 L
.38383 .01704 L
.42216 .01902 L
.44155 .01986 L
.45259 .02023 L
.46295 .02051 L
.48343 .02096 L
.50221 .02136 L
.52106 .02185 L
.5409 .02255 L
.56064 .02353 L
.57901 .02478 L
.59947 .02668 L
.61805 .02904 L
.63724 .03237 L
.65804 .03741 L
.67791 .04422 L
.68793 .04865 L
.69895 .05451 L
.7184 .06803 L
.73929 .08843 L
.76047 .11699 L
Mistroke
.78057 .15202 L
.81882 .23101 L
.84017 .27099 L
.85951 .29906 L
.8797 .32041 L
.8987 .33603 L
.9373 .36845 L
.95622 .39027 L
.97619 .42081 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{146, 90},
  ImageMargins->{{87, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002g0000LA000`40l00?003`]ooo002gool00;Oo
o`00]ooo001Oool00`0?ooooo`02ool01@0?ool03ooo00l01?oo0P0?B?oo001Oool00`0?ooooo`02
ool01@0?ool03ooo00l01?oo0P0?B?oo001Nool00`0?ool03`03ool01@0?ool03ooo00l00ooo00@0
3oooool03dOoo`00G_oo00<03ooo00l00ooo00@03ooo00l03`Coo`0400oooooo00m7ool006coo`04
00oooooo00m7ool006Coo`0300oooooo053oo`00]ooo002gool00;Ooo`00]ooo002gool00;Ooo`00
9_oo0P0?4Ooo0P0?0_oo00@03ooo00l03a7oo`0300oooooo00ooo`0500oooooo00ooo`0200lAool0
0`0?ooooo`0@ool01@0?ooooo`0?ool00P0?4Ooo00<03oooool03Ooo000Xool00`0?ooooo`0@ool0
0`0?ooooo`03ool00`0?ooooo`0=ool00`0?ool03`0?ool00`0?ool03`05ool00`0?ooooo`0>ool0
0`0?ooooo`0@ool00`0?ooooo`04ool00`0?ooooo`0=ool00`0?ool03`0>ool002Koo`803a7oo`80
3`Coo`803a3oo`803a3oo`803`Coo`803a;oo`0300oooooo013oo`0400ooooooool200lAool00`0?
ooooo`0=ool002Koo`0300oooooo013oo`0300oooooo00?oo`0300oooooo00ooo`0300oooooo00oo
o`0300oooooo00?oo`0300oooooo017oo`0300oooooo013oo`0500ooooooool03`0Aool00`0?ool0
3`0>ool002Koo`<03a3oo`<03`?oo`<03a3oo`803a3oo`803`?oo`<03`ooo`<03a3oo`<03`?oo`<0
3a3oo`0300oooooo00goo`00]ooo002gool00;Ooo`00]ooo000Nool00`0?ooooo`2Fool000koo`03
00oooooo00;oo`0300oooooo00Ooo`0300ooo`0?00GoohL03`_oo`003_oo1@0?2_oo00<03ooo00l0
1Ooo00@03oooool03aCoo`0300oooooo01;oo`0300oooooo01?oo`0300oooooo01;oo`0300oooooo
01;oo`0300oooooo01;oo`0500ooooooool03`0;ool000koo`0300oooooo00coo`0300ooo`0?00Go
o`0300oooooo03l03`03ool0Sooo01?oo`0307oooooo01;oo`0308oooooo01Goo`803`_oo`004Ooo
0P0?2ooo00<03oooool01?oo00<03oooool05Ooo00<0Soooool04_oo00<0Ooooool04Ooo2`0?0_oo
0`0?1ooo00<0Soooool04_oo00<0Ooooool05_oo00<03oooool02Ooo000@ool0100?ooooo`0?4Ooo
00<03oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo00<0Soooool01?oo1`0?0_oo100?00?o
o`1oool04ooo00<0Soooool05_oo00<03oooool02Ooo000@ool0100?ooooo`0?4Ooo00<03oooool0
5Ooo00<0Soooool04_oo00<0Ooooool04ooo00<0Ooooool02_oo1@0?0ooo0`0?4_oo00<0Ooooool0
5_oo00<03oooool02Ooo000Aool200lBool00`0?ooooo`0Eool00`1oooooo`0Bool00`2?ooooo`0C
ool00`2?ooooo`0>ool400l0101oool03`0?4Ooo00<0Soooool05Ooo0P0?2ooo000Aool00`0?ool0
3`0Aool00`0?ooooo`0Eool00`2?ooooo`0Bool00`1oooooo`0Cool00`1oooooo`0Aool300l3ool2
00l>ool00`1oooooo`0Fool00`0?ooooo`09ool0013oo`803`03ool03ooo013oo`0300oooooo01Go
o`0307oooooo01;oo`0308oooooo01?oo`0308oooooo01;oo`0307l03`0?00803`;oo`0300oooooo
00_oo`0308oooooo01Koo`0300oooooo00Woo`004?oo00<03ooo00l04_oo00<03oooool05Ooo00<0
Soooool04_oo00<0Ooooool04ooo00<0Ooooool04_oo00@0Soooooooo`@03`goo`0307oooooo01Ko
o`0300oooooo00Woo`004Ooo0P0?4_oo00<03oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo
00<0Soooool04_oo00<0Ooooool00ooo0P0?00?oo`0?ool02_oo00<0Soooool05Ooo0P0?2ooo000@
ool0100?ooooo`0?4Ooo00<03oooool05Ooo00<0Soooool04_oo00<0Ooooool04ooo00<0Ooooool0
4_oo00<0Soooool01?oo100?2_oo00<0Ooooool05_oo00<03oooool02Ooo000@ool200l00ooo00oo
o`0@ool00`0?ooooo`0Eool00`1oooooo`0Bool00`2?ooooo`0Cool00`2?ooooo`0Bool00`1ooooo
o`06ool300l9ool00`2?ooooo`0Fool00`0?ooooo`09ool002Goo`0300oooooo01Goo`0308oooooo
01;oo`0307oooooo01?oo`0307oooooo01;oo`0308oooooo00Ooo`<03`Soo`0307oooooo01Goo`80
3`_oo`009Ooo00<03oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo00<0Soooool04_oo00<0
Ooooool02Ooo0P0?1ooo00<0Soooool05_oo00<03oooool02Ooo000Aool00`0?ool03`09ool300l5
ool00`0?ooooo`0Eool00`2?ooooo`0Bool00`1oooooo`0Cool00`1oooooo`0Bool00`2?ooooo`0:
ool200l6ool00`1oooooo`0Fool00`0?ooooo`09ool000koo`0300ooo`0?00<03`Woo`0300oooooo
00Goo`0300oooooo01Goo`0307oooooo01;oo`0308oooooo01?oo`0308oooooo01;oo`0307oooooo
00_oo`803`Goo`0308oooooo01Koo`0300oooooo00Woo`004?oo100?2_oo00<03oooool01?oo06H0
3`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l300l0701o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?0P0?2ooo000@ool0100?ooooo`0?2Ooo00<03ooo00l01Ooo
00<03oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo00<0Soooool04_oo00<0Ooooool03Ooo
0P0?0ooo00<0Soooool05_oo00<03oooool02Ooo000@ool00`0?ooooo`0;ool200l5ool00`0?oooo
o`0Eool00`2?ooooo`0Bool00`1oooooo`0Cool00`1oooooo`0Bool00`2?ooooo`0=ool300l2ool0
0`1oooooo`0Fool00`0?ooooo`09ool0017oo`<03a7oo`0300oooooo01Goo`0307oooooo01;oo`03
08oooooo01?oo`0308oooooo01;oo`0307oooooo00goo`0300ooo`0?00;oo`0308oooooo01Koo`03
00oooooo00Woo`009Ooo00<03oooool05Ooo00<0Soooool04_oo00<0Ooooool04ooo00<0Ooooool0
4_oo00<0Soooool03_oo00D03ooo00ooo`1o01Ooo`803`_oo`009Ooo00<03oooool05Ooo00<0Oooo
ool04_oo00<0Soooool04ooo00<0Soooool04_oo00<0Ooooool04?oo0P0?00<0Soooool05_oo00<0
3oooool02Ooo000@ool600l?ool00`0?ooooo`0Eool00`2?ooooo`0Bool00`1oooooo`0Cool00`1o
ooooo`0Bool00`2?ooooo`0Aool200lHool00`0?ooooo`09ool0013oo`0600oooooo00ooo`0?3ooo
00<03oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo00<0Soooool04_oo00<0Ooooool03ooo
00<03oooool00P0?5ooo00<03oooool02Ooo000@ool0100?ooooo`0?4Ooo00<03oooool05Ooo00<0
Soooool04_oo00<0Ooooool04ooo00<0Ooooool04_oo00<0Soooool04?oo00@03ooo07l03aKoo`80
3`_oo`004Ooo0P0?4_oo00<03oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo00<0Soooool0
4_oo00<0Ooooool04?oo00<03ooo08l00P0?5_oo00<03oooool02Ooo000Cool00`0?ooooo`0?ool0
0`0?ooooo`0Eool00`2?ooooo`0Bool00`1oooooo`0Cool00`1oooooo`0Bool00`2?ooooo`0Bool0
0`1oool03`0Fool00`0?ooooo`09ool0017oo`<03a7oo`0300oooooo01Goo`0307oooooo01;oo`03
08oooooo01?oo`0308oooooo01;oo`0307oooooo01;oo`0408ooo`0?00lEool00`0?ooooo`09ool0
00koo`@03a?oo`0300oooooo01Goo`0308oooooo01;oo`0307oooooo01?oo`0307oooooo01;oo`03
08oooooo017oo`803`;oo`803a?oo`803`_oo`003ooo0`0?4ooo00<03oooool05Ooo00<0Ooooool0
4_oo00<0Soooool04ooo00<0Soooool04_oo00<0Ooooool04_oo00D03oooooooo`0?01Coo`0300oo
oooo00Woo`004_oo0P0?2ooo00<03oooool00ooo00<03oooool05Ooo00<0Soooool04_oo00<0Oooo
ool04ooo00<0Ooooool04_oo00<0Soooool04_oo0P0?0_oo0P0?4ooo00<03oooool02Ooo000Cool0
0`0?ooooo`07ool300l5ool00`0?ooooo`0Eool00`1oooooo`0Bool00`2?ooooo`0Cool00`2?oooo
o`0Bool00`1oooooo`0Bool00`2?ooooo`02ool00`0?ooooo`0Aool00`0?ooooo`09ool001goo`03
00ooo`0?00Goo`1b00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o
0P0?0140S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00803`_oo`007_oo0P0?1Ooo00<0
3oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo00<0Soooool04_oo00<0Ooooool04_oo00<0
Sooo00l00ooo00<03oooool04?oo00<03oooool02Ooo000Aool200l<ool00`0?ooooo`03ool00`0?
ooooo`0Eool00`2?ooooo`0Bool00`1oooooo`0Cool00`1oooooo`0Bool00`2?ooooo`0Bool0101o
ooooo`0?0_oo0P0?4Ooo00<03oooool02Ooo000@ool0100?ooooo`0?4Ooo00<03oooool05Ooo00<0
Ooooool04_oo00<0Soooool04ooo00<0Soooool04_oo00<0Ooooool04_oo00@0Soooool03`?oo`03
00oooooo00ooo`0300oooooo00Woo`004?oo00@03oooool03a7oo`0300oooooo01Goo`0308oooooo
01;oo`0307oooooo01?oo`0307oooooo01;oo`0308oooooo01;oo`0307oooooo00Coo`803`ooo`80
3`_oo`004Ooo0P0?4_oo00<03oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo00<0Soooool0
4_oo00<0Ooooool04_oo00<0Soooool00_oo00@03oooool03a3oo`0300oooooo00Woo`004?oo00<0
3oooool04_oo00<03oooool05Ooo00<0Soooool04_oo00<0Ooooool04ooo00<0Ooooool04_oo00<0
Soooool04_oo00<0Ooooool00_oo00<03oooool00P0?3ooo00<03oooool02Ooo000@ool200lCool0
0`0?ooooo`0Eool00`1oooooo`0Bool00`2?ooooo`0Cool00`2?ooooo`0Bool00`1oooooo`0Bool0
0`2?ooooo`03ool0100?ooooo`0?3ooo00<03oooool02Ooo000Bool200lAool00`0?ooooo`0Eool0
0`2?ooooo`0Bool00`1oooooo`0Cool00`1oooooo`0Bool00`2?ooooo`0Bool00`1oooooo`06ool2
00l=ool200l;ool0013oo`803a?oo`0300oooooo01Goo`0307oooooo01;oo`0308oooooo01?oo`03
08oooooo01;oo`0307oooooo01;oo`0308oooooo00Goo`0300ooo`0?00koo`0300oooooo00Woo`00
4Ooo0P0?4_oo00<03oooool05Ooo00<0Soooool04_oo00<0Ooooool04ooo00<0Ooooool04_oo00<0
Soooool04_oo00<0Ooooool01Ooo0`0?3_oo00<03oooool02Ooo000@ool200l00ooo00ooo`0@ool0
0`0?ooooo`0Eool00`1oooooo`0Bool00`2?ooooo`0Cool00`2?ooooo`0Bool00`1oooooo`0Bool0
0`2?ooooo`07ool200l=ool00`0?ooooo`09ool0013oo`803`03ool03ooo013oo`0300oooooo01Go
o`0308oooooo01;oo`0307oooooo01?oo`0307oooooo01;oo`0308oooooo01;oo`0307oooooo00So
o`0300oooooo00[oo`803`_oo`004_oo0P0?2_oo00<03oooool01?oo00<03oooool05Ooo00<0Oooo
ool04_oo00<0Soooool04ooo00<0Soooool04_oo00<0Ooooool04_oo00<0Soooool02?oo0`0?2ooo
00<03oooool02Ooo000@ool400l9ool00`0?ool03`05ool00`0?ooooo`0Eool00`2?ooooo`0Bool0
0`1oooooo`0Cool00`1oooooo`0Bool00`2?ooooo`0Bool00`1oooooo`09ool00`0?ool03`0:ool0
0`0?ooooo`09ool0013oo`0400oooooo00l9ool200l6ool00`0?ooooo`0Eool00`1oooooo`0Bool0
0`2?ooooo`0Cool00`2?ooooo`0Bool00`1oooooo`0Bool00`2?ooooo`09ool00`0?ooooo`0:ool0
0`0?ooooo`09ool001goo`0300oooooo00Goo`1i00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l00P0?00X0O`2?00l0S`1o08l0O`2?07l0S`80
3`_oo`007_oo0P0?1Ooo00<03oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo00<0Soooool0
4_oo00<0Ooooool04_oo00<0Soooool02_oo00D03oooooooo`0?00Ooo`0300oooooo00Woo`009Ooo
00<03oooool05Ooo00<0Soooool04_oo00<0Ooooool04ooo00<0Ooooool04_oo00<0Soooool04_oo
00<0Ooooool02_oo00<03oooool00_oo00<03oooool01?oo00<03oooool02Ooo000?ool01@0?oooo
oooo00l04Ooo00<03oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo00<0Soooool04_oo00<0
Ooooool04_oo00<0Soooool02_oo0P0?2_oo00<03oooool02Ooo000>ool600lAool00`0?ooooo`0E
ool00`2?ooooo`0Bool00`1oooooo`0Cool00`1oooooo`0Bool00`2?ooooo`0Bool00`1oooooo`0;
ool00`0?ooooo`03ool0100?oooooooo0P0?2ooo000Cool00`0?ooooo`0?ool00`0?ooooo`0Eool0
0`1oooooo`0Bool00`2?ooooo`0Cool00`2?ooooo`0Bool00`1oooooo`0Bool00`2?ooooo`0;ool0
0`0?ooooo`03ool00`0?ooooo`02ool00`0?ooooo`09ool000ooo`@03a;oo`0300oooooo01Goo`03
08oooooo01;oo`0307oooooo01?oo`0307oooooo01;oo`0308oooooo01;oo`0307oooooo00_oo`80
3`Goo`0500ooooooool03`0;ool000koo`0300oooooo00;oo`0300oooooo00ooo`0300oooooo01Go
o`0307oooooo01;oo`0308oooooo01?oo`0308oooooo01;oo`0307oooooo01;oo`0308oooooo00co
o`0300oooooo00Ooo`0300oooooo00Woo`003_oo00<03oooool00_oo00<03oooool03ooo00<03ooo
ool05Ooo00<0Soooool04_oo00<0Ooooool04ooo00<0Ooooool04_oo00<0Soooool04_oo00<0Oooo
ool03?oo00<03oooool01_oo0P0?2ooo000?ool400lBool00`0?ooooo`0Eool00`1oooooo`0Bool0
0`2?ooooo`0Cool00`2?ooooo`0Bool00`1oooooo`0Bool00`2?ooooo`0<ool200l8ool00`0?oooo
o`09ool000ooo`@03a;oo`0300oooooo01Goo`0308oooooo01;oo`0307oooooo01?oo`0307oooooo
01;oo`0308oooooo01;oo`0307oooooo00goo`0300oooooo00Koo`0300oooooo00Woo`003_oo00<0
3oooool00_oo00<03oooool03ooo00<03oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo00<0
Soooool04_oo00<0Ooooool04_oo00<0Soooool03Ooo00<03oooool01_oo00<03oooool02Ooo000>
ool00`0?ooooo`02ool00`0?ooooo`0?ool00`0?ooooo`0Eool00`2?ooooo`0Bool00`1oooooo`0C
ool00`1oooooo`0Bool00`2?ooooo`0Bool00`1oooooo`0=ool200l6ool200l;ool000ooo`@03`_o
o`0300oooooo00Coo`0300oooooo01Goo`0307oooooo01;oo`0308oooooo01?oo`0308oooooo01;o
o`0307oooooo01;oo`0308oooooo00koo`0300oooooo00Goo`0300oooooo00Woo`007Ooo00<03ooo
00l01Ooo00<03oooool05Ooo00<0Soooool04_oo00<0Ooooool04ooo00<0Ooooool04_oo00<0Sooo
ool04_oo00<0Ooooool03_oo00<03oooool01Ooo00<03oooool02Ooo000Nool00`0?ooooo`04ool0
0`0?ooooo`0Eool00`1oooooo`0Bool00`2?ooooo`0Cool00`2?ooooo`0Bool00`1oooooo`0Bool0
0`2?ooooo`0>ool00`0?ooooo`05ool00`0?ooooo`09ool0013oo`@03`Woo`0300ooo`0?00Goo`1n
00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o0P0?00D0S`1o08l0O`2?00803`_oo`004?oo00@03oooool03`[oo`0300oooooo
00Coo`0300oooooo01Goo`0307oooooo01;oo`0308oooooo01?oo`0308oooooo01;oo`0307oooooo
01;oo`0308oooooo00ooo`0300oooooo00Coo`0300oooooo00Woo`004?oo00<03oooool04_oo00<0
3oooool05Ooo00<0Soooool04_oo00<0Ooooool04ooo00<0Ooooool04_oo00<0Soooool04_oo00<0
Ooooool03ooo00<03oooool01?oo00<03oooool02Ooo000Aool300lAool00`0?ooooo`0Eool00`1o
ooooo`0Bool00`2?ooooo`0Cool00`2?ooooo`0Bool00`1oooooo`0Bool00`2?ooooo`0?ool00`0?
ooooo`04ool00`0?ooooo`09ool002Goo`0300oooooo01Goo`0308oooooo01;oo`0307oooooo01?o
o`0307oooooo01;oo`0308oooooo01;oo`0307oooooo00ooo`803`Coo`803`_oo`004?oo100?4Ooo
00<03oooool05Ooo00<0Ooooool04_oo00<0Soooool04ooo00<0Soooool04_oo00<0Ooooool04_oo
00<0Soooool04?oo00<03oooool00ooo00<03oooool02Ooo000@ool00`0?ooooo`0Bool00`0?oooo
o`0Eool00`2?ooooo`0Bool00`1oooooo`0Cool00`1oooooo`0Bool00`2?ooooo`0Bool00`1ooooo
o`0@ool00`0?ooooo`03ool00`0?ooooo`09ool0017oo`<03a7oo`0300oooooo01Goo`0307oooooo
01;oo`0308oooooo01?oo`0308oooooo01;oo`0307oooooo01;oo`0308oooooo013oo`0300oooooo
00?oo`0300oooooo00Woo`004?oo00<03oooool04_oo00<03oooool05Ooo00<0Soooool04_oo00<0
Ooooool04ooo00<0Ooooool04_oo00<0Soooool04_oo00<0Ooooool04?oo0P0?0ooo0P0?2ooo000A
ool300lAool00`0?ooooo`0Eool00`1oooooo`0Bool00`2?ooooo`0Cool00`2?ooooo`0Bool00`1o
ooooo`0Bool00`2?ooooo`0Aool00`0?ooooo`02ool00`0?ooooo`09ool000ooo`803aCoo`0300oo
oooo01Goo`0308oooooo01;oo`0307oooooo01?oo`0307oooooo01;oo`0308oooooo01;oo`0307oo
oooo017oo`0300oooooo00;oo`0300oooooo00Woo`003_oo00<03oooool05?oo00<03oooool05Ooo
00<0Ooooool04_oo00<0Soooool04ooo00<0Soooool04_oo00<0Ooooool04_oo00<0Soooool04Ooo
00<03oooool00_oo00<03oooool02Ooo000?ool200lDool00`0?ooooo`0Eool00`2?ooooo`0Bool0
0`1oooooo`0Cool00`1oooooo`0Bool00`2?ooooo`0Bool00`1oooooo`0Aool200l2ool200l;ool0
01Woo`<03`;oo`0300oooooo00Coo`0300oooooo01Goo`0307oooooo01;oo`0308oooooo01?oo`03
08oooooo01;oo`0307oooooo01;oo`0308oooooo01;oo`0500ooooooool03`0;ool000ooo`0300oo
oooo00Soo`0600oooooo00ooo`0?1Ooo00<03oooool05Ooo00<0Soooool04_oo00<0Ooooool04ooo
00<0Ooooool04_oo00<0Soooool04_oo00<0Ooooool04_oo00D03oooooooo`0?00_oo`003_oo00@0
3oooooooo`803`Koo`0600oooooo00ooo`0?1Ooo00<03oooool05Ooo00<0Ooooool04_oo00<0Sooo
ool04ooo00<0Soooool04_oo00<0Ooooool04_oo00<0Soooool04_oo00<03oooool00P0?2ooo000>
ool01P0?ooooo`0?ool03`Koo`0600oooooo00ooo`0?1Ooo00<03oooool05Ooo00<0Soooool04_oo
00<0Ooooool04ooo00<0Ooooool04_oo00<0Soooool04_oo00<0Ooooool05_oo00<03oooool02Ooo
000?ool200l2ool00`0?ooooo`03ool200l3ool00`0?ooooo`04oon700l;ool00;Ooo`00]ooo002g
ool00;Ooo`00\
\>"],
  ImageRangeCache->{{{0, 181.5}, {111.5, 0}} -> {4.052244, -3.379062, 
  0.029392, 0.158521}}]
}, Open  ]],

Cell[BoxData[{
    \(\(Clear[G]; \)\), 
    \(G[v_] := 
      \(-\(\(v\ Log[Josc[v, 0]\/\(B1\ \((v\/d)\)\^2\)]\ nano\)\/d\)\) /. case1
        \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(F[v_] := \(v\ nano\)\/d /. case1\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig11x5 = 
      ParametricPlot[{F[v], G[v]}, {v, 5, 8}, 
        FrameLabel \[Rule] {"\<F in V over nm\>", "\<G in V over nm\>"}, 
        Evaluate[opt]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
-1.563492 0.952381 -10.71133 0.239413 [
[.15079 -0.0125 -7 -12 ]
[.15079 -0.0125 7 0 ]
[.34127 -0.0125 -4 -12 ]
[.34127 -0.0125 4 0 ]
[.53175 -0.0125 -7 -12 ]
[.53175 -0.0125 7 0 ]
[.72222 -0.0125 -7 -12 ]
[.72222 -0.0125 7 0 ]
[.9127 -0.0125 -7 -12 ]
[.9127 -0.0125 7 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26.5 -24 ]
[.5 -0.0125 26.5 -12 ]
[-0.0125 .06225 -12 -6 ]
[-0.0125 .06225 0 6 ]
[-0.0125 .18196 -18 -6 ]
[-0.0125 .18196 0 6 ]
[-0.0125 .30167 -12 -6 ]
[-0.0125 .30167 0 6 ]
[-0.0125 .42137 -18 -6 ]
[-0.0125 .42137 0 6 ]
[-0.0125 .54108 -12 -6 ]
[-0.0125 .54108 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30 -27 ]
[-0.01875 .30902 -18 27 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.15079 0 m
.15079 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.53175 0 m
.53175 .61803 L
s
.72222 0 m
.72222 .61803 L
s
.9127 0 m
.9127 .61803 L
s
0 .06225 m
1 .06225 L
s
0 .18196 m
1 .18196 L
s
0 .30167 m
1 .30167 L
s
0 .42137 m
1 .42137 L
s
0 .54108 m
1 .54108 L
s
0 g
.15079 0 m
.15079 .00625 L
s
gsave
.15079 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.53175 0 m
.53175 .00625 L
s
gsave
.53175 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.72222 0 m
.72222 .00625 L
s
gsave
.72222 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.9127 0 m
.9127 .00625 L
s
gsave
.9127 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.19841 0 m
.19841 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.29365 0 m
.29365 .00375 L
s
.38889 0 m
.38889 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.48413 0 m
.48413 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.6746 0 m
.6746 .00375 L
s
.76984 0 m
.76984 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.86508 0 m
.86508 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.05556 0 m
.05556 .00375 L
s
.00794 0 m
.00794 .00375 L
s
.96032 0 m
.96032 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(F) show
69.437500 13.000000 moveto
(in) show
77.625000 13.000000 moveto
(V) show
85.375000 13.000000 moveto
(over) show
101.500000 13.000000 moveto
(nm) show
111.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .06225 m
.00625 .06225 L
s
gsave
-0.0125 .06225 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(45) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .18196 m
.00625 .18196 L
s
gsave
-0.0125 .18196 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(45.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .30167 m
.00625 .30167 L
s
gsave
-0.0125 .30167 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(46) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .42137 m
.00625 .42137 L
s
gsave
-0.0125 .42137 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(46.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .54108 m
.00625 .54108 L
s
gsave
-0.0125 .54108 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(47) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .08619 m
.00375 .08619 L
s
0 .11014 m
.00375 .11014 L
s
0 .13408 m
.00375 .13408 L
s
0 .15802 m
.00375 .15802 L
s
0 .2059 m
.00375 .2059 L
s
0 .22984 m
.00375 .22984 L
s
0 .25378 m
.00375 .25378 L
s
0 .27772 m
.00375 .27772 L
s
0 .32561 m
.00375 .32561 L
s
0 .34955 m
.00375 .34955 L
s
0 .37349 m
.00375 .37349 L
s
0 .39743 m
.00375 .39743 L
s
0 .44531 m
.00375 .44531 L
s
0 .46926 m
.00375 .46926 L
s
0 .4932 m
.00375 .4932 L
s
0 .51714 m
.00375 .51714 L
s
0 .03831 m
.00375 .03831 L
s
0 .01437 m
.00375 .01437 L
s
0 .56502 m
.00375 .56502 L
s
0 .58896 m
.00375 .58896 L
s
0 .6129 m
.00375 .6129 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -112 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
88 10 translate
90 rotate
-88 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(G) show
70.750000 13.000000 moveto
(in) show
78.937500 13.000000 moveto
(V) show
86.687500 13.000000 moveto
(over) show
102.812500 13.000000 moveto
(nm) show
113.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.15079 .61178 m
.15079 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.53175 .61178 m
.53175 .61803 L
s
.72222 .61178 m
.72222 .61803 L
s
.9127 .61178 m
.9127 .61803 L
s
.125 Mabswid
.19841 .61428 m
.19841 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.29365 .61428 m
.29365 .61803 L
s
.38889 .61428 m
.38889 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.48413 .61428 m
.48413 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.6746 .61428 m
.6746 .61803 L
s
.76984 .61428 m
.76984 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.86508 .61428 m
.86508 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.05556 .61428 m
.05556 .61803 L
s
.00794 .61428 m
.00794 .61803 L
s
.96032 .61428 m
.96032 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06225 m
1 .06225 L
s
.99375 .18196 m
1 .18196 L
s
.99375 .30167 m
1 .30167 L
s
.99375 .42137 m
1 .42137 L
s
.99375 .54108 m
1 .54108 L
s
.125 Mabswid
.99625 .08619 m
1 .08619 L
s
.99625 .11014 m
1 .11014 L
s
.99625 .13408 m
1 .13408 L
s
.99625 .15802 m
1 .15802 L
s
.99625 .2059 m
1 .2059 L
s
.99625 .22984 m
1 .22984 L
s
.99625 .25378 m
1 .25378 L
s
.99625 .27772 m
1 .27772 L
s
.99625 .32561 m
1 .32561 L
s
.99625 .34955 m
1 .34955 L
s
.99625 .37349 m
1 .37349 L
s
.99625 .39743 m
1 .39743 L
s
.99625 .44531 m
1 .44531 L
s
.99625 .46926 m
1 .46926 L
s
.99625 .4932 m
1 .4932 L
s
.99625 .51714 m
1 .51714 L
s
.99625 .03831 m
1 .03831 L
s
.99625 .01437 m
1 .01437 L
s
.99625 .56502 m
1 .56502 L
s
.99625 .58896 m
1 .58896 L
s
.99625 .6129 m
1 .6129 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .0222 m
.02605 .01893 L
.02729 .01752 L
.02846 .01645 L
.02954 .01568 L
.03072 .0151 L
.0318 .0148 L
.03279 .01472 L
.03396 .01485 L
.03506 .01521 L
.03626 .01586 L
.03756 .01686 L
.03891 .01823 L
.0402 .01984 L
.04262 .02363 L
.04753 .03432 L
.0521 .04751 L
.06244 .08679 L
.10458 .29766 L
.14371 .46373 L
.15399 .49703 L
.16512 .52792 L
.17474 .55033 L
.18529 .57035 L
.1956 .58533 L
.20055 .59091 L
.20523 .59524 L
.20778 .59721 L
.21055 .59904 L
.21285 .60031 L
.2154 .60146 L
.21814 .60239 L
.21965 .60276 L
.22033 .6029 L
.22106 .60302 L
.22237 .6032 L
.22358 .60329 L
.22488 .60332 L
.22561 .6033 L
.22629 .60327 L
.22757 .60316 L
.22821 .60307 L
.22892 .60296 L
.23134 .60241 L
.23271 .602 L
.23417 .60146 L
.23682 .60027 L
.24201 .59706 L
.24675 .59313 L
.25629 .58235 L
Mistroke
.26534 .56854 L
.28519 .52614 L
.30359 .47226 L
.34277 .31751 L
.36278 .22732 L
.3733 .18171 L
.3844 .13834 L
.39438 .10612 L
.39966 .09249 L
.40531 .08095 L
.40798 .07669 L
.41051 .07339 L
.41278 .07105 L
.41396 .07007 L
.41525 .06918 L
.41646 .06853 L
.41759 .06807 L
.41878 .06775 L
.42007 .06759 L
.4212 .06762 L
.42239 .0678 L
.42341 .06809 L
.42452 .06855 L
.42585 .06928 L
.42707 .07013 L
.42982 .07266 L
.43225 .0756 L
.43482 .07938 L
.44417 .09869 L
.45416 .12751 L
.46513 .16632 L
.50553 .3315 L
.5444 .46701 L
.55456 .49426 L
.56562 .51958 L
.57517 .53772 L
.58573 .55364 L
.59063 .55956 L
.59591 .56489 L
.60048 .56861 L
.60548 .57175 L
.60824 .57306 L
.61081 .57401 L
.61221 .57442 L
.61353 .57473 L
.61426 .57488 L
.61505 .57501 L
.61576 .57511 L
.61643 .57519 L
.61764 .57528 L
Mistroke
.61828 .57531 L
.61897 .57532 L
.61969 .57531 L
.62037 .57528 L
.62166 .57518 L
.62285 .57503 L
.62396 .57483 L
.62648 .57422 L
.62913 .57331 L
.63156 .57223 L
.63706 .56895 L
.6419 .56509 L
.64702 .56004 L
.65589 .54891 L
.66563 .53329 L
.68515 .49164 L
.70607 .43292 L
.74746 .28651 L
.76817 .21036 L
.77727 .17969 L
.78732 .14954 L
.79627 .12701 L
.80592 .10838 L
.81124 .10094 L
.81356 .09835 L
.81611 .09601 L
.81852 .09426 L
.82077 .09304 L
.82201 .09255 L
.82314 .0922 L
.82444 .09193 L
.82567 .0918 L
.82682 .09178 L
.82807 .09189 L
.82924 .0921 L
.83031 .09239 L
.83156 .09284 L
.83292 .09347 L
.8354 .095 L
.83799 .09709 L
.84075 .09988 L
.8457 .10628 L
.85539 .12358 L
.86416 .14402 L
.90429 .27175 L
.94292 .40063 L
.97619 .48739 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{146, 90},
  ImageMargins->{{87, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002g0000LA000`40l00?003`]ooo002gool00;Oo
o`00]ooo001Dool00`0?ooooo`02ool01P0?ooooo`0?ool03`Coo`803`Goo`0500ooooooool03`03
ool200l00ooo00ooo`03ool02@0?ool03ooo00ooo`0?ool03`0dool005Coo`0300oooooo00;oo`06
00oooooo00ooo`0?1?oo0P0?1?oo00<03ooo00l00_oo00@03oooool03`?oo`0300oooooo00;oo`09
00ooo`0?ool03ooo00ooo`0?03Coo`00E?oo0P0?0ooo00H03oooool03ooo00l3ool0100?ooooo`0?
0ooo00`03ooo00ooo`0?ool03ooo00ooo`0?ool200l3ool02@0?ool03ooo00ooo`0?ool03`0dool0
05Coo`0300oooooo00;oo`0300oooooo00803`Coo`0400oooooo00l4ool01P0?ooooo`0?ool03`;o
o`803`04ool03ooo00l2ool200l2ool200l00ooo00ooo`0dool005?oo`@03`_oo`0400oooooo00mA
ool005Woo`0300oooooo05_oo`00]ooo002gool00;Ooo`00]ooo002gool00;Ooo`00=Ooo0`0?00Go
o`0?ooooo`0?01Koo`<03aGoo`<03`03ool03ooo00<03a;oo`<03`03ool03ooo00;oo`0300oooooo
00ooo`<03`05ool03oooool03`0?ool003Koo`0300oooooo00;oo`0300ooo`0?01Goo`0300oooooo
01Goo`0300oooooo00?oo`0300oooooo01;oo`0300oooooo00?oo`<03a7oo`0300oooooo00?oo`03
00ooo`0?00koo`00=_oo00<03oooool00ooo00<03oooool05Ooo00<03oooool05Ooo00<03oooool0
0ooo00<03oooool04_oo00<03oooool00_oo00<03ooo00l04_oo00<03oooool00_oo0P0?3ooo000f
ool00`0?ooooo`02ool00`0?ool03`0Eool00`0?ool03`0Eool00`0?ool03`03ool00`0?ool03`0B
ool00`0?ool03`04ool200lAool00`0?ool03`03ool00`0?ooooo`0>ool003Goo`803`Goo`0300oo
oooo01Goo`803aKoo`803`Coo`803a?oo`803`Goo`0300oooooo013oo`803`Coo`803`koo`00]ooo
002gool00;Ooo`00]ooo002gool002Goohd03`Goo`009Ooo00<03oooool04_oo00<03oooool06?oo
00<03oooool05ooo00<03oooool06?oo00<03oooool06?oo00<03oooool02Ooo00<03oooool00ooo
000Uool00`0?ooooo`0300l?ool00`2?ooooo`0Hool00`1oooooo`0Gool00`1oooooo`0Hool00`2?
ooooo`0Hool00`1oooooo`09ool00`0?ooooo`03ool002Goo`0500oooooo00ooo`0200l>ool00`1o
ooooo`0Hool00`2?ooooo`0Gool00`2?ooooo`0Hool00`1oooooo`0Hool00`2?ooooo`09ool00`0?
ooooo`03ool002Goo`0300oooooo00?oo`0300oooooo00coo`0308oooooo01Soo`0307oooooo01Oo
o`0307oooooo01Soo`0308oooooo01Soo`0307oooooo00Woo`0300oooooo00?oo`009Ooo00<03ooo
ool00ooo0P0?3Ooo00<0Ooooool06?oo00<0Soooool05ooo00<0Soooool06?oo00<0Ooooool06?oo
00<0Soooool02Ooo00<03oooool00ooo000Lool0100?ool03`0?1Ooo00<03oooool01?oo00<03ooo
ool02ooo00<0Soooool06?oo00<0Ooooool05ooo00<0Ooooool06?oo00<0Soooool06?oo00<0Oooo
ool02Ooo00<03oooool00ooo000Jool300l3ool00`0?ooooo`02ool00`0?ooooo`04ool00`0?oooo
o`0;ool00`1oooooo`0Hool00`2?ooooo`0Gool00`2?ooooo`0Hool00`1oooooo`0Hool00`2?oooo
o`09ool00`0?ooooo`03ool001[oo`0400ooo`0?ool200l5ool200l01@1o08l0O`2?07l00P0?0880
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`803`Goo`006ooo0P0?00?oo`0?ool01Ooo00<03oooool01Ooo00<0
3oooool02_oo00<0Ooooool06?oo00<0Soooool01ooo0`0?3Ooo00<0Soooool06?oo00<0Ooooool0
6?oo00<0Soooool02Ooo00<03oooool00ooo000Lool00`0?ool03`0200l4ool00`0?ooooo`05ool0
0`0?ooooo`0:ool00`2?ooooo`0Hool00`1oooooo`06ool200l00ooo00l03`0<ool00`1oooooo`0H
ool00`2?ooooo`0Hool00`1oooooo`09ool00`0?ooooo`03ool002Goo`0300oooooo00Goo`0300oo
oooo00[oo`0307oooooo01Soo`0308oooooo00Koo`0500ooooooool03`0<ool00`2?ooooo`0Hool0
0`1oooooo`0Hool00`2?ooooo`09ool00`0?ooooo`03ool002Goo`0300oooooo00Goo`803`_oo`03
08oooooo01Soo`0307oooooo00Goo`803`?oo`803`_oo`0307oooooo01Soo`0308oooooo01Soo`03
07oooooo00Woo`0300oooooo00?oo`009Ooo00<03oooool01_oo00<03oooool02Ooo00<0Ooooool0
6?oo00<0Soooool01Ooo00<03oooool00ooo00<03oooool02Ooo00<0Soooool06?oo00<0Ooooool0
2_oo1@0?2Ooo00<0Soooool02Ooo00<03oooool00ooo000Uool00`0?ooooo`06ool00`0?ooooo`09
ool00`2?ooooo`0Hool00`1oooooo`04ool200l5ool00`0?ooooo`09ool00`1oooooo`0Hool00`2?
ooooo`09ool200l3ool00`0?ooooo`07ool00`1oooooo`09ool00`0?ooooo`03ool002Goo`0300oo
oooo00Koo`0300oooooo00Woo`0307oooooo01Soo`0308oooooo00Coo`0300oooooo00Coo`803`[o
o`0308oooooo01Soo`0307oooooo00Woo`0300oooooo00;oo`803`Soo`0308oooooo00Woo`0300oo
oooo00?oo`009Ooo00<03oooool01_oo0P0?2_oo00<0Soooool06?oo00<0Ooooool01?oo00<03ooo
ool01Ooo00<03oooool02?oo00<0Ooooool06?oo00<0Soooool02?oo0P0?1Ooo0P0?1ooo00<0Oooo
ool02Ooo00<03oooool00ooo000Uool00`0?ooooo`07ool00`0?ooooo`08ool00`1oooooo`0Hool0
0`2?ooooo`03ool200l7ool200l9ool00`2?ooooo`0Hool00`1oooooo`08ool00`0?ooooo`05ool0
0`0?ooooo`05ool00`2?ooooo`09ool00`0?ooooo`03ool002Goo`0300oooooo00Ooo`0300oooooo
00Soo`0308oooooo01Soo`0307oooooo00?oo`0300oooooo00Ooo`0300oooooo00Ooo`0307oooooo
01Soo`0308oooooo00Ooo`803`Ooo`0300oooooo00Goo`0307oooooo00Woo`0300oooooo00?oo`00
2_oo0`0?6?oo00<03oooool01ooo00<03oooool02?oo00<0Ooooool06?oo00<0Soooool00ooo00<0
3oooool01ooo00<03oooool01ooo00<0Soooool06?oo00<0Ooooool01ooo00<03oooool01_oo0P0?
1_oo00<0Soooool02Ooo00<03oooool00ooo0009ool01@0?oooooooo00l05ooo00<03oooool01ooo
00<03oooool02?oo00<0Soooool06?oo00<0Ooooool00_oo0P0?2Ooo00<03oooool01ooo00<0Oooo
ool06?oo00<0Soooool01_oo0P0?2Ooo00<03oooool01?oo00<0Ooooool02Ooo00<03oooool00ooo
0008ool00`0?ooooo`02ool00`0?ooooo`0Eool00`0?ooooo`07ool00`0?ooooo`08ool00`1ooooo
o`0Hool00`2?ooooo`02ool00`0?ooooo`08ool200l8ool00`2?ooooo`0Hool00`1oooooo`06ool0
0`0?ooooo`08ool200l5ool00`2?ooooo`09ool00`0?ooooo`03ool000Soo`0600oooooo00ooo`0?
5ooo00<03oooool02?oo00<03oooool01ooo00<0Soooool06?oo00<0Ooooool00_oo00<03oooool0
2Ooo00<03oooool01_oo00<0Ooooool06?oo00<0Soooool01_oo00<03oooool02Ooo00<03oooool0
0ooo00<0Ooooool02Ooo00<03oooool00ooo0008ool200l00ooo00l03`09ool0100?ool03`0?0_oo
00@03ooo00l03`Goo`0300oooooo00Soo`0300oooooo00Ooo`0307oooooo01Soo`0308oooooo00;o
o`0300oooooo00Woo`0300oooooo00Koo`0308oooooo01Soo`0307oooooo00Goo`803`_oo`0300oo
oooo00?oo`0308oooooo00Woo`0300oooooo00?oo`005?oo0`0?0ooo00<03oooool00ooo00<03ooo
ool00_oo00<03oooool02?oo00<03oooool01ooo00<0Soooool06?oo00@0Ooooooooo`803`_oo`03
00oooooo00Koo`0307oooooo01Soo`0308oooooo00Goo`0300oooooo00[oo`803`Coo`0307oooooo
00Woo`0300oooooo00?oo`005?oo00@03ooo00ooo`803`Coo`803`Goo`803`0o08l0O`2?07l0S`1o
08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00803`18
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?0P0?1Ooo000;ool00`0?ool03`07ool200l00ooo00ooo`04
ool00`0?ooooo`04ool00`0?ooooo`08ool00`0?ooooo`07ool00`2?ooooo`0Hool01@1ooooooooo
00l03Ooo00<03oooool01Ooo00<0Ooooool06?oo00<0Soooool01?oo0P0?3Ooo00<03oooool00_oo
00<0Ooooool02Ooo00<03oooool00ooo0008ool00`0?ool03`0300l8ool00`0?ool03`0200l3ool3
00l4ool00`0?ooooo`09ool00`0?ooooo`06ool00`1oooooo`0Hool01@2?oooooooo00l03Ooo00<0
3oooool01Ooo00<0Soooool06?oo00<0Ooooool01?oo00<03oooool03?oo00<03oooool00_oo00<0
Soooool02Ooo00<03oooool00ooo000=ool00`0?ooooo`0Eool00`0?ooooo`09ool00`0?ooooo`06
ool00`2?ooooo`0Hool00`1oooooo`0200l=ool00`0?ooooo`05ool00`1oooooo`0Hool00`2?oooo
o`04ool00`0?ooooo`0<ool200l3ool00`1oooooo`09ool00`0?ooooo`03ool000[oo`@03aOoo`03
00oooooo00Woo`0300oooooo00Koo`0307oooooo01Soo`0408oooooo00l>ool200l6ool00`2?oooo
o`0Hool00`1oooooo`04ool00`0?ooooo`0=ool01@0?oooooooo08l02ooo00<03oooool00ooo000:
ool0100?ooooo`0?5ooo00<03oooool02Ooo00<03oooool01_oo00<0Soooool06?oo00@0Ooooool0
3`ooo`0300oooooo00Coo`0307oooooo01Soo`0308oooooo00?oo`803`ooo`0500ooooooool0O`0;
ool00`0?ooooo`03ool000[oo`0300oooooo01Soo`0300oooooo00Woo`0300oooooo00Koo`0307oo
oooo01Soo`0408oooooo00l?ool00`0?ooooo`04ool00`2?ooooo`0Hool00`1oooooo`03ool00`0?
ooooo`0>ool200l2ool00`2?ooooo`09ool00`0?ooooo`03ool000_oo`<03aOoo`0300oooooo00Wo
o`803`Ooo`0308oooooo01Soo`0407oooooo00l?ool00`0?ooooo`04ool00`1oooooo`0Hool00`2?
ooooo`03ool00`0?ooooo`0?ool0100?ooooo`1o2ooo00<03oooool00ooo000Uool00`0?ooooo`0:
ool00`0?ooooo`05ool00`1oooooo`0Hool0102?ool03`0?3ooo0P0?1Ooo00<0Soooool06?oo00<0
Ooooool00_oo0P0?4Ooo00@03oooool0S`_oo`0300oooooo00?oo`009Ooo00<03oooool02_oo00<0
3oooool01Ooo00<0Soooool06?oo00<0Oooo00l04Ooo00<03oooool00ooo00<0Ooooool06?oo00<0
Soooool00_oo00<03oooool04?oo0P0?00?oo`1oool02_oo00<03oooool00ooo0008ool00`0?oooo
o`0Jool00`0?ooooo`0:ool00`0?ooooo`05ool00`1oooooo`0Hool00`2?ool03`0Aool00`0?oooo
o`03ool00`2?ooooo`0Hool00`1oooooo`02ool00`0?ooooo`0Aool00`0?ool0S`0;ool00`0?oooo
o`03ool000Soo`<03a[oo`0300oooooo00[oo`0300oooooo00Goo`0308oooooo01Soo`0307ooo`0?
017oo`0300oooooo00?oo`0307oooooo01Soo`0308oooooo00;oo`0300oooooo017oo`0300ooo`1o
00_oo`0300oooooo00?oo`002ooo0`0?5ooo00<03oooool02_oo0P0?1_oo00<0Ooooool06?oo00<0
S`0?00l04Ooo0P0?1?oo00<0Soooool06?oo00@0Ooooooooo`803a?oo`803`0308oooooo00Woo`03
00oooooo00?oo`002?oo00@03ooo00l03aWoo`0300oooooo00_oo`0300oooooo00Coo`0308oooooo
01Soo`0307l03ooo01;oo`0300oooooo00;oo`0307oooooo01Soo`0508ooooooool03`0Eool00`0?
07ooo`0:ool00`0?ooooo`03ool000Soo`803a_oo`0300oooooo00_oo`0300oooooo00Coo`0307oo
oooo01Soo`0308l03ooo01;oo`0300oooooo00;oo`0308oooooo01Soo`0507ooooooool03`0Eool0
0`0?08ooo`0:ool00`0?ooooo`03ool001coo`0400oooooo00l5ool00`0?ooooo`0;ool00`0?oooo
o`04ool00`2?ooooo`0Hool00`1o00ooo`0Bool00`0?ooooo`02ool00`1oooooo`0Hool01@2?oooo
oooo00l05Ooo0P0?2ooo00<03oooool00ooo000Jool300l01?oo00ooo`0?1?oo00<03oooool02ooo
00<03oooool01?oo00<0Ooooool06?oo00<0S`0?ool04_oo0P0?0ooo00<0Soooool06?oo00<0Oooo
ool00P0?5_oo00<03oooool02Ooo00<03oooool00ooo000;ool200l=ool0100?ool03ooo0P0?1Ooo
0P0?00`0O`2?07l0S`1o08l0O`2?07l0S`1o08l200l0801o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l200l0F@1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l00P0?1Ooo000:ool0100?oooo
o`0?3Ooo0P0?00?oo`0?ool01Ooo00<03oooool03?oo00<03oooool00ooo00<0Ooooool06?oo00<0
3oooool04ooo00D03oooooooo`2?01[oo`0407oooooo00lGool00`0?ooooo`09ool00`0?ooooo`03
ool000[oo`0400oooooo00l>ool00`0?ooooo`0200l4ool00`0?ooooo`0<ool00`0?ooooo`03ool0
0`2?ooooo`0Hool00`0?ooooo`0Cool01@0?oooooooo07l06_oo00@0Sooo00l03aOoo`803`[oo`03
00oooooo00?oo`002ooo0P0?6?oo00<03oooool03?oo00<03oooool00ooo00<0Ooooool06?oo00<0
3oooool04ooo0P0?0_oo00<0Soooool06?oo00<0Oooo00l06?oo00<0S`0?ool02Ooo00<03oooool0
0ooo000:ool00`0?ooooo`0Hool00`0?ooooo`0<ool200l4ool00`2?ooooo`0Gool200lFool0100?
ooooo`1o6_oo00<0Sooo00l06?oo00<0O`0?ool02Ooo00<03oooool00ooo000:ool200lIool00`0?
ooooo`0=ool00`0?ooooo`02ool00`1oooooo`0Gool00`0?08ooo`0Eool0100?ooooo`2?6_oo00<0
Oooo00l06?oo00<0S`0?00l02Ooo00<03oooool00ooo000<ool200lGool00`0?ooooo`0=ool00`0?
ooooo`02ool00`2?ooooo`0Gool00`0?07ooo`0Eool0100?ooooo`1o6_oo00<0S`0?00l06?oo00<0
Oooo00l02Ooo00<03oooool00ooo000:ool200lIool00`0?ooooo`0=ool00`0?ooooo`02ool00`1o
ooooo`0Gool00`0?08ooo`0Eool200l00ooo08ooo`0Iool00`1o00ooo`0Hool00`2?ool03`09ool0
0`0?ooooo`03ool000_oo`803aSoo`0300oooooo00goo`803`?oo`0308oooooo01Koo`803`0307oo
oooo01Goo`0300ooo`1o01[oo`0308l03ooo01Soo`0407ooo`0?00l8ool00`0?ooooo`03ool000[o
o`803`03ool03ooo01Koo`0300oooooo00koo`0500ooooooool0O`0Hool00`0?ool0S`0Gool00`0?
ool0S`0Jool200lIool0102?ooooo`0?2?oo00<03oooool00ooo000:ool200l00ooo00ooo`0Fool0
0`0?ooooo`0>ool01@0?oooooooo08l06?oo00<03ooo07l05ooo0P0?00<0Ooooool06?oo00<03ooo
ool06?oo00@0Ooooool03`Soo`0300oooooo00?oo`003?oo0P0?5ooo00<03oooool03_oo00D03ooo
ooooo`1o01Soo`0300ooo`2?01Soo`0300l0Sooo01Woo`0300oooooo01Soo`0408oooooo00l8ool0
0`0?ooooo`03ool000[oo`@03aOoo`0300oooooo00koo`803`;oo`0308oooooo01Goo`803`03ool0
Oooo01Ooo`0300l0Oooo01Woo`0300oooooo01Soo`0307oooooo00803`Ooo`0300oooooo00?oo`00
2_oo00@03oooool03aOoo`0300oooooo00ooo`0400oooooo07lGool0100?ooooo`2?6?oo00<03`2?
ool06?oo0P0?6_oo00D0Soooooooo`0?00Ooo`0300oooooo00?oo`005_oo00@03oooool03`;oo`04
00ooo`0?00l5ool00`0?ooooo`0?ool0100?ooooo`2?5ooo00@03oooool0OaSoo`803aWoo`0300l0
Sooo01Woo`0507ooooooool03`07ool00`0?ooooo`03ool001Coo`<03`04ool03ooo00l5ool00`0?
ooooo`02ool00`0?ooooo`0?ool0100?ooooo`1o5ooo00@03oooool0SaWoo`0300oooooo01Ooo`03
00l0Oooo01Woo`0408ooooooool200l6ool00`0?ooooo`03ool000[oo`@03`Koo`0400ooo`0?ool2
00l4ool200l5ool00`0?ooooo`0?ool0100?ooooo`2?5_oo0P0?0_oo00<0Ooooool05ooo00<03ooo
ool05_oo0P0?00<0Soooool06?oo00<0Ooooool00_oo00<03oooool01?oo00<03oooool00ooo000:
ool0100?ooooo`0?1ooo0P0?00?oo`0?ool01?oo00<03oooool01?oo0P0?04P0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l200l0>@2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`0200l0101o08l0O`2?0P0?1Ooo000:ool00`0?ooooo`09ool00`0?ooooo`0200l3
ool300l4ool00`0?ooooo`0@ool00`0?ool0S`0Fool01@0?oooooooo07l06Ooo00<0O`0?ool05_oo
00<03ooo08l06_oo00<0Ooooool00ooo00<03oooool00ooo00<03oooool00ooo000;ool300lGool0
0`0?ooooo`0@ool00`0?ool0O`0Fool01@0?oooooooo08l06Ooo00<0S`0?ool05_oo00<03ooo07l0
6_oo00<0Soooool00ooo00<03oooool00ooo00<03oooool00ooo000Uool00`0?ooooo`0@ool00`0?
ool0S`0Eool200l3ool00`1oooooo`0Gool00`1o00ooo`0Eool200l00ooo08ooo`0Iool00`1ooooo
o`03ool200l4ool00`0?ooooo`03ool000[oo`@03aOoo`0300oooooo013oo`803`0307oooooo01?o
o`0300oooooo00;oo`0308oooooo01Ooo`0308l03`0?01Goo`0400oooooo07lJool00`2?ooooo`04
ool00`0?ooooo`02ool00`0?ooooo`03ool000[oo`0300oooooo01Soo`0300oooooo017oo`0300l0
Sooo01Coo`0300oooooo00;oo`0307oooooo01Ooo`0307ooo`0?01Goo`0400oooooo08lJool00`1o
ooooo`04ool00`0?ooooo`02ool00`0?ooooo`03ool000_oo`<03aOoo`0300oooooo017oo`0300l0
Oooo01Coo`0300oooooo00;oo`0308oooooo01Ooo`0308ooo`0?01Coo`803`;oo`0307oooooo01So
o`0308oooooo00Coo`803`?oo`0300oooooo00?oo`002_oo00<03oooool06?oo00<03oooool04Ooo
0P0?5?oo0P0?1?oo00<0Ooooool05ooo00@0Oooo00l03a?oo`0500ooooooool0S`0Jool00`1ooooo
o`05ool01@0?oooooooo00l01Ooo000;ool300lGool00`0?ooooo`0Bool00`0?ooooo`0Bool00`0?
ooooo`03ool00`2?ooooo`0Gool0102?ooooo`0?4_oo0P0?0ooo00<0Ooooool06?oo00<0Soooool0
1Ooo0P0?0_oo00<03oooool00ooo000Uool00`0?ooooo`0Bool00`0?ooooo`0Bool00`0?ooooo`03
ool00`1oooooo`0Gool0101oooooo`0?4_oo00<03oooool00_oo00<0Soooool06?oo00<0Ooooool0
1_oo00@03oooool03`Goo`009Ooo00<03oooool04_oo00<03oooool04Ooo0P0?1Ooo00<0Soooool0
5ooo00<0Soooool00P0?4Ooo00<03oooool00_oo00<0Ooooool06?oo00<0Soooool02Ooo00<03ooo
ool00ooo000Uool00`0?ooooo`0Bool200lBool00`0?ooooo`04ool00`1oooooo`0Gool01@1ooooo
oooo00l04?oo0P0?1?oo00<0Soooool06?oo00<0Ooooool02Ooo00<03oooool00ooo000Uool00`0?
ooooo`0Bool00`1o00ooo`0Aool00`0?ooooo`04ool00`2?ooooo`0Gool0102?oooooooo0P0?3ooo
00<03oooool00ooo00<0Ooooool06?oo00<0Soooool02Ooo00<03oooool00ooo000Uool00`0?oooo
o`0Bool00`2?00l03`0@ool200l6ool00`1oooooo`0Gool00`1oooooo`02ool00`0?ooooo`0<ool2
00l5ool00`2?ooooo`0Hool00`1oooooo`09ool00`0?ooooo`03ool001coo`0400oooooo00l5ool0
0`0?ooooo`0Bool00`1oool03`0@ool00`0?ooooo`05ool00`2?ooooo`0Gool00`2?ooooo`02ool2
00l=ool00`0?ooooo`04ool00`1oooooo`0Hool00`2?ooooo`09ool00`0?ooooo`03ool001[oo`<0
3`;oo`0300oooooo00?oo`0300oooooo01;oo`0308ooo`0?00ooo`803`Ooo`0307oooooo01Ooo`03
07oooooo00?oo`0300oooooo00[oo`803`Koo`0308oooooo01Soo`0307oooooo00Woo`0300oooooo
00?oo`006_oo00<03ooo00l00ooo00<03oooool00_oo00<03oooool04_oo00@0Oooo00l03`koo`03
00oooooo00Koo`0308oooooo01Ooo`0308oooooo00?oo`803`_oo`0300oooooo00Goo`0307oooooo
01Soo`0308oooooo00Woo`0300oooooo00?oo`006ooo0P0?0ooo00<03oooool00_oo0P0?05X0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l200l0
;@1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0200l5ool001coo`0300ooo`0?00803`Coo`03
00oooooo01;oo`0307oooooo00803`coo`0300oooooo00Ooo`0308oooooo01Ooo`0308oooooo00Co
o`803`Soo`803`Soo`0307oooooo01Soo`0308oooooo00Woo`0300oooooo00?oo`009Ooo00<03ooo
ool04_oo00D0Soooooooo`0?00coo`0300oooooo00Ooo`0307oooooo01Ooo`0307oooooo00Goo`80
3`Koo`803`Woo`0308oooooo01Soo`0307oooooo00Woo`0300oooooo00?oo`009Ooo00<03oooool0
4_oo00@0Ooooooooo`803`[oo`803`Woo`0308oooooo01Ooo`0308oooooo00Koo`803`Coo`803`[o
o`0307oooooo01Soo`0308oooooo00Woo`0300oooooo00?oo`009Ooo00<03oooool04_oo00<0Sooo
ool00_oo00<03oooool01ooo0P0?2_oo00<0Ooooool05ooo00<0Ooooool01ooo1P0?2ooo00<0Sooo
ool06?oo00<0Ooooool02Ooo00<03oooool00ooo000Uool00`0?ooooo`0Bool00`1oooooo`02ool2
00l8ool00`0?ooooo`09ool00`2?ooooo`0Gool00`2?ooooo`0:ool00`0?ooooo`0;ool00`1ooooo
o`0Hool00`2?ooooo`09ool00`0?ooooo`03ool002Goo`0300oooooo01;oo`0308oooooo00?oo`80
3`Koo`803`_oo`0307oooooo01Ooo`0307oooooo01Soo`0308oooooo01Soo`0307oooooo00Woo`03
00oooooo00?oo`009Ooo00<03oooool04_oo00<0Ooooool01?oo0P0?1?oo0P0?3?oo00<0Soooool0
5ooo00<0Soooool06?oo00<0Ooooool06?oo00<0Soooool02Ooo00<03oooool00ooo000Uool00`0?
ooooo`0Bool00`2?ooooo`05ool600l=ool00`1oooooo`0Gool00`1oooooo`0Hool00`2?ooooo`0H
ool00`1oooooo`09ool00`0?ooooo`03ool002Goo`0300oooooo01;oo`0307oooooo01Soo`0308oo
oooo01Ooo`0308oooooo01Soo`0307oooooo01Soo`0308oooooo00Woo`0300oooooo00?oo`009Ooo
S@0?1Ooo0000\
\>"],
  ImageRangeCache->{{{0, 181.5}, {111.5, 0}} -> {1.36244, 44.003288, 0.009351,
   0.037199}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Print["\<C1 = \>", N[nano\ C1 /. case1], "\< [nm/V]\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("C1 = "\[InvisibleSpace]45.7859663580248366`
        \[InvisibleSpace]" [nm/V]"\),
      SequenceForm[ "C1 = ", 45.78596635802483661, " [nm/V]"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Averaged Oscillations"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[C2]; \)\), 
    \(C2[phi_, v_] := \(C1\ d\)\/\(phi\ v\) /. case1\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[bave]; \)\), 
    \(\(bave[v_] := 
      C2[phi, v]\ 
        NIntegrate[
          b[v, En]\ Exp[\(-C2[phi, v]\)\ En], {En, 0, 
            e\ v - phiSi /. case1}]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tbl1 = Table[{v, bave[v]}, {v, 5, 10, .5}]; \)\), 
    \(\(Fig11x6 = 
      ListPlot[tbl1, PlotJoined \[Rule] True, 
        FrameLabel \[Rule] {"\<v in V\>", "\<bave\>"}, Evaluate[opt1]]; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
-0.928571 0.190476 -0.703398 1.129291 [
[.02381 -0.0125 -4 -12 ]
[.02381 -0.0125 4 0 ]
[.21429 -0.0125 -4 -12 ]
[.21429 -0.0125 4 0 ]
[.40476 -0.0125 -4 -12 ]
[.40476 -0.0125 4 0 ]
[.59524 -0.0125 -4 -12 ]
[.59524 -0.0125 4 0 ]
[.78571 -0.0125 -4 -12 ]
[.78571 -0.0125 4 0 ]
[.97619 -0.0125 -6 -12 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12 -24 ]
[.5 -0.0125 12 -12 ]
[-0.0125 .08711 -14 -6 ]
[-0.0125 .08711 0 6 ]
[-0.0125 .20004 -14 -6 ]
[-0.0125 .20004 0 6 ]
[-0.0125 .31296 -14 -6 ]
[-0.0125 .31296 0 6 ]
[-0.0125 .42589 -8 -6 ]
[-0.0125 .42589 0 6 ]
[-0.0125 .53882 -14 -6 ]
[-0.0125 .53882 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26 -9.5 ]
[-0.01875 .30902 -14 9.5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
0 .08711 m
1 .08711 L
s
0 .20004 m
1 .20004 L
s
0 .31296 m
1 .31296 L
s
0 .42589 m
1 .42589 L
s
0 .53882 m
1 .53882 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -73 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(v) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(V) show
82.937500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .08711 m
.00625 .08711 L
s
gsave
-0.0125 .08711 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.7) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .20004 m
.00625 .20004 L
s
gsave
-0.0125 .20004 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .31296 m
.00625 .31296 L
s
gsave
-0.0125 .31296 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.9) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .42589 m
.00625 .42589 L
s
gsave
-0.0125 .42589 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .53882 m
.00625 .53882 L
s
gsave
-0.0125 .53882 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .10969 m
.00375 .10969 L
s
0 .13228 m
.00375 .13228 L
s
0 .15486 m
.00375 .15486 L
s
0 .17745 m
.00375 .17745 L
s
0 .22262 m
.00375 .22262 L
s
0 .24521 m
.00375 .24521 L
s
0 .26779 m
.00375 .26779 L
s
0 .29038 m
.00375 .29038 L
s
0 .33555 m
.00375 .33555 L
s
0 .35814 m
.00375 .35814 L
s
0 .38072 m
.00375 .38072 L
s
0 .40331 m
.00375 .40331 L
s
0 .44848 m
.00375 .44848 L
s
0 .47107 m
.00375 .47107 L
s
0 .49365 m
.00375 .49365 L
s
0 .51624 m
.00375 .51624 L
s
0 .06452 m
.00375 .06452 L
s
0 .04193 m
.00375 .04193 L
s
0 .01935 m
.00375 .01935 L
s
0 .56141 m
.00375 .56141 L
s
0 .58399 m
.00375 .58399 L
s
0 .60658 m
.00375 .60658 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -90.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
70.5 10 translate
90 rotate
-70.5 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(bave) show
78.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08711 m
1 .08711 L
s
.99375 .20004 m
1 .20004 L
s
.99375 .31296 m
1 .31296 L
s
.99375 .42589 m
1 .42589 L
s
.99375 .53882 m
1 .53882 L
s
.125 Mabswid
.99625 .10969 m
1 .10969 L
s
.99625 .13228 m
1 .13228 L
s
.99625 .15486 m
1 .15486 L
s
.99625 .17745 m
1 .17745 L
s
.99625 .22262 m
1 .22262 L
s
.99625 .24521 m
1 .24521 L
s
.99625 .26779 m
1 .26779 L
s
.99625 .29038 m
1 .29038 L
s
.99625 .33555 m
1 .33555 L
s
.99625 .35814 m
1 .35814 L
s
.99625 .38072 m
1 .38072 L
s
.99625 .40331 m
1 .40331 L
s
.99625 .44848 m
1 .44848 L
s
.99625 .47107 m
1 .47107 L
s
.99625 .49365 m
1 .49365 L
s
.99625 .51624 m
1 .51624 L
s
.99625 .06452 m
1 .06452 L
s
.99625 .04193 m
1 .04193 L
s
.99625 .01935 m
1 .01935 L
s
.99625 .56141 m
1 .56141 L
s
.99625 .58399 m
1 .58399 L
s
.99625 .60658 m
1 .60658 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.11905 .18056 L
.21429 .01472 L
.30952 .56431 L
.40476 .0654 L
.5 .37747 L
.59524 .3585 L
.69048 .13626 L
.78571 .43998 L
.88095 .3423 L
.97619 .1991 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{146, 90},
  ImageMargins->{{87, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[TextData["Effective Tunneling Area"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
},
FrontEndVersion->"NeXT 3.0",
ScreenRectangle->{{0, 957}, {0, 768}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{668, 719},
WindowMargins->{{Automatic, 31}, {Automatic, 3}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"NeXTAutomaticEncoding",
Magnification->1.25
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 100, 2, 169, "Title"],

Cell[CellGroupData[{
Cell[1856, 57, 55, 1, 31, "Input"],
Cell[1914, 60, 123, 2, 27, "Message"]
}, Open  ]],
Cell[2052, 65, 87, 2, 64, "Section"],
Cell[2142, 69, 85, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[2252, 75, 89, 2, 64, "Section"],
Cell[2344, 79, 1957, 37, 751, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4338, 121, 97, 2, 64, "Section"],
Cell[4438, 125, 286, 5, 65, "Input"],
Cell[4727, 132, 89, 2, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4853, 139, 108, 2, 64, "Section"],
Cell[4964, 143, 156, 4, 83, "Input"],
Cell[5123, 149, 182, 5, 84, "Input"],

Cell[CellGroupData[{
Cell[5330, 158, 92, 2, 31, "Input"],
Cell[5425, 162, 440, 14, 49, "Print"]
}, Open  ]],
Cell[5880, 179, 131, 3, 80, "Input"],
Cell[6014, 184, 198, 5, 92, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6249, 194, 94, 2, 64, "Section"],
Cell[6346, 198, 139, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[6510, 205, 264, 6, 77, "Input"],
Cell[6777, 213, 247, 5, 27, "Print"]
}, Open  ]],
Cell[7039, 221, 137, 3, 31, "Input"],
Cell[7179, 226, 90, 2, 31, "Input"],
Cell[7272, 230, 132, 3, 48, "Input"],
Cell[7407, 235, 160, 4, 74, "Input"],

Cell[CellGroupData[{
Cell[7592, 243, 207, 5, 98, "Input"],
Cell[7802, 250, 46283, 1208, 233, 14865, 816, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[54134, 1464, 106, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[54265, 1470, 171, 4, 76, "Input"],
Cell[54439, 1476, 236, 5, 27, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[54724, 1487, 95, 2, 64, "Section"],
Cell[54822, 1491, 153, 4, 76, "Input"],

Cell[CellGroupData[{
Cell[55000, 1499, 124, 3, 31, "Input"],
Cell[55127, 1504, 229, 5, 27, "Print"]
}, Open  ]],
Cell[55371, 1512, 145, 3, 75, "Input"],

Cell[CellGroupData[{
Cell[55541, 1519, 128, 3, 55, "Input"],
Cell[55672, 1524, 231, 5, 27, "Print"]
}, Open  ]],
Cell[55918, 1532, 152, 4, 90, "Input"],

Cell[CellGroupData[{
Cell[56095, 1540, 121, 3, 31, "Input"],
Cell[56219, 1545, 225, 5, 27, "Print"]
}, Open  ]],
Cell[56459, 1553, 321, 9, 170, "Input"],

Cell[CellGroupData[{
Cell[56805, 1566, 202, 5, 48, "Input"],
Cell[57010, 1573, 63435, 1691, 233, 19688, 1146, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[120460, 3267, 126, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[120611, 3274, 241, 5, 98, "Input"],
Cell[120855, 3281, 30231, 1062, 123, 15840, 878, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[151101, 4346, 183, 5, 97, "Input"],
Cell[151287, 4353, 91, 2, 52, "Input"],

Cell[CellGroupData[{
Cell[151403, 4359, 219, 5, 65, "Input"],
Cell[151625, 4366, 31432, 1043, 123, 14288, 825, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[183094, 5414, 114, 2, 31, "Input"],
Cell[183211, 5418, 224, 5, 27, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[183484, 5429, 98, 2, 64, "Section"],
Cell[183585, 5433, 133, 3, 77, "Input"],
Cell[183721, 5438, 237, 7, 65, "Input"],

Cell[CellGroupData[{
Cell[183983, 5449, 259, 6, 65, "Input"],
Cell[184245, 5457, 12900, 734, 123, 12734, 728, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],
Cell[197172, 6195, 101, 2, 64, "Section"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

