(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    356716,      12731]*)
(*NotebookOutlinePosition[    357635,      12763]*)
(*  CellTagsIndexPosition[    357591,      12759]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["SCANNING TUNNELING SPECTROSCOPY"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Remove["\<Global`*\>"]\)], "Input"],

Cell[BoxData[
    \(Remove::"rmnsm" \( : \ \) 
      "There are no symbols matching \"\!\(\"Global`*\"\)\"."\)], "Message"]
}, Open  ]],

Cell[TextData["Highlights"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Abstract"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Off[General::"\<spell\>", General::"\<spell1\>"]; \)\), 
    \(\(Needs["\<Graphics`Arrow`\>"]; \)\), 
    \(tera = 10\^12; micro = 1\/10\^6; \), 
    \(giga = 10\^9; nano = 1\/10\^9; \), 
    \(mega = 10\^6; pico = 1\/10\^12; \), 
    \(kilo = 10\^3; femto = 1\/10\^15; \), 
    \(milli = 1\/10.\^3; atto = 1\/10\^18; \), 
    \(\(NSub
       = {c \[Rule] 2.99792458\ 10\^8, e \[Rule] 1.6021773\/10\^19, 
        h \[Rule] 6.6260755\/10.\^34, hbar \[Rule] 1.05457\/10.\^34, 
        K \[Rule] 1.380658\/10\^23, me \[Rule] 9.109389\/10\^31, 
        mu0 \[Rule] \(4.\ \[Pi]\)\/10\^7, eps0 \[Rule] 8.85419\/10\^12}; \)\),
   
    \(ESi = 0.179\ tera; rhoSi = 2330; nuSi = 0.28; \), 
    \(ESiO2 = 0.06\ tera; rhoSiO2 = 2200; nuSiO2 = 0.3; \), 
    \(ESi3N4 = 0.15\ tera; rhoSi3N4 = 3100; nuSi3N4 = 0.24; \), 
    \(EAu = 0.08\ tera; rhoAu = 19300; nuAu = 0.42; \), 
    \(ENi = 0.207\ tera; rhoNi = 8900; nuNi = 0.41; \), 
    \(EW = 0.345\ tera; rhoW = 19300; nuW = 0.28; \), 
    \(EPt = 0.17\ tera; rhoPt = 21400; nuPt = 0.39; \), 
    \(EIr = 0.52\ tera; rhoIr = 22500; nuIr = 0.3; \), 
    \(EHOPG = 0.2\ tera; rhoHOPG = 2250; nuHOPG = 0.3; \), 
    \(EPol = 0.001\ tera; rhoPol = 1000; nuPol = 0.3; \), 
    \(\(xx = 0.8; \)\), 
    \(\(EPtIr = xx\ 0.8\ EPt + \((1 - xx)\)\ EIr; \)\), 
    \(\(rhoPtIr = xx\ rhoPt + \((1 - xx)\)\ rhoIr; \)\), 
    \(\(nuPtIr = 0.3; \)\), 
    \(\(opt
       = {PlotRange \[Rule] All, AxesOrigin \[Rule] {0, 0}, 
        Frame \[Rule] True, GridLines \[Rule] Automatic, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        PlotStyle 
          \[Rule] {Dashing[{.0001}], Dashing[{.0200}], Dashing[{.0200}], 
            Dashing[{.0200}], Dashing[{.0200}], Dashing[{.0001}]}}; \)\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Introduction"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Scanning Tunneling Spectroscopy"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Fermi-Dirac Statistics"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f]; \)\), 
    \(\(f[En_, EF_, v_, T_] = 
      N[1\/\(1 + Exp[\(e\ \((En - EF + v)\)\)\/\(K\ T\)]\) /. NSub]; \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(tblT = {4.2, 77., 300.}; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig12x1 = 
      Plot[{f[En, 0., 0., tblT\[LeftDoubleBracket]1\[RightDoubleBracket]], 
          f[En, 0., 0., tblT\[LeftDoubleBracket]2\[RightDoubleBracket]], 
          f[En, 0., 0., tblT\[LeftDoubleBracket]3\[RightDoubleBracket]]}, {
          En, \(-.1\), .1}, 
        FrameLabel \[Rule] {"\<Energy in eV\>", "\<Probability\>"}, 
        Evaluate[opt]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 4.761905 0.014715 0.588604 [
[.02381 -0.0125 -10 -12 ]
[.02381 -0.0125 10 0 ]
[.2619 -0.0125 -12 -12 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.7381 -0.0125 -9 -12 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -7 -12 ]
[.97619 -0.0125 7 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -23.5 -24 ]
[.5 -0.0125 23.5 -12 ]
[-0.0125 .01472 -8 -6 ]
[-0.0125 .01472 0 6 ]
[-0.0125 .13244 -14 -6 ]
[-0.0125 .13244 0 6 ]
[-0.0125 .25016 -14 -6 ]
[-0.0125 .25016 0 6 ]
[-0.0125 .36788 -14 -6 ]
[-0.0125 .36788 0 6 ]
[-0.0125 .4856 -14 -6 ]
[-0.0125 .4856 0 6 ]
[-0.0125 .60332 -8 -6 ]
[-0.0125 .60332 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26 -20 ]
[-0.01875 .30902 -14 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .13244 m
1 .13244 L
s
0 .25016 m
1 .25016 L
s
0 .36788 m
1 .36788 L
s
0 .4856 m
1 .4856 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -71 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -73 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -70 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -84.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Energy) show
88.000000 13.000000 moveto
(in) show
96.187500 13.000000 moveto
(eV) show
105.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10 translate
90 rotate
-81 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Probability) show
98.312500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .60332 m
.06244 .60332 L
.10458 .60332 L
.14415 .60332 L
.18221 .60332 L
.22272 .60332 L
.26171 .60332 L
.30316 .60332 L
.34309 .60332 L
.3815 .60332 L
.40095 .60332 L
.41127 .60332 L
.42237 .60332 L
.42781 .60332 L
.43049 .60332 L
.43298 .60332 L
.43522 .60332 L
.43648 .60332 L
.43762 .60332 L
.43887 .60332 L
.43958 .60332 L
.44023 .60332 L
.44142 .60332 L
.44268 .60332 L
.44387 .60332 L
.44495 .60332 L
.44619 .60332 L
.44738 .60332 L
.44847 .60332 L
.44947 .60332 L
.45058 .60332 L
.45176 .60332 L
.45293 .60332 L
.4542 .60332 L
.45539 .60332 L
.45649 .60332 L
.45771 .60332 L
.4584 .60332 L
.45904 .60332 L
.46033 .60332 L
.46106 .60332 L
.46172 .60332 L
.46291 .60332 L
.46403 .60332 L
.46525 .60332 L
.46656 .60332 L
.46722 .60332 L
.46794 .60332 L
.46925 .60332 L
.47052 .60332 L
Mistroke
.4717 .60332 L
.4729 .60332 L
.47404 .60332 L
.47506 .60332 L
.47616 .60332 L
.47736 .60332 L
.47863 .60332 L
.47971 .60331 L
.4809 .60331 L
.48157 .60331 L
.4823 .6033 L
.48362 .60327 L
.48491 .60323 L
.4861 .60313 L
.48738 .60293 L
.48811 .60272 L
.4888 .60243 L
.48952 .60198 L
.49018 .60135 L
.4909 .60033 L
.49166 .59869 L
.49287 .59408 L
.49415 .58421 L
.49536 .56597 L
.49646 .53644 L
.49775 .47755 L
.49848 .4307 L
.49916 .37966 L
.50046 .26987 L
.5017 .1747 L
.50287 .10823 L
.50415 .06331 L
.50531 .04053 L
.50639 .02883 L
.50755 .02201 L
.50883 .01821 L
.50947 .01713 L
.51016 .01633 L
.51142 .01549 L
.51252 .01513 L
.51372 .01492 L
.51498 .01481 L
.51615 .01477 L
.51725 .01474 L
.51825 .01473 L
.51941 .01472 L
.5205 .01472 L
.52169 .01472 L
.523 .01472 L
.52366 .01472 L
Mistroke
.52437 .01472 L
.52565 .01472 L
.52693 .01472 L
.52814 .01472 L
.52922 .01472 L
.53041 .01472 L
.53114 .01472 L
.53182 .01472 L
.53311 .01472 L
.53382 .01472 L
.53449 .01472 L
.53521 .01472 L
.53598 .01472 L
.53726 .01472 L
.53845 .01472 L
.53975 .01472 L
.54049 .01472 L
.54115 .01472 L
.54233 .01472 L
.54344 .01472 L
.54466 .01472 L
.54597 .01472 L
.54727 .01472 L
.54792 .01472 L
.54863 .01472 L
.5499 .01472 L
.55108 .01472 L
.55227 .01472 L
.5534 .01472 L
.55442 .01472 L
.55551 .01472 L
.55671 .01472 L
.55798 .01472 L
.55906 .01472 L
.56025 .01472 L
.56092 .01472 L
.56164 .01472 L
.56296 .01472 L
.56424 .01472 L
.56543 .01472 L
.56616 .01472 L
.56684 .01472 L
.56812 .01472 L
.56884 .01472 L
.5695 .01472 L
.57022 .01472 L
.57098 .01472 L
.57218 .01472 L
.57346 .01472 L
.57467 .01472 L
Mistroke
.57577 .01472 L
.57707 .01472 L
.5778 .01472 L
.57847 .01472 L
.57971 .01472 L
.58102 .01472 L
.58222 .01472 L
.58354 .01472 L
.58478 .01472 L
.58593 .01472 L
.58707 .01472 L
.5881 .01472 L
.5893 .01472 L
.59042 .01472 L
.59165 .01472 L
.59296 .01472 L
.59407 .01472 L
.59528 .01472 L
.5966 .01472 L
.59733 .01472 L
.598 .01472 L
.59931 .01472 L
.60054 .01472 L
.60159 .01472 L
.60275 .01472 L
.60396 .01472 L
.6051 .01472 L
.60615 .01472 L
.60712 .01472 L
.60819 .01472 L
.60931 .01472 L
.61045 .01472 L
.61167 .01472 L
.61281 .01472 L
.61386 .01472 L
.61509 .01472 L
.61578 .01472 L
.61642 .01472 L
.6176 .01472 L
.61884 .01472 L
.62005 .01472 L
.62137 .01472 L
.62261 .01472 L
.62377 .01472 L
.62491 .01472 L
.62595 .01472 L
.62715 .01472 L
.62827 .01472 L
.62951 .01472 L
.63081 .01472 L
Mistroke
.63192 .01472 L
.63314 .01472 L
.63446 .01472 L
.6352 .01472 L
.63587 .01472 L
.63717 .01472 L
.63841 .01472 L
.63946 .01472 L
.64062 .01472 L
.64183 .01472 L
.64297 .01472 L
.64403 .01472 L
.645 .01472 L
.64606 .01472 L
.64718 .01472 L
.64832 .01472 L
.64954 .01472 L
.65069 .01472 L
.65174 .01472 L
.65297 .01472 L
.65366 .01472 L
.6543 .01472 L
.65547 .01472 L
.65672 .01472 L
.65793 .01472 L
.65925 .01472 L
.6605 .01472 L
.66166 .01472 L
.6627 .01472 L
.66385 .01472 L
.66505 .01472 L
.66617 .01472 L
.66741 .01472 L
.66872 .01472 L
.66983 .01472 L
.67105 .01472 L
.67237 .01472 L
.67311 .01472 L
.67378 .01472 L
.67509 .01472 L
.67632 .01472 L
.67738 .01472 L
.67854 .01472 L
.67975 .01472 L
.68089 .01472 L
.68195 .01472 L
.68292 .01472 L
.68404 .01472 L
.68511 .01472 L
.68625 .01472 L
Mistroke
.68747 .01472 L
.68862 .01472 L
.68967 .01472 L
.6909 .01472 L
.69159 .01472 L
.69223 .01472 L
.6934 .01472 L
.69464 .01472 L
.69586 .01472 L
.69655 .01472 L
.69719 .01472 L
.69836 .01472 L
.6996 .01472 L
.70071 .01472 L
.70175 .01472 L
.70289 .01472 L
.70413 .01472 L
.70536 .01472 L
.70606 .01472 L
.70671 .01472 L
.70802 .01472 L
.70876 .01472 L
.70943 .01472 L
.71063 .01472 L
.71193 .01472 L
.71316 .01472 L
.71429 .01472 L
.71534 .01472 L
.71648 .01472 L
.71755 .01472 L
.71853 .01472 L
.71967 .01472 L
.72092 .01472 L
.7221 .01472 L
.72319 .01472 L
.72443 .01472 L
.72559 .01472 L
.72664 .01472 L
.72776 .01472 L
.72899 .01472 L
.7303 .01472 L
.73141 .01472 L
.73262 .01472 L
.73393 .01472 L
.73514 .01472 L
.73578 .01472 L
.73647 .01472 L
.7372 .01472 L
.73788 .01472 L
.73913 .01472 L
Mistroke
.74028 .01472 L
.7416 .01472 L
.74286 .01472 L
.74398 .01472 L
.74517 .01472 L
.74629 .01472 L
.74731 .01472 L
.74852 .01472 L
.74982 .01472 L
.75105 .01472 L
.75218 .01472 L
.75339 .01472 L
.75468 .01472 L
.75591 .01472 L
.75703 .01472 L
.75834 .01472 L
.75908 .01472 L
.75976 .01472 L
.76102 .01472 L
.76165 .01472 L
.76235 .01472 L
.76303 .01472 L
.76374 .01472 L
.76502 .01472 L
.76573 .01472 L
.76639 .01472 L
.76712 .01472 L
.7679 .01472 L
.76857 .01472 L
.7693 .01472 L
.76999 .01472 L
.77063 .01472 L
.77183 .01472 L
.77311 .01472 L
.77431 .01472 L
.77563 .01472 L
.77688 .01472 L
.77803 .01472 L
.77917 .01472 L
.78021 .01472 L
.78141 .01472 L
.78253 .01472 L
.78377 .01472 L
.78507 .01472 L
.78618 .01472 L
.7874 .01472 L
.78871 .01472 L
.78945 .01472 L
.79012 .01472 L
.79143 .01472 L
Mistroke
.79266 .01472 L
.79371 .01472 L
.79487 .01472 L
.79608 .01472 L
.79722 .01472 L
.79828 .01472 L
.79925 .01472 L
.80031 .01472 L
.80143 .01472 L
.80258 .01472 L
.8038 .01472 L
.80495 .01472 L
.80599 .01472 L
.80722 .01472 L
.80791 .01472 L
.80855 .01472 L
.80973 .01472 L
.81097 .01472 L
.81218 .01472 L
.8135 .01472 L
.81475 .01472 L
.81591 .01472 L
.81706 .01472 L
.8181 .01472 L
.81929 .01472 L
.82042 .01472 L
.82166 .01472 L
.82296 .01472 L
.82408 .01472 L
.8253 .01472 L
.82662 .01472 L
.82735 .01472 L
.82802 .01472 L
.82933 .01472 L
.83056 .01472 L
.83162 .01472 L
.83278 .01472 L
.834 .01472 L
.83513 .01472 L
.83619 .01472 L
.83716 .01472 L
.83828 .01472 L
.83935 .01472 L
.84049 .01472 L
.84171 .01472 L
.84286 .01472 L
.84391 .01472 L
.84514 .01472 L
.84583 .01472 L
.84647 .01472 L
Mistroke
.84764 .01472 L
.84888 .01472 L
.8501 .01472 L
.85079 .01472 L
.85143 .01472 L
.8526 .01472 L
.85384 .01472 L
.85495 .01472 L
.85599 .01472 L
.85713 .01472 L
.85836 .01472 L
.85959 .01472 L
.86029 .01472 L
.86094 .01472 L
.86226 .01472 L
.86299 .01472 L
.86366 .01472 L
.86486 .01472 L
.86616 .01472 L
.86739 .01472 L
.86852 .01472 L
.86958 .01472 L
.87071 .01472 L
.87178 .01472 L
.87276 .01472 L
.8739 .01472 L
.87515 .01472 L
.87633 .01472 L
.87742 .01472 L
.87866 .01472 L
.87982 .01472 L
.88086 .01472 L
.88199 .01472 L
.88322 .01472 L
.88452 .01472 L
.88563 .01472 L
.88685 .01472 L
.88816 .01472 L
.88937 .01472 L
.89 .01472 L
.8907 .01472 L
.89143 .01472 L
.89211 .01472 L
.89336 .01472 L
.8945 .01472 L
.89576 .01472 L
.89708 .01472 L
.8982 .01472 L
.89939 .01472 L
.90051 .01472 L
Mistroke
.90153 .01472 L
.90273 .01472 L
.90404 .01472 L
.90527 .01472 L
.9064 .01472 L
.90761 .01472 L
.9089 .01472 L
.91013 .01472 L
.91124 .01472 L
.91255 .01472 L
.91329 .01472 L
.91398 .01472 L
.91523 .01472 L
.91587 .01472 L
.91657 .01472 L
.91725 .01472 L
.91796 .01472 L
.91924 .01472 L
.91995 .01472 L
.92061 .01472 L
.92134 .01472 L
.92211 .01472 L
.92279 .01472 L
.92352 .01472 L
.92421 .01472 L
.92484 .01472 L
.92605 .01472 L
.92732 .01472 L
.92853 .01472 L
.92985 .01472 L
.93109 .01472 L
.93224 .01472 L
.93339 .01472 L
.93442 .01472 L
.93562 .01472 L
.93674 .01472 L
.93798 .01472 L
.93928 .01472 L
.94039 .01472 L
.94161 .01472 L
.94292 .01472 L
.94366 .01472 L
.94433 .01472 L
.94563 .01472 L
.94687 .01472 L
.94792 .01472 L
.94908 .01472 L
.95029 .01472 L
.95143 .01472 L
.95248 .01472 L
Mistroke
.95345 .01472 L
.95452 .01472 L
.95564 .01472 L
.95678 .01472 L
.958 .01472 L
.95915 .01472 L
.96019 .01472 L
.96142 .01472 L
.96212 .01472 L
.96276 .01472 L
.96393 .01472 L
.96517 .01472 L
.96591 .01472 L
.96661 .01472 L
.96792 .01472 L
.96865 .01472 L
.96933 .01472 L
.97007 .01472 L
.97087 .01472 L
.97156 .01472 L
.97231 .01472 L
.97301 .01472 L
.97366 .01472 L
.97489 .01472 L
.97619 .01472 L
Mfstroke
[ .02 ] 0 setdash
.02381 .60332 m
.03279 .60332 L
.04262 .60332 L
.05288 .60332 L
.06244 .60332 L
.0731 .60332 L
.0828 .60332 L
.094 .60332 L
.10458 .60332 L
.11428 .60332 L
.12455 .60331 L
.13333 .60331 L
.14299 .60331 L
.15313 .60331 L
.1624 .60331 L
.17311 .6033 L
.18328 .60329 L
.19287 .60328 L
.20309 .60327 L
.21273 .60325 L
.22147 .60323 L
.2315 .6032 L
.24072 .60316 L
.25085 .6031 L
.26154 .60301 L
.27102 .6029 L
.28118 .60274 L
.29077 .60254 L
.29951 .60229 L
.30943 .60191 L
.3186 .60143 L
.32866 .60073 L
.33936 .5997 L
.34873 .59845 L
.35883 .59664 L
.36837 .59433 L
.37711 .59152 L
.38691 .58734 L
.39603 .58219 L
.40604 .5747 L
.41673 .56394 L
.42698 .55022 L
.43808 .53063 L
.44856 .50672 L
.45823 .47942 L
.47699 .41166 L
.49763 .32003 L
.51871 .22433 L
.53797 .15077 L
.5475 .1218 L
Mistroke
.55789 .09593 L
.56763 .07665 L
.5768 .06232 L
.58714 .04982 L
.59651 .04122 L
.6066 .03422 L
.61749 .02866 L
.62703 .02509 L
.63747 .02221 L
.64838 .02004 L
.65855 .01859 L
.66903 .0175 L
.67894 .01675 L
.68784 .01625 L
.69751 .01585 L
.70694 .01556 L
.71732 .01532 L
.72817 .01514 L
.73835 .01503 L
.7482 .01494 L
.75857 .01488 L
.76742 .01484 L
.77709 .01481 L
.78739 .01478 L
.79673 .01476 L
.80752 .01475 L
.8177 .01474 L
.82745 .01473 L
.83775 .01473 L
.84655 .01473 L
.85622 .01472 L
.86641 .01472 L
.8757 .01472 L
.88643 .01472 L
.89661 .01472 L
.90625 .01472 L
.91649 .01472 L
.92524 .01472 L
.93491 .01472 L
.94498 .01472 L
.95423 .01472 L
.96438 .01472 L
.97508 .01472 L
.97619 .01472 L
Mfstroke
.02381 .59127 m
.06244 .58695 L
.10458 .58053 L
.14415 .57235 L
.18221 .56192 L
.22272 .54732 L
.26171 .52908 L
.30316 .50436 L
.34309 .47473 L
.3815 .44065 L
.42237 .39886 L
.46172 .35441 L
.49955 .30955 L
.53984 .26181 L
.57861 .21812 L
.61984 .17611 L
.65954 .14117 L
.69774 .11308 L
.73838 .0889 L
.77751 .07062 L
.81909 .05571 L
.85916 .04491 L
.89771 .0371 L
.93871 .03093 L
.97619 .02676 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.9375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000ga000`40l00?003`ooooJOoo003ooomY
ool00;goo`<03`03ool03ooo0:Goo`00_Ooo00<03ooo00l00_oo00<03oooool0Xooo002^ool400l0
1?oo00ooo`0?0_oo0P0?00Goo`0?ooooo`0?00?oo`0300oooooo00;oo`0600oooooo00ooo`0?1?oo
0P0?00?oo`0?00l0T_oo002_ool02@0?oooooooo00ooo`0?ool03`03ool02@0?ool03ooo00ooo`0?
ool03`03ool01P0?ooooo`0?ool03`?oo`0400ooooooool200nBool00:ooo`803`;oo`0800ooo`0?
ool03ooo00ooo`<03`06ool03ooo00ooo`0?0ooo00H03oooool03ooo00l3ool0100?ool03`0?0_oo
00<03oooool0Sooo002_ool0100?oooooooo0P0?0ooo0P0?00?oo`0?ool00`0?00Coo`0?ool03`?o
o`0300oooooo00803`Goo`<03`;oo`0300oooooo08ooo`00[_oo100?8Ooo00@03oooool03i7oo`00
aooo00<03oooool0W_oo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00oooo
JOoo000^ool01@0?ooooo`0?ool00`0?@?oo00@03oooool03`;oo`0300oooooo00803d;oo`0300oo
oooo04;oo`0400oooooo00l2ool00`0?ooooo`0200m2ool01@0?ooooo`0?ool00`0?2ooo000]ool0
0`0?ool03`04ool00`0?ooooo`0nool00`0?ool03`03ool00`0?ool03`03ool00`0?ooooo`0nool0
0`0?ool03`12ool00`0?ool03`03ool00`0?ool03`03ool00`0?ooooo`0nool00`0?ool03`04ool0
0`0?ooooo`0:ool002Soo`<03`;oo`0300ooo`0?00Coo`0300oooooo03Woo`<03`;oo`0300ooo`0?
00?oo`0400ooo`0?ool200m1ool00`0?ool03`12ool00`0?ool03`03ool0100?ool03ooo0P0?@Ooo
00<03ooo00l01?oo00<03oooool02_oo000]ool00`0?ool03`04ool00`0?ooooo`0nool00`0?ool0
3`03ool01@0?ool03ooo00l0@_oo00<03ooo00l0@_oo00<03ooo00l00ooo00D03ooo00ooo`0?04;o
o`0300ooo`0?00Coo`0300oooooo00[oo`00;_oo00<03oooool00_oo0P0?@Ooo00<03oooool00ooo
00<03oooool00`0?@Ooo00<03oooool0@_oo00<03oooool00ooo00<03oooool00`0?@Ooo00<03ooo
ool00_oo0P0?3?oo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo
003ooomYool002Ooool03c/03`Ooo`009ooo00<03oooool01Ooo00<03oooool02ooo00<03oooool0
3?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool0
3?oo00<03oooool03?oo00<03oooool02ooo00<03oooool03?oo00<03oooool03?oo00<03oooool0
3?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool0
2ooo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool01Ooo00<03oooool0
1Ooo000Oool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`17ool00`0?ooooo`17ool00`0?
ooooo`18ool00`0?ooooo`17ool00`0?ooooo`05ool00`0?ooooo`05ool001koo`0300ooo`0?00Ko
o`0300oooooo04ooo`0308oooooo04Ooo`0300oooooo04Soo`0307oooooo04ooo`0300oooooo00Go
o`007_oo00<03ooo00l01_oo00<03oooool0Cooo00<0Ooooool0Aooo00<03oooool0B?oo00<0Sooo
ool0Cooo00<03oooool01Ooo000Nool00`0?ool03`06ool300m?ool00`2?ooooo`17ool00`0?oooo
o`2C00l5ool300l7ool001ooo`0300oooooo00Goo`0300oooooo04ooo`0307oooooo04Ooo`0400oo
oooo00lZool200lKool00`2?ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`0308oo
oooo04Ooo`0400oooooo00lVool400lMool00`1oooooo`1?ool00`0?ooooo`05ool002Ooo`0300oo
oooo04ooo`0307oooooo04Ooo`0400ooo`0?00lUool00`0?ooooo`0Oool00`2?ooooo`1?ool00`0?
ooooo`05ool002Ooo`0300oooooo04ooo`0308oooooo04Ooo`0300ooo`0?04Soo`0307oooooo03ko
o`P03`Woo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Ooooool0Aooo00<03ooo00l08?oo
00<03oooool09Ooo00<0Soooool0=ooo0P0?5_oo00<03oooool01Ooo000Wool00`0?ooooo`1?ool0
0`2?ooooo`17ool00`0?ool03`0Nool200lXool00`1oooooo`0bool500lHool00`0?ooooo`05ool0
02Ooo`0300oooooo04ooo`0307oooooo04Ooo`0300ooo`0?01goo`0300oooooo02Soo`0308oooooo
02_oo`803b;oo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Soooool0Aooo00<03ooo00l0
6ooo0P0?:ooo00<0Ooooool09_oo1@0?9?oo00<03oooool01Ooo000Wool200m@ool00`1oooooo`17
ool00`0?ool03`18ool00`2?ooooo`1=ool300l7ool002Ooo`0300oooooo04ooo`0308oooooo04Oo
o`0300ooo`0?04Soo`0307oooooo01koo`<03bkoo`0300oooooo00Goo`009ooo00<03oooool0Cooo
00<0Ooooool0Aooo00<03ooo00l0B?oo00<0Soooool06_oo100?<Ooo00<03oooool01Ooo000Wool0
0`0?ooooo`1?ool00`2?ooooo`17ool00`0?ool03`18ool00`1oooooo`1?ool00`0?ooooo`05ool0
02Ooo`0300oooooo04ooo`0307oooooo04Ooo`0300ooo`0?01Ooo`0300oooooo02koo`0308oooooo
01Coo`0300oooooo03Soo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Soooool0Aooo00<0
3ooo00l05Ooo0P0?<Ooo00<0Ooooool04Ooo0`0?>ooo00<03oooool01Ooo000Wool00`0?ooooo`1?
ool00`1oooooo`17ool00`0?ool03`0Eool00`0?ooooo`0`ool00`2?ooooo`0>ool300lnool00`0?
ooooo`05ool002Ooo`0300oooooo04ooo`0308oooooo04Ooo`0300ooo`0?01Coo`0300oooooo037o
o`0307oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Ooooool0Aooo00<03ooo
00l05?oo00<03oooool0<Ooo00<0Soooool0Cooo00<03oooool01Ooo000Wool200m@ool00`2?oooo
o`17ool00`0?ool03`0Cool00`0?ooooo`0bool00`1oooooo`07ool200m4ool300l7ool002Ooo`03
00oooooo04ooo`0307oooooo04Ooo`0300ooo`0?04Soo`0308oooooo00Coo`<03dSoo`0300oooooo
00Goo`009ooo00<03oooool0Cooo00<0Soooool0Aooo0`0?B?oo00<0Ooooool00_oo0P0?Booo00<0
3oooool01Ooo000Wool00`0?ooooo`1?ool00`1oooooo`17ool200m9ool00`2?ooooo`1?ool00`0?
ooooo`05ool002Ooo`0300oooooo04ooo`0308oooooo04Ooo`803dWoo`0307oooooo04ooo`0300oo
oooo00Goo`009ooo00<03oooool0Cooo00<0Ooooool0Aooo0P0?4Ooo00<03oooool0=?oo0P0?DOoo
00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`2?ooooo`17ool200lAool00`0?ooooo`0bool2
00l00ooo07ooo`1@ool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`0307oooooo04Ooo`803a3o
o`0300oooooo03;oo`0500ooooooool0S`1Aool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`03
08oooooo04Ooo`803a3oo`0300oooooo033oo`803`Coo`0307oooooo04ooo`0300oooooo00Goo`00
9ooo0P0?D?oo00<0Ooooool0Aooo0P0?4?oo00<03oooool0=_oo00<0Soooool0COoo0`0?1ooo000W
ool00`0?ooooo`1?ool00`2?ooooo`17ool200l?ool00`0?ooooo`0gool00`1oooooo`1?ool00`0?
ooooo`05ool002Ooo`0300oooooo04ooo`0307oooooo04Ooo`803`ooo`0300oooooo02coo`0300oo
oooo00Soo`0308oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Soooool0Aooo
0P0???oo0P0?2ooo00<0Ooooool0Cooo00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`1ooooo
o`17ool200lkool00`0?ooooo`0;ool00`2?ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo
04ooo`0308oooooo04Ooo`803c[oo`0300oooooo00coo`0307oooooo04ooo`0300oooooo00Goo`00
9ooo00<03oooool0Cooo00<0Ooooool0Aooo0P0?>Ooo00<03oooool03Ooo00<0Soooool0Cooo00<0
3oooool01Ooo000Iool01@0?ooooo`0?ool00`0?1_oo00<03oooool0Cooo00<0Soooool0Aooo0P0?
BOoo00<0Ooooool0Cooo00<03oooool01Ooo000Hool00`0?ool03`03ool00`0?ooooo`06ool00`0?
ooooo`1?ool00`1oooooo`17ool200l=ool00`0?ooooo`0iool00`2?ooooo`1?ool00`0?ooooo`05
ool001Soo`0300ooo`0?00Coo`0300oooooo00Goo`<03`2I07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00803`2I08l0O`2?07l0S`1o
08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00<03`Oo
o`006?oo00<03ooo00l00ooo00<03ooo00l01_oo00<03oooool0Cooo00<0Ooooool0Aooo0P0?3?oo
00<03oooool09?oo0P0?5?oo00<0Soooool0Cooo00<03oooool01Ooo000Iool00`0?ooooo`03ool2
00l6ool00`0?ooooo`1?ool00`2?ooooo`17ool200l<ool00`0?ooooo`0Sool00`0?ooooo`0Dool0
0`1oooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`0307oooooo04Ooo`803`_oo`03
00oooooo02;oo`803aOoo`0308oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0
Soooool0Aooo0P0?2ooo00<03oooool08Ooo00<03oooool05ooo00<0Ooooool0Cooo00<03oooool0
1Ooo000Wool00`0?ooooo`1?ool00`1oooooo`17ool200l;ool00`0?ooooo`0kool00`2?ooooo`1?
ool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`0308oooooo04Ooo`803dWoo`0307oooooo04oo
o`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Ooooool0Aooo0P0?BOoo00<0Soooool0Cooo
00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`2?ooooo`17ool200lZool00`0?ooooo`0Lool0
0`1oooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`0307oooooo04Ooo`803bWoo`80
3akoo`0308oooooo04ooo`0300oooooo00Goo`009ooo0P0?D?oo00<0Soooool0Aooo0P0?:?oo00<0
3oooool07_oo00<0Ooooool0COoo0`0?1ooo000Wool00`0?ooooo`1?ool00`1oooooo`17ool200l9
ool00`0?ooooo`0Kool00`0?ooooo`0Oool00`2?ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oo
oooo04ooo`0308oooooo04Ooo`803`Woo`0300oooooo01[oo`0300oooooo023oo`0307oooooo04oo
o`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Ooooool0Aooo0P0?2?oo00<03oooool06_oo
00<03oooool08Ooo00<0Soooool0Cooo00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`2?oooo
o`17ool200l8ool00`0?ooooo`0nool00`1oooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo
04ooo`0307oooooo04Ooo`803`Soo`0300oooooo03koo`0308oooooo04ooo`0300oooooo00Goo`00
9ooo00<03oooool0Cooo00<0Soooool0Aooo0P0?2?oo00<03oooool0?_oo00<0Ooooool0Cooo00<0
3oooool01Ooo000Wool00`0?ooooo`1?ool00`1oooooo`17ool200l7ool00`0?ooooo`0Gool00`0?
ooooo`0Uool00`2?ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`0308oooooo04Oo
o`803b3oo`0300oooooo02Koo`0307oooooo04ooo`0300oooooo00Goo`009ooo0P0?D?oo00<0Oooo
ool0Aooo0P0?7ooo00<03oooool09ooo00<0Soooool0COoo0`0?1ooo000Wool00`0?ooooo`1?ool0
0`2?ooooo`17ool200lNool00`0?ooooo`0Xool00`1oooooo`1?ool00`0?ooooo`05ool002Ooo`03
00oooooo04ooo`0307oooooo04Ooo`803agoo`0300oooooo02Woo`0308oooooo04ooo`0300oooooo
00Goo`009ooo00<03oooool0Cooo00<0Soooool0Aooo0P0?BOoo00<0Ooooool0Cooo00<03oooool0
1Ooo000Wool00`0?ooooo`1?ool00`1oooooo`17ool200l6ool00`0?ooooo`10ool00`2?ooooo`1?
ool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`0308oooooo04Ooo`803`Koo`0300oooooo043o
o`0307oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Ooooool0Aooo0P0?1Ooo
00<03oooool0@Ooo00<0Soooool0Cooo00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`2?oooo
o`17ool200l5ool00`0?ooooo`0@ool00`0?ooooo`0^ool00`1oooooo`1?ool00`0?ooooo`05ool0
02Ooo`0300oooooo04ooo`0307oooooo04Ooo`803`Goo`0300oooooo00ooo`0300oooooo02ooo`03
08oooooo04ooo`0300oooooo00Goo`009ooo0P0?D?oo00<0Soooool0Aooo0P0?1Ooo00<03oooool0
3_oo00<03oooool0<?oo00<0Ooooool0COoo0`0?1ooo000Wool00`0?ooooo`1?ool00`1oooooo`17
ool200l4ool00`0?ooooo`0>ool00`0?ooooo`0aool00`2?ooooo`1?ool00`0?ooooo`05ool002Oo
o`0300oooooo04ooo`0308oooooo04Ooo`803aCoo`0300oooooo03;oo`0307oooooo04ooo`0300oo
oooo00Goo`009ooo00<03oooool0Cooo00<0Ooooool0Aooo0P0?BOoo00<0Soooool0Cooo00<03ooo
ool01Ooo000Wool00`0?ooooo`1?ool00`2?ooooo`17ool200m9ool00`1oooooo`1?ool00`0?oooo
o`05ool002Ooo`0300oooooo04ooo`0307oooooo04Ooo`803dWoo`0308oooooo04ooo`0300oooooo
00Goo`009ooo00<03oooool0Cooo00<0Soooool0Aooo0P0?BOoo00<0Ooooool0Cooo00<03oooool0
1Ooo000Iool0100?ooooo`0?0ooo00<03oooool01?oo00<03oooool0Cooo00<0Ooooool0Aooo0P0?
0ooo00<03oooool02_oo00<03oooool0=_oo00<0Soooool0Cooo00<03oooool01Ooo000Hool00`0?
ool03`03ool300l6ool00`0?ooooo`1?ool00`2?ooooo`17ool200l3ool00`0?ooooo`09ool00`0?
ooooo`0gool00`1oooooo`1?ool00`0?ooooo`05ool001Soo`0300ooo`0?00?oo`0300ooo`0?00Ko
o`<03`2I08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?00803`2I07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o00<03`Ooo`002ooo00<03oooool00_oo00<03oooool01Ooo
00<03ooo00l01?oo0P0?1_oo00<03oooool0Cooo00<0Soooool0Aooo0P0?0_oo00<03oooool02?oo
00<03oooool0>Ooo00<0Ooooool0Cooo00<03oooool01Ooo000;ool600l8ool00`0?ooooo`04ool0
0`0?ooooo`04ool00`0?ooooo`1?ool00`1oooooo`17ool200l2ool00`0?ooooo`07ool00`0?oooo
o`0jool00`2?ooooo`1?ool00`0?ooooo`05ool000_oo`0400oooooo00lHool00`0?ooooo`1?ool0
0`2?ooooo`17ool200l2ool00`0?ooooo`07ool00`0?ooooo`0jool00`1oooooo`1?ool00`0?oooo
o`05ool000coo`803aWoo`0300oooooo04ooo`0307oooooo04Ooo`803`;oo`0300oooooo04Coo`03
08oooooo04ooo`0300oooooo00Goo`004?oo00<03oooool05?oo00<03oooool0Cooo00<0Soooool0
Aooo0P0?BOoo00<0Ooooool0Cooo00<03oooool01Ooo000=ool400lFool00`0?ooooo`1?ool00`1o
ooooo`17ool200m9ool00`2?ooooo`1?ool00`0?ooooo`05ool000goo`0400oooooo00lFool00`0?
ooooo`1?ool00`2?ooooo`17ool200m9ool00`1oooooo`1?ool00`0?ooooo`05ool000koo`803aOo
o`0300oooooo04ooo`0307oooooo04Ooo`0300oooooo00Koo`803d3oo`0308oooooo04ooo`0300oo
oooo00Goo`003Ooo00@03oooool03aKoo`803e3oo`0308oooooo04Ooo`0300oooooo00Goo`0300oo
oooo043oo`0307oooooo04goo`<03`Ooo`003Ooo00@03oooool03aKoo`0300oooooo04ooo`0307oo
oooo04Ooo`0300ooo`0?00Goo`0300oooooo043oo`0308oooooo04ooo`0300oooooo00Goo`003_oo
0P0?5ooo00<03oooool0Cooo00<0Soooool0Aooo00<03ooo00l01?oo00<03oooool0@Ooo00<0Oooo
ool0Cooo00<03oooool01Ooo000;ool500lGool00`0?ooooo`1?ool00`1oooooo`17ool00`0?ool0
3`03ool00`0?ooooo`12ool00`2?ooooo`1?ool00`0?ooooo`05ool000goo`0400oooooo00lFool0
0`0?ooooo`1?ool00`2?ooooo`17ool00`0?ool03`18ool00`1oooooo`1?ool00`0?ooooo`05ool0
00goo`0400oooooo00lFool00`0?ooooo`1?ool00`1oooooo`17ool200m9ool00`2?ooooo`1?ool0
0`0?ooooo`05ool000koo`803aOoo`0300oooooo04ooo`0308oooooo04Ooo`803dWoo`0307oooooo
04ooo`0300oooooo00Goo`003Ooo00<03ooo00l05ooo00<03oooool0Cooo00<0Ooooool0Aooo0P0?
BOoo00<0Soooool0Cooo00<03oooool01Ooo000=ool200l00ooo00ooo`0Eool00`0?ooooo`1?ool0
0`2?ooooo`17ool300m8ool00`1oooooo`1?ool00`0?ooooo`05ool000koo`<03aKoo`0300oooooo
04ooo`0307oooooo04Ooo`803dWoo`0308oooooo04ooo`0300oooooo00Goo`004?oo00<03oooool0
5?oo0P0?D?oo00<0Soooool0Aooo00<03oooool0B?oo00<0Ooooool0COoo0`0?1ooo000;ool500lG
ool00`0?ooooo`1?ool00`1oooooo`16ool200m:ool00`2?ooooo`1?ool00`0?ooooo`05ool000go
o`0400oooooo00lFool00`0?ooooo`1?ool00`2?ooooo`15ool00`0?ool03`1:ool00`1oooooo`1?
ool00`0?ooooo`05ool000goo`0400oooooo00lFool00`0?ooooo`1?ool00`1oooooo`15ool00`0?
ool03`1:ool00`2?ooooo`1?ool00`0?ooooo`05ool000koo`803aOoo`0300oooooo04ooo`0308oo
oooo04Koo`803d[oo`0307oooooo04ooo`0300oooooo00Goo`003_oo00<03ooo00l05_oo00<03ooo
ool0Cooo00<0Ooooool0A_oo0P0?B_oo00<0Soooool0Cooo00<03oooool01Ooo000;ool00`0?ool0
3`0300lFool00`0?ooooo`1?ool00`2?ooooo`16ool200m:ool00`1oooooo`1?ool00`0?ooooo`05
ool000coo`0500ooooooool03`0Fool00`0?ooooo`1?ool00`1oooooo`16ool200m:ool00`2?oooo
o`1?ool00`0?ooooo`05ool000_oo`H03aKoo`0300oooooo04ooo`0308oooooo043oo`803`Coo`80
3d[oo`0307oooooo04ooo`0300oooooo00Goo`003_oo00<03ooo00l05_oo0P0?D?oo00<0Ooooool0
?ooo00<03oooool00ooo00<03ooo00l0B_oo00<0Soooool0COoo0`0?1ooo000;ool00`0?ool03`03
00lFool00`0?ooooo`1?ool00`2?ooooo`0oool00`0?ooooo`03ool00`0?ool03`1:ool00`1ooooo
o`1?ool00`0?ooooo`05ool000coo`D03aKoo`0300oooooo04ooo`0307oooooo03koo`0300oooooo
00Koo`0300oooooo04Soo`0308oooooo04ooo`0300oooooo00Goo`003Ooo00@03oooool03aKoo`03
00oooooo04ooo`0308oooooo03coo`803`Woo`0300oooooo04Soo`0307oooooo04ooo`0300oooooo
00Goo`009ooo00<03oooool0Cooo00<0Ooooool0Aooo00<03oooool0B?oo00<0Soooool0Cooo00<0
3oooool01Ooo000=ool00`0?ooooo`02ool00`0?ooooo`0Bool00`0?ooooo`1?ool00`2?ooooo`17
ool00`0?ooooo`18ool00`1oooooo`1?ool00`0?ooooo`05ool000goo`<03`03ool03`0?00Koo`04
00oooooo00l2ool00`0?ooooo`05ool00`0?ooooo`1?ool00`1oooooo`17ool00`0?ooooo`18ool0
0`2?ooooo`1?ool00`0?ooooo`05ool000ooo`803`Ooo`0300ooo`0?00?oo`0300ooo`0?00Koo`03
00oooooo04ooo`0308oooooo04Coo`0400oooooo00m:ool00`1oooooo`1?ool00`0?ooooo`05ool0
00goo`803`Woo`0300ooo`0?00?oo`803`Ooo`0300oooooo04ooo`0307oooooo03Soo`0300oooooo
00Soo`0500ooooooool03`1:ool00`2?ooooo`1?ool00`0?ooooo`05ool001Soo`0300ooo`0?00?o
o`0300oooooo00Koo`<03`3o07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o
08l0O`2?07l0S`1o08l0O`0?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o000e07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0300l7ool001Woo`0300oooooo00?o
o`803`Koo`0300oooooo04ooo`0307oooooo03Ooo`0300oooooo00Woo`0500ooooooool03`1:ool0
0`2?ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`0308oooooo03Koo`0300oooooo
00[oo`0500ooooooool03`1:ool00`1oooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04oo
o`0307oooooo03Goo`0300oooooo00_oo`0500ooooooool03`1:ool00`2?ooooo`1?ool00`0?oooo
o`05ool002Ooo`0300oooooo04ooo`0308oooooo03Coo`0300oooooo00_oo`0300oooooo00;oo`03
00oooooo04Soo`0307oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Ooooool0
Aooo00<03oooool0B?oo00<0Soooool0Cooo00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`2?
ooooo`17ool00`0?ooooo`18ool00`1oooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04oo
o`0307oooooo04Ooo`0300oooooo04Soo`0308oooooo04ooo`0300oooooo00Goo`009ooo00<03ooo
ool0Cooo00<0Soooool0Aooo00<03oooool0B?oo00<0Ooooool0Cooo00<03oooool01Ooo000Wool2
00m@ool00`1oooooo`0`ool00`0?ooooo`0Dool00`0?ooooo`18ool00`2?ooooo`1=ool300l7ool0
02Ooo`0300oooooo04ooo`0308oooooo02ooo`0300oooooo00ooo`0300oooooo00?oo`0300oooooo
04Soo`0307oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Ooooool0;_oo00<0
3oooool04?oo00<03oooool00ooo00<03oooool0B?oo00<0Soooool0Cooo00<03oooool01Ooo000W
ool00`0?ooooo`1?ool00`2?ooooo`0]ool00`0?ooooo`0Aool00`0?ooooo`03ool00`0?ooooo`18
ool00`1oooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`0307oooooo02coo`0300oo
oooo017oo`0300oooooo00Coo`0300oooooo04Soo`0308oooooo04ooo`0300oooooo00Goo`009ooo
00<03oooool0Cooo00<0Soooool0@?oo00<03oooool01?oo00<03oooool0B?oo00<0Ooooool0Cooo
00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`1oooooo`10ool00`0?ooooo`04ool00`0?oooo
o`18ool00`2?ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`0308oooooo03ooo`03
00oooooo00Goo`0300oooooo04Soo`0307oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool0
Cooo00<0Ooooool0Aooo00<03oooool0B?oo00<0Soooool0Cooo00<03oooool01Ooo000Wool200m@
ool00`2?ooooo`0Wool00`0?ooooo`0Mool00`0?ooooo`18ool00`1oooooo`1=ool300l7ool002Oo
o`0300oooooo04ooo`0307oooooo02Koo`0300oooooo01koo`0300oooooo04Soo`0308oooooo04oo
o`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Soooool09Ooo00<03oooool07ooo00<03ooo
ool0B?oo00<0Ooooool0Cooo00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`1oooooo`0Tool0
0`0?ooooo`0Pool00`0?ooooo`18ool00`2?ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo
04ooo`0308oooooo02?oo`0300oooooo01Soo`0300oooooo00Koo`0300oooooo04Soo`0307oooooo
04ooo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Ooooool0?_oo00<03oooool01_oo00<0
3oooool0B?oo00<0Soooool0Cooo00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`2?ooooo`0m
ool00`0?ooooo`07ool00`0?ooooo`18ool00`1oooooo`1?ool00`0?ooooo`05ool002Ooo`0300oo
oooo04ooo`0307oooooo03goo`0300oooooo00Ooo`0300oooooo04Soo`0308oooooo04ooo`0300oo
oooo00Goo`009ooo00<03oooool0Cooo00<0Soooool07_oo00<03oooool07?oo00<03oooool01ooo
00<03oooool0B?oo00<0Ooooool0Cooo00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`1ooooo
o`0Mool200lMool00`0?ooooo`08ool00`0?ooooo`18ool00`2?ooooo`1?ool00`0?ooooo`05ool0
02Ooo`803e3oo`0308oooooo01coo`0300oooooo01goo`0300oooooo00Soo`0300oooooo04Soo`03
07oooooo04goo`<03`Ooo`009ooo00<03oooool0Cooo00<0Ooooool06ooo00<03oooool0:Ooo00<0
3oooool0B?oo00<0Soooool0Cooo00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`2?ooooo`0J
ool00`0?ooooo`0Zool00`0?ooooo`18ool00`1oooooo`1?ool00`0?ooooo`05ool002Ooo`0300oo
oooo04ooo`0307oooooo04Ooo`0300oooooo04Soo`0308oooooo04ooo`0300oooooo00Goo`009ooo
00<03oooool0Cooo00<0Soooool0Aooo00<03oooool0B?oo00<0Ooooool0Cooo00<03oooool01Ooo
000Wool00`0?ooooo`1?ool00`1oooooo`17ool00`0?ooooo`18ool00`2?ooooo`1?ool00`0?oooo
o`05ool001Woo`0400oooooo00l2ool00`0?ooooo`05ool00`0?ooooo`1?ool00`2?ooooo`0Eool0
0`0?ooooo`0Rool00`0?ooooo`0:ool00`0?ooooo`18ool00`1oooooo`1?ool00`0?ooooo`05ool0
01Soo`0300ooo`0?00?oo`0300ooo`0?00Koo`0300oooooo04ooo`0307oooooo01Coo`0300oooooo
02?oo`0300oooooo00[oo`0300oooooo04Soo`0308oooooo04ooo`0300oooooo00Goo`006?oo00<0
3ooo00l01?oo00<03oooool01Ooo00<03oooool0Cooo00<0Soooool04ooo00<03oooool09?oo00<0
3oooool02_oo00<03oooool0B?oo00<0Ooooool0Cooo00<03oooool01Ooo000Hool00`0?ool03`03
ool00`0?ool03`06ool300l0H`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0200l0c`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0300l7ool001Woo`0300oooooo00?o
o`0300oooooo00Goo`0300oooooo04ooo`0308oooooo013oo`0300oooooo02Koo`0300oooooo00_o
o`0300oooooo04Soo`0307oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Oooo
ool0>Ooo00<03oooool02ooo00<03oooool0B?oo00<0Soooool0Cooo00<03oooool01Ooo000Wool0
0`0?ooooo`1?ool00`2?ooooo`0hool00`0?ooooo`0<ool00`0?ooooo`18ool00`1oooooo`1?ool0
0`0?ooooo`05ool002Ooo`0300oooooo04ooo`0307oooooo04Ooo`0300oooooo04Soo`0308oooooo
04ooo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Soooool02_oo0P0?>_oo0P0?B_oo00<0
Ooooool0Cooo00<03oooool01Ooo000Wool00`0?ooooo`1?ool00`1oooooo`09ool200lkool200m:
ool00`2?ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04ooo`0308oooooo00Ooo`803cgo
o`803d[oo`0307oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Ooooool01_oo
00<03oooool0?Ooo0P0?B_oo00<0Soooool0Cooo00<03oooool01Ooo000Wool200m@ool00`2?oooo
o`0fool00`0?ooooo`0=ool200m:ool00`1oooooo`1=ool300l7ool002Ooo`0300oooooo04ooo`03
07oooooo03Koo`0300oooooo00goo`803d[oo`0308oooooo04ooo`0300oooooo00Goo`009ooo00<0
3oooool0Cooo00@0Soooool03cCoo`0300oooooo00koo`803d[oo`0307oooooo04ooo`0300oooooo
00Goo`009ooo00<03oooool0Cooo00<0Oooo00l0=Ooo00<03oooool03_oo0P0?B_oo00<0Soooool0
Cooo00<03oooool01Ooo000Wool00`0?ooooo`1?ool200leool00`0?ooooo`0?ool200m:ool00`1o
ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04goo`803`0307oooooo03Coo`0300oooooo
00ooo`803d[oo`0308oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool0Cooo00<0Soooool0
=?oo00<03oooool03ooo0P0?B_oo00<0Ooooool0Cooo00<03oooool01Ooo000Wool00`0?ooooo`1?
ool00`1oooooo`16ool200m:ool00`2?ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo04Ko
o`803`Ooo`0308oooooo04Koo`803d[oo`0307oooooo04ooo`0300oooooo00Goo`009ooo0P0?AOoo
0P0?2Ooo00<0Ooooool0A_oo0P0?B_oo00<0Soooool0COoo0`0?1ooo000Wool00`0?ooooo`11ool3
00l;ool00`2?ooooo`16ool200m:ool00`1oooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo
04ooo`0307oooooo033oo`803aCoo`803d[oo`0308oooooo04ooo`0300oooooo00Goo`009ooo00<0
3oooool0Cooo00<0Soooool0<?oo00<03oooool04ooo0P0?B_oo00<0Ooooool0Cooo00<03oooool0
1Ooo000Wool00`0?ooooo`0jool300lBool00`1oooooo`0_ool00`0?ooooo`0Dool200m:ool00`2?
ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo03Ooo`<03aGoo`0308oooooo02koo`0300oo
oooo01Goo`803d[oo`0307oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<03ooo
ool05_oo00<0Ooooool0;Ooo00<03oooool05_oo0P0?B_oo00<0Soooool0Cooo00<03oooool01Ooo
000Wool00`0?ooooo`0`ool00`0?ooooo`0Lool00`2?ooooo`0]ool00`0?ooooo`0Fool200m:ool0
0`1oooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo02coo`@03aooo`0307oooooo04Koo`80
3d[oo`0308oooooo04ooo`0300oooooo00Goo`009ooo0P0?:ooo0P0?8ooo00<0Soooool0A_oo0P0?
B_oo00<0Ooooool0COoo0`0?1ooo000Wool00`0?ooooo`0Sool200lZool00`1oooooo`16ool200m:
ool00`2?ooooo`1?ool00`0?ooooo`05ool002Ooo`0300oooooo01goo`H03bcoo`0308oooooo02So
o`0300oooooo01_oo`803d[oo`0307oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool05ooo
00<03oooool0=Ooo00<0Ooooool09_oo0P0?7_oo0P0?B_oo00<0Soooool0Cooo00<03oooool01Ooo
000Wool00`0?ooooo`0Aool600lhool00`2?ooooo`0Uool00`0?ooooo`0Mool300m:ool00`1ooooo
o`1?ool00`0?ooooo`05ool002Ooo`0300oooooo00Ooo`D03d?oo`0307oooooo02?oo`803b3oo`03
00ooo`0?04[oo`0308oooooo04ooo`0300oooooo00Goo`009ooo00<03oooool01Ooo0P0?B?oo00<0
Soooool0AOoo00<03ooo00l0B_oo00<0Ooooool0Cooo00<03oooool01Ooo000Nool300l6ool00`0?
ooooo`1?ool00`1oooooo`0Kool300lWool00`0?ool03`1:ool00`2?ooooo`1?ool00`0?ooooo`05
ool001ooo`0300oooooo00Goo`0300oooooo04ooo`0308oooooo01Ooo`@03b[oo`0300ooo`0?04[o
o`0307oooooo04ooo`0300oooooo00Goo`007ooo00<03oooool01Ooo0`0?1OooT`0?00?oo`0?ool0
BOoo00<0Soooool0COoo0`0?1ooo000Oool00`0?ooooo`05ool00`0?ooooo`1?ool00`2?ooooo`17
ool00`0?ooooo`18ool00`1oooooo`1?ool00`0?ooooo`05ool001koo`803`Ooo`0300oooooo04oo
o`0307oooooo04Ooo`0300oooooo04Soo`0308oooooo04ooo`0300oooooo00Goo`009ooo00<03ooo
ool01Ooo00<03oooool0Aooo00<03oooool0Aooo00<03oooool0B?oo00<03oooool0Aooo00<03ooo
ool01Ooo00<03oooool01Ooo000Wool00`0?ooooo`05ool00`0?ooooo`0;ool00`0?ooooo`0<ool0
0`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool0
0`0?ooooo`0<ool00`0?ooooo`0;ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool0
0`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0;ool0
0`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`05ool00`0?ooooo`05ool0
02Ooool03c/03`Ooo`00ooooJOoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.13167, -0.171329, 0.00084,
   0.006798}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(vb = 1; \)\), 
    \(\(Fig12x2 = 
      Plot[f[En, 0, 0, tblT\[LeftDoubleBracket]3\[RightDoubleBracket]] - 
          f[En, 0, vb, tblT\[LeftDoubleBracket]3\[RightDoubleBracket]], {En, 
          \(-2\), 1}, 
        FrameLabel \[Rule] {"\<Energy in eV\>", "\<Probability\>"}, 
        Evaluate[opt]]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.014715 0.588604 [
[.02381 -0.0125 -7 -12 ]
[.02381 -0.0125 7 0 ]
[.18254 -0.0125 -10 -12 ]
[.18254 -0.0125 10 0 ]
[.34127 -0.0125 -7 -12 ]
[.34127 -0.0125 7 0 ]
[.5 -0.0125 -10 -12 ]
[.5 -0.0125 10 0 ]
[.65873 -0.0125 -4 -12 ]
[.65873 -0.0125 4 0 ]
[.81746 -0.0125 -7 -12 ]
[.81746 -0.0125 7 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -23.5 -24 ]
[.5 -0.0125 23.5 -12 ]
[-0.0125 .01472 -8 -6 ]
[-0.0125 .01472 0 6 ]
[-0.0125 .13244 -14 -6 ]
[-0.0125 .13244 0 6 ]
[-0.0125 .25016 -14 -6 ]
[-0.0125 .25016 0 6 ]
[-0.0125 .36788 -14 -6 ]
[-0.0125 .36788 0 6 ]
[-0.0125 .4856 -14 -6 ]
[-0.0125 .4856 0 6 ]
[-0.0125 .60332 -8 -6 ]
[-0.0125 .60332 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26 -20 ]
[-0.01875 .30902 -14 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .13244 m
1 .13244 L
s
0 .25016 m
1 .25016 L
s
0 .36788 m
1 .36788 L
s
0 .4856 m
1 .4856 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -71 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -71 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -84.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Energy) show
88.000000 13.000000 moveto
(in) show
96.187500 13.000000 moveto
(eV) show
105.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10 translate
90 rotate
-81 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Probability) show
98.312500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03523 .01472 L
.03754 .01472 L
.03881 .01472 L
.03953 .01472 L
.0402 .01472 L
.04137 .01472 L
.04262 .01472 L
.04496 .01472 L
.04626 .01472 L
.04749 .01472 L
.04863 .01472 L
.04987 .01472 L
.051 .01472 L
.05205 .01472 L
.0527 .01472 L
.05341 .01472 L
.05469 .01472 L
.05594 .01472 L
.05708 .01472 L
.05833 .01472 L
.05969 .01472 L
.06244 .01472 L
.0631 .01472 L
.0638 .01472 L
.06456 .01472 L
.06527 .01472 L
.06665 .01472 L
.06795 .01472 L
.06909 .01472 L
.07033 .01472 L
.07296 .01472 L
.07445 .01472 L
.07583 .01472 L
.07727 .01472 L
.07884 .01472 L
.08145 .01472 L
.08424 .01472 L
.08687 .01472 L
.08835 .01472 L
.08972 .01472 L
.09223 .01472 L
.09489 .01472 L
.09728 .01472 L
.09951 .01472 L
.10195 .01472 L
.10458 .01472 L
.10713 .01472 L
Mistroke
.10984 .01472 L
.11239 .01472 L
.11471 .01472 L
.11745 .01472 L
.1204 .01472 L
.12319 .01472 L
.12575 .01472 L
.12817 .01472 L
.13042 .01472 L
.13289 .01472 L
.13554 .01472 L
.13831 .01472 L
.14094 .01472 L
.1433 .01472 L
.14586 .01472 L
.1482 .01472 L
.15072 .01472 L
.1531 .01472 L
.15528 .01472 L
.1577 .01472 L
.16034 .01472 L
.1631 .01472 L
.16567 .01472 L
.16841 .01472 L
.171 .01472 L
.17332 .01472 L
.17584 .01472 L
.17859 .01472 L
.18149 .01472 L
.18397 .01472 L
.18669 .01472 L
.18919 .01472 L
.19192 .01472 L
.1945 .01472 L
.19688 .01472 L
.19902 .01472 L
.20139 .01472 L
.20386 .01472 L
.20618 .01472 L
.20873 .01472 L
.21142 .01472 L
.21372 .01472 L
.21623 .01472 L
.21895 .01472 L
.22185 .01472 L
.22459 .01472 L
.22708 .01472 L
.22939 .01472 L
.23192 .01472 L
.23457 .01472 L
Mistroke
.23705 .01472 L
.23936 .01472 L
.24148 .01472 L
.24392 .01472 L
.24624 .01472 L
.24874 .01472 L
.2514 .01473 L
.25391 .01473 L
.25619 .01473 L
.25887 .01474 L
.26177 .01475 L
.26451 .01477 L
.26703 .01478 L
.26949 .01481 L
.27174 .01484 L
.27433 .01488 L
.27678 .01494 L
.27904 .01501 L
.28113 .0151 L
.28343 .01523 L
.28587 .0154 L
.28831 .01564 L
.29094 .01599 L
.29342 .01644 L
.2957 .01699 L
.29822 .0178 L
.30098 .01903 L
.30386 .02082 L
.30654 .02314 L
.30917 .02627 L
.3116 .03013 L
.31426 .03583 L
.31707 .04404 L
.31952 .05355 L
.32181 .06497 L
.32432 .08092 L
.32701 .10281 L
.332 .15847 L
.33673 .22964 L
.34561 .38499 L
.35056 .45987 L
.35523 .51245 L
.35781 .53411 L
.3606 .55233 L
.36314 .565 L
.36547 .57399 L
.36768 .58066 L
.36974 .58554 L
.372 .58972 L
.37442 .59314 L
Mistroke
.37697 .59581 L
.37937 .5977 L
.38153 .59899 L
.38387 .60006 L
.38622 .60087 L
.38874 .60151 L
.39112 .60197 L
.3933 .60228 L
.39585 .60256 L
.39863 .60278 L
.40126 .60293 L
.4037 .60303 L
.40645 .60311 L
.40903 .60317 L
.41136 .6032 L
.41387 .60323 L
.41662 .60326 L
.41952 .60328 L
.422 .60329 L
.42472 .6033 L
.42723 .6033 L
.42996 .60331 L
.43254 .60331 L
.43492 .60331 L
.43707 .60331 L
.43943 .60332 L
.4419 .60332 L
.44422 .60332 L
.44678 .60332 L
.44947 .60332 L
.45177 .60332 L
.45429 .60332 L
.457 .60332 L
.45991 .60332 L
.46265 .60332 L
.46514 .60332 L
.46744 .60332 L
.46998 .60332 L
.47263 .60332 L
.47511 .60332 L
.47743 .60332 L
.47955 .60332 L
.48199 .60332 L
.48431 .60332 L
.48681 .60332 L
.48818 .60332 L
.48947 .60332 L
.49068 .60332 L
.49198 .60332 L
.49316 .60332 L
Mistroke
.49426 .60332 L
.49557 .60332 L
.49632 .60332 L
.49701 .60332 L
.49773 .60332 L
.49841 .60332 L
.49913 .60332 L
.49991 .60332 L
.50122 .60332 L
.50188 .60332 L
.50261 .60332 L
.5039 .60332 L
.50511 .60332 L
.50629 .60332 L
.50755 .60332 L
.50981 .60332 L
.5112 .60332 L
.51251 .60332 L
.51496 .60332 L
.51755 .60332 L
.51993 .60332 L
.52255 .60332 L
.52532 .60332 L
.52752 .60332 L
.52988 .60332 L
.53211 .60332 L
.53414 .60332 L
.53652 .60332 L
.53911 .60332 L
.54156 .60332 L
.54383 .60332 L
.54624 .60332 L
.54845 .60332 L
.55088 .60332 L
.55344 .60332 L
.55567 .60332 L
.55775 .60332 L
.56003 .60332 L
.56247 .60331 L
.56512 .60331 L
.56801 .60331 L
.57073 .60331 L
.57325 .6033 L
.57551 .6033 L
.57801 .60329 L
.58061 .60328 L
.58305 .60326 L
.58563 .60324 L
.58802 .60321 L
.59064 .60317 L
Mistroke
.59344 .60311 L
.5961 .60303 L
.59862 .60293 L
.60087 .60281 L
.60331 .60263 L
.60555 .60242 L
.608 .6021 L
.61056 .60166 L
.61296 .6011 L
.6152 .60041 L
.61724 .59959 L
.6196 .59836 L
.62183 .59682 L
.6242 .59468 L
.62643 .59205 L
.62886 .58825 L
.63149 .58276 L
.6341 .57544 L
.63684 .56508 L
.63919 .55352 L
.64175 .53731 L
.64636 .49653 L
.64895 .46623 L
.65129 .43392 L
.66017 .28324 L
.66502 .20142 L
.67016 .13187 L
.67454 .08955 L
.67703 .07186 L
.67936 .05879 L
.68205 .04716 L
.6846 .03884 L
.68689 .03315 L
.68939 .02843 L
.6921 .02464 L
.69498 .02174 L
.6977 .01977 L
.70016 .01847 L
.7025 .01755 L
.70505 .01679 L
.70773 .01621 L
.71022 .01582 L
.71255 .01555 L
.71468 .01536 L
.71713 .01519 L
.71945 .01508 L
.72197 .01498 L
.72464 .01491 L
.72692 .01486 L
.72944 .01482 L
Mistroke
.73214 .01479 L
.73504 .01477 L
.73778 .01475 L
.74029 .01474 L
.74278 .01474 L
.74505 .01473 L
.74766 .01473 L
.75012 .01472 L
.7524 .01472 L
.75451 .01472 L
.75682 .01472 L
.75925 .01472 L
.76172 .01472 L
.76436 .01472 L
.76685 .01472 L
.76913 .01472 L
.77179 .01472 L
.77469 .01472 L
.77743 .01472 L
.77997 .01472 L
.78238 .01472 L
.7846 .01472 L
.78703 .01472 L
.78959 .01472 L
.79182 .01472 L
.7939 .01472 L
.79618 .01472 L
.79862 .01472 L
.80128 .01472 L
.80417 .01472 L
.80689 .01472 L
.80941 .01472 L
.81167 .01472 L
.81417 .01472 L
.81677 .01472 L
.81921 .01472 L
.82179 .01472 L
.82418 .01472 L
.82681 .01472 L
.82961 .01472 L
.83228 .01472 L
.83479 .01472 L
.83704 .01472 L
.83948 .01472 L
.84172 .01472 L
.84418 .01472 L
.84674 .01472 L
.84914 .01472 L
.85138 .01472 L
.85342 .01472 L
Mistroke
.85578 .01472 L
.85801 .01472 L
.86038 .01472 L
.86261 .01472 L
.86505 .01472 L
.86768 .01472 L
.87029 .01472 L
.87304 .01472 L
.87538 .01472 L
.87794 .01472 L
.88036 .01472 L
.88256 .01472 L
.8851 .01472 L
.88749 .01472 L
.88971 .01472 L
.89175 .01472 L
.894 .01472 L
.89637 .01472 L
.8989 .01472 L
.90131 .01472 L
.90347 .01472 L
.90582 .01472 L
.90837 .01472 L
.91109 .01472 L
.91365 .01472 L
.91596 .01472 L
.91833 .01472 L
.92051 .01472 L
.92289 .01472 L
.92541 .01472 L
.9276 .01472 L
.92964 .01472 L
.93189 .01472 L
.93428 .01472 L
.93686 .01472 L
.9396 .01472 L
.94193 .01472 L
.9445 .01472 L
.94726 .01472 L
.94878 .01472 L
.95022 .01472 L
.95302 .01472 L
.95559 .01472 L
.958 .01472 L
.96058 .01472 L
.96301 .01472 L
.96521 .01472 L
.96781 .01472 L
.97063 .01472 L
.97328 .01472 L
Mistroke
.97573 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.9375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000ga000`40l00?003`ooooJOoo003ooomY
ool00;goo`<03`03ool03ooo0:Goo`00_Ooo00<03ooo00l00_oo00<03oooool0Xooo002^ool400l0
1?oo00ooo`0?0_oo0P0?00Goo`0?ooooo`0?00?oo`0300oooooo00;oo`0600oooooo00ooo`0?1?oo
0P0?00?oo`0?00l0T_oo002_ool02@0?oooooooo00ooo`0?ool03`03ool02@0?ool03ooo00ooo`0?
ool03`03ool01P0?ooooo`0?ool03`?oo`0400ooooooool200nBool00:ooo`803`;oo`0800ooo`0?
ool03ooo00ooo`<03`06ool03ooo00ooo`0?0ooo00H03oooool03ooo00l3ool0100?ool03`0?0_oo
00<03oooool0Sooo002_ool0100?oooooooo0P0?0ooo0P0?00?oo`0?ool00`0?00Coo`0?ool03`?o
o`0300oooooo00803`Goo`<03`;oo`0300oooooo08ooo`00[_oo100?8Ooo00@03oooool03i7oo`00
aooo00<03oooool0W_oo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00oooo
JOoo000`ool300l[ool300l00ooo00ooo`0200l]ool300l/ool01@0?ooooo`0?ool00P0?:ooo00<0
3oooool0;?oo00D03oooool03ooo00803bgoo`<03`koo`00<?oo00<03oooool0;?oo00<03oooool0
1?oo00<03oooool0:ooo00<03oooool0:_oo00<03ooo00l01Ooo00<03oooool09ooo00<03ooo00l0
;?oo00<03ooo00l01Ooo00<03oooool0:ooo00<03oooool03Ooo000[ool300l3ool00`0?ooooo`0V
ool300l2ool00`0?ooooo`02ool200lXool300l3ool00`0?ooooo`0Vool300l01?oo00ooo`0?0ooo
0P0?:_oo00<03ooo00l0;?oo00<03ooo00l00ooo0P0?;_oo00<03oooool03Ooo000`ool00`0?ool0
3`0/ool00`0?ooooo`02ool00`0?ooooo`0]ool00`0?ooooo`0Zool00`0?ool03`03ool00`0?oooo
o`0Yool00`0?ool03`0/ool00`0?ool03`03ool00`0?ooooo`0]ool00`0?ooooo`0=ool0037oo`80
3b_oo`803`Coo`<03bcoo`803bgoo`0300oooooo00;oo`<03b[oo`0300oooooo02coo`0300oooooo
00;oo`<03bcoo`803`ooo`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?oo
ofWoo`00ooooJOoo000Woooo00lk00l7ool002Ooo`0300oooooo00Goo`0300oooooo00Ooo`0300oo
oooo00Koo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oo
oooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oo
oooo00Ooo`0300oooooo00Ooo`0300oooooo00Koo`0300oooooo00Ooo`0300oooooo00Ooo`0300oo
oooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oo
oooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Koo`0300oo
oooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Ooo`0300oooooo00Goo`0300oo
oooo00Goo`007ooo00<03oooool01Ooo00<03oooool01Ooo00<03oooool0;_oo00<03oooool0;ooo
00<03oooool0;_oo00<03oooool0;ooo00<03oooool0;ooo00<03oooool0;_oo00<03oooool01Ooo
00<03oooool01Ooo000Nool00`0?ool03`06ool00`0?ooooo`0fool00`1oooooo`0_ool00`1ooooo
o`0^ool00`2?ooooo`0_ool00`0?ooooo`0_ool00`2?ooooo`0fool00`0?ooooo`05ool001koo`03
00ooo`0?00Koo`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`03
00oooooo02ooo`0307oooooo03Koo`0300oooooo00Goo`007_oo00<03ooo00l01_oo0`0?1OooEP0?
3Ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<03oooool02oooEP0?1Ooo0`0?1ooo000Oool00`0?
ooooo`05ool00`0?ooooo`0fool00`2?ooooo`0Qool300l;ool00`2?ooooo`0^ool00`1oooooo`0_
ool00`0?ooooo`09ool300lSool00`1oooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Ko
o`0307oooooo02?oo`803`[oo`0307oooooo02koo`0308oooooo02ooo`0300oooooo00Soo`803bGo
o`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Soooool09?oo0P0?2Ooo
00<0Soooool0;_oo00<0Ooooool0;ooo00<03oooool01ooo0P0?9_oo00<0Ooooool0=_oo00<03ooo
ool01Ooo000Wool00`0?ooooo`0fool00`1oooooo`0Uool200l8ool00`1oooooo`0^ool00`2?oooo
o`0_ool00`0?ooooo`06ool200lWool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo
03Koo`0308oooooo02Koo`0300oooooo00Koo`0308oooooo02koo`0307oooooo02ooo`0300oooooo
00Koo`0300oooooo02Koo`0307oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0
Ooooool09_oo00<03oooool01_oo00<0Ooooool0;_oo00<0Soooool0;ooo00<03oooool01Ooo0P0?
:?oo00<0Soooool0=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool00`2?ooooo`0Vool200l7
ool00`2?ooooo`0^ool00`1oooooo`0_ool00`0?ooooo`05ool00`0?ooooo`0Wool00`1oooooo`0f
ool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0307oooooo02Ooo`0300oooooo00Goo`0307oo
oooo02koo`0308oooooo02ooo`0300oooooo00Goo`0300oooooo02Ooo`0308oooooo03Koo`0300oo
oooo00Goo`009ooo0P0?=ooo00<0Soooool09ooo00<03oooool01Ooo00<0Soooool0;_oo00<0Oooo
ool0;ooo00<03oooool01?oo0P0?:Ooo00<0Ooooool0=?oo0`0?1ooo000Wool00`0?ooooo`0fool0
0`1oooooo`0Wool200l6ool00`1oooooo`0^ool00`2?ooooo`0_ool00`0?ooooo`04ool00`0?oooo
o`0Xool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo02Soo`03
00oooooo00Coo`0308oooooo02koo`0307oooooo02ooo`0300oooooo00Coo`0300oooooo02Soo`03
07oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Ooooool0:?oo00<03oooool0
1?oo00<0Ooooool0;_oo00<0Soooool0;ooo00<03oooool01?oo00<03oooool0:?oo00<0Soooool0
=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool00`2?ooooo`0Xool00`0?ooooo`04ool00`2?
ooooo`0^ool00`1oooooo`0_ool00`0?ooooo`03ool200lZool00`1oooooo`0fool00`0?ooooo`05
ool002Ooo`0300oooooo03Koo`0307oooooo02Soo`803`Goo`0307oooooo02koo`0308oooooo02oo
o`0300oooooo00?oo`0300oooooo02Woo`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03ooo
ool0=_oo00<0Soooool0:Ooo00<03oooool00ooo00<0Soooool0;_oo00<0Ooooool0;ooo00<03ooo
ool00ooo00<03oooool0:Ooo00<0Ooooool0=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool0
0`1oooooo`0Yool00`0?ooooo`03ool00`1oooooo`0^ool00`2?ooooo`0_ool00`0?ooooo`03ool0
0`0?ooooo`0Yool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo
02Woo`0300oooooo00?oo`0308oooooo02koo`0307oooooo02ooo`0300oooooo00?oo`0300oooooo
02Woo`0307oooooo03Koo`0300oooooo00Goo`009ooo0P0?=ooo00<0Ooooool0:Ooo00<03oooool0
0ooo00<0Ooooool0;_oo00<0Soooool0;ooo00<03oooool00ooo00<03oooool0:Ooo00<0Soooool0
=?oo0`0?1ooo000Wool00`0?ooooo`0fool00`2?ooooo`0Yool00`0?ooooo`03ool00`2?ooooo`0^
ool00`1oooooo`0_ool00`0?ooooo`02ool200l[ool00`1oooooo`0fool00`0?ooooo`05ool002Oo
o`0300oooooo03Koo`0307oooooo02Woo`803`Coo`0307oooooo02koo`0308oooooo02ooo`0300oo
oooo00;oo`0300oooooo02[oo`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo
00<0Soooool0:_oo00<03oooool00_oo00<0Soooool0;_oo00<0Ooooool0;ooo00<03oooool00_oo
00<03oooool0:_oo00<0Ooooool0=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool00`1ooooo
o`0Zool00`0?ooooo`02ool00`1oooooo`0^ool00`2?ooooo`0_ool00`0?ooooo`02ool00`0?oooo
o`0Zool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo02[oo`03
00oooooo00;oo`0308oooooo02koo`0307oooooo02ooo`0300oooooo00;oo`0300oooooo02[oo`03
07oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Ooooool0:_oo00<03oooool0
0_oo00<0Ooooool0;_oo00<0Soooool0;ooo00<03oooool00_oo00<03oooool0:_oo00<0Soooool0
=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool00`2?ooooo`0Zool00`0?ooooo`02ool00`2?
ooooo`0^ool00`1oooooo`0_ool00`0?ooooo`02ool00`0?ooooo`0Zool00`1oooooo`0fool00`0?
ooooo`05ool002Ooo`0300oooooo03Koo`0307oooooo02[oo`0300oooooo00;oo`0307oooooo02ko
o`0308oooooo02ooo`0300oooooo00;oo`0300oooooo02[oo`0308oooooo03Koo`0300oooooo00Go
o`009ooo0P0?=ooo00<0Soooool0:_oo00<03oooool00_oo00<0Soooool0;_oo00<0Ooooool0;ooo
00@03oooooooo`803bcoo`0307oooooo03Coo`<03`Ooo`009ooo00<03oooool0=_oo00<0Ooooool0
:_oo00<03oooool00_oo00<0Ooooool0;_oo00<0Soooool0;ooo00D03oooooooo`0?02goo`0308oo
oooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Soooool0:_oo0P0?0ooo00<0Sooo
ool0;_oo00<0Ooooool0;ooo00D03oooooooo`0?02goo`0307oooooo03Koo`0300oooooo00Goo`00
9ooo00<03oooool0=_oo00<0Ooooool0:ooo00D03oooooooo`1o033oo`0308oooooo02ooo`0500oo
ooooool03`0]ool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo
02_oo`0500ooooooool0S`0`ool00`1oooooo`0_ool01@0?oooooooo00l0;Ooo00<0Ooooool0=_oo
00<03oooool01Ooo000Wool00`0?ooooo`0fool00`1oooooo`0[ool01@0?oooooooo07l0<?oo00<0
Soooool0;ooo00D03oooooooo`0?02goo`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03ooo
ool0=_oo00<0Soooool0:ooo00D03oooooooo`2?033oo`0307oooooo02ooo`0500ooooooool03`0]
ool00`1oooooo`0fool00`0?ooooo`05ool001Woo`0500oooooo00ooo`0300l6ool00`0?ooooo`0f
ool00`1oooooo`0[ool01@0?oooooooo07l0<?oo00<0Soooool0;ooo00D03oooooooo`0?02goo`03
08oooooo03Koo`0300oooooo00Goo`006?oo00<03ooo00l00ooo00<03oooool01_oo00<03oooool0
=_oo00<0Soooool0:ooo00D03oooooooo`2?033oo`0307oooooo02ooo`0500ooooooool03`0]ool0
0`1oooooo`0fool00`0?ooooo`05ool001Soo`0300ooo`0?00Coo`0300oooooo00Goo`<03`3o07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o00l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o000e07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`0300l7ool001Soo`0300ooo`0?00?oo`0300ooo`0?00Koo`0300oooooo
03Koo`0308oooooo02_oo`0500ooooooool0S`0`ool00`1oooooo`0_ool00`0?ooooo`0200l]ool0
0`1oooooo`0fool00`0?ooooo`05ool001Woo`0300oooooo00?oo`803`Koo`0300oooooo03Koo`03
07oooooo02_oo`0500ooooooool0O`0`ool00`2?ooooo`0_ool0100?ooooo`0?;_oo00<0Soooool0
=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool00`2?ooooo`0[ool01@0?oooooooo08l0<?oo
00<0Ooooool0;ooo00@03oooool03bkoo`0307oooooo03Koo`0300oooooo00Goo`009ooo00<03ooo
ool0=_oo00<0Ooooool0:ooo0P0?0_oo00<0Ooooool0;_oo00<0Soooool0;ooo00@03oooool03bko
o`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Soooool0;?oo00@03ooo
ool0Sc3oo`0307oooooo02ooo`0400oooooo00l^ool00`1oooooo`0fool00`0?ooooo`05ool002Oo
o`0300oooooo03Koo`0307oooooo02coo`0400oooooo07l`ool00`2?ooooo`0_ool0100?ooooo`0?
;_oo00<0Soooool0=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool00`2?ooooo`0/ool0100?
ooooo`2?<?oo00<0Ooooool0;ooo00@03oooool03bkoo`0307oooooo03Koo`0300oooooo00Goo`00
9ooo00<03oooool0=_oo00<0Ooooool0;?oo00@03oooool0Oc3oo`0308oooooo02ooo`0400oooooo
00l^ool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo02coo`04
00oooooo08l`ool00`1oooooo`0_ool0100?ooooo`0?;_oo00<0Ooooool0=_oo00<03oooool01Ooo
000Wool200lgool00`1oooooo`0/ool0100?ooooo`1o<?oo00<0Soooool0;ooo00@03oooool03bko
o`0308oooooo03Coo`<03`Ooo`009ooo00<03oooool0=_oo00<0Soooool0;?oo00@03oooool0Sc3o
o`0307oooooo02ooo`0400oooooo00l^ool00`1oooooo`0fool00`0?ooooo`05ool002Ooo`0300oo
oooo03Koo`0307oooooo02coo`0400oooooo07l`ool00`2?ooooo`0_ool0100?ooooo`0?;_oo00<0
Soooool0=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool00`2?ooooo`0/ool0100?ooooo`2?
<?oo00<0Ooooool0;ooo00@03oooool03bkoo`0307oooooo03Koo`0300oooooo00Goo`009ooo00<0
3oooool0=_oo00<0Ooooool0;?oo00@03oooool0Oc3oo`0308oooooo02ooo`0400ooo`0?00l^ool0
0`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo02coo`0400oooooo
08l`ool00`1oooooo`0_ool00`0?ool03`0_ool00`1oooooo`0fool00`0?ooooo`05ool002Ooo`03
00oooooo03Koo`0307oooooo02coo`0400oooooo07l`ool00`2?ooooo`0_ool00`0?ool03`0_ool0
0`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo02coo`0400oooooo
08l`ool00`1oooooo`0_ool00`0?ool03`0_ool00`1oooooo`0fool00`0?ooooo`05ool002Ooo`03
00oooooo03Koo`0307oooooo02coo`803`03ool0Oooo02ooo`0308oooooo02ooo`0300ooo`0?02oo
o`0308oooooo03Koo`0300oooooo00Goo`009ooo0P0?=ooo00<0Soooool0;Ooo00<03ooo08l0<?oo
00<0Ooooool0;ooo00<03ooo00l0;ooo00<0Ooooool0=?oo0`0?1ooo000Wool00`0?ooooo`0fool0
0`1oooooo`0]ool00`0?ool0O`0`ool00`2?ooooo`0_ool00`0?ool03`0_ool00`2?ooooo`0fool0
0`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo02goo`0300ooo`2?033oo`0307oooooo
02ooo`0300ooo`0?02ooo`0307oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0
Ooooool0;Ooo00<03ooo07l0<?oo00<0Soooool0;ooo00<03ooo00l0;ooo00<0Soooool0=_oo00<0
3oooool01Ooo000Wool00`0?ooooo`0fool00`2?ooooo`0]ool00`0?ool0S`0`ool00`1oooooo`0_
ool00`0?ool03`0_ool00`1oooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0307oo
oooo02goo`0300ooo`1o033oo`0308oooooo02ooo`0300ooo`0?02ooo`0308oooooo03Koo`0300oo
oooo00Goo`009ooo00<03oooool0=_oo00<0Soooool0;Ooo00<03ooo08l0<?oo00<0Ooooool0;ooo
00<03ooo00l0;ooo00<0Ooooool0=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool00`1ooooo
o`0]ool00`0?ool0O`0`ool00`2?ooooo`0_ool00`0?ool03`0_ool00`2?ooooo`0fool00`0?oooo
o`05ool002Ooo`0300oooooo03Koo`0308oooooo02goo`0300ooo`2?033oo`0307oooooo02ooo`03
00ooo`0?02ooo`0307oooooo03Koo`0300oooooo00Goo`009ooo0P0?=ooo00<0Ooooool0;Ooo00<0
3ooo07l0<?oo00<0Soooool0;ooo00<03ooo00l0;ooo00<0Soooool0=?oo0`0?1ooo000Wool00`0?
ooooo`0fool00`2?ooooo`0]ool00`0?ool0S`0`ool00`1oooooo`0_ool300l_ool00`1oooooo`0f
ool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0307oooooo02goo`0300ooo`1o033oo`0308oo
oooo02ooo`803c3oo`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Sooo
ool0;Ooo00<03ooo08l0<?oo00<0Ooooool0;ooo0P0?<?oo00<0Ooooool0=_oo00<03oooool01Ooo
000Wool00`0?ooooo`0fool00`1oooooo`0]ool00`0?ool0O`0`ool00`2?ooooo`0_ool200l`ool0
0`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo02goo`803`0308oo
oooo02koo`0307oooooo02ooo`803c3oo`0307oooooo03Koo`0300oooooo00Goo`009ooo00<03ooo
ool0=_oo00<0Ooooool0;_oo00<03`1oool0;ooo00<0Soooool0;ooo0P0?<?oo00<0Soooool0=_oo
00<03oooool01Ooo000Iool0100?ooooo`0?0ooo00<03oooool01?oo00<03oooool0=_oo00<0Sooo
ool0;_oo00<03`2?ool0;ooo00<0Ooooool0;ooo0P0?<?oo00<0Ooooool0=_oo00<03oooool01Ooo
000Hool00`0?ool03`03ool300l6ool00`0?ooooo`0fool00`1oooooo`0^ool00`0?07ooo`0_ool0
0`2?ooooo`0_ool200l`ool00`2?ooooo`0fool00`0?ooooo`05ool001Soo`0300ooo`0?00?oo`03
00ooo`0?00Koo`<03`3;08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`0200l0I`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00<03`Ooo`002ooo00<03oooool00_oo00<0
3oooool01Ooo00<03ooo00l01?oo0P0?1_oo00<03oooool0=_oo00<0Ooooool0;_oo00<03`1oool0
;ooo00<0Soooool0;ooo0P0?<?oo00<0Soooool0=_oo00<03oooool01Ooo000;ool600l8ool00`0?
ooooo`04ool00`0?ooooo`04ool00`0?ooooo`0fool00`2?ooooo`0^ool00`0?08ooo`0_ool00`1o
ooooo`0_ool200l`ool00`1oooooo`0fool00`0?ooooo`05ool000_oo`0400oooooo00lHool00`0?
ooooo`0fool00`1oooooo`0^ool00`0?07ooo`0_ool00`2?ooooo`0_ool200l`ool00`2?ooooo`0f
ool00`0?ooooo`05ool000coo`803aWoo`0300oooooo03Koo`0308oooooo02koo`0300l0Sooo02oo
o`0307oooooo02ooo`803c3oo`0307oooooo03Koo`0300oooooo00Goo`004?oo00<03oooool05?oo
00<03oooool0=_oo00<0Ooooool0;_oo00<03`1oool0;ooo00<0Soooool0;ooo0P0?<?oo00<0Sooo
ool0=_oo00<03oooool01Ooo000=ool400lFool00`0?ooooo`0fool00`2?ooooo`0^ool00`0?08oo
o`0_ool00`1oooooo`0_ool200l`ool00`1oooooo`0fool00`0?ooooo`05ool000goo`0400oooooo
00lFool00`0?ooooo`0fool00`1oooooo`0^ool00`0?07ooo`0_ool00`2?ooooo`0_ool200l`ool0
0`2?ooooo`0fool00`0?ooooo`05ool000koo`803aOoo`0300oooooo03Koo`0308oooooo02koo`03
00l0Sooo02ooo`0307oooooo02ooo`803c3oo`0307oooooo03Koo`0300oooooo00Goo`003Ooo00@0
3oooool03aKoo`803cOoo`0307oooooo02koo`0300l0Oooo02ooo`0308oooooo02ooo`803c3oo`03
08oooooo03Coo`<03`Ooo`003Ooo00@03oooool03aKoo`0300oooooo03Koo`0308oooooo02koo`03
00l0Sooo02ooo`0307oooooo02ooo`0300oooooo02ooo`0307oooooo03Koo`0300oooooo00Goo`00
3_oo0P0?5ooo00<03oooool0=_oo00<0Ooooool0;_oo00<03`1oool0;ooo00<0Soooool0;ooo00<0
3oooool0;ooo00<0Soooool0=_oo00<03oooool01Ooo000;ool500lGool00`0?ooooo`0fool00`2?
ooooo`0^ool00`0?08ooo`0_ool00`1oooooo`0_ool00`0?ooooo`0_ool00`1oooooo`0fool00`0?
ooooo`05ool000goo`0400oooooo00lFool00`0?ooooo`0fool00`1oooooo`0^ool00`0?07ooo`0_
ool00`2?ooooo`0_ool00`0?ooooo`0_ool00`2?ooooo`0fool00`0?ooooo`05ool000goo`0400oo
oooo00lFool00`0?ooooo`0fool00`2?ooooo`0^ool200l`ool00`1oooooo`0_ool00`0?ooooo`0_
ool00`1oooooo`0fool00`0?ooooo`05ool000koo`803aOoo`0300oooooo03Koo`0307oooooo02oo
o`0300oooooo02koo`0308oooooo02ooo`0300oooooo02ooo`0308oooooo03Koo`0300oooooo00Go
o`003Ooo00<03ooo00l05ooo00<03oooool0=_oo00<0Soooool0;ooo00<03oooool0;_oo00<0Oooo
ool0;ooo00<03oooool0;ooo00<0Ooooool0=_oo00<03oooool01Ooo000=ool200l00ooo00ooo`0E
ool00`0?ooooo`0fool00`1oooooo`0_ool00`0?ooooo`0^ool00`2?ooooo`0_ool00`0?ooooo`0_
ool00`2?ooooo`0fool00`0?ooooo`05ool000koo`<03aKoo`0300oooooo03Koo`0308oooooo02oo
o`0300oooooo02koo`0307oooooo02ooo`0300oooooo02ooo`0307oooooo03Koo`0300oooooo00Go
o`004?oo00<03oooool05?oo0P0?=ooo00<0Ooooool0;ooo00<03oooool0;_oo00<0Soooool0;ooo
00<03oooool0;ooo00<0Soooool0=?oo0`0?1ooo000;ool500lGool00`0?ooooo`0fool00`2?oooo
o`0_ool00`0?ooooo`0^ool00`1oooooo`0_ool00`0?ooooo`0_ool00`1oooooo`0fool00`0?oooo
o`05ool000goo`0400oooooo00lFool00`0?ooooo`0fool00`1oooooo`0_ool00`0?ooooo`0^ool0
0`2?ooooo`0_ool00`0?ooooo`0_ool00`2?ooooo`0fool00`0?ooooo`05ool000goo`0400oooooo
00lFool00`0?ooooo`0fool00`2?ooooo`0_ool00`0?ooooo`0^ool00`1oooooo`0_ool00`0?oooo
o`0_ool00`1oooooo`0fool00`0?ooooo`05ool000koo`803aOoo`0300oooooo03Koo`0307oooooo
02ooo`0300oooooo02koo`0308oooooo02ooo`0300oooooo02ooo`0308oooooo03Koo`0300oooooo
00Goo`003_oo00<03ooo00l05_oo00<03oooool0=_oo00<0Soooool0;ooo00<03oooool0;_oo00<0
Ooooool0;ooo00<03oooool0;ooo00<0Ooooool0=_oo00<03oooool01Ooo000;ool00`0?ool03`03
00lFool00`0?ooooo`0fool00`1oooooo`0_ool00`0?ooooo`0^ool00`2?ooooo`0_ool00`0?oooo
o`0_ool00`2?ooooo`0fool00`0?ooooo`05ool000coo`0500ooooooool03`0Fool00`0?ooooo`0f
ool00`2?ooooo`0_ool00`0?ooooo`0^ool00`1oooooo`0^ool200laool00`1oooooo`0fool00`0?
ooooo`05ool000_oo`H03aKoo`0300oooooo03Koo`0307oooooo02ooo`0300oooooo02koo`0308oo
oooo02koo`803c7oo`0308oooooo03Koo`0300oooooo00Goo`003_oo00<03ooo00l05_oo0P0?=ooo
00<0Soooool0;ooo00<03oooool0;_oo00<0Ooooool0;_oo0P0?<Ooo00<0Ooooool0=?oo0`0?1ooo
000;ool00`0?ool03`0300lFool00`0?ooooo`0fool00`1oooooo`0_ool00`0?ooooo`0^ool00`2?
ooooo`0^ool200laool00`2?ooooo`0fool00`0?ooooo`05ool000coo`D03aKoo`0300oooooo03Ko
o`0308oooooo02ooo`0300oooooo02koo`0307oooooo02koo`803c7oo`0307oooooo03Koo`0300oo
oooo00Goo`003Ooo00@03oooool03aKoo`0300oooooo03Koo`0307oooooo02ooo`803booo`0308oo
oooo02koo`803c7oo`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Sooo
ool0;ooo00<0S`0?ool0;_oo00<0Ooooool0;_oo0P0?<Ooo00<0Ooooool0=_oo00<03oooool01Ooo
000=ool00`0?ooooo`02ool00`0?ooooo`0Bool00`0?ooooo`0fool00`1oooooo`0_ool00`1o00oo
o`0^ool00`2?ooooo`0^ool200laool00`2?ooooo`0fool00`0?ooooo`05ool000goo`<03`03ool0
3`0?00Koo`0400oooooo00l2ool00`0?ooooo`05ool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?
00ooo`0^ool00`1oooooo`0^ool200laool00`1oooooo`0fool00`0?ooooo`05ool000ooo`803`Oo
o`0300ooo`0?00?oo`0300ooo`0?00Koo`0300oooooo03Koo`0307oooooo02ooo`0307l03ooo02ko
o`0308oooooo02koo`803c7oo`0308oooooo03Koo`0300oooooo00Goo`003Ooo0P0?2Ooo00<03ooo
00l00ooo0P0?1ooo00<03oooool0=_oo00<0Soooool0;ooo00<0S`0?ool0;_oo00<0Ooooool0;_oo
0P0?<Ooo00<0Ooooool0=_oo00<03oooool01Ooo000Hool00`0?ool03`03ool00`0?ooooo`06ool3
00l0bP1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?0P0?06P0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?0`0?1ooo000Iool00`0?ooooo`03ool200l6ool00`0?ooooo`0f
ool00`2?ooooo`0_ool00`2?00ooo`0^ool00`1oooooo`0^ool200laool00`1oooooo`0fool00`0?
ooooo`05ool002Ooo`0300oooooo03Koo`0307oooooo02ooo`0307l03ooo02koo`0308oooooo02ko
o`803c7oo`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Soooool0;ooo
00<0S`0?ool0;_oo00<0Ooooool0;_oo0P0?<Ooo00<0Ooooool0=_oo00<03oooool01Ooo000Wool0
0`0?ooooo`0fool00`1oooooo`0_ool00`1o00ooo`0^ool00`2?ooooo`0^ool200laool00`2?oooo
o`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo02ooo`0308l03ooo02koo`03
07oooooo02koo`803c7oo`0307oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0
Ooooool0;ooo00<0O`0?ool0;_oo00<0Soooool0;Ooo0`0?<Ooo00<0Soooool0=_oo00<03oooool0
1Ooo000Wool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?00ooo`0^ool00`1oooooo`0]ool00`0?
ool03`0aool00`1oooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0307oooooo02oo
o`0307l03ooo02koo`0308oooooo02goo`0300ooo`0?037oo`0308oooooo03Koo`0300oooooo00Go
o`009ooo0P0?=ooo00<0Soooool0;ooo00<0S`0?ool0;_oo00<0Ooooool0;Ooo00<03ooo00l0<Ooo
00<0Ooooool0=?oo0`0?1ooo000Wool00`0?ooooo`0fool00`1oooooo`0_ool00`1o00ooo`0^ool0
0`2?ooooo`0]ool00`0?ool03`0aool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo
03Koo`0308oooooo02ooo`0308l03`0?02koo`0307oooooo02goo`0300ooo`0?037oo`0307oooooo
03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Ooooool0;ooo00<0Oooo00l0;_oo00<0
Soooool0;Ooo00<03ooo00l0<Ooo00<0Soooool0=_oo00<03oooool01Ooo000Wool00`0?ooooo`0f
ool00`2?ooooo`0_ool00`2?ool03`0^ool00`1oooooo`0]ool00`0?ool03`0aool00`1oooooo`0f
ool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0307oooooo02ooo`0307ooo`0?02koo`0308oo
oooo02goo`0300ooo`0?037oo`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo
00<0Soooool0;ooo00<0Sooo00l0;_oo00<0Ooooool0;Ooo00<03ooo00l0<Ooo00<0Ooooool0=_oo
00<03oooool01Ooo000Wool00`0?ooooo`0fool00`1oooooo`0_ool00`1oool03`0^ool00`2?oooo
o`0]ool00`0?ool03`0aool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`03
08oooooo02ooo`0308ooo`0?02koo`0307oooooo02goo`0300ooo`0?037oo`0307oooooo03Koo`03
00oooooo00Goo`009ooo0P0?=ooo00<0Ooooool0;ooo00<0Oooo00l0;_oo00<0Soooool0;Ooo00<0
3ooo00l0<Ooo00<0Soooool0=?oo0`0?1ooo000Wool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?
ool03`0^ool00`1oooooo`0]ool00`0?ool03`0aool00`1oooooo`0fool00`0?ooooo`05ool002Oo
o`0300oooooo03Koo`0307oooooo02ooo`0307ooo`0?02koo`0308oooooo02goo`0300ooo`0?037o
o`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Soooool0;ooo00<0Sooo
00l0;_oo00<0Ooooool0;Ooo00<03ooo00l0<Ooo00<0Ooooool0=_oo00<03oooool01Ooo000Wool0
0`0?ooooo`0fool00`1oooooo`0_ool00`1oool03`0^ool00`2?ooooo`0/ool200l00ooo00ooo`0`
ool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo02ooo`0308oo
o`0?02koo`0307oooooo02coo`0400oooooo00laool00`1oooooo`0fool00`0?ooooo`05ool002Oo
o`0300oooooo03Koo`0307oooooo02ooo`0307ooo`0?02koo`0308oooooo02coo`0400oooooo00la
ool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo02ooo`0308oo
o`0?02koo`0307oooooo02coo`0400oooooo00laool00`1oooooo`0fool00`0?ooooo`05ool002Oo
o`0300oooooo03Koo`0307oooooo02ooo`0407ooo`0?00l]ool00`2?ooooo`0/ool0100?ooooo`0?
<Ooo00<0Soooool0=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool00`2?ooooo`0_ool0102?
ooooo`0?;Ooo00<0Ooooool0;?oo00@03oooool03c7oo`0307oooooo03Koo`0300oooooo00Goo`00
9ooo0P0?=ooo00<0Ooooool0;ooo00@0Ooooool03bgoo`0308oooooo02coo`0400oooooo00laool0
0`2?ooooo`0dool300l7ool002Ooo`0300oooooo03Koo`0308oooooo02ooo`0408oooooo00l]ool0
0`1oooooo`0/ool0100?ooooo`0?<Ooo00<0Ooooool0=_oo00<03oooool01Ooo000Wool00`0?oooo
o`0fool00`1oooooo`0_ool0101oooooo`0?;Ooo00<0Soooool0;?oo00@03oooool03c7oo`0308oo
oooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Soooool0;ooo00@0Soooool03bgo
o`0307oooooo02coo`0400oooooo00laool00`1oooooo`0fool00`0?ooooo`05ool002Ooo`0300oo
oooo03Koo`0307oooooo02ooo`0407oooooo00l]ool00`2?ooooo`0/ool0100?ooooo`0?<Ooo00<0
Soooool0=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool00`2?ooooo`0_ool0102?ooooo`0?
;Ooo00<0Ooooool0;?oo00@03oooool03c7oo`0307oooooo03Koo`0300oooooo00Goo`006Ooo00@0
3oooool03`;oo`0300oooooo00Goo`0300oooooo03Koo`0307oooooo02ooo`0407oooooo00l]ool0
0`2?ooooo`0/ool0100?ooooo`0?<Ooo00<0Soooool0=_oo00<03oooool01Ooo000Hool00`0?ool0
3`03ool00`0?ool03`06ool00`0?ooooo`0fool00`2?ooooo`0_ool0102?ooooo`0?;Ooo00<0Oooo
ool0:ooo0P0?0_oo00<03oooool0;ooo00<0Ooooool0=_oo00<03oooool01Ooo000Hool00`0?ool0
3`04ool00`0?ooooo`05ool00`0?ooooo`0fool00`1oooooo`0_ool0101oooooo`0?;Ooo00<0Sooo
ool0:ooo00D03oooooooo`0?037oo`0308oooooo03Koo`0300oooooo00Goo`006?oo00<03ooo00l0
0ooo00<03ooo00l01_oo0`0?0?l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?
08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l003D0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00<03`Ooo`006Ooo00<03oooool0
0ooo00<03oooool01Ooo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool00P0?;?oo00<0Sooo
ool0:ooo00D03oooooooo`0?037oo`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0
=_oo00<0Soooool0;ooo00D0Soooooooo`0?02coo`0307oooooo02_oo`0500ooooooool03`0aool0
0`1oooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0307oooooo02ooo`0507oooooo
ool03`0/ool00`2?ooooo`0[ool01@0?oooooooo00l0<Ooo00<0Soooool0=_oo00<03oooool01Ooo
000Wool00`0?ooooo`0fool00`2?ooooo`0_ool01@2?oooooooo00l0;?oo00<0Ooooool0:ooo00D0
3oooooooo`0?037oo`0307oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Oooo
ool0;ooo00D0Ooooooooo`0?02coo`0308oooooo02_oo`0500ooooooool03`0aool00`2?ooooo`0f
ool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oooooo02ooo`0508ooooooool03`0/ool0
0`1oooooo`0[ool01@0?oooooooo00l0<Ooo00<0Ooooool0=_oo00<03oooool01Ooo000Wool00`0?
ooooo`0fool00`1oooooo`0_ool01@1ooooooooo00l0;?oo00<0Soooool0:ooo00D03oooooooo`0?
037oo`0308oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Soooool0;ooo00D0
Soooooooo`0?02coo`0307oooooo02[oo`803`?oo`0300oooooo02ooo`0307oooooo03Koo`0300oo
oooo00Goo`009ooo0P0?=ooo00<0Ooooool0;ooo00D0Ooooooooo`0?02coo`0308oooooo02[oo`03
00oooooo00;oo`0300oooooo02ooo`0308oooooo03Coo`<03`Ooo`009ooo00<03oooool0=_oo00<0
Soooool0;ooo00D0Soooooooo`0?02coo`0307oooooo02[oo`0300oooooo00;oo`0300oooooo02oo
o`0307oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Ooooool0;ooo00@0Oooo
ooooo`803b_oo`0308oooooo02[oo`0300oooooo00;oo`0300oooooo02ooo`0308oooooo03Koo`03
00oooooo00Goo`009ooo00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool00_oo00<03oooool0
:Ooo00<0Ooooool0:_oo00<03oooool00_oo00<03oooool0;ooo00<0Ooooool0=_oo00<03oooool0
1Ooo000Wool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`02ool00`0?ooooo`0Yool00`2?
ooooo`0Zool00`0?ooooo`02ool00`0?ooooo`0_ool00`2?ooooo`0fool00`0?ooooo`05ool002Oo
o`0300oooooo03Koo`0308oooooo02ooo`0308oooooo00;oo`0300oooooo02Woo`0307oooooo02[o
o`0300oooooo00;oo`0300oooooo02ooo`0307oooooo03Koo`0300oooooo00Goo`009ooo00<03ooo
ool0=_oo00<0Ooooool0;ooo00<0Ooooool00_oo00<03oooool0:Ooo00<0Soooool0:_oo00<03ooo
ool00_oo00<03oooool0;ooo00<0Soooool0=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool0
0`2?ooooo`0_ool00`2?ooooo`02ool00`0?ooooo`0Yool00`1oooooo`0Zool00`0?ooooo`02ool0
0`0?ooooo`0_ool00`1oooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0307oooooo
02ooo`0307oooooo00;oo`0300oooooo02Woo`0308oooooo02Woo`803`Coo`0300oooooo02ooo`03
08oooooo03Koo`0300oooooo00Goo`009ooo0P0?=ooo00<0Soooool0;ooo00<0Soooool00_oo0P0?
:_oo00<0Ooooool0:Ooo00<03oooool00ooo00<03oooool0;ooo00<0Ooooool0=?oo0`0?1ooo000W
ool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`03ool00`0?ooooo`0Xool00`2?ooooo`0Y
ool00`0?ooooo`03ool00`0?ooooo`0_ool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oo
oooo03Koo`0308oooooo02ooo`0308oooooo00?oo`0300oooooo02Soo`0307oooooo02Woo`0300oo
oooo00?oo`0300oooooo02ooo`0307oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo
00<0Ooooool0;ooo00<0Ooooool00ooo00<03oooool0:?oo00<0Soooool0:Ooo00<03oooool00ooo
00<03oooool0;ooo00<0Soooool0=_oo00<03oooool01Ooo000Wool00`0?ooooo`0fool00`2?oooo
o`0_ool00`2?ooooo`03ool00`0?ooooo`0Xool00`1oooooo`0Yool00`0?ooooo`03ool00`0?oooo
o`0_ool00`1oooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0307oooooo02ooo`03
07oooooo00?oo`0300oooooo02Soo`0308oooooo02Soo`803`Goo`0300oooooo02ooo`0308oooooo
03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool00ooo0P0?
:Ooo00<0Ooooool0:?oo00<03oooool01?oo00<03oooool0;ooo00<0Ooooool0=_oo00<03oooool0
1Ooo000Wool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`04ool00`0?ooooo`0Wool00`2?
ooooo`0Xool00`0?ooooo`04ool00`0?ooooo`0_ool00`2?ooooo`0fool00`0?ooooo`05ool002Oo
o`0300oooooo03Koo`0308oooooo02ooo`0308oooooo00Coo`0300oooooo02Ooo`0307oooooo02So
o`0300oooooo00Coo`0300oooooo02ooo`0307oooooo03Koo`0300oooooo00Goo`009ooo0P0?=ooo
00<0Ooooool0;ooo00<0Ooooool01?oo00<03oooool09ooo00<0Soooool09ooo0P0?1_oo00<03ooo
ool0;ooo00<0Soooool0=?oo0`0?1ooo000Wool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?oooo
o`04ool200lXool00`1oooooo`0Wool00`0?ooooo`05ool00`0?ooooo`0_ool00`1oooooo`0fool0
0`0?ooooo`05ool002Ooo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo00Goo`0300oooooo
02Koo`0308oooooo02Ooo`0300oooooo00Goo`0300oooooo02ooo`0308oooooo03Koo`0300oooooo
00Goo`009ooo00<03oooool0=_oo00<0Soooool0;ooo00<0Soooool01Ooo00<03oooool09_oo00<0
Ooooool09_oo0P0?1ooo00<03oooool0;ooo00<0Ooooool0=_oo00<03oooool01Ooo000Wool00`0?
ooooo`0fool00`1oooooo`0_ool00`1oooooo`05ool200lWool00`2?ooooo`0Vool00`0?ooooo`06
ool00`0?ooooo`0_ool00`2?ooooo`0fool00`0?ooooo`05ool002Ooo`0300oooooo03Koo`0308oo
oooo02ooo`0308oooooo00Koo`803bKoo`0307oooooo02Goo`803`Soo`0300oooooo02ooo`0307oo
oooo03Koo`0300oooooo00Goo`009ooo00<03oooool0=_oo00<0Ooooool0;ooo00<0Ooooool01ooo
00<03oooool09?oo00<0Soooool09?oo0P0?2Ooo00<03oooool0;ooo00<0Soooool0=_oo00<03ooo
ool01Ooo000Nool300l6ool00`0?ooooo`0fool00`2?ooooo`0_ool00`2?ooooo`07ool200lUool0
0`1oooooo`0Sool200l:ool00`0?ooooo`0_ool00`1oooooo`0fool00`0?ooooo`05ool001ooo`03
00oooooo00Goo`0300oooooo03Koo`0307oooooo02ooo`0307oooooo00Soo`<03b?oo`0308oooooo
02;oo`803`_oo`0300oooooo02ooo`0308oooooo03Koo`0300oooooo00Goo`007ooo00<03oooool0
1Ooo0`0?=_oo00<0Soooool0;ooo00<0Soooool02_ooBP0?3?oo00<03oooool0;ooo00<0Ooooool0
=?oo0`0?1ooo000Oool00`0?ooooo`05ool00`0?ooooo`0fool00`1oooooo`0_ool00`1oooooo`0^
ool00`2?ooooo`0_ool00`0?ooooo`0_ool00`2?ooooo`0fool00`0?ooooo`05ool001koo`803`Oo
o`0300oooooo03Koo`0308oooooo02ooo`0308oooooo02koo`0307oooooo02ooo`0300oooooo02oo
o`0307oooooo03Koo`0300oooooo00Goo`009ooo00<03oooool01Ooo00<03oooool0;_oo00<03ooo
ool0;ooo00<03oooool0;_oo00<03oooool0;ooo00<03oooool0;ooo00<03oooool0;_oo00<03ooo
ool01Ooo00<03oooool01Ooo000Wool00`0?ooooo`05ool00`0?ooooo`07ool00`0?ooooo`06ool0
0`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool0
0`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool0
0`0?ooooo`07ool00`0?ooooo`06ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool0
0`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool0
0`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`06ool00`0?ooooo`07ool0
0`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?ooooo`05ool00`0?ooooo`05ool0
02Ooool03c/03`Ooo`00ooooJOoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2.475058, -0.171329, 
  0.012605, 0.006798}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Print["\<side-wall width = \>", 
      \(4\ K\ tblT\[LeftDoubleBracket]3\[RightDoubleBracket]\)\/e /. NSub, 
      "\< [eV]\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("side-wall width = "\[InvisibleSpace]0.10340863024335698`
        \[InvisibleSpace]" [eV]"\),
      SequenceForm[ "side-wall width = ", 0.10340863024335698, " [eV]"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[{
    \(\(Clear[fc]; \)\), 
    \(\(fc[En_, EF_, T_] = f[En, EF, 0, T]\ \((1. - f[En, EF, 0, T])\); 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig12x3 = 
      Plot[Evaluate[{
            fc[En, 0, tblT\[LeftDoubleBracket]1\[RightDoubleBracket]], 
            fc[En, 0, tblT\[LeftDoubleBracket]2\[RightDoubleBracket]], 
            fc[En, 0, tblT\[LeftDoubleBracket]3\[RightDoubleBracket]]}], {En, 
          \(-.1\), .1}, 
        FrameLabel \[Rule] {"\<Energy in eV\>", "\<Convolution\>"}, 
        Evaluate[opt]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 4.761905 0.014715 2.354415 [
[.02381 -0.0125 -10 -12 ]
[.02381 -0.0125 10 0 ]
[.2619 -0.0125 -12 -12 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.7381 -0.0125 -9 -12 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -7 -12 ]
[.97619 -0.0125 7 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -23.5 -24 ]
[.5 -0.0125 23.5 -12 ]
[-0.0125 .01472 -8 -6 ]
[-0.0125 .01472 0 6 ]
[-0.0125 .13244 -18 -6 ]
[-0.0125 .13244 0 6 ]
[-0.0125 .25016 -14 -6 ]
[-0.0125 .25016 0 6 ]
[-0.0125 .36788 -18 -6 ]
[-0.0125 .36788 0 6 ]
[-0.0125 .4856 -14 -6 ]
[-0.0125 .4856 0 6 ]
[-0.0125 .60332 -18 -6 ]
[-0.0125 .60332 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30 -22 ]
[-0.01875 .30902 -18 22 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .13244 m
1 .13244 L
s
0 .25016 m
1 .25016 L
s
0 .36788 m
1 .36788 L
s
0 .4856 m
1 .4856 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -71 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -73 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -70 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -84.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Energy) show
88.000000 13.000000 moveto
(in) show
96.187500 13.000000 moveto
(eV) show
105.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .03826 m
.00375 .03826 L
s
0 .0618 m
.00375 .0618 L
s
0 .08535 m
.00375 .08535 L
s
0 .10889 m
.00375 .10889 L
s
0 .15598 m
.00375 .15598 L
s
0 .17952 m
.00375 .17952 L
s
0 .20307 m
.00375 .20307 L
s
0 .22661 m
.00375 .22661 L
s
0 .2737 m
.00375 .2737 L
s
0 .29724 m
.00375 .29724 L
s
0 .32079 m
.00375 .32079 L
s
0 .34433 m
.00375 .34433 L
s
0 .39142 m
.00375 .39142 L
s
0 .41497 m
.00375 .41497 L
s
0 .43851 m
.00375 .43851 L
s
0 .46205 m
.00375 .46205 L
s
0 .50914 m
.00375 .50914 L
s
0 .53269 m
.00375 .53269 L
s
0 .55623 m
.00375 .55623 L
s
0 .57977 m
.00375 .57977 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
83 10 translate
90 rotate
-83 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Convolution) show
102.875000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03826 m
1 .03826 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .08535 m
1 .08535 L
s
.99625 .10889 m
1 .10889 L
s
.99625 .15598 m
1 .15598 L
s
.99625 .17952 m
1 .17952 L
s
.99625 .20307 m
1 .20307 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .2737 m
1 .2737 L
s
.99625 .29724 m
1 .29724 L
s
.99625 .32079 m
1 .32079 L
s
.99625 .34433 m
1 .34433 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .41497 m
1 .41497 L
s
.99625 .43851 m
1 .43851 L
s
.99625 .46205 m
1 .46205 L
s
.99625 .50914 m
1 .50914 L
s
.99625 .53269 m
1 .53269 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57977 m
1 .57977 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.40095 .01472 L
.41127 .01472 L
.42237 .01472 L
.42781 .01472 L
.43049 .01472 L
.43298 .01472 L
.43522 .01472 L
.43648 .01472 L
.43762 .01472 L
.43887 .01472 L
.43958 .01472 L
.44023 .01472 L
.44142 .01472 L
.44268 .01472 L
.44387 .01472 L
.44495 .01472 L
.44619 .01472 L
.44738 .01472 L
.44847 .01472 L
.44947 .01472 L
.45058 .01472 L
.45176 .01472 L
.45293 .01472 L
.4542 .01472 L
.45539 .01472 L
.45649 .01472 L
.45771 .01472 L
.4584 .01472 L
.45904 .01472 L
.46033 .01472 L
.46106 .01472 L
.46172 .01472 L
.46291 .01472 L
.46403 .01472 L
.46525 .01472 L
.46656 .01472 L
.46722 .01472 L
.46794 .01472 L
.46925 .01472 L
.47052 .01472 L
Mistroke
.4717 .01472 L
.4729 .01472 L
.47404 .01472 L
.47506 .01472 L
.47616 .01472 L
.47736 .01472 L
.47863 .01472 L
.47971 .01473 L
.4809 .01475 L
.48157 .01477 L
.4823 .0148 L
.48362 .01489 L
.48491 .01509 L
.4861 .01545 L
.48738 .01627 L
.48811 .01709 L
.4888 .01825 L
.48952 .02007 L
.49018 .02255 L
.4909 .0266 L
.49166 .0331 L
.49287 .05108 L
.49415 .08868 L
.49536 .15464 L
.49646 .25184 L
.49775 .41029 L
.49844 .49699 L
.49916 .5694 L
.49979 .60107 L
.50048 .59206 L
.5017 .48071 L
.50291 .32441 L
.5042 .18858 L
.50488 .13876 L
.50562 .09857 L
.50693 .0555 L
.50816 .03506 L
.50885 .02841 L
.50949 .02423 L
.51065 .01956 L
.51189 .01709 L
.513 .01596 L
.51419 .01534 L
.51531 .01504 L
.51633 .0149 L
.51752 .01481 L
.51882 .01476 L
.52005 .01474 L
.52118 .01473 L
.52239 .01472 L
Mistroke
.52368 .01472 L
.5249 .01472 L
.52602 .01472 L
.52732 .01472 L
.52806 .01472 L
.52874 .01472 L
.53 .01472 L
.5307 .01472 L
.53134 .01472 L
.53201 .01472 L
.53272 .01472 L
.534 .01472 L
.53471 .01472 L
.53537 .01472 L
.5361 .01472 L
.53687 .01472 L
.53755 .01472 L
.53828 .01472 L
.53897 .01472 L
.5396 .01472 L
.54081 .01472 L
.54209 .01472 L
.54323 .01472 L
.54448 .01472 L
.54578 .01472 L
.54698 .01472 L
.54812 .01472 L
.54915 .01472 L
.55035 .01472 L
.55147 .01472 L
.5527 .01472 L
.55399 .01472 L
.5551 .01472 L
.55632 .01472 L
.55763 .01472 L
.55837 .01472 L
.55904 .01472 L
.56034 .01472 L
.56158 .01472 L
.56273 .01472 L
.56378 .01472 L
.56498 .01472 L
.56612 .01472 L
.56717 .01472 L
.56814 .01472 L
.56921 .01472 L
.57033 .01472 L
.57146 .01472 L
.57268 .01472 L
.57383 .01472 L
Mistroke
.57488 .01472 L
.5761 .01472 L
.5768 .01472 L
.57744 .01472 L
.57861 .01472 L
.57986 .01472 L
.58106 .01472 L
.58238 .01472 L
.58362 .01472 L
.58477 .01472 L
.58591 .01472 L
.58695 .01472 L
.58814 .01472 L
.58927 .01472 L
.5905 .01472 L
.5918 .01472 L
.59291 .01472 L
.59413 .01472 L
.59544 .01472 L
.59618 .01472 L
.59685 .01472 L
.59815 .01472 L
.59939 .01472 L
.60044 .01472 L
.60159 .01472 L
.6028 .01472 L
.60394 .01472 L
.60499 .01472 L
.60596 .01472 L
.60703 .01472 L
.60815 .01472 L
.60929 .01472 L
.61051 .01472 L
.61166 .01472 L
.6127 .01472 L
.61393 .01472 L
.61462 .01472 L
.61526 .01472 L
.61644 .01472 L
.61768 .01472 L
.61889 .01472 L
.62021 .01472 L
.62146 .01472 L
.62261 .01472 L
.62376 .01472 L
.62479 .01472 L
.62599 .01472 L
.62711 .01472 L
.62835 .01472 L
.62965 .01472 L
Mistroke
.63077 .01472 L
.63199 .01472 L
.6333 .01472 L
.63404 .01472 L
.63471 .01472 L
.63601 .01472 L
.63725 .01472 L
.6383 .01472 L
.63946 .01472 L
.64067 .01472 L
.64181 .01472 L
.64287 .01472 L
.64384 .01472 L
.6449 .01472 L
.64602 .01472 L
.64717 .01472 L
.64838 .01472 L
.64954 .01472 L
.65058 .01472 L
.65181 .01472 L
.6525 .01472 L
.65314 .01472 L
.65432 .01472 L
.65556 .01472 L
.65677 .01472 L
.6581 .01472 L
.65935 .01472 L
.6605 .01472 L
.66154 .01472 L
.66269 .01472 L
.66389 .01472 L
.66501 .01472 L
.66625 .01472 L
.66756 .01472 L
.66867 .01472 L
.6699 .01472 L
.67121 .01472 L
.67195 .01472 L
.67262 .01472 L
.67393 .01472 L
.67516 .01472 L
.67622 .01472 L
.67738 .01472 L
.6786 .01472 L
.67973 .01472 L
.68079 .01472 L
.68176 .01472 L
.68288 .01472 L
.68395 .01472 L
.68509 .01472 L
Mistroke
.68631 .01472 L
.68747 .01472 L
.68851 .01472 L
.68974 .01472 L
.69043 .01472 L
.69107 .01472 L
.69225 .01472 L
.69349 .01472 L
.69471 .01472 L
.6954 .01472 L
.69603 .01472 L
.6972 .01472 L
.69845 .01472 L
.69955 .01472 L
.7006 .01472 L
.70174 .01472 L
.70297 .01472 L
.7042 .01472 L
.7049 .01472 L
.70555 .01472 L
.70687 .01472 L
.7076 .01472 L
.70827 .01472 L
.70947 .01472 L
.71077 .01472 L
.712 .01472 L
.71313 .01472 L
.71419 .01472 L
.71532 .01472 L
.71639 .01472 L
.71737 .01472 L
.71852 .01472 L
.71977 .01472 L
.72094 .01472 L
.72204 .01472 L
.72327 .01472 L
.72443 .01472 L
.72548 .01472 L
.7266 .01472 L
.72784 .01472 L
.72914 .01472 L
.73025 .01472 L
.73147 .01472 L
.73278 .01472 L
.73399 .01472 L
.73462 .01472 L
.73532 .01472 L
.73604 .01472 L
.73673 .01472 L
.73798 .01472 L
Mistroke
.73912 .01472 L
.74044 .01472 L
.7417 .01472 L
.74282 .01472 L
.74401 .01472 L
.74513 .01472 L
.74615 .01472 L
.74736 .01472 L
.74866 .01472 L
.74989 .01472 L
.75102 .01472 L
.75223 .01472 L
.75353 .01472 L
.75475 .01472 L
.75587 .01472 L
.75718 .01472 L
.75792 .01472 L
.7586 .01472 L
.75986 .01472 L
.76049 .01472 L
.76119 .01472 L
.76187 .01472 L
.76259 .01472 L
.76386 .01472 L
.76457 .01472 L
.76524 .01472 L
.76596 .01472 L
.76674 .01472 L
.76741 .01472 L
.76814 .01472 L
.76883 .01472 L
.76947 .01472 L
.77067 .01472 L
.77195 .01472 L
.77316 .01472 L
.77447 .01472 L
.77572 .01472 L
.77687 .01472 L
.77802 .01472 L
.77905 .01472 L
.78025 .01472 L
.78137 .01472 L
.78261 .01472 L
.78391 .01472 L
.78502 .01472 L
.78624 .01472 L
.78756 .01472 L
.78829 .01472 L
.78896 .01472 L
.79027 .01472 L
Mistroke
.7915 .01472 L
.79256 .01472 L
.79372 .01472 L
.79493 .01472 L
.79606 .01472 L
.79712 .01472 L
.79809 .01472 L
.79916 .01472 L
.80028 .01472 L
.80142 .01472 L
.80264 .01472 L
.80379 .01472 L
.80483 .01472 L
.80606 .01472 L
.80676 .01472 L
.80739 .01472 L
.80857 .01472 L
.80981 .01472 L
.81103 .01472 L
.81235 .01472 L
.8136 .01472 L
.81475 .01472 L
.8159 .01472 L
.81694 .01472 L
.81814 .01472 L
.81926 .01472 L
.8205 .01472 L
.82181 .01472 L
.82292 .01472 L
.82414 .01472 L
.82546 .01472 L
.8262 .01472 L
.82687 .01472 L
.82817 .01472 L
.82941 .01472 L
.83046 .01472 L
.83162 .01472 L
.83284 .01472 L
.83397 .01472 L
.83503 .01472 L
.83601 .01472 L
.83713 .01472 L
.83819 .01472 L
.83934 .01472 L
.84056 .01472 L
.84171 .01472 L
.84275 .01472 L
.84398 .01472 L
.84467 .01472 L
.84531 .01472 L
Mistroke
.84649 .01472 L
.84773 .01472 L
.84895 .01472 L
.84963 .01472 L
.85027 .01472 L
.85144 .01472 L
.85268 .01472 L
.85379 .01472 L
.85483 .01472 L
.85597 .01472 L
.8572 .01472 L
.85844 .01472 L
.85913 .01472 L
.85978 .01472 L
.8611 .01472 L
.86183 .01472 L
.8625 .01472 L
.8637 .01472 L
.865 .01472 L
.86623 .01472 L
.86736 .01472 L
.86842 .01472 L
.86955 .01472 L
.87062 .01472 L
.8716 .01472 L
.87275 .01472 L
.87399 .01472 L
.87517 .01472 L
.87627 .01472 L
.8775 .01472 L
.87866 .01472 L
.87971 .01472 L
.88083 .01472 L
.88206 .01472 L
.88337 .01472 L
.88448 .01472 L
.88569 .01472 L
.887 .01472 L
.88821 .01472 L
.88884 .01472 L
.88954 .01472 L
.89027 .01472 L
.89095 .01472 L
.8922 .01472 L
.89334 .01472 L
.8946 .01472 L
.89592 .01472 L
.89704 .01472 L
.89823 .01472 L
.89935 .01472 L
Mistroke
.90037 .01472 L
.90158 .01472 L
.90288 .01472 L
.90411 .01472 L
.90524 .01472 L
.90645 .01472 L
.90774 .01472 L
.90897 .01472 L
.91009 .01472 L
.91139 .01472 L
.91213 .01472 L
.91282 .01472 L
.91407 .01472 L
.91471 .01472 L
.91541 .01472 L
.91609 .01472 L
.9168 .01472 L
.91808 .01472 L
.91879 .01472 L
.91945 .01472 L
.92018 .01472 L
.92096 .01472 L
.92163 .01472 L
.92236 .01472 L
.92305 .01472 L
.92368 .01472 L
.92489 .01472 L
.92617 .01472 L
.92737 .01472 L
.92869 .01472 L
.92993 .01472 L
.93109 .01472 L
.93223 .01472 L
.93326 .01472 L
.93446 .01472 L
.93558 .01472 L
.93682 .01472 L
.93812 .01472 L
.93923 .01472 L
.94045 .01472 L
.94176 .01472 L
.9425 .01472 L
.94317 .01472 L
.94448 .01472 L
.94571 .01472 L
.94676 .01472 L
.94792 .01472 L
.94913 .01472 L
.95027 .01472 L
.95133 .01472 L
Mistroke
.9523 .01472 L
.95336 .01472 L
.95448 .01472 L
.95562 .01472 L
.95684 .01472 L
.95799 .01472 L
.95904 .01472 L
.96027 .01472 L
.96096 .01472 L
.9616 .01472 L
.96277 .01472 L
.96402 .01472 L
.96483 .01472 L
.9656 .01472 L
.96629 .01472 L
.96705 .01472 L
.96787 .01472 L
.96874 .01472 L
.96956 .01472 L
.97031 .01472 L
.97107 .01472 L
.97176 .01472 L
.97253 .01472 L
.97334 .01472 L
.97404 .01472 L
.9747 .01472 L
.97542 .01472 L
.97619 .01472 L
Mfstroke
[ .02 ] 0 setdash
.02381 .01472 m
.03279 .01472 L
.04262 .01472 L
.05288 .01472 L
.06244 .01472 L
.0731 .01472 L
.0828 .01472 L
.094 .01472 L
.10458 .01472 L
.11428 .01473 L
.12455 .01473 L
.13333 .01474 L
.14299 .01474 L
.15313 .01476 L
.1624 .01477 L
.17311 .01479 L
.18328 .01482 L
.19287 .01486 L
.20309 .01491 L
.21273 .01498 L
.22147 .01506 L
.2315 .0152 L
.24072 .01536 L
.25085 .0156 L
.26154 .01596 L
.27102 .01639 L
.28118 .01702 L
.29077 .01784 L
.29951 .01883 L
.30943 .02034 L
.3186 .02223 L
.32866 .02502 L
.33936 .02912 L
.34873 .03401 L
.35883 .04112 L
.36837 .05013 L
.37711 .06097 L
.38691 .07689 L
.39603 .09621 L
.40604 .12364 L
.41673 .16169 L
.43808 .26957 L
.45823 .40599 L
.47655 .52915 L
.48157 .55594 L
.48433 .56857 L
.48696 .57894 L
.48939 .58704 L
.49205 .59409 L
.49322 .59659 L
Mistroke
.49446 .59882 L
.49555 .60041 L
.4967 .60171 L
.49734 .60228 L
.49804 .60275 L
.49928 .60324 L
.49998 .60332 L
.50072 .60324 L
.50143 .60302 L
.50207 .60269 L
.50332 .6017 L
.50402 .60094 L
.50467 .60012 L
.50713 .59589 L
.50931 .59073 L
.51171 .58356 L
.51657 .56462 L
.52743 .50498 L
.53762 .43569 L
.55613 .30618 L
.56661 .24208 L
.57636 .19179 L
.58688 .14772 L
.59643 .11618 L
.60665 .09002 L
.61755 .06909 L
.62756 .05485 L
.63677 .04496 L
.64689 .03683 L
.65758 .03057 L
.66704 .02651 L
.67719 .02329 L
.68678 .02106 L
.69552 .01953 L
.70542 .01824 L
.71458 .01735 L
.72464 .01664 L
.73533 .01609 L
.74469 .01573 L
.75478 .01546 L
.76431 .01526 L
.77305 .01513 L
.78284 .01502 L
.79195 .01494 L
.80195 .01488 L
.81264 .01483 L
.82287 .0148 L
.83397 .01478 L
.84444 .01476 L
.85411 .01475 L
Mistroke
.86379 .01474 L
.87285 .01473 L
.88279 .01473 L
.89348 .01472 L
.9036 .01472 L
.91463 .01472 L
.92505 .01472 L
.93472 .01472 L
.9453 .01472 L
.95526 .01472 L
.96421 .01472 L
.97387 .01472 L
.97619 .01472 L
Mfstroke
.02381 .06192 m
.06244 .07836 L
.10458 .10234 L
.14415 .13209 L
.18221 .16868 L
.22272 .21741 L
.26171 .27421 L
.30316 .344 L
.34309 .4167 L
.3815 .48556 L
.40095 .51746 L
.42237 .54847 L
.44292 .57278 L
.46172 .58931 L
.47167 .59559 L
.47625 .59787 L
.48113 .59987 L
.48384 .60079 L
.4863 .6015 L
.48881 .6021 L
.49111 .60255 L
.4938 .60295 L
.49522 .6031 L
.49594 .60316 L
.49672 .60321 L
.49802 .60328 L
.49924 .60331 L
.49998 .60332 L
.50069 .60331 L
.502 .60328 L
.50314 .60322 L
.50437 .60313 L
.50553 .60302 L
.50659 .6029 L
.50906 .60252 L
.51166 .602 L
.51656 .60067 L
.52191 .59868 L
.53146 .59382 L
.54033 .5878 L
.56079 .56885 L
.57938 .54614 L
.61936 .48409 L
.65783 .41503 L
.69875 .34063 L
.73815 .27444 L
.77604 .21907 L
.81638 .17021 L
.8552 .13264 L
.89648 .10165 L
Mistroke
.93624 .07901 L
.97448 .06255 L
.97619 .06192 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.9375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000ga000`40l00?003`ooooJOoo003ooomY
ool00;ooo`<03`03ool03ooo0:?oo`00_ooo00<03ooo00l00_oo00<03oooool0XOoo002`ool400l0
1?oo00ooo`0?0_oo0P0?00Goo`0?ooooo`0?00?oo`0300oooooo00;oo`0600oooooo00ooo`0?1?oo
0P0?00?oo`0?00l0T?oo002aool02@0?oooooooo00ooo`0?ool03`03ool02@0?ool03ooo00ooo`0?
ool03`03ool01P0?ooooo`0?ool03`?oo`0400ooooooool200n@ool00;7oo`803`;oo`0800ooo`0?
ool03ooo00ooo`<03`06ool03ooo00ooo`0?0ooo00H03oooool03ooo00l3ool0100?ool03`0?0_oo
00<03oooool0SOoo002aool0100?oooooooo0P0?0ooo0P0?00?oo`0?ool00`0?00Coo`0?ool03`?o
o`0300oooooo00803`Goo`<03`;oo`0300oooooo08goo`00/?oo100?8Ooo00@03oooool03hooo`00
bOoo00<03oooool0W?oo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00oooo
JOoo000`ool01@0?ooooo`0?ool00`0?@?oo00@03oooool03`;oo`0300oooooo00803d;oo`0300oo
oooo04;oo`0400oooooo00l2ool00`0?ooooo`0200m2ool01@0?ooooo`0?ool00`0?2Ooo000_ool0
0`0?ool03`04ool00`0?ooooo`0nool00`0?ool03`03ool00`0?ool03`03ool00`0?ooooo`0nool0
0`0?ool03`12ool00`0?ool03`03ool00`0?ool03`03ool00`0?ooooo`0nool00`0?ool03`04ool0
0`0?ooooo`08ool002[oo`<03`;oo`0300ooo`0?00Coo`0300oooooo03Woo`<03`;oo`0300ooo`0?
00?oo`0400ooo`0?ool200m1ool00`0?ool03`12ool00`0?ool03`03ool0100?ool03ooo0P0?@Ooo
00<03ooo00l01?oo00<03oooool02?oo000_ool00`0?ool03`04ool00`0?ooooo`0nool00`0?ool0
3`03ool01@0?ool03ooo00l0@_oo00<03ooo00l0@_oo00<03ooo00l00ooo00D03ooo00ooo`0?04;o
o`0300ooo`0?00Coo`0300oooooo00Soo`00<?oo00<03oooool00_oo0P0?@Ooo00<03oooool00ooo
00<03oooool00`0?@Ooo00<03oooool0@_oo00<03oooool00ooo00<03oooool00`0?@Ooo00<03ooo
ool00_oo0P0?2_oo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo
003ooomYool002Woool03c/03`Goo`00:Ooo00<03oooool01Ooo00<03oooool02ooo00<03oooool0
3?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool0
3?oo00<03oooool03?oo00<03oooool02ooo00<03oooool03?oo00<03oooool03?oo00<03oooool0
3?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool0
2ooo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool01Ooo00<03oooool0
0ooo000Qool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`17ool00`0?ooooo`17ool00`0?
ooooo`18ool00`0?ooooo`17ool00`0?ooooo`05ool00`0?ooooo`03ool0023oo`0300ooo`0?00Ko
o`0300oooooo04ooo`0308oooooo04Ooo`0300oooooo04Soo`0307oooooo04ooo`0300oooooo00?o
o`008?oo00<03ooo00l01_oo00<03oooool0Cooo00<0Ooooool0Aooo00<03oooool0B?oo00<0Sooo
ool0Cooo00<03oooool00ooo000Pool00`0?ool03`06ool300l5oonB00l2ool0100?ooooooooTP0?
1Ooo0`0?1Ooo000Qool00`0?ooooo`05ool00`0?ooooo`1?ool00`1oooooo`0:ool300lgool0100?
ooooo`0?0ooo00<03oooool0=Ooo100?2ooo00<0Soooool0Cooo00<03oooool00ooo000Yool00`0?
ooooo`1?ool00`2?ooooo`0=ool400lcool0100?ooooo`0?0_oo0P0?=?oo0`0?3ooo00<0Ooooool0
Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`1oooooo`14ool200l01Ooo00oooooo00l0
Aooo00<0Soooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`2?ooooo`15ool00`0?
ool03`02ool00`0?ooooo`0/ool200lGool00`1oooooo`1?ool00`0?ooooo`03ool002Woo`0300oo
oooo04ooo`0307oooooo01Koo`803bgoo`0300ooo`0?00;oo`0300oooooo02_oo`803aSoo`0308oo
oooo04ooo`0300oooooo00?oo`00:Ooo00<03oooool0Cooo00<0Soooool06?oo0P0?:ooo00<03ooo
00l00_oo00<03oooool0:Ooo0P0?6_oo00<0Ooooool0Cooo00<03oooool00ooo000Yool200m@ool0
0`1oooooo`0Jool00`0?ooooo`0Xool00`0?ool03`02ool00`0?ooooo`0Xool00`0?ooooo`0Jool0
0`2?ooooo`1=ool300l5ool002Woo`0300oooooo04ooo`0308oooooo01_oo`0300oooooo02Ooo`03
00ooo`0?00;oo`0300oooooo04Goo`0307oooooo04ooo`0300oooooo00?oo`00:Ooo00<03oooool0
Cooo00<0Ooooool0AOoo00<03ooo00l00_oo00<03oooool0AOoo00<0Soooool0Cooo00<03oooool0
0ooo000Yool00`0?ooooo`1?ool00`2?ooooo`15ool00`0?ool03`02ool00`0?ooooo`15ool00`1o
ooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0307oooooo04Goo`0300ooo`0?00;o
o`0300oooooo02?oo`0300oooooo01ooo`0308oooooo04ooo`0300oooooo00?oo`00:Ooo00<03ooo
ool0Cooo00<0Soooool08?oo00<03oooool08_oo00<03ooo00l00_oo00<03oooool08_oo00<03ooo
ool08?oo00<0Ooooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`1oooooo`0Pool0
0`0?ooooo`0Rool0100?ool03ooo0P0?9?oo00<03oooool08?oo00<0Soooool0Cooo00<03oooool0
0ooo000Yool200l6ool00`0?ooooo`17ool00`2?ooooo`0Qool00`0?ooooo`0Qool01@0?ool03ooo
00l09?oo00<03oooool08Ooo00<0Ooooool0Aooo00<03oooool00ooo0`0?1Ooo000Yool00`0?oooo
o`05ool300m7ool00`1oooooo`0Rool00`0?ooooo`0Pool01@0?ool03ooo00l08ooo00<03oooool0
8_oo00<0Soooool0A_oo0P0?1ooo00<03oooool00ooo000Yool00`0?ooooo`08ool200m5ool00`2?
ooooo`0Rool00`0?ooooo`0Pool01@0?ool03ooo00l08_oo00<03oooool08ooo00<0Ooooool0Cooo
00<03oooool00ooo000Yool00`0?ooooo`0:ool00`0?ooooo`12ool00`1oooooo`0Sool00`0?oooo
o`0Oool01@0?ool03ooo00l0B?oo00<0Soooool0@?oo0P0?3Ooo00<03oooool00ooo000Yool00`0?
ooooo`1?ool00`2?ooooo`0Sool00`0?ooooo`0Oool01@0?ool03ooo00l0B?oo00<0Ooooool0?_oo
0P0?3ooo00<03oooool00ooo000Yool00`0?ooooo`0@ool00`0?ooooo`0lool00`1oooooo`15ool0
1@0?ool03ooo00l0B?oo00<0Soooool0??oo0P0?4Ooo00<03oooool00ooo000Yool00`0?ooooo`0A
ool200llool00`2?ooooo`15ool01@0?ool03ooo00l0B?oo00<0Ooooool0>ooo00<03oooool04Ooo
00<03oooool00ooo000Yool00`0?ooooo`0Cool200ljool00`1oooooo`15ool01@0?ool03ooo00l0
B?oo00<0Soooool0Cooo00<03oooool00ooo000Yool200lFool200lhool00`2?ooooo`15ool300l0
0ooo00ooo`0Nool00`0?ooooo`0Vool00`1oooooo`1=ool300l5ool002Woo`0300oooooo04ooo`03
07oooooo02Koo`0300oooooo01goo`803`03ool03ooo01koo`0300oooooo02Koo`0308oooooo03Co
o`803aWoo`0300oooooo00?oo`00:Ooo00<03oooool0Cooo00<0Soooool09_oo00<03oooool07Ooo
0P0?00?oo`0?ool07Ooo00<03oooool09ooo00<0Ooooool0<ooo00<03oooool06Ooo00<03oooool0
0ooo000Yool00`0?ooooo`0Kool00`0?ooooo`0aool00`1oooooo`0Wool00`0?ooooo`0Lool200l0
0ooo00ooo`0Mool00`0?ooooo`0Wool00`2?ooooo`0aool200lLool00`0?ooooo`03ool002Woo`03
00oooooo01coo`0300oooooo033oo`0308oooooo02Ooo`0300oooooo01coo`803`03ool03ooo01go
o`0300oooooo02Ooo`0307oooooo033oo`0300oooooo01coo`0300oooooo00?oo`00:Ooo00<03ooo
ool07Ooo0P0?<?oo00<0Ooooool0:?oo00<03oooool06ooo0P0?00?oo`0?ool07?oo00<03oooool0
:?oo00<0Soooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`0Oool00`0?ooooo`0]ool00`2?
ooooo`0Xool00`0?ooooo`0Kool200l00ooo00ooo`0Lool00`0?ooooo`0Xool00`1oooooo`1?ool0
0`0?ooooo`03ool002Woo`803b7oo`0300oooooo02coo`0307oooooo02Soo`0300oooooo01_oo`80
3`03ool03ooo04Ooo`0308oooooo02_oo`0300oooooo01ooo`<03`Goo`00:Ooo00<03oooool0Cooo
00<0Soooool0A_oo0P0?00?oo`0?ool0Aooo00<0Ooooool0:_oo00<03oooool08_oo00<03oooool0
0ooo000Yool00`0?ooooo`1?ool00`1oooooo`16ool200l00ooo00ooo`17ool00`2?ooooo`0Xool2
00lUool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0308oooooo04Koo`803`03ool03ooo04Oo
o`0307oooooo02Ooo`0300oooooo02Goo`0300oooooo00?oo`00:Ooo00<03oooool09Ooo0P0?:?oo
00<0Ooooool0A_oo0P0?00?oo`0?ool06_oo00<03oooool0:_oo00<0Soooool09_oo00<03oooool0
9_oo00<03oooool00ooo000Gool0100?ooooo`0?0_oo00<03oooool00P0?1ooo00<03oooool09ooo
00<03oooool09Ooo00<0Soooool0A_oo0P0?00?oo`0?ool06_oo00<03oooool0:_oo00<0Ooooool0
Cooo00<03oooool00ooo000Fool00`0?ool03`03ool00`0?ool03`03ool00`0?ooooo`04ool00`0?
ooooo`0Xool200lUool00`1oooooo`0Zool00`0?ooooo`0Iool200l00ooo00ooo`0Iool00`0?oooo
o`0[ool00`2?ooooo`1?ool00`0?ooooo`03ool001Koo`0300ooo`0?00?oo`0400ooo`0?ool200l7
ool300l0V01o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l200l0VP1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?0`0?1Ooo000Fool00`0?ool03`03ool01@0?ool03ooo00l0
2?oo00<03oooool0Cooo00<0Ooooool0:ooo00<03oooool06?oo0P0?00?oo`0?ool06Ooo00<03ooo
ool0:ooo00<0Soooool08Ooo00<03oooool0:ooo00<03oooool00ooo000Gool00`0?ooooo`03ool0
0`0?ooooo`0300l6ool00`0?ooooo`1?ool00`2?ooooo`0[ool00`0?ooooo`0Hool200l00ooo00oo
o`0Hool00`0?ooooo`0/ool00`1oooooo`0Pool00`0?ooooo`0/ool00`0?ooooo`03ool002Woo`03
00oooooo04ooo`0307oooooo02coo`0300oooooo01Ooo`803`03ool03ooo01Soo`0300oooooo02co
o`0308oooooo01ooo`0300oooooo02goo`0300oooooo00?oo`00:Ooo00<03oooool0Cooo00<0Sooo
ool0;?oo00<03oooool05ooo0P0?00?oo`0?ool0Aooo00<0Ooooool07_oo00<03oooool0;_oo00<0
3oooool00ooo000Yool00`0?ooooo`0_ool00`0?ooooo`0Mool00`1oooooo`0/ool00`0?ooooo`0G
ool200l00ooo00ooo`17ool00`2?ooooo`0Lool200laool00`0?ooooo`03ool002Woo`0300oooooo
033oo`0300oooooo01coo`0308oooooo04Koo`803`03ool03ooo04Ooo`0307oooooo04ooo`0300oo
oooo00?oo`00:Ooo00<03oooool0<Ooo00<03oooool06ooo00<0Ooooool0A_oo0P0?00?oo`0?ool0
Aooo00<0Soooool0Cooo00<03oooool00ooo000Yool200lcool00`0?ooooo`0Jool00`2?ooooo`16
ool200l00ooo00ooo`17ool00`1oooooo`1=ool300l5ool002Woo`0300oooooo03?oo`0300oooooo
01Woo`0307oooooo04Koo`803`03ool03ooo04Ooo`0308oooooo04ooo`0300oooooo00?oo`00:Ooo
00<03oooool0Cooo00<0Soooool0A_oo0P0?00?oo`0?ool05_oo00<03oooool0;_oo00<0Ooooool0
5ooo0P0?=_oo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`1oooooo`0^ool00`0?ooooo`0E
ool200l00ooo00ooo`0Fool00`0?ooooo`0^ool00`2?ooooo`0Fool00`0?ooooo`0fool00`0?oooo
o`03ool002Woo`0300oooooo04ooo`0308oooooo02koo`0300oooooo01Goo`803`03ool03ooo01Ko
o`0300oooooo02koo`0307oooooo01Goo`0300oooooo03Ooo`0300oooooo00?oo`00:Ooo00<03ooo
ool0>?oo00<03oooool05?oo00<0Ooooool0;_oo00<03oooool05Ooo0P0?00?oo`0?ool05_oo00<0
3oooool0;_oo00<0Soooool05Ooo00<03oooool0=ooo00<03oooool00ooo000Yool00`0?ooooo`0h
ool00`0?ooooo`0Dool00`2?ooooo`0^ool00`0?ooooo`0Eool200l00ooo00ooo`0Eool00`0?oooo
o`0_ool00`1oooooo`0Dool00`0?ooooo`0hool00`0?ooooo`03ool002Woo`803c[oo`0300oooooo
01?oo`0307oooooo02koo`0300oooooo01Goo`803`03ool03ooo01Goo`0300oooooo02ooo`0308oo
oooo04goo`<03`Goo`00:Ooo00<03oooool0>_oo00<03oooool04_oo00<0Soooool0;ooo00<03ooo
ool05?oo0P0?00?oo`0?ool05Ooo00<03oooool0;ooo00<0Ooooool0Cooo00<03oooool00ooo000Y
ool00`0?ooooo`0jool00`0?ooooo`0Bool00`1oooooo`0_ool00`0?ooooo`0Dool200l00ooo00oo
o`17ool00`2?ooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo03_oo`803a;oo`0308oooooo
04Koo`803`03ool03ooo04Ooo`0307oooooo04ooo`0300oooooo00?oo`00:Ooo00<03oooool0Cooo
00<0Ooooool0A_oo0P0?00?oo`0?ool0Aooo00<0Soooool04?oo00<03oooool0??oo00<03oooool0
0ooo000Yool00`0?ooooo`1?ool00`2?ooooo`16ool200l00ooo00ooo`17ool00`1oooooo`0?ool0
0`0?ooooo`0mool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0307oooooo04Koo`803`03ool0
3ooo04Ooo`0308oooooo00koo`0300oooooo03koo`0300oooooo00?oo`00:Ooo0P0?D?oo00<0Sooo
ool0A_oo0P0?00?oo`0?ool05?oo00<03oooool0<?oo00<0Ooooool03Ooo00<03oooool0?Ooo0`0?
1Ooo000Yool00`0?ooooo`10ool00`0?ooooo`0<ool00`1oooooo`0`ool00`0?ooooo`0Cool200l0
0ooo00ooo`0Cool00`0?ooooo`0aool00`2?ooooo`0<ool00`0?ooooo`10ool00`0?ooooo`03ool0
02Woo`0300oooooo043oo`0300oooooo00coo`0308oooooo033oo`0300oooooo01?oo`803`03ool0
3ooo01?oo`0300oooooo037oo`0307oooooo00coo`0300oooooo043oo`0300oooooo00?oo`00:Ooo
00<03oooool0@Ooo00<03oooool02ooo00<0Ooooool0<?oo00<03oooool04ooo0P0?00?oo`0?ool0
4ooo00<03oooool0<Ooo00<0Soooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`12ool00`0?
ooooo`0:ool00`2?ooooo`0aool00`0?ooooo`0Bool200l00ooo00ooo`0Cool00`0?ooooo`0aool0
0`1oooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo04?oo`0300oooooo00Woo`0307oooooo
037oo`0300oooooo01;oo`803`03ool03ooo01?oo`0300oooooo037oo`0308oooooo04ooo`0300oo
oooo00?oo`00:Ooo00<03oooool0@ooo00<03oooool02Ooo00<0Soooool0<Ooo00<03oooool04_oo
0P0?00?oo`0?ool04_oo00<03oooool0<_oo00<0Ooooool0Cooo00<03oooool00ooo000Yool00`0?
ooooo`1?ool00`1oooooo`0aool00`0?ooooo`0Bool200l00ooo00ooo`17ool00`2?ooooo`08ool0
0`0?ooooo`14ool00`0?ooooo`03ool002Woo`803e3oo`0308oooooo04Koo`803`03ool03ooo04Oo
o`0307oooooo00Ooo`0300oooooo04?oo`<03`Goo`00:Ooo00<03oooool0Cooo00<0Ooooool0A_oo
0P0?00?oo`0?ool0Aooo00<0Soooool01_oo00<03oooool0A_oo00<03oooool00ooo000Yool00`0?
ooooo`1?ool00`2?ooooo`16ool200l00ooo00ooo`17ool00`1oooooo`05ool00`0?ooooo`17ool0
0`0?ooooo`03ool002Woo`0300oooooo04Ooo`0300oooooo00Goo`0307oooooo04Koo`803`03ool0
3ooo04Ooo`0308oooooo00Goo`0300oooooo04Ooo`0300oooooo00?oo`00:Ooo00<03oooool0B?oo
00<03oooool01?oo00<0Soooool0A_oo0P0?00?oo`0?ool04Ooo00<03oooool0<ooo00<0Ooooool0
1?oo00<03oooool0B?oo00<03oooool00ooo000Kool01@0?ooooo`0?ool00`0?1_oo00<03oooool0
B?oo00<03oooool01?oo00<0Ooooool0<_oo00<03oooool04Ooo0P0?00?oo`0?ool04Ooo00<03ooo
ool0<ooo00<0Soooool0Cooo00<03oooool00ooo000;ool300l<ool00`0?ool03`04ool00`0?oooo
o`05ool00`0?ooooo`19ool00`0?ooooo`03ool00`2?ooooo`0cool00`0?ooooo`0@ool400lBool0
0`0?ooooo`0cool00`1oooooo`1?ool00`0?ooooo`03ool000Woo`803`?oo`0300oooooo00Woo`03
00ooo`0?00Coo`0300oooooo00Goo`<03`2H08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`<03`2I07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00<03`Goo`002Ooo00<03ooo
ool00_oo00<03oooool02Ooo00<03ooo00l01?oo00<03oooool01Ooo00<03oooool0Booo00D03ooo
ooooo`2?03Goo`0300oooooo013oo`<03a?oo`0300oooooo03?oo`0307oooooo04ooo`0300oooooo
00?oo`002Ooo00<03oooool00_oo00<03oooool02_oo00<03oooool00_oo0P0?1ooo00<03oooool0
Cooo00<0Ooooool0<ooo00<03oooool04?oo0`0?4_oo00<03oooool0=?oo00D0Soooooooo`0?04go
o`0300oooooo00?oo`002Ooo0P0?0_oo00<03oooool06Ooo00<03oooool0Cooo00<0Soooool0<ooo
00<03oooool04?oo0`0?4_oo00<03oooool0=?oo00@0Ooooool03dkoo`0300oooooo00?oo`003?oo
0P0?6ooo00<03oooool0Cooo00<0Ooooool0=?oo00<03oooool03ooo0`0?BOoo00<0Sooo00l0Cooo
00<03oooool00ooo000;ool0100?ooooo`0?6_oo00<03oooool0Cooo00<0Soooool0A_oo0`0?BOoo
00<0Oooo00l0Cooo00<03oooool00ooo000;ool0100?ooooo`0?6_oo00<03oooool0C_oo00<03`1o
ool0Aooo0`0?BOoo00<0S`0?ool0Cooo00<03oooool00ooo000<ool200lKool00`0?ooooo`1>ool0
0`0?08ooo`17ool300m9ool00`0?ooooo`1?ool00`0?ooooo`03ool000_oo`@03a[oo`803e3oo`03
00oooooo04Koo`<03dWoo`0308oooooo04goo`<03`Goo`002ooo00@03oooool03a[oo`0300oooooo
04ooo`0308l03ooo04Koo`<03a7oo`0300oooooo03Goo`0307oooooo04ooo`0300oooooo00?oo`00
2ooo00<03oooool06ooo00<03oooool0Cooo00<0O`0?ool0A_oo0`0?4Ooo00<03oooool0=Ooo00<0
Soooool0Cooo00<03oooool00ooo000<ool300lJool00`0?ooooo`1?ool00`2?ool03`0eool00`0?
ooooo`0>ool300lAool00`0?ooooo`0eool00`1oooooo`1?ool00`0?ooooo`03ool000_oo`0300oo
oooo01_oo`0300oooooo04ooo`0307ooo`0?03Goo`0300oooooo00koo`<03a7oo`0300oooooo03;o
o`0400oooooo08mAool00`0?ooooo`03ool000_oo`803acoo`0300oooooo04ooo`0308oooooo03Go
o`0300oooooo00koo`<03a7oo`0300oooooo03;oo`0400oooooo07mAool00`0?ooooo`03ool000go
o`803a[oo`0300oooooo04ooo`0307oooooo03Goo`0300oooooo00koo`<03a7oo`0300oooooo037o
o`0500ooooooool0S`1Aool00`0?ooooo`03ool000_oo`803acoo`803e3oo`0308oooooo03Goo`03
00oooooo00koo`<03a3oo`0300oooooo037oo`0300oooooo00;oo`0307oooooo04goo`<03`Goo`00
3?oo0P0?6ooo00<03oooool0Cooo00<0Ooooool0=Ooo00<03oooool03_oo0`0?A?oo00<03oooool0
0_oo00<0Soooool0Cooo00<03oooool00ooo000;ool0100?ooooo`0?6_oo00<03oooool0Cooo00<0
Soooool00ooo00<03oooool0<?oo00<03oooool03Ooo0`0?@ooo00<03oooool00ooo00<0Ooooool0
Cooo00<03oooool00ooo000;ool0100?ooooo`0?6_oo00<03oooool0Cooo00<0Ooooool00ooo00<0
3oooool0@?oo0`0?@ooo00<03oooool00ooo00<0Soooool0Cooo00<03oooool00ooo000<ool200lK
ool00`0?ooooo`1?ool00`2?ooooo`04ool00`0?ooooo`0oool300m9ool00`1oooooo`1?ool00`0?
ooooo`03ool000[oo`0500ooooooool03`0Jool00`0?ooooo`1?ool00`1oooooo`04ool00`0?oooo
o`0oool300m9ool00`2?ooooo`1?ool00`0?ooooo`03ool000Woo`H03a[oo`0300oooooo04ooo`03
08oooooo00Goo`0300oooooo03koo`<03dWoo`0307oooooo04ooo`0300oooooo00?oo`003_oo00<0
3oooool06?oo0P0?D?oo00<0Ooooool01_oo00<03oooool0?Ooo0`0?3ooo00<03oooool0=ooo00<0
Soooool0COoo0`0?1Ooo000;ool300lKool00`0?ooooo`1?ool00`2?ooooo`0fool00`0?ooooo`0=
ool300l?ool00`0?ooooo`0^ool00`0?ooooo`06ool00`1oooooo`1?ool00`0?ooooo`03ool000ko
o`0300oooooo01Soo`0300oooooo04ooo`0307oooooo03Ooo`0300oooooo00coo`<03`ooo`0300oo
oooo02goo`0300oooooo00Ooo`0308oooooo04ooo`0300oooooo00?oo`002ooo100?6_oo00<03ooo
ool0Cooo00<0Soooool0=ooo00<03oooool03?oo0`0?3ooo00<03oooool0;?oo00<03oooool02?oo
00<0Ooooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`1oooooo`0gool00`0?oooo
o`0<ool300l?ool00`0?ooooo`0/ool00`0?ooooo`08ool00`2?ooooo`1?ool00`0?ooooo`03ool0
00[oo`@03a_oo`0300oooooo04ooo`0308oooooo03Ooo`0300oooooo00coo`<03`ooo`0300oooooo
02_oo`0300oooooo00Woo`0307oooooo04ooo`0300oooooo00?oo`002ooo00@03oooool03a[oo`03
00oooooo04ooo`0307oooooo00Woo`0300oooooo02_oo`0300oooooo00coo`<03`koo`0300oooooo
02_oo`0300oooooo00[oo`0308oooooo04ooo`0300oooooo00?oo`003?oo00<03ooo00l06_oo00<0
3oooool0Cooo00<0Soooool02_oo00<03oooool0:_oo00<03oooool03?oo0`0???oo00<03oooool0
2_oo00<0Ooooool0Cooo00<03oooool00ooo0009ool00`0?ool03`0300lJool200m@ool00`1ooooo
o`0:ool00`0?ooooo`0iool300m9ool00`2?ooooo`1=ool300l5ool000coo`<03a[oo`0300oooooo
04ooo`0308oooooo00_oo`0300oooooo03Woo`803dWoo`0307oooooo04ooo`0300oooooo00?oo`00
2ooo00@03oooool03a[oo`0300oooooo04ooo`0307oooooo00_oo`0300oooooo03Woo`803dWoo`03
08oooooo04ooo`0300oooooo00?oo`002ooo00@03oooool03a[oo`0300oooooo04ooo`0308oooooo
00coo`0300oooooo03Soo`803dWoo`0307oooooo04ooo`0300oooooo00?oo`003?oo0P0?2Ooo00D0
3oooool03ooo00<03`03ool03`0?00Ooo`0300oooooo04ooo`0307oooooo04Ooo`803`koo`0300oo
oooo02Soo`0300oooooo00goo`0308oooooo04ooo`0300oooooo00?oo`002ooo100?1ooo00<03ooo
00l01?oo00<03oooool00_oo00<03oooool01?oo00<03oooool0Cooo00<0Soooool0>?oo00<03ooo
ool03?oo0P0?3Ooo00<03oooool0:Ooo00<03oooool03Ooo00<0Ooooool0Cooo00<03oooool00ooo
000;ool0100?ooooo`0?1ooo00<03ooo00l01?oo00<03oooool00P0?1ooo00<03oooool0Cooo00<0
Ooooool0>?oo00<03oooool03?oo0P0?3Ooo00<03oooool0:?oo00<03oooool03_oo00<0Soooool0
Cooo00<03oooool00ooo000;ool00`0?ooooo`08ool00`0?ool03`04ool0100?ooooo`0?2?oo0`0?
09T0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l00P0?09T0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l00`0?1Ooo000<ool300l8ool00`0?ooooo`02ool200l2ool300l6
ool00`0?ooooo`1?ool00`1oooooo`0iool00`0?ooooo`0;ool200l=ool00`0?ooooo`0Wool00`0?
ooooo`0?ool00`2?ooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0308oooooo00oo
o`0300oooooo02Ooo`0300oooooo00_oo`803`goo`0300oooooo02Koo`0300oooooo013oo`0307oo
oooo04ooo`0300oooooo00?oo`00:Ooo00<03oooool0Cooo00<0Ooooool04?oo00<03oooool09_oo
00<03oooool02ooo0P0?3Ooo00<03oooool0>Ooo00<0Soooool0Cooo00<03oooool00ooo000Yool0
0`0?ooooo`1?ool00`2?ooooo`0@ool00`0?ooooo`0Vool00`0?ooooo`0;ool200m9ool00`1ooooo
o`1?ool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0307oooooo017oo`0300oooooo02Goo`03
00oooooo00_oo`803dWoo`0308oooooo04ooo`0300oooooo00?oo`00:Ooo00<03oooool0Cooo00<0
Soooool04Ooo00<03oooool0<ooo0P0?BOoo00<0Ooooool0Cooo00<03oooool00ooo000Yool200m@
ool00`1oooooo`0Bool00`0?ooooo`0bool200m9ool00`2?ooooo`1=ool300l5ool002Woo`0300oo
oooo04ooo`0308oooooo04Ooo`803c?oo`0300oooooo01?oo`0307oooooo04ooo`0300oooooo00?o
o`00:Ooo00<03oooool0Cooo00<0Ooooool0Aooo0P0?3?oo00<03oooool09?oo00<03oooool04ooo
00<0Soooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`2?ooooo`17ool200l<ool0
0`0?ooooo`0Sool00`0?ooooo`0Dool00`1oooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo
04ooo`0307oooooo03[oo`0300oooooo00[oo`803`coo`0300oooooo02?oo`0300oooooo01Coo`03
08oooooo04ooo`0300oooooo00?oo`00:Ooo00<03oooool0Cooo00<0Soooool0>_oo00<03oooool0
2_oo0P0?2ooo00<03oooool08ooo00<03oooool05Ooo00<0Ooooool0Cooo00<03oooool00ooo000Y
ool00`0?ooooo`1?ool00`1oooooo`0Eool00`0?ooooo`0Rool00`0?ooooo`0:ool200l;ool00`0?
ooooo`0Rool00`0?ooooo`0Fool00`2?ooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo04oo
o`0308oooooo01Koo`0300oooooo02;oo`0300oooooo00Woo`803`_oo`0300oooooo03_oo`0307oo
oooo04ooo`0300oooooo00?oo`00:Ooo0P0?D?oo00<0Ooooool05_oo00<03oooool08_oo00<03ooo
ool02Ooo0P0?2ooo00<03oooool0>ooo00<0Soooool0COoo0`0?1Ooo000Yool00`0?ooooo`1?ool0
0`2?ooooo`0Gool00`0?ooooo`0Qool00`0?ooooo`09ool200l;ool00`0?ooooo`0kool00`1ooooo
o`1?ool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0307oooooo01Ooo`0300oooooo027oo`03
00oooooo00Woo`803dWoo`0308oooooo04ooo`0300oooooo00?oo`00:Ooo00<03oooool0Cooo00<0
Soooool06?oo00<03oooool0;?oo0P0?BOoo00<0Ooooool0Cooo00<03oooool00ooo000Yool00`0?
ooooo`1?ool00`1oooooo`17ool200l]ool00`0?ooooo`0Iool00`2?ooooo`1?ool00`0?ooooo`03
ool002Woo`0300oooooo04ooo`0308oooooo04Ooo`803bgoo`0300oooooo01Woo`0307oooooo04oo
o`0300oooooo00?oo`00:Ooo00<03oooool0Cooo00<0Ooooool0Aooo0P0?;?oo00<03oooool06_oo
00<0Soooool0Cooo00<03oooool00ooo000Yool200m@ool00`2?ooooo`17ool200l:ool00`0?oooo
o`0Oool00`0?ooooo`0Jool00`1oooooo`1=ool300l5ool002Woo`0300oooooo04ooo`0307oooooo
03coo`0300oooooo00Soo`803`[oo`0300oooooo01koo`0300oooooo01_oo`0308oooooo04ooo`03
00oooooo00?oo`00:Ooo00<03oooool0Cooo00<0Soooool06ooo00<03oooool07_oo00<03oooool0
2?oo0P0?2_oo00<03oooool07Ooo00<03oooool07?oo00<0Ooooool0Cooo00<03oooool00ooo000Y
ool00`0?ooooo`1?ool00`1oooooo`0Lool00`0?ooooo`0Mool00`0?ooooo`08ool200l:ool00`0?
ooooo`0lool00`2?ooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0308oooooo01co
o`0300oooooo01goo`0300oooooo00Soo`803`Woo`0300oooooo03goo`0307oooooo04ooo`0300oo
oooo00?oo`00:Ooo00<03oooool0Cooo00<0Ooooool07Ooo00<03oooool07Ooo00<03oooool01ooo
0P0?2Ooo00<03oooool0?Ooo00<0Soooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool0
0`2?ooooo`0Mool00`0?ooooo`0Mool00`0?ooooo`07ool200l9ool00`0?ooooo`0mool00`1ooooo
o`1?ool00`0?ooooo`03ool002Woo`803e3oo`0307oooooo01koo`0300oooooo01coo`0300oooooo
00Ooo`803dWoo`0308oooooo04goo`<03`Goo`00:Ooo00<03oooool0Cooo00<0Soooool0Aooo0P0?
9ooo00<03oooool07ooo00<0Ooooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`1o
ooooo`17ool200lWool00`0?ooooo`0Oool00`2?ooooo`1?ool00`0?ooooo`03ool002Woo`0300oo
oooo04ooo`0308oooooo04Ooo`803bKoo`0300oooooo023oo`0307oooooo04ooo`0300oooooo00?o
o`00:Ooo00<03oooool0Cooo00<0Ooooool0Aooo0P0?9Ooo00<03oooool08Ooo00<0Soooool0Cooo
00<03oooool00ooo000Kool01@0?ooooo`0?ool00`0?1_oo00<03oooool0Cooo00<0Soooool0Aooo
0P0?2?oo00<03oooool06_oo00<03oooool08Ooo00<0Ooooool0Cooo00<03oooool00ooo000Jool0
0`0?ool03`03ool00`0?ooooo`06ool00`0?ooooo`1?ool00`1oooooo`0Qool00`0?ooooo`0Jool0
0`0?ooooo`06ool200l8ool00`0?ooooo`0Iool00`0?ooooo`0Rool00`2?ooooo`1?ool00`0?oooo
o`03ool001[oo`0300ooo`0?00Coo`0300oooooo00Goo`0300oooooo04ooo`0308oooooo02;oo`03
00oooooo01Woo`0300oooooo00Koo`803`Soo`0300oooooo03koo`0307oooooo04ooo`0300oooooo
00?oo`006_oo00<03ooo00l00ooo00<03ooo00l01_oo0`0?07@0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o0P0?02<0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?00803`2I07l0S`1o08l0
O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00<0
3`Goo`006ooo00<03oooool00ooo0P0?1_oo00<03oooool0Cooo00<0Soooool08ooo00<03oooool0
6?oo00<03oooool01_oo0P0?2?oo00<03oooool0?_oo00<0Ooooool0Cooo00<03oooool00ooo000Y
ool00`0?ooooo`1?ool00`1oooooo`0Tool00`0?ooooo`0Gool00`0?ooooo`06ool200l7ool00`0?
ooooo`0oool00`2?ooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0308oooooo02Co
o`0300oooooo01Soo`0300oooooo00Goo`803`Ooo`0300oooooo03ooo`0307oooooo04ooo`0300oo
oooo00?oo`00:Ooo00<03oooool0Cooo00<0Ooooool0?ooo00<03oooool01Ooo0P0?8Ooo00<03ooo
ool09Ooo00<0Soooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`2?ooooo`0oool0
0`0?ooooo`05ool200lPool00`0?ooooo`0Vool00`1oooooo`1?ool00`0?ooooo`03ool002Woo`03
00oooooo04ooo`0307oooooo04Ooo`803aooo`0300oooooo02Ooo`0308oooooo04ooo`0300oooooo
00?oo`00:Ooo0P0?D?oo00<0Soooool0Aooo0P0?7ooo00<03oooool09ooo00<0Ooooool0COoo0`0?
1Ooo000Yool00`0?ooooo`1?ool00`1oooooo`0Xool00`0?ooooo`0Lool200lNool00`0?ooooo`0X
ool00`2?ooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0308oooooo02Soo`0300oo
oooo01coo`803`Koo`0300oooooo01Coo`0300oooooo02Woo`0307oooooo04ooo`0300oooooo00?o
o`00:Ooo00<03oooool0Cooo00<0Ooooool0:?oo0P0?7Ooo0P0?1_oo00<03oooool0@?oo00<0Sooo
ool0Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`2?ooooo`0Yool00`0?ooooo`0Dool0
0`0?ooooo`04ool200l6ool00`0?ooooo`10ool00`1oooooo`1?ool00`0?ooooo`03ool002Woo`03
00oooooo04ooo`0307oooooo02[oo`0300oooooo01?oo`0300oooooo00Coo`803`Koo`0300oooooo
043oo`0308oooooo04ooo`0300oooooo00?oo`00:Ooo00<03oooool0Cooo00<0Soooool0:ooo00<0
3oooool04_oo00<03oooool01?oo0P0?1_oo00<03oooool0@?oo00<0Ooooool0Cooo00<03oooool0
0ooo000Yool200m@ool00`1oooooo`10ool00`0?ooooo`04ool200l5ool00`0?ooooo`0Bool00`0?
ooooo`0/ool00`2?ooooo`1=ool300l5ool002Woo`0300oooooo04ooo`0308oooooo043oo`0300oo
oooo00Coo`803`Goo`0300oooooo01;oo`0300oooooo02coo`0307oooooo04ooo`0300oooooo00?o
o`00:Ooo00<03oooool0Cooo00<0Ooooool0@Ooo00<03oooool00ooo0P0?1Ooo00<03oooool04Ooo
00<03oooool0;Ooo00<0Soooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`2?oooo
o`11ool00`0?ooooo`03ool200lHool00`0?ooooo`0^ool00`1oooooo`1?ool00`0?ooooo`03ool0
02Woo`0300oooooo04ooo`0307oooooo04Ooo`803aSoo`0300oooooo02koo`0308oooooo04ooo`03
00oooooo00?oo`00:Ooo00<03oooool0Cooo00<0Soooool0;ooo00<03oooool05Ooo0P0?5ooo00<0
3oooool0;ooo00<0Ooooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`1oooooo`0`
ool00`0?ooooo`0Dool200m9ool00`2?ooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo04oo
o`0308oooooo033oo`0300oooooo01Coo`803dWoo`0307oooooo04ooo`0300oooooo00?oo`00:Ooo
0P0?D?oo00<0Ooooool0<Ooo00<03oooool04ooo0P0?1?oo00<03oooool0@_oo00<0Soooool0COoo
0`0?1Ooo000Yool00`0?ooooo`1?ool00`2?ooooo`0bool200l>ool00`0?ooooo`02ool200l4ool0
0`0?ooooo`12ool00`1oooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0307oooooo
04;oo`0300oooooo00;oo`803`Coo`0300oooooo00coo`0300oooooo03?oo`0308oooooo04ooo`03
00oooooo00?oo`00:Ooo00<03oooool0Cooo00<0Soooool0@_oo00<03oooool00_oo0P0?0ooo00<0
3oooool03?oo00<03oooool0=?oo00<0Ooooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`1?
ool00`1oooooo`12ool200l3ool200l3ool00`0?ooooo`0;ool00`0?ooooo`0eool00`2?ooooo`1?
ool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0308oooooo04?oo`0400ooooooool200l3ool0
0`0?ooooo`0:ool00`0?ooooo`0fool00`1oooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo
04ooo`0307oooooo03Ooo`0300oooooo00Woo`0400ooooooool200l3ool00`0?ooooo`09ool00`0?
ooooo`0gool00`2?ooooo`1?ool00`0?ooooo`03ool002Woo`803e3oo`0308oooooo03Soo`0300oo
oooo00Soo`0400ooooooool200l>ool00`0?ooooo`0hool00`1oooooo`1=ool300l5ool002Woo`03
00oooooo04ooo`0307oooooo03Woo`0300oooooo00_oo`803dWoo`0308oooooo04ooo`0300oooooo
00?oo`00:Ooo00<03oooool0Cooo00<0Soooool0>_oo00<03oooool02_oo0P0?BOoo00<0Ooooool0
Cooo00<03oooool00ooo000Yool00`0?ooooo`1?ool00`1oooooo`0kool00`0?ooooo`09ool200m9
ool00`2?ooooo`1?ool00`0?ooooo`03ool002Woo`0300oooooo04ooo`0308oooooo04Ooo`803`Wo
o`803ckoo`0307oooooo04ooo`0300oooooo00?oo`005ooo00D03oooool03ooo00<03`03ool03`0?
00Ooo`0300oooooo04ooo`0307oooooo04Ooo`0400oooooo00l5ool200m0ool00`2?ooooo`1?ool0
0`0?ooooo`03ool001Koo`0300ooo`0?00?oo`0300oooooo00?oo`0300oooooo00Coo`0300oooooo
04ooo`0308oooooo047oo`0300oooooo00;oo`803`03ool03ooo00;oo`<03d;oo`0307oooooo04oo
o`0300oooooo00?oo`005_oo00<03ooo00l01?oo00<03oooool00P0?1ooo0`0?Cooo00<0Ooooool0
@_oo200?B?oo00<0Soooool0COoo0`0?1Ooo000Fool00`0?ool03`03ool01@0?ool03ooo00l02?oo
00<03oooool0Cooo00<0Soooool0Aooo00<03oooool0B?oo00<0Ooooool0Cooo00<03oooool00ooo
000Gool00`0?ooooo`03ool200l01?oo00l03`0?1_oo00<03oooool0Cooo00<0Ooooool0Aooo00<0
3oooool0B?oo00<0Soooool0Cooo00<03oooool00ooo000Yool00`0?ooooo`05ool00`0?ooooo`17
ool00`0?ooooo`17ool00`0?ooooo`18ool00`0?ooooo`17ool00`0?ooooo`05ool00`0?ooooo`03
ool002Woo`0300oooooo00Goo`0300oooooo00_oo`0300oooooo00coo`0300oooooo00coo`0300oo
oooo00coo`0300oooooo00coo`0300oooooo00coo`0300oooooo00coo`0300oooooo00coo`0300oo
oooo00_oo`0300oooooo00coo`0300oooooo00coo`0300oooooo00coo`0300oooooo00coo`0300oo
oooo00coo`0300oooooo00coo`0300oooooo00coo`0300oooooo00_oo`0300oooooo00coo`0300oo
oooo00coo`0300oooooo00coo`0300oooooo00Goo`0300oooooo00?oo`00:Oooo`0?>`0?1Ooo003o
oomYool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.133015, -0.042832, 
  0.00084, 0.0017}}]
}, Open  ]]
}, Open  ]],

Cell[TextData["Feenstra's Parameter "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["File Reading"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Initialization"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetDirectory["\</Users/sarid/papers/3.0book\>"]; \n
    \(name = "\<sts1601\>"; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["File Characterization"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[tbl1]; \)\), 
    \(\(tbl1 = 
      ReadList[name, Number, RecordSeparators \[Rule] {"\<\n\>", "\< \>"}]; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dim1 = 
      \(Dimensions[tbl1]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \)\), 
    \(\(min1 = Min[tbl1]; \)\), 
    \(\(max1 = Max[tbl1]; \)\), 
    \(\(del1 = Max[tbl1] - Min[tbl1]; \)\), 
    \(\(mid1 = tbl1\[LeftDoubleBracket]dim1\/2\[RightDoubleBracket]; \)\), 
    \(\(Print["\<dimension = \>", dim1]; \)\), 
    \(\(Print["\<minimum   = \>", min1]; \)\), 
    \(\(Print["\<maximum   = \>", max1]; \)\), 
    \(\(Print["\<delta     = \>", del1]; \)\), 
    \(\(Print["\<middle    = \>", mid1]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[\("dimension = "\[InvisibleSpace]256\),
      SequenceForm[ "dimension = ", 256],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("minimum   = "\[InvisibleSpace]\( - 182520540\)\),
      SequenceForm[ "minimum   = ", -182520540],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("maximum   = "\[InvisibleSpace]56034126\),
      SequenceForm[ "maximum   = ", 56034126],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("delta     = "\[InvisibleSpace]238554666\),
      SequenceForm[ "delta     = ", 238554666],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("middle    = "\[InvisibleSpace]589834\),
      SequenceForm[ "middle    = ", 589834],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["File Preparation"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Averaging"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[tbl2, b1, b2]; \)\), 
    \(\(nav = 5; \)\), 
    \(\(tbl2 = tbl1; \)\), 
    \(\(Do[b1 = tbl2; 
      b2 = Table[
          N[1\/3\ \((
                b1\[LeftDoubleBracket]i - 1\[RightDoubleBracket] + 
                  b1\[LeftDoubleBracket]i\[RightDoubleBracket] + 
                  b1\[LeftDoubleBracket]i + 1\[RightDoubleBracket])\)], {i, 
            2, 255}]; 
      tbl2 = Join[{b2\[LeftDoubleBracket]1\[RightDoubleBracket]}, 
          b2, {b2\[LeftDoubleBracket]254\[RightDoubleBracket]}], {n, 1, 
        nav}]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dim2 = 
      \(Dimensions[tbl2]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \)\), 
    \(\(del2 = Max[tbl2] - Min[tbl2]; \)\), 
    \(\(Print["\<dimension = \>", dim2]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[\("dimension = "\[InvisibleSpace]256\),
      SequenceForm[ "dimension = ", 256],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Normalization"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[tbli]; \)\), 
    \(\(tbli = 
      Table[N[\(tbl2\[LeftDoubleBracket]n\[RightDoubleBracket] - 
              tbl2\[LeftDoubleBracket]dim1\/2\[RightDoubleBracket]\)\/del2], {
          n, 1, dim1, 1}]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dimi = 
      \(Dimensions[tbli]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \)\), 
    \(\(mini = Min[tbli]; \)\), 
    \(\(maxi = Max[tbli]; \)\), 
    \(\(midi = tbli\[LeftDoubleBracket]dimi\[RightDoubleBracket]; \)\), 
    \(\(deli = Max[tbli] - Min[tbli]; \)\), 
    \(\(Print["\<dimension = \>", dimi]; \)\), 
    \(\(Print["\<minimum   = \>", mini]; \)\), 
    \(\(Print["\<maximum   = \>", maxi]; \)\), 
    \(\(Print["\<delta     = \>", deli]; \)\), 
    \(\(Print["\<middle    = \>", 
      tbli\[LeftDoubleBracket]dimi\/2\[RightDoubleBracket]]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[\("dimension = "\[InvisibleSpace]256\),
      SequenceForm[ "dimension = ", 256],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("minimum   = "\[InvisibleSpace]\( - 0.76945371487436498`\)\),
      SequenceForm[ "minimum   = ", -0.76945371487436498],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("maximum   = "\[InvisibleSpace]0.230546285125635019`\),
      SequenceForm[ "maximum   = ", 0.23054628512563502],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("delta     = "\[InvisibleSpace]1.`\),
      SequenceForm[ "delta     = ", 1.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("middle    = "\[InvisibleSpace]0.`\),
      SequenceForm[ "middle    = ", 0.0],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Voltage Information"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(vmax = 3.; \)\), 
    \(\(delv = \(2\ vmax\)\/dim1; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[tblv]; \)\), 
    \(\(tblv = Table[\(\((n - dim1\/2)\)\ 2\ vmax\)\/dim1, {n, 1, dim1}]; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Print["\<goof = \>", 
      tblv\[LeftDoubleBracket]1\[RightDoubleBracket] + vmax]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[\("goof = "\[InvisibleSpace]0.0234375`\),
      SequenceForm[ "goof = ", 0.0234375],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Spectroscopic Data"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["$i(v)$"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(tbliv = 
      Table[{tblv\[LeftDoubleBracket]n\[RightDoubleBracket], 
          Abs[tbli\[LeftDoubleBracket]n\[RightDoubleBracket]]}, {n, 1, 
          dim1}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xlimit = .1; \)\), 
    \(\(ylimit = .3; \)\), 
    \(\(Fig12x4 = 
      ListPlot[tbliv, 
        PlotRange \[Rule] {{\(-vmax\) + xlimit, vmax - xlimit}, {0, ylimit}}, 
        Frame \[Rule] True, PlotJoined \[Rule] True, 
        GridLines \[Rule] Automatic, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        FrameLabel \[Rule] {"\<Energy in eV\>", "\<i in a.u.\>"}]; \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.172414 0 2.060113 [
[.15517 -0.0125 -7 -12 ]
[.15517 -0.0125 7 0 ]
[.32759 -0.0125 -7 -12 ]
[.32759 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.67241 -0.0125 -4 -12 ]
[.67241 -0.0125 4 0 ]
[.84483 -0.0125 -4 -12 ]
[.84483 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -23.5 -24 ]
[.5 -0.0125 23.5 -12 ]
[-0.0125 .10301 -18 -6 ]
[-0.0125 .10301 0 6 ]
[-0.0125 .20601 -14 -6 ]
[-0.0125 .20601 0 6 ]
[-0.0125 .30902 -18 -6 ]
[-0.0125 .30902 0 6 ]
[-0.0125 .41202 -14 -6 ]
[-0.0125 .41202 0 6 ]
[-0.0125 .51503 -18 -6 ]
[-0.0125 .51503 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30 -14 ]
[-0.01875 .30902 -18 14 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.15517 0 m
.15517 .61803 L
s
.32759 0 m
.32759 .61803 L
s
.5 0 m
.5 .61803 L
s
.67241 0 m
.67241 .61803 L
s
.84483 0 m
.84483 .61803 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 g
.15517 0 m
.15517 .00625 L
s
gsave
.15517 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.32759 0 m
.32759 .00625 L
s
gsave
.32759 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.67241 0 m
.67241 .00625 L
s
gsave
.67241 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.84483 0 m
.84483 .00625 L
s
gsave
.84483 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.18966 0 m
.18966 .00375 L
s
.22414 0 m
.22414 .00375 L
s
.25862 0 m
.25862 .00375 L
s
.2931 0 m
.2931 .00375 L
s
.36207 0 m
.36207 .00375 L
s
.39655 0 m
.39655 .00375 L
s
.43103 0 m
.43103 .00375 L
s
.46552 0 m
.46552 .00375 L
s
.53448 0 m
.53448 .00375 L
s
.56897 0 m
.56897 .00375 L
s
.60345 0 m
.60345 .00375 L
s
.63793 0 m
.63793 .00375 L
s
.7069 0 m
.7069 .00375 L
s
.74138 0 m
.74138 .00375 L
s
.77586 0 m
.77586 .00375 L
s
.81034 0 m
.81034 .00375 L
s
.12069 0 m
.12069 .00375 L
s
.08621 0 m
.08621 .00375 L
s
.05172 0 m
.05172 .00375 L
s
.01724 0 m
.01724 .00375 L
s
.87931 0 m
.87931 .00375 L
s
.91379 0 m
.91379 .00375 L
s
.94828 0 m
.94828 .00375 L
s
.98276 0 m
.98276 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -84.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Energy) show
88.000000 13.000000 moveto
(in) show
96.187500 13.000000 moveto
(eV) show
105.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .10301 m
.00625 .10301 L
s
gsave
-0.0125 .10301 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .20601 m
.00625 .20601 L
s
gsave
-0.0125 .20601 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .41202 m
.00625 .41202 L
s
gsave
-0.0125 .41202 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .51503 m
.00625 .51503 L
s
gsave
-0.0125 .51503 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
75 10 translate
90 rotate
-75 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(i) show
67.187500 13.000000 moveto
(in) show
75.375000 13.000000 moveto
(a) show
78.875000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
80.875000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
84.875000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
86.875000 13.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.15517 .61178 m
.15517 .61803 L
s
.32759 .61178 m
.32759 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.67241 .61178 m
.67241 .61803 L
s
.84483 .61178 m
.84483 .61803 L
s
.125 Mabswid
.18966 .61428 m
.18966 .61803 L
s
.22414 .61428 m
.22414 .61803 L
s
.25862 .61428 m
.25862 .61803 L
s
.2931 .61428 m
.2931 .61803 L
s
.36207 .61428 m
.36207 .61803 L
s
.39655 .61428 m
.39655 .61803 L
s
.43103 .61428 m
.43103 .61803 L
s
.46552 .61428 m
.46552 .61803 L
s
.53448 .61428 m
.53448 .61803 L
s
.56897 .61428 m
.56897 .61803 L
s
.60345 .61428 m
.60345 .61803 L
s
.63793 .61428 m
.63793 .61803 L
s
.7069 .61428 m
.7069 .61803 L
s
.74138 .61428 m
.74138 .61803 L
s
.77586 .61428 m
.77586 .61803 L
s
.81034 .61428 m
.81034 .61803 L
s
.12069 .61428 m
.12069 .61803 L
s
.08621 .61428 m
.08621 .61803 L
s
.05172 .61428 m
.05172 .61803 L
s
.01724 .61428 m
.01724 .61803 L
s
.87931 .61428 m
.87931 .61803 L
s
.91379 .61428 m
.91379 .61803 L
s
.94828 .61428 m
.94828 .61803 L
s
.98276 .61428 m
.98276 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.09017 .61803 m
.09186 .60257 L
.09591 .56762 L
.09995 .53465 L
.10399 .50366 L
.10803 .47473 L
.11207 .448 L
.11611 .42341 L
.12015 .4006 L
.12419 .37907 L
.12823 .35823 L
.13227 .33793 L
.13631 .31854 L
.14036 .30088 L
.1444 .28554 L
.14844 .27257 L
.15248 .26142 L
.15652 .25152 L
.16056 .24255 L
.1646 .23458 L
.16864 .2278 L
.17268 .22226 L
.17672 .21775 L
.18077 .21389 L
.18481 .21041 L
.18885 .20713 L
.19289 .20396 L
.19693 .20082 L
.20097 .19762 L
.20501 .19428 L
.20905 .1907 L
.21309 .18687 L
.21713 .18274 L
.22117 .17824 L
.22522 .17323 L
.22926 .1677 L
.2333 .16177 L
.23734 .15579 L
.24138 .15005 L
.24542 .14469 L
.24946 .13971 L
.2535 .13508 L
.25754 .13087 L
.26158 .12714 L
.26563 .1239 L
.26967 .12102 L
.27371 .11836 L
.27775 .11574 L
.28179 .11304 L
.28583 .11012 L
Mistroke
.28987 .10689 L
.29391 .10334 L
.29795 .0995 L
.30199 .09535 L
.30603 .09087 L
.31008 .08597 L
.31412 .08066 L
.31816 .07498 L
.3222 .06909 L
.32624 .06304 L
.33028 .05684 L
.33432 .05044 L
.33836 .04391 L
.3424 .03753 L
.34644 .03163 L
.35048 .02642 L
.35453 .02184 L
.35857 .01771 L
.36261 .01391 L
.36665 .01047 L
.37069 .00756 L
.37473 .00533 L
.37877 .00377 L
.38281 .00271 L
.38685 .00196 L
.39089 .00142 L
.39494 .00106 L
.39898 .00091 L
.40302 .00089 L
.40706 .00091 L
.4111 .00084 L
.41514 .00066 L
.41918 .00038 L
.42322 5e-05 L
.42726 .00035 L
.4313 .00072 L
.43534 .00098 L
.43939 .00097 L
.44343 .00064 L
.44747 .00011 L
.45151 .0004 L
.45555 .00067 L
.45959 .00068 L
.46363 .00051 L
.46767 .00028 L
.47171 2e-05 L
.47575 .00018 L
.4798 .00025 L
.48384 .00015 L
.48788 1e-05 L
Mistroke
.49192 .00011 L
.49596 9e-05 L
.5 0 L
.50404 .00013 L
.50808 .00028 L
.51212 .00043 L
.51616 .00048 L
.5202 .00037 L
.52425 8e-05 L
.52829 .00025 L
.53233 .00047 L
.53637 .00044 L
.54041 .00017 L
.54445 .00016 L
.54849 .00035 L
.55253 .00035 L
.55657 .00025 L
.56061 .00015 L
.56466 .0001 L
.5687 7e-05 L
.57274 5e-05 L
.57678 2e-05 L
.58082 .00019 L
.58486 .0005 L
.5889 .00085 L
.59294 .00111 L
.59698 .00117 L
.60102 .00105 L
.60506 .00081 L
.60911 .00053 L
.61315 .00024 L
.61719 4e-05 L
.62123 .00031 L
.62527 .00054 L
.62931 .00075 L
.63335 .00097 L
.63739 .00122 L
.64143 .00148 L
.64547 .00171 L
.64952 .00196 L
.65356 .0023 L
.6576 .00282 L
.66164 .00354 L
.66568 .00447 L
.66972 .00558 L
.67376 .00689 L
.6778 .00836 L
.68184 .00995 L
.68588 .01159 L
.68992 .01325 L
Mistroke
.69397 .01493 L
.69801 .01671 L
.70205 .01857 L
.70609 .02046 L
.71013 .0222 L
.71417 .02368 L
.71821 .02482 L
.72225 .0257 L
.72629 .02648 L
.73033 .02724 L
.73438 .02797 L
.73842 .0286 L
.74246 .02913 L
.7465 .0296 L
.75054 .03006 L
.75458 .03042 L
.75862 .03063 L
.76266 .03061 L
.7667 .03049 L
.77074 .03043 L
.77478 .03059 L
.77883 .031 L
.78287 .0316 L
.78691 .03239 L
.79095 .03343 L
.79499 .03488 L
.79903 .03683 L
.80307 .03936 L
.80711 .04248 L
.81115 .04623 L
.81519 .05069 L
.81923 .05593 L
.82328 .06204 L
.82732 .06901 L
.83136 .07676 L
.8354 .08512 L
.83944 .09394 L
.84348 .10308 L
.84752 .11254 L
.85156 .12236 L
.8556 .13254 L
.85964 .14287 L
.86369 .15294 L
.86773 .16231 L
.87177 .17072 L
.87581 .1782 L
.87985 .18487 L
.88389 .19088 L
.88793 .19647 L
.89197 .20196 L
Mistroke
.89601 .20761 L
.90005 .21333 L
.90409 .21876 L
.90814 .22345 L
.91218 .2274 L
.91622 .23093 L
.92026 .23457 L
.9243 .2386 L
.92834 .24316 L
.93238 .24835 L
.93642 .2545 L
.94046 .26178 L
.9445 .27006 L
.94855 .27898 L
.95259 .28826 L
.95663 .29799 L
.96067 .30842 L
.96471 .31979 L
.96875 .33185 L
.97279 .34423 L
.97683 .35637 L
.98087 .36847 L
.98491 .38079 L
.98895 .39394 L
.993 .408 L
.99704 .42327 L
Mfstroke
.99704 .42327 m
1 .43505 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{170, 105},
  ImageMargins->{{110, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003E0000Q1000`40l00?003`eOoo003Eool007Co
o`<03`03ool03ooo05_oo`00M?oo00<03ooo00l00_oo00<03oooool0FOoo001Uool400l01?oo00oo
o`0?0_oo0P0?00Goo`0?ooooo`0?00?oo`0300oooooo00;oo`0600oooooo00ooo`0?0ooo0P0?0_oo
0P0?B?oo001Vool02@0?oooooooo00ooo`0?ool03`03ool02@0?ool03ooo00ooo`0?ool03`03ool0
1P0?ooooo`0?ool03`;oo`0300oooooo00;oo`803dSoo`00I_oo0P0?0_oo00P03ooo00ooo`0?ool0
3ooo0`0?00Koo`0?ool03ooo00l3ool01P0?ooooo`0?ool03`;oo`0500ooo`0?ool03`02ool00`0?
ooooo`15ool006Koo`0400ooooooool200l3ool200l00ooo00ooo`0300l01?oo00ooo`0?0ooo00<0
3oooool00P0?1?oo0P0?00Goo`0?ooooo`0?04Ooo`00IOoo100?8Ooo00@03oooool03dOoo`00O_oo
00<03oooool0E?oo003Eool00=Goo`00eOoo003Eool00=Goo`00eOoo0011ool300lJool300lIool0
0`0?ooooo`0Iool300lJool300lOool0047oo`0300oooooo01_oo`0300oooooo01Ooo`0300ooo`0?
01_oo`0300oooooo01Woo`0300oooooo01ooo`00??oo0`0?0ooo00<03oooool05?oo0`0?0ooo00<0
3oooool05ooo00<03ooo00l06ooo00<03oooool06_oo00<03oooool07_oo0011ool00`0?ool03`0K
ool00`0?ooooo`0Gool00`0?ool03`0Kool00`0?ooooo`0Iool00`0?ool03`0Oool004;oo`803a[o
o`803a[oo`0300oooooo01Woo`803acoo`803aooo`00eOoo003Eool00=Goo`00eOoo003Eool002Go
oj/03`Goo`009Ooo00@03oooool03`Goo`0300oooooo00?oo`0300oooooo00?oo`0300oooooo00?o
o`0300oooooo00;oo`0300oooooo00?oo`0300oooooo00?oo`0300oooooo00?oo`0300oooooo00?o
o`0300oooooo00?oo`0300ooo`0?00H03`?oo`803`?oo`0300oooooo00?oo`0300oooooo00?oo`03
00oooooo00?oo`0300oooooo00@03`?oo`T03`Coo`0300oooooo00?oo`0300oooooo00?oo`0300oo
oooo00?oo`0300oooooo00?oo`0300oooooo00?oo`0300oooooo00?oo`0300oooooo00?oo`0300oo
oooo00;oo`0400oooooo00l5ool002Goo`0300oooooo01Soo`0307oooooo01[oo`0308oooooo00Co
o`0300oooooo01?oo`0300oooooo01_oo`<03a[oo`0308oooooo01Ooo`0300oooooo00?oo`009Ooo
00<03oooool06?oo00<0Soooool06_oo00<0Ooooool00_oo0P0?5_oo00<03oooool06ooo00<0Sooo
ool00P0?6?oo00<0Ooooool05ooo00<03oooool00ooo000Uool200lIool00`1oooooo`0Jool00`2?
ooooo`02ool00`0?ooooo`0Eool00`0?ooooo`0Kool00`1oooooo`02ool300lEool00`2?ooooo`0G
ool00`0?ooooo`03ool002Goo`0300oooooo01Soo`0308oooooo01[oo`0507ooooooool03`0Hool0
0`0?ooooo`0Kool00`2?ooooo`04ool700l?ool00`1oooooo`0Gool00`0?ooooo`03ool002Goo`03
00oooooo01Soo`0307oooooo01[oo`0408oooooo00lIool00`0?ooooo`0Kool00`1oooooo`0;ool7
00l8ool00`2?ooooo`0Gool00`0?ooooo`03ool002Goo`803aWoo`0308oooooo01[oo`0307ooo`0?
01[oo`0300oooooo01_oo`0308oooooo01;oo`803`Koo`0307oooooo01Ooo`0300oooooo00?oo`00
9Ooo00<03oooool06?oo00<0Ooooool06_oo00<0Sooo00l06_oo00<03oooool06ooo00<0Ooooool0
5?oo00<03oooool00ooo00<0Soooool05ooo00<03oooool00ooo000Uool00`0?ooooo`0Hool00`2?
ooooo`0Jool00`1o00ooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Eool00`0?ooooo`02ool00`1o
ooooo`0Gool00`0?ooooo`03ool002Goo`0300oooooo01Soo`0307oooooo01[oo`0300oooooo01[o
o`0300oooooo01_oo`0307oooooo01Koo`0500ooooooool0S`0Iool00`0?ooooo`03ool002Goo`80
3aWoo`0308oooooo01[oo`0300oooooo01[oo`0300oooooo01_oo`0308oooooo01Koo`0500oooooo
ool0O`0Iool00`0?ooooo`03ool002Goo`0300oooooo01Soo`0307oooooo01Woo`0300l0Sooo01_o
o`0300oooooo01_oo`0307oooooo01Ooo`0400oooooo08lIool00`0?ooooo`03ool002Goo`0300oo
oooo01Soo`0308oooooo01Soo`0300ooo`1o01coo`0300oooooo01_oo`0308oooooo01Soo`0300oo
o`1o01Woo`0300oooooo00?oo`009Ooo0P0?6Ooo00<0Ooooool06?oo00<03ooo08l07?oo00<03ooo
ool06ooo00<0Ooooool06?oo00<03ooo08l06Ooo00<03oooool00ooo000Eool0100?ooooo`0?0_oo
00<03oooool00P0?1Ooo00<03oooool06?oo00<0Soooool05ooo00@03oooool0Oacoo`0300oooooo
01_oo`0308oooooo01Soo`0300ooo`1o01Woo`0300oooooo00?oo`005?oo00<03ooo00l00ooo00<0
3ooo00l00ooo00<03oooool00_oo00<03oooool06?oo00<0Ooooool05_oo00D03oooooooo`2?01co
o`0300oooooo01_oo`0307oooooo01Woo`0300l0Sooo01Soo`0300oooooo00?oo`005?oo00<03ooo
00l00ooo00@03ooo00ooo`803`Goo`0300oooooo01Soo`0308oooooo01Goo`803`?oo`0307oooooo
01[oo`0300oooooo01_oo`0308oooooo01Woo`0300l0Oooo01Soo`0300oooooo00?oo`005?oo00<0
3ooo00l00ooo00D03ooo00ooo`0?00Koo`803`2W08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`0200l5ool001Goo`0300oooooo00?oo`0300oooooo00<03`Coo`0300oooooo01Soo`0308oo
oooo01?oo`803`Goo`0307oooooo01[oo`0300oooooo01_oo`0308oooooo01[oo`0300oooooo01Oo
o`0300oooooo00?oo`009Ooo00<03oooool06?oo00<0Ooooool04Ooo0P0?1ooo00<0Soooool06_oo
00<03oooool06ooo00<0Ooooool06_oo0P0?6?oo00<03oooool00ooo000Uool200lIool00`2?oooo
o`0?ool300l8ool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1o00ooo`0Gool0
0`0?ooooo`03ool002Goo`0300oooooo01Soo`0307oooooo00ooo`0300oooooo00Soo`0308oooooo
01[oo`0300oooooo01_oo`0307oooooo01[oo`0308l03ooo01Ooo`0300oooooo00?oo`009Ooo00<0
3oooool06?oo00<0Soooool03Ooo0P0?2ooo00<0Ooooool06_oo00<03oooool06ooo00<0Soooool0
6_oo00<0Oooo00l05ooo00<03oooool00ooo000Uool00`0?ooooo`0Hool00`1oooooo`0=ool00`0?
ooooo`0:ool00`2?ooooo`0Jool00`0?ooooo`0Kool00`1oooooo`0Jool00`2?ool03`0Gool00`0?
ooooo`03ool002Goo`803aWoo`0308oooooo00coo`0300oooooo00_oo`0307oooooo01[oo`0300oo
oooo01_oo`0308oooooo01[oo`0407ooo`0?00lFool00`0?ooooo`03ool002Goo`0300oooooo01So
o`0307oooooo00_oo`0300oooooo00coo`0308oooooo01[oo`0300oooooo01_oo`0307oooooo01[o
o`0408oooooo00lFool00`0?ooooo`03ool002Goo`0300oooooo01Soo`0308oooooo00_oo`0300oo
oooo00coo`0307oooooo01[oo`0300oooooo01_oo`0308oooooo01[oo`0407oooooo00lFool00`0?
ooooo`03ool002Goo`803aWoo`0307oooooo00[oo`0300oooooo00goo`0308oooooo01[oo`0300oo
oooo01_oo`0307oooooo01[oo`0508ooooooool03`0Eool00`0?ooooo`03ool002Goo`0300oooooo
01Soo`0308oooooo00Woo`0300oooooo00koo`0307oooooo01[oo`0300oooooo01_oo`0308oooooo
01[oo`0307oooooo00;oo`0300oooooo01;oo`0300oooooo00?oo`009Ooo00<03oooool06?oo00<0
Ooooool02?oo0P0?4?oo00<0Soooool06_oo00<03oooool06ooo00<0Ooooool06_oo00<0Soooool0
0_oo00<03oooool04_oo00<03oooool00ooo000Uool00`0?ooooo`0Hool00`2?ooooo`07ool200lA
ool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1oooooo`02ool00`0?ooooo`0B
ool00`0?ooooo`03ool002Goo`803aWoo`0307oooooo00Koo`803a;oo`0308oooooo01[oo`0300oo
oooo01_oo`0307oooooo01[oo`0308oooooo00?oo`0300oooooo017oo`0300oooooo00?oo`006Ooo
00D03oooool03ooo00<03`Coo`0300oooooo01Soo`0308oooooo00Goo`803a?oo`0307oooooo01[o
o`0300oooooo01_oo`0308oooooo01[oo`0307oooooo00Coo`0300oooooo013oo`0300oooooo00?o
o`006?oo00<03ooo00l01?oo00<03oooool00ooo00<03oooool06?oo00<0Ooooool01?oo0P0?5?oo
00<0Soooool06_oo00<03oooool06ooo00<0Ooooool06_oo00<0Soooool01?oo00<03oooool04?oo
00<03oooool00ooo000Hool00`0?ool03`04ool00`0?ooooo`03ool200l07`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00803`2608l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`803`Goo`006?oo00<03ooo00l01?oo00<03oooool00ooo00<0
3oooool06?oo00<0Ooooool00_oo00<03oooool05Ooo00<0Soooool06_oo00<03oooool06ooo00<0
Ooooool06_oo00<0Soooool01_oo00<03oooool03_oo00<03oooool00ooo000Iool00`0?ooooo`02
ool200l5ool00`0?ooooo`0Hool00`2?ooooo`0200lHool00`1oooooo`0Jool00`0?ooooo`0Kool0
0`2?ooooo`0Jool00`1oooooo`06ool200l?ool00`0?ooooo`03ool002Goo`0300oooooo01Soo`04
07oooooo00lIool00`2?ooooo`0Jool00`0?ooooo`0Kool00`1oooooo`0Jool00`2?ooooo`07ool2
00l>ool00`0?ooooo`03ool002Goo`803aWoo`0308ooo`0?01[oo`0307oooooo01[oo`0300oooooo
01_oo`0308oooooo01[oo`0307oooooo00Soo`0300oooooo00coo`0300oooooo00?oo`009Ooo00<0
3oooool06?oo00<0O`0?ool06_oo00<0Soooool06_oo00<03oooool06ooo00<0Ooooool06_oo00<0
Soooool02Ooo0P0?3?oo00<03oooool00ooo000;ool00`0?ool03`0Gool00`0?ooooo`0Hool00`2?
00ooo`0Jool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1oooooo`0:ool00`0?
ooooo`0:ool00`0?ooooo`03ool000Soo`0300ooo`0?00<03aOoo`803aWoo`803a_oo`0308oooooo
01[oo`0300oooooo01_oo`0307oooooo01[oo`0308oooooo00_oo`0300oooooo00Woo`0300oooooo
00?oo`003Ooo00<03oooool05Ooo00<03oooool06?oo00<03oooool06_oo00<0Ooooool06_oo00<0
3oooool06ooo00<0Soooool06_oo00<0Ooooool03?oo00<03oooool02?oo00<03oooool00ooo000U
ool00`0?ooooo`0Hool00`0?ooooo`0Jool00`2?ooooo`0Jool00`0?ooooo`0Kool00`1oooooo`0J
ool00`2?ooooo`0=ool00`0?ooooo`07ool00`0?ooooo`03ool002Goo`0300oooooo01Ooo`0300l0
Sooo01_oo`0307oooooo01[oo`0300oooooo01_oo`0308oooooo01[oo`0307oooooo00goo`0300oo
oooo00Ooo`0300oooooo00?oo`002ooo00<03ooo00l05ooo0P0?6?oo00<03`1oool06ooo00<0Sooo
ool06_oo00<03oooool06ooo00<0Ooooool06_oo00<0Soooool03_oo00<03oooool01_oo00<03ooo
ool00ooo0008ool00`0?ool03`0300lGool00`0?ooooo`0Fool00`0?ool0S`0Lool00`1oooooo`0J
ool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1oooooo`0>ool00`0?ooooo`06ool00`0?ooooo`03
ool000[oo`@03aOoo`0300oooooo01Koo`0300ooo`1o01coo`0308oooooo01[oo`0300oooooo01_o
o`0307oooooo01[oo`0308oooooo00ooo`0300oooooo00Goo`0300oooooo00?oo`002_oo00@03ooo
ool03aOoo`803aOoo`0300ooo`2?01coo`0307oooooo01[oo`0300oooooo01_oo`0308oooooo01[o
o`0307oooooo00ooo`0300oooooo00Goo`0300oooooo00?oo`002_oo00<03oooool02?oo00D03ooo
ool03ooo00<03`03ool03`0?00Goo`0300oooooo01Koo`0300ooo`1o01coo`0308oooooo01[oo`03
00oooooo01_oo`0307oooooo01[oo`0308oooooo013oo`0300oooooo00Coo`0300oooooo00?oo`00
2ooo0`0?1_oo00<03ooo00l01?oo00<03oooool00_oo00<03oooool00_oo00<03oooool05Ooo00@0
3oooool0Sacoo`0307oooooo01[oo`0300oooooo01_oo`0308oooooo01[oo`0307oooooo013oo`03
00oooooo00Coo`0300oooooo00?oo`005?oo00<03ooo00l01?oo00<03oooool00P0?1Ooo00<03ooo
ool05Ooo00@03oooool0Oacoo`0308oooooo01[oo`0300oooooo01_oo`0307oooooo01[oo`0308oo
oooo013oo`0300oooooo00Coo`0300oooooo00?oo`005?oo00<03ooo00l01?oo00@03oooool03`Ko
o`803`2W07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`0200l5ool000[oo`0300ooo`0?
00Soo`0300oooooo00;oo`803`;oo`<03`Coo`0300oooooo01Goo`0400oooooo07lLool00`2?oooo
o`0Jool00`0?ooooo`0Kool00`1oooooo`0Jool00`2?ooooo`0Aool00`0?ooooo`03ool00`0?oooo
o`03ool000[oo`803`03ool03ooo01Koo`0300oooooo01Coo`0500ooooooool0S`0Lool00`1ooooo
o`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1oooooo`0Aool00`0?ooooo`03ool00`0?oooo
o`03ool000_oo`<03aOoo`803aGoo`0500ooooooool0O`0Lool00`2?ooooo`0Jool00`0?ooooo`0K
ool00`1oooooo`0Jool00`2?ooooo`0Bool00`0?ooooo`02ool00`0?ooooo`03ool000goo`0300oo
oooo01Goo`0300oooooo01Coo`0500ooooooool0S`0Lool00`1oooooo`0Jool00`0?ooooo`0Kool0
0`2?ooooo`0Jool00`1oooooo`0Bool00`0?ooooo`02ool00`0?ooooo`03ool000goo`0300oooooo
01Goo`0300oooooo01Coo`0500ooooooool0O`0Lool00`2?ooooo`0Jool00`0?ooooo`0Kool00`1o
ooooo`0Jool00`2?ooooo`0Bool00`0?ooooo`02ool00`0?ooooo`03ool000[oo`<03aSoo`0300oo
oooo01Coo`0500ooooooool0S`0Lool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool0
0`1oooooo`0Cool01@0?oooooooo00l01Ooo000=ool00`0?ooooo`0Eool200lDool00`0?ooooo`02
ool00`1oooooo`0Jool00`2?ooooo`0Jool00`0?ooooo`0Kool00`1oooooo`0Jool00`2?ooooo`0C
ool01@0?oooooooo00l01Ooo000:ool400lGool00`0?ooooo`0Cool00`0?ooooo`02ool00`2?oooo
o`0Jool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1oooooo`0Cool01@0?oooo
oooo00l01Ooo000Uool00`0?ooooo`0Cool00`0?ooooo`02ool00`1oooooo`0Jool00`2?ooooo`0J
ool00`0?ooooo`0Kool00`1oooooo`0Jool00`2?ooooo`0Dool0100?ooooo`0?1Ooo000Uool200lD
ool00`0?ooooo`02ool00`2?ooooo`0Jool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0J
ool00`1oooooo`0Dool0100?ooooo`0?1Ooo000=ool00`0?ooooo`0Eool00`0?ooooo`0Cool00`0?
ooooo`02ool00`1oooooo`0Jool00`2?ooooo`0Jool00`0?ooooo`0Kool00`1oooooo`0Jool00`2?
ooooo`0Dool0100?ooooo`0?1Ooo000Uool00`0?ooooo`0Bool00`0?ooooo`03ool00`2?ooooo`0J
ool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1oooooo`0Eool00`0?ool03`05
ool002Goo`0300oooooo01;oo`0300oooooo00?oo`0307oooooo01[oo`0308oooooo01[oo`0300oo
oooo01_oo`0307oooooo01[oo`0308oooooo01Goo`0300ooo`0?00Goo`009Ooo0P0?4ooo00<03ooo
ool00ooo00<0Soooool06_oo00<0Ooooool06_oo00<03oooool06ooo00<0Soooool06_oo00<0Oooo
ool05Ooo00<03ooo00l01Ooo000Iool01@0?ooooo`0?ool00`0?1?oo00<03oooool04_oo00<03ooo
ool00ooo00<0Ooooool06_oo00<0Soooool06_oo00<03oooool06ooo00<0Ooooool06_oo00<0Sooo
ool05_oo0P0?1Ooo000Hool00`0?ool03`03ool00`0?ooooo`04ool00`0?ooooo`0Bool00`0?oooo
o`03ool00`2?ooooo`0Jool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1ooooo
o`0Fool200l5ool001Soo`0300ooo`0?00Coo`0300oooooo00?oo`803`2W08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`0200l5ool001Soo`0300ooo`0?00?oo`0300ooo`0?00Coo`0300oo
oooo017oo`0300oooooo00Coo`0308oooooo01[oo`0307oooooo01[oo`0300oooooo01_oo`0308oo
oooo01[oo`0307oooooo01Koo`803`Goo`006Ooo00<03oooool00ooo0P0?1?oo00<03oooool04Ooo
00<03oooool01?oo00<0Ooooool06_oo00<0Soooool06_oo00<03oooool06ooo00<0Ooooool06_oo
00<0Soooool05ooo00<03oooool00ooo000Uool00`0?ooooo`0Aool00`0?ooooo`04ool00`2?oooo
o`0Jool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1oooooo`0Gool00`0?oooo
o`03ool002Goo`803a;oo`0300oooooo00Coo`0307oooooo01[oo`0308oooooo01[oo`0300oooooo
01_oo`0307oooooo01[oo`0308oooooo01Ooo`0300oooooo00?oo`009Ooo00<03oooool04Ooo00<0
3oooool01?oo00<0Soooool06_oo00<0Ooooool06_oo00<03oooool06ooo00<0Soooool06_oo00<0
Ooooool05ooo00<03oooool00ooo000Uool00`0?ooooo`0@ool00`0?ooooo`05ool00`1oooooo`0J
ool00`2?ooooo`0Jool00`0?ooooo`0Kool00`1oooooo`0Jool00`2?ooooo`0Gool00`0?ooooo`03
ool002Goo`803a7oo`0300oooooo00Goo`0308oooooo01[oo`0307oooooo01[oo`0300oooooo01_o
o`0308oooooo01[oo`0307oooooo01Ooo`0300oooooo00?oo`009Ooo00<03oooool04?oo00<03ooo
ool01Ooo00<0Ooooool06_oo00<0Soooool06_oo00<03oooool06ooo00<0Ooooool06_oo00<0Sooo
ool05ooo00<03oooool00ooo000Uool00`0?ooooo`0@ool00`0?ooooo`05ool00`2?ooooo`0Jool0
0`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1oooooo`0Gool00`0?ooooo`03ool0
02Goo`0300oooooo013oo`0300oooooo00Goo`0307oooooo01[oo`0308oooooo01[oo`0300oooooo
01_oo`0307oooooo01[oo`0308oooooo01Ooo`0300oooooo00?oo`009Ooo0P0?4Ooo00<03oooool0
1Ooo00<0Soooool06_oo00<0Ooooool06_oo00<03oooool06ooo00<0Soooool06_oo00<0Ooooool0
5ooo00<03oooool00ooo000Uool00`0?ooooo`0?ool00`0?ooooo`06ool00`1oooooo`0Jool00`2?
ooooo`0Jool00`0?ooooo`0Kool00`1oooooo`0Jool00`2?ooooo`0Gool00`0?ooooo`03ool002Go
o`0300oooooo00ooo`0300oooooo00Koo`0308oooooo01[oo`0307oooooo01[oo`0300oooooo01_o
o`0308oooooo01[oo`0307oooooo01Ooo`0300oooooo00?oo`009Ooo0P0?4?oo00<03oooool01_oo
00<0Ooooool06_oo00<0Soooool06_oo00<03oooool06ooo00<0Ooooool06_oo00<0Soooool05ooo
00<03oooool00ooo000Eool01@0?ooooo`0?ool00`0?00?oo`0?00l01Ooo00<03oooool03ooo00<0
3oooool01_oo00<0Soooool06_oo00<0Ooooool06_oo00<03oooool06ooo00<0Soooool06_oo00<0
Ooooool05ooo00<03oooool00ooo000Dool00`0?ool03`03ool00`0?ooooo`03ool00`0?ooooo`02
ool00`0?ooooo`0?ool00`0?ooooo`06ool00`1oooooo`0Jool00`2?ooooo`0Jool00`0?ooooo`0K
ool00`1oooooo`0Jool00`2?ooooo`0Gool00`0?ooooo`03ool001Coo`0300ooo`0?00Coo`0300oo
oooo00803`Goo`0300oooooo00ooo`0300oooooo00Koo`0308oooooo01[oo`0307oooooo01[oo`03
00oooooo01_oo`0308oooooo01[oo`0307oooooo01Ooo`0300oooooo00?oo`005?oo00<03ooo00l0
0ooo00D03ooo00ooo`0?00Koo`803`2W08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`02
00l5ool001Goo`0300oooooo00?oo`803`04ool03`0?00l4ool00`0?ooooo`0?ool00`0?ooooo`06
ool00`2?ooooo`0Jool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1oooooo`0G
ool00`0?ooooo`03ool002Goo`0300oooooo00koo`0300oooooo00Ooo`0307oooooo01[oo`0308oo
oooo01[oo`0300oooooo01_oo`0307oooooo01[oo`0308oooooo01Ooo`0300oooooo00?oo`009Ooo
0P0?3ooo00<03oooool01ooo00<0Soooool06_oo00<0Ooooool06_oo00<03oooool06ooo00<0Sooo
ool06_oo00<0Ooooool05ooo00<03oooool00ooo000Uool00`0?ooooo`0>ool00`0?ooooo`07ool0
0`1oooooo`0Jool00`2?ooooo`0Jool00`0?ooooo`0Kool00`1oooooo`0Jool00`2?ooooo`0Gool0
0`0?ooooo`03ool002Goo`0300oooooo00koo`0300oooooo00Ooo`0308oooooo01[oo`0307oooooo
01[oo`0300oooooo01_oo`0308oooooo01[oo`0307oooooo01Ooo`0300oooooo00?oo`009Ooo00<0
3oooool03_oo00<03oooool01ooo00<0Ooooool06_oo00<0Soooool06_oo00<03oooool06ooo00<0
Ooooool06_oo00<0Soooool05ooo00<03oooool00ooo000Uool200l?ool00`0?ooooo`07ool00`2?
ooooo`0Jool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1oooooo`0Gool00`0?
ooooo`03ool002Goo`0300oooooo00koo`0300oooooo00Ooo`0307oooooo01[oo`0308oooooo01[o
o`0300oooooo01_oo`0307oooooo01[oo`0308oooooo01Ooo`0300oooooo00?oo`009Ooo00<03ooo
ool03_oo00<03oooool01ooo00<0Soooool06_oo00<0Ooooool06_oo00<03oooool06ooo00<0Sooo
ool06_oo00<0Ooooool05ooo00<03oooool00ooo000Uool200l>ool00`0?ooooo`08ool00`1ooooo
o`0Jool00`2?ooooo`0Jool00`0?ooooo`0Kool00`1oooooo`0Jool00`2?ooooo`0Gool00`0?oooo
o`03ool002Goo`0300oooooo00goo`0300oooooo00Soo`0308oooooo01[oo`0307oooooo01[oo`03
00oooooo01_oo`0308oooooo01[oo`0307oooooo01Ooo`0300oooooo00?oo`009Ooo00<03oooool0
3Ooo00<03oooool02?oo00<0Ooooool06_oo00<0Soooool06_oo00<03oooool06ooo00<0Ooooool0
6_oo00<0Soooool05ooo00<03oooool00ooo000Uool00`0?ooooo`0=ool00`0?ooooo`08ool00`2?
ooooo`0Jool00`1oooooo`0Jool00`0?ooooo`0Kool00`2?ooooo`0Jool00`1oooooo`0Gool00`0?
ooooo`03ool002Goo`803`koo`0300oooooo00Soo`0307oooooo01[oo`0308oooooo01[oo`0300oo
oooo01_oo`0307oooooo01[oo`0308oooooo01Ooo`0300oooooo00?oo`009Ooo00<03oooool03Ooo
00<03oooool02?oo00<0Soooool06_oo00<0Ooooool06_oo00<03oooool06ooo00<0Soooool06_oo
00<0Ooooool05ooo00<03oooool00ooo000Uool00`0?ooooo`0=ool00`0?ooooo`08ool00`0?oooo
o`0Jool00`0?ooooo`0Jool00`0?ooooo`0Kool00`0?ooooo`0Jool00`0?ooooo`0Gool00`0?oooo
o`03ool002Gooj/03`Goo`00\
\>"],
  ImageRangeCache->{{{0, 211.5}, {130.25, 0}} -> {-4.186735, -0.071706, 
  0.042624, 0.003567}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["$\\partial i/\\partial v$"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(c1 = 
      N[Table[\(tbli\[LeftDoubleBracket]n + 5\[RightDoubleBracket] - 
              tbli\[LeftDoubleBracket]n - 5\[RightDoubleBracket]\)\/delv, {n, 
            1 + 5, dim1 - 5}]]; \)\), 
    \(\(c2 = {0, 0, 0, 0, 0}; \)\), 
    \(\(c3 = {0, 0, 0, 0, 0}; \)\), 
    \(\(tbldidv = Join[c2, c1, c3]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dimdidv = 
      \(Dimensions[tbldidv]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \)\),
   
    \(\(Print["\<dimension = \>", dimdidv]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[\("dimension = "\[InvisibleSpace]256\),
      SequenceForm[ "dimension = ", 256],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(tbldidvv = 
      Table[{tblv\[LeftDoubleBracket]n\[RightDoubleBracket], 
          Abs[tbldidv\[LeftDoubleBracket]n\[RightDoubleBracket]]}, {n, 2, 
          dim1}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xlimit = .2; \)\), 
    \(\(ylimit = 3.; \)\), 
    \(\(Fig12x5 = 
      ListPlot[tbldidvv, 
        PlotRange \[Rule] {{\(-vmax\) + xlimit, vmax - xlimit}, {0, ylimit}}, 
        Frame \[Rule] True, PlotJoined \[Rule] True, 
        GridLines \[Rule] Automatic, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        FrameLabel \[Rule] {"\<Energy in eV\>", "\<didv in a.u.\>"}]; \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.178571 0 0.206011 [
[.14286 -0.0125 -7 -12 ]
[.14286 -0.0125 7 0 ]
[.32143 -0.0125 -7 -12 ]
[.32143 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.67857 -0.0125 -4 -12 ]
[.67857 -0.0125 4 0 ]
[.85714 -0.0125 -4 -12 ]
[.85714 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -23.5 -24 ]
[.5 -0.0125 23.5 -12 ]
[-0.0125 .10301 -14 -6 ]
[-0.0125 .10301 0 6 ]
[-0.0125 .20601 -8 -6 ]
[-0.0125 .20601 0 6 ]
[-0.0125 .30902 -14 -6 ]
[-0.0125 .30902 0 6 ]
[-0.0125 .41202 -8 -6 ]
[-0.0125 .41202 0 6 ]
[-0.0125 .51503 -14 -6 ]
[-0.0125 .51503 0 6 ]
[-0.0125 .61803 -8 -6 ]
[-0.0125 .61803 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26 -20 ]
[-0.01875 .30902 -14 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .61803 L
s
.32143 0 m
.32143 .61803 L
s
.5 0 m
.5 .61803 L
s
.67857 0 m
.67857 .61803 L
s
.85714 0 m
.85714 .61803 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 g
.14286 0 m
.14286 .00625 L
s
gsave
.14286 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.32143 0 m
.32143 .00625 L
s
gsave
.32143 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.67857 0 m
.67857 .00625 L
s
gsave
.67857 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.85714 0 m
.85714 .00625 L
s
gsave
.85714 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.17857 0 m
.17857 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.25 0 m
.25 .00375 L
s
.28571 0 m
.28571 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.39286 0 m
.39286 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.46429 0 m
.46429 .00375 L
s
.53571 0 m
.53571 .00375 L
s
.57143 0 m
.57143 .00375 L
s
.60714 0 m
.60714 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.71429 0 m
.71429 .00375 L
s
.75 0 m
.75 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.82143 0 m
.82143 .00375 L
s
.10714 0 m
.10714 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.03571 0 m
.03571 .00375 L
s
.89286 0 m
.89286 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.96429 0 m
.96429 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -84.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Energy) show
88.000000 13.000000 moveto
(in) show
96.187500 13.000000 moveto
(eV) show
105.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .10301 m
.00625 .10301 L
s
gsave
-0.0125 .10301 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .20601 m
.00625 .20601 L
s
gsave
-0.0125 .20601 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .41202 m
.00625 .41202 L
s
gsave
-0.0125 .41202 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .51503 m
.00625 .51503 L
s
gsave
-0.0125 .51503 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10 translate
90 rotate
-81 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(didv) show
79.187500 13.000000 moveto
(in) show
87.375000 13.000000 moveto
(a) show
90.875000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
92.875000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
96.875000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
98.875000 13.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.14286 .61178 m
.14286 .61803 L
s
.32143 .61178 m
.32143 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.67857 .61178 m
.67857 .61803 L
s
.85714 .61178 m
.85714 .61803 L
s
.125 Mabswid
.17857 .61428 m
.17857 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.28571 .61428 m
.28571 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.39286 .61428 m
.39286 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.46429 .61428 m
.46429 .61803 L
s
.53571 .61428 m
.53571 .61803 L
s
.57143 .61428 m
.57143 .61803 L
s
.60714 .61428 m
.60714 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.71429 .61428 m
.71429 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.82143 .61428 m
.82143 .61803 L
s
.10714 .61428 m
.10714 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.03571 .61428 m
.03571 .61803 L
s
.89286 .61428 m
.89286 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.96429 .61428 m
.96429 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.13159 .61803 m
.1317 .61651 L
.13588 .5565 L
.14007 .49356 L
.14425 .43005 L
.14844 .37116 L
.15262 .32053 L
.15681 .2792 L
.16099 .24516 L
.16518 .21631 L
.16936 .19169 L
.17355 .17195 L
.17773 .15831 L
.18192 .15099 L
.1861 .14937 L
.19029 .1521 L
.19448 .15864 L
.19866 .16824 L
.20285 .18001 L
.20703 .19214 L
.21122 .20299 L
.2154 .21157 L
.21959 .21755 L
.22377 .22096 L
.22796 .2213 L
.23214 .21803 L
.23633 .21048 L
.24051 .19914 L
.2447 .18522 L
.24888 .17089 L
.25307 .15791 L
.25725 .14753 L
.26144 .14001 L
.26563 .13543 L
.26981 .13385 L
.274 .13564 L
.27818 .14093 L
.28237 .14955 L
.28655 .16086 L
.29074 .17389 L
.29492 .18753 L
.29911 .20085 L
.30329 .21355 L
.30748 .22572 L
.31166 .23718 L
.31585 .24671 L
.32003 .25275 L
.32422 .25409 L
.3284 .25096 L
.33259 .24436 L
Mistroke
.33677 .23544 L
.34096 .22433 L
.34515 .21026 L
.34933 .19246 L
.35352 .17127 L
.3577 .14858 L
.36189 .12661 L
.36607 .10669 L
.37026 .08866 L
.37444 .07169 L
.37863 .05552 L
.38281 .04076 L
.387 .0287 L
.39118 .01994 L
.39537 .01446 L
.39955 .01135 L
.40374 .00984 L
.40792 .00911 L
.41211 .00871 L
.41629 .008 L
.42048 .00656 L
.42467 .00435 L
.42885 .00187 L
.43304 5e-05 L
.43722 .00128 L
.44141 .00198 L
.44559 .00266 L
.44978 .00316 L
.45396 .00341 L
.45815 .00305 L
.46233 .00211 L
.46652 .00051 L
.4707 .00123 L
.47489 .00248 L
.47907 .00289 L
.48326 .00271 L
.48744 .00237 L
.49163 .00192 L
.49581 .00129 L
.5 .00051 L
.50419 .00027 L
.50837 .00103 L
.51256 .00157 L
.51674 .00151 L
.52093 .00072 L
.52511 .00014 L
.5293 .00031 L
.53348 .00036 L
.53767 .00102 L
.54185 .00095 L
Mistroke
.54604 6e-05 L
.55022 .00138 L
.55441 .00224 L
.55859 .00179 L
.56278 .0001 L
.56696 .00281 L
.57115 .00513 L
.57533 .00622 L
.57952 .00606 L
.58371 .00511 L
.58789 .00389 L
.59208 .00258 L
.59626 .00125 L
.60045 .00026 L
.60463 .00214 L
.60882 .00444 L
.613 .00684 L
.61719 .00889 L
.62137 .01023 L
.62556 .01079 L
.62974 .01078 L
.63393 .01062 L
.63811 .01083 L
.6423 .01183 L
.64648 .0138 L
.65067 .01677 L
.65485 .02062 L
.65904 .02524 L
.66323 .03044 L
.66741 .03616 L
.6716 .04215 L
.67578 .04817 L
.67997 .05391 L
.68415 .05926 L
.68834 .06412 L
.69252 .06819 L
.69671 .07091 L
.70089 .07164 L
.70508 .07023 L
.70926 .06719 L
.71345 .06351 L
.71763 .05968 L
.72182 .05563 L
.726 .05073 L
.73019 .04506 L
.73438 .03901 L
.73856 .0335 L
.74275 .02877 L
.74693 .02478 L
.75112 .02096 L
Mistroke
.7553 .01713 L
.75949 .01363 L
.76367 .01119 L
.76786 .01026 L
.77204 .01055 L
.77623 .0119 L
.78041 .01439 L
.7846 .01901 L
.78878 .02648 L
.79297 .03732 L
.79715 .05115 L
.80134 .06742 L
.80552 .08575 L
.80971 .10638 L
.8139 .12988 L
.81808 .15627 L
.82227 .18488 L
.82645 .21438 L
.83064 .24365 L
.83482 .27189 L
.83901 .29894 L
.84319 .32481 L
.84738 .34922 L
.85156 .37093 L
.85575 .38782 L
.85993 .39805 L
.86412 .40089 L
.8683 .39711 L
.87249 .38795 L
.87667 .3746 L
.88086 .35811 L
.88504 .33963 L
.88923 .32031 L
.89342 .30063 L
.8976 .28081 L
.90179 .2609 L
.90597 .24185 L
.91016 .22502 L
.91434 .21209 L
.91853 .20362 L
.92271 .19918 L
.9269 .19793 L
.93108 .20006 L
.93527 .2067 L
.93945 .21892 L
.94364 .2369 L
.94782 .25965 L
.95201 .2861 L
.95619 .31508 L
.96038 .3464 L
Mistroke
.96456 .37843 L
.96875 .40906 L
.97294 .43465 L
.97712 .45522 L
.98131 .47243 L
.98549 .49049 L
.98968 .5109 L
.99386 .53455 L
.99805 .55855 L
Mfstroke
.99805 .55855 m
1 .56708 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.9375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000ga000`40l00?003`ooooJOoo003ooomY
ool00;goo`<03`03ool03ooo0:Goo`00_Ooo00<03ooo00l00_oo00<03oooool0Xooo002^ool400l0
1?oo00ooo`0?0_oo0P0?00Goo`0?ooooo`0?00?oo`0300oooooo00;oo`0600oooooo00ooo`0?0ooo
0P0?0_oo0P0?T_oo002_ool02@0?oooooooo00ooo`0?ool03`03ool02@0?ool03ooo00ooo`0?ool0
3`03ool01P0?ooooo`0?ool03`;oo`0300oooooo00;oo`803i;oo`00[ooo0P0?0_oo00P03ooo00oo
o`0?ool03ooo0`0?00Koo`0?ool03ooo00l3ool01P0?ooooo`0?ool03`;oo`0500ooo`0?ool03`02
ool00`0?ooooo`2?ool00:ooo`0400ooooooool200l3ool200l00ooo00ooo`0300l01?oo00ooo`0?
0ooo00<03oooool00P0?1?oo0P0?00Goo`0?ooooo`0?097oo`00[_oo100?8Ooo00@03oooool03i7o
o`00aooo00<03oooool0W_oo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00
ooooJOoo001Gool300ldool300lbool00`0?ooooo`0bool300ldool300lfool005Ooo`0300oooooo
03Goo`0300oooooo033oo`0300ooo`0?03Coo`0300oooooo03?oo`0300oooooo03Koo`00Dooo0`0?
0_oo00<03oooool0;_oo0`0?0ooo00<03oooool0<?oo00<03ooo00l0=?oo00<03oooool0=?oo00<0
3oooool0=Ooo001Gool00`0?ool03`0eool00`0?ooooo`0`ool00`0?ool03`0dool00`0?ooooo`0c
ool00`0?ool03`0fool005Soo`803cCoo`803c?oo`0300oooooo03;oo`803cKoo`803cKoo`00oooo
JOoo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo000[oooo00lc
00l;ool002_oo`0300oooooo00Soo`0300oooooo00Soo`0300oooooo00Ooo`0300oooooo00Soo`03
00oooooo00Soo`0300oooooo00Soo`0300oooooo00Soo`0300oooooo00Soo`0300oooooo00Soo`03
00oooooo00Soo`0300oooooo00Soo`0300oooooo00Koo`<03`;oo`P03`;oo`L03`03ool03ooo00Wo
o`0300oooooo00?oo`803`;oo`803`?oo`@03`;oo`803`[oo`0300oooooo00Soo`0300oooooo00So
o`0300oooooo00Soo`0300oooooo00Ooo`0300oooooo00Soo`0300oooooo00Soo`0300oooooo00So
o`0300oooooo00Soo`0300oooooo00Soo`0300oooooo00Soo`0300oooooo00Woo`00:ooo00<03ooo
ool0:?oo00<03oooool0=?oo00<03oooool06_oo0P0?5ooo00<03oooool04ooo100?2?oo0P0?4ooo
00<03oooool0<ooo00<03oooool0:Ooo00<03oooool02Ooo000[ool00`0?ooooo`0Xool00`1ooooo
o`0dool00`2?ooooo`0Eool500lIool00`0?ooooo`0Qool800l;ool00`1oooooo`0Gool400lHool0
0`1oooooo`0Yool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0308oooooo03Coo`0307oooooo
01?oo`803akoo`0300oooooo02Woo`803`Woo`0308oooooo01Goo`803`Coo`803aKoo`0308oooooo
02Woo`0300oooooo00Woo`00:ooo00<03oooool0:?oo00<0Ooooool0=?oo00<0Soooool04ooo00<0
3oooool07Ooo00<03oooool0:ooo00<03oooool01_oo00<0Ooooool05?oo00<03oooool01Ooo00<0
3oooool05?oo00<0Ooooool0:Ooo00<03oooool02Ooo000[ool200lYool00`2?ooooo`0dool00`1o
ooooo`0Bool00`0?ooooo`0Nool00`0?ooooo`0/ool200l6ool00`2?ooooo`0Cool00`0?ooooo`07
ool00`0?ooooo`0Cool00`2?ooooo`0Xool200l;ool002_oo`0300oooooo02Soo`0307oooooo03Co
o`0308oooooo01;oo`0300oooooo01koo`0300oooooo02goo`0300oooooo00Coo`0307oooooo01;o
o`0300oooooo00Woo`0300oooooo01;oo`0307oooooo02Woo`0300oooooo00Woo`00:ooo00<03ooo
ool0:?oo00<0Soooool0=?oo00<0Ooooool04Ooo00<03oooool07ooo00<03oooool0;_oo00<03ooo
ool00ooo00<0Soooool04Ooo00<03oooool02_oo00<03oooool04_oo00<0Soooool0:Ooo00<03ooo
ool02Ooo000[ool00`0?ooooo`0Xool00`1oooooo`0dool00`2?ooooo`0Aool00`0?ooooo`0Oool0
0`0?ooooo`0_ool00`0?ooooo`02ool00`1oooooo`0@ool00`0?ooooo`0<ool00`0?ooooo`0Aool0
0`1oooooo`0Yool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0308oooooo03Coo`0307oooooo
013oo`0300oooooo023oo`0300oooooo033oo`0500ooooooool0S`0Aool00`0?ooooo`0=ool00`0?
ooooo`0Aool00`2?ooooo`0Yool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0307oooooo03Co
o`0308oooooo013oo`0300oooooo023oo`0300oooooo033oo`0500ooooooool0O`0@ool00`0?oooo
o`0?ool00`0?ooooo`0@ool00`1oooooo`0Yool00`0?ooooo`09ool002_oo`0300oooooo02Soo`03
08oooooo03Coo`0307oooooo013oo`0300oooooo023oo`0300oooooo037oo`0400oooooo08l@ool0
0`0?ooooo`0?ool00`0?ooooo`0@ool00`2?ooooo`0Yool00`0?ooooo`09ool002_oo`803bWoo`03
07oooooo03Coo`0308oooooo00ooo`0300oooooo027oo`0300oooooo03;oo`0300ooo`1o00ooo`03
00oooooo013oo`0300oooooo013oo`0307oooooo02Soo`803`_oo`00:ooo00<03oooool0:?oo00<0
Soooool0=?oo00<0Ooooool03ooo00<03oooool08Ooo00<03oooool0<_oo00<03ooo08l03_oo0P0?
4_oo00<03oooool04?oo00<0Soooool0:Ooo00<03oooool02Ooo000[ool00`0?ooooo`0Xool00`1o
ooooo`0dool00`2?ooooo`0?ool00`0?ooooo`0Qool00`0?ooooo`0cool00`0?07ooo`0<ool00`0?
ooooo`0Cool00`0?ooooo`0?ool00`1oooooo`0Yool00`0?ooooo`09ool002_oo`0300oooooo02So
o`0308oooooo03Coo`0307oooooo00ooo`0300oooooo027oo`0300oooooo03Coo`0300oooooo00_o
o`0300oooooo01?oo`0300oooooo00ooo`0308oooooo02Woo`0300oooooo00Woo`00:ooo00<03ooo
ool0:?oo00<0Ooooool0=?oo00<0Soooool03_oo00<03oooool08_oo00<03oooool0=?oo00<0O`0?
ool02_oo00<03oooool05?oo00<03oooool03ooo00<0Ooooool0:Ooo00<03oooool02Ooo000[ool0
0`0?ooooo`0Xool00`2?ooooo`0dool00`1oooooo`0>ool00`0?ooooo`0Rool00`0?ooooo`0dool0
0`2?00ooo`09ool00`0?ooooo`0Fool00`0?ooooo`0>ool00`2?ooooo`0Yool00`0?ooooo`09ool0
02_oo`803bWoo`0307oooooo03Coo`0308oooooo00koo`0300oooooo02;oo`0300oooooo03Coo`03
07ooo`0?00Ooo`803aWoo`0300oooooo00koo`0307oooooo02Soo`803`_oo`00:ooo00<03oooool0
:?oo00<0Soooool0=?oo00<0Ooooool03Ooo00<03oooool08ooo00<03oooool0=?oo00@0Soooool0
3`Goo`803a[oo`0300oooooo00koo`0308oooooo02Woo`0300oooooo00Woo`00:ooo00<03oooool0
:?oo00<0Ooooool0=?oo00<0Soooool03Ooo00<03oooool08ooo00<03oooool0=?oo00@0Oooooooo
o`803`;oo`803a_oo`0300oooooo00koo`0307oooooo02Woo`0300oooooo00Woo`00:ooo00<03ooo
ool0:?oo00<0Soooool0=?oo00<0Ooooool03Ooo00<03oooool08ooo00<03oooool0=?oo00<0Sooo
ool00_oo0`0?7_oo00<03oooool03Ooo00<0Soooool0:Ooo00<03oooool02Ooo000[ool00`0?oooo
o`0Xool00`1oooooo`0dool00`2?ooooo`0=ool00`0?ooooo`0Sool00`0?ooooo`0dool00`1ooooo
o`0Sool00`0?ooooo`0=ool00`1oooooo`0Yool00`0?ooooo`09ool002_oo`0300oooooo02Soo`03
08oooooo03Coo`0307oooooo00coo`0300oooooo02Coo`0300oooooo03Coo`0308oooooo02?oo`03
00oooooo00goo`0308oooooo02Woo`0300oooooo00Woo`00:ooo0P0?:Ooo00<0Ooooool0=?oo00<0
Soooool03?oo00<03oooool09?oo00<03oooool0=?oo00<0Ooooool08ooo00<03oooool03Ooo00<0
Ooooool0:?oo0P0?2ooo000[ool00`0?ooooo`0Xool00`2?ooooo`0dool00`1oooooo`0<ool00`0?
ooooo`0Tool00`0?ooooo`0dool00`2?ooooo`0Tool00`0?ooooo`0<ool00`2?ooooo`0Yool00`0?
ooooo`09ool002_oo`0300oooooo02Soo`0307oooooo03Coo`0308oooooo00coo`0300oooooo02Co
o`0300oooooo03Coo`0307oooooo02Coo`0300oooooo00coo`0307oooooo02Woo`0300oooooo00Wo
o`00:ooo00<03oooool0:?oo00<0Soooool0=?oo00<0Ooooool02ooo00<03oooool09Ooo00<03ooo
ool0=?oo00<0Soooool09?oo00<03oooool03?oo00<0Soooool0:Ooo00<03oooool02Ooo000Lool0
1@0?ooooo`0?ool00P0?2?oo00<03oooool0:?oo00<0Ooooool0=?oo00<0Soooool02ooo00<03ooo
ool09Ooo00<03oooool0=?oo00<0Ooooool09?oo00<03oooool03?oo00<0Ooooool0:Ooo00<03ooo
ool02Ooo000Kool00`0?ool03`05ool00`0?ooooo`05ool00`0?ooooo`0Xool00`2?ooooo`0dool0
0`1oooooo`0;ool00`0?ooooo`0Uool00`0?ooooo`0dool00`2?ooooo`0Tool00`0?ooooo`0<ool0
0`2?ooooo`0Yool00`0?ooooo`09ool001_oo`0300ooo`0?00?oo`803`Soo`<03`3o07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
3`2?07l0S`1o08l0O`2?07l0S`1o000]07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00<03`_o
o`006ooo00<03ooo00l00ooo00<03oooool01ooo00<03oooool0:?oo00<0Soooool0=?oo00<0Oooo
ool02_oo00<03oooool09_oo00<03oooool0=?oo00<0Soooool09Ooo00<03oooool02ooo00<0Sooo
ool0:Ooo00<03oooool02Ooo000Lool00`0?ooooo`02ool300l7ool00`0?ooooo`0Xool00`1ooooo
o`0dool00`2?ooooo`0:ool00`0?ooooo`0Vool00`0?ooooo`0dool00`1oooooo`0Uool00`0?oooo
o`0;ool00`1oooooo`0Yool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0308oooooo03Coo`03
07oooooo00[oo`0300oooooo02Koo`0300oooooo03Coo`0308oooooo02Goo`0300oooooo00_oo`03
08oooooo02Woo`0300oooooo00Woo`00:ooo00<03oooool0:?oo00<0Ooooool0=?oo00<0Soooool0
2_oo00<03oooool09_oo00<03oooool0=?oo00<0Ooooool09Ooo00<03oooool02ooo00<0Ooooool0
:Ooo00<03oooool02Ooo000[ool00`0?ooooo`0Xool00`2?ooooo`0dool00`1oooooo`0:ool00`0?
ooooo`0Vool00`0?ooooo`0dool00`2?ooooo`0Uool00`0?ooooo`0;ool00`2?ooooo`0Yool00`0?
ooooo`09ool002_oo`0300oooooo02Soo`0307oooooo03Coo`0308oooooo00Woo`0300oooooo02Oo
o`0300oooooo03Coo`0307oooooo02Koo`0300oooooo00[oo`0307oooooo02Woo`0300oooooo00Wo
o`00:ooo0P0?:Ooo00<0Soooool0=?oo00<0Ooooool02Ooo00<03oooool09ooo00<03oooool0=?oo
00<0Soooool09_oo00<03oooool02_oo00<0Soooool0:?oo0P0?2ooo000[ool00`0?ooooo`0Xool0
0`1oooooo`0dool00`2?ooooo`09ool00`0?ooooo`0Wool00`0?ooooo`0dool00`1oooooo`0Vool0
0`0?ooooo`0:ool00`1oooooo`0Yool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0308oooooo
03Coo`0307oooooo00Woo`0300oooooo02Ooo`0300oooooo03Coo`0308oooooo02Koo`0300oooooo
00[oo`0308oooooo02Woo`0300oooooo00Woo`00:ooo00<03oooool0:?oo00<0Ooooool08ooo0`0?
3_oo00<0Soooool02Ooo00<03oooool09ooo00<03oooool0=?oo00<0Ooooool09_oo00<03oooool0
2_oo00<0Ooooool0:Ooo00<03oooool02Ooo000[ool00`0?ooooo`0Xool00`2?ooooo`0Rool01@0?
oooooooo00l03Ooo00<0Ooooool02Ooo00<03oooool09ooo00<03oooool0=?oo00<0Soooool09_oo
00<03oooool02_oo00<0Soooool0:Ooo00<03oooool02Ooo000[ool00`0?ooooo`0Xool00`1ooooo
o`0Qool200l4ool00`0?ooooo`0:ool00`2?ooooo`08ool00`0?ooooo`0Xool00`0?ooooo`0dool0
0`1oooooo`0Wool00`0?ooooo`09ool00`1oooooo`0Yool00`0?ooooo`09ool002_oo`803bWoo`03
08oooooo027oo`0300oooooo00?oo`0300oooooo00[oo`0307oooooo00Soo`0300oooooo02Soo`03
00oooooo03Coo`0308oooooo02Ooo`0300oooooo00Woo`0308oooooo02Soo`803`_oo`00:ooo00<0
3oooool0:?oo00<0Ooooool08?oo00<03oooool01Ooo00<03oooool02Ooo00<0Soooool02?oo00<0
3oooool0:?oo00<03oooool0=?oo00<0Ooooool09ooo00<03oooool02Ooo00<0Ooooool0:Ooo00<0
3oooool02Ooo000[ool00`0?ooooo`0Xool00`2?ooooo`09ool400lCool00`0?ooooo`05ool00`0?
ooooo`09ool00`1oooooo`08ool00`0?ooooo`0Xool00`0?ooooo`0dool00`2?ooooo`0Wool00`0?
ooooo`09ool00`2?ooooo`0Yool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0307oooooo00Wo
o`0400oooooo00lBool00`0?ooooo`06ool00`0?ooooo`09ool00`2?ooooo`08ool00`0?ooooo`0X
ool00`0?ooooo`0dool00`1oooooo`0Wool00`0?ooooo`09ool00`1oooooo`0Yool00`0?ooooo`09
ool002_oo`0300oooooo02Soo`0308oooooo00Soo`0300oooooo00;oo`0300oooooo00ooo`0300oo
oooo00Ooo`0300oooooo00Soo`0307oooooo00Ooo`0300oooooo02Woo`0300oooooo03Coo`0308oo
oooo02Ooo`0300oooooo00Woo`0308oooooo02Woo`0300oooooo00Woo`00:ooo00<03oooool0:?oo
00<0Ooooool02?oo00<03oooool00_oo00<03oooool03ooo00<03oooool01ooo00<03oooool02?oo
00<0Soooool01ooo00<03oooool0:Ooo00<03oooool0=?oo00<0Ooooool0:?oo00<03oooool02?oo
00<0Ooooool0:Ooo00<03oooool02Ooo000[ool200lYool00`2?ooooo`07ool00`0?ooooo`04ool0
0`0?ooooo`0=ool00`0?ooooo`08ool00`0?ooooo`08ool00`1oooooo`07ool00`0?ooooo`0Yool0
0`0?ooooo`0dool00`2?ooooo`0Xool00`0?ooooo`08ool00`2?ooooo`0Xool200l;ool002_oo`03
00oooooo02Soo`0307oooooo00Ooo`0300oooooo00Coo`0300oooooo00goo`0300oooooo00Woo`03
00oooooo00Ooo`0308oooooo00Ooo`0300oooooo02Woo`0300oooooo03Coo`0307oooooo02Soo`03
00oooooo00Soo`0307oooooo02Woo`0300oooooo00Woo`00:ooo00<03oooool0:?oo00<0Soooool0
1ooo00<03oooool01Ooo00<03oooool03?oo00<03oooool02Ooo00<03oooool01ooo00<0Ooooool0
1ooo00<03oooool0:Ooo00<03oooool0=?oo00<0Soooool0:?oo00<03oooool02?oo00<0Soooool0
:Ooo00<03oooool02Ooo000[ool00`0?ooooo`0Xool00`1oooooo`07ool00`0?ooooo`05ool00`0?
ooooo`0;ool00`0?ooooo`0:ool00`0?ooooo`07ool00`2?ooooo`06ool00`0?ooooo`0Zool00`0?
ooooo`0dool00`1oooooo`0Xool00`0?ooooo`08ool00`1oooooo`0Yool00`0?ooooo`09ool002_o
o`0300oooooo02Soo`0308oooooo00Koo`0300oooooo00Koo`0300oooooo00_oo`0300oooooo00_o
o`0300oooooo00Koo`0307oooooo00Koo`0300oooooo02[oo`0300oooooo03Coo`0308oooooo02So
o`0300oooooo00Soo`0308oooooo02Woo`0300oooooo00Woo`00:ooo00<03oooool0:?oo00<0Oooo
ool01_oo00<03oooool01ooo00<03oooool02_oo00<03oooool02ooo00<03oooool01_oo00<0Sooo
ool01_oo00<03oooool0:_oo00<03oooool0=?oo00<0Ooooool0:?oo00<03oooool02?oo00<0Oooo
ool0:Ooo00<03oooool02Ooo000[ool00`0?ooooo`0Xool00`2?ooooo`06ool00`0?ooooo`07ool0
0`0?ooooo`09ool00`0?ooooo`0<ool00`0?ooooo`06ool00`1oooooo`06ool00`0?ooooo`0Zool0
0`0?ooooo`0dool00`2?ooooo`0Yool00`0?ooooo`07ool00`2?ooooo`0Yool00`0?ooooo`09ool0
02_oo`803bWoo`0307oooooo00Koo`0300oooooo00Ooo`0300oooooo00Woo`0300oooooo00goo`03
00oooooo00Goo`0308oooooo00Koo`0300oooooo02[oo`0300oooooo03Coo`0307oooooo02Woo`03
00oooooo00Ooo`0307oooooo02Soo`803`_oo`00:ooo00<03oooool0:?oo00<0Soooool01Ooo00<0
3oooool02Ooo00<03oooool02?oo00<03oooool03Ooo00<03oooool01Ooo00<0Ooooool01Ooo00<0
3oooool0:ooo00<03oooool0=?oo00<0Soooool0:Ooo00<03oooool01ooo00<0Soooool0:Ooo00<0
3oooool02Ooo000[ool00`0?ooooo`0Xool00`1oooooo`05ool00`0?ooooo`09ool00`0?ooooo`08
ool00`0?ooooo`0=ool00`0?ooooo`05ool00`2?ooooo`05ool00`0?ooooo`0[ool00`0?ooooo`0d
ool00`1oooooo`0Yool00`0?ooooo`07ool00`1oooooo`0Yool00`0?ooooo`09ool0027oo`<03`Oo
o`0300oooooo02Soo`0308oooooo00Goo`0300oooooo00Woo`0300oooooo00Ooo`0300oooooo00oo
o`0300oooooo00Coo`0307oooooo00Goo`0300oooooo02_oo`0300oooooo03Coo`0308oooooo02Wo
o`0300oooooo00Ooo`0308oooooo01;oo`803aGoo`0300oooooo00Woo`008_oo00<03oooool01_oo
00<03oooool0:?oo00<0Ooooool01Ooo00<03oooool02_oo00<03oooool01_oo00<03oooool03ooo
00<03oooool01?oo00<0Soooool01Ooo00<03oooool0:ooo00<03oooool0=?oo00<0Ooooool0:Ooo
00<03oooool01ooo00<0Ooooool04Ooo00@03ooo00l03aCoo`0300oooooo00Woo`008_oo00<03ooo
ool01_oo00<03oooool0:?oo00<0Soooool01Ooo00<03oooool02_oo00<03oooool01_oo00<03ooo
ool03ooo00<03oooool01?oo00<0Ooooool01Ooo00<03oooool0:ooo00<03oooool0=?oo00<0Sooo
ool0:Ooo00<03oooool01ooo00<0Soooool04?oo00D03oooooooo`0?01Coo`0300oooooo00Woo`00
8_oo00<03oooool01_oo0`0?0?l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l002d0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l00`0?2ooo000Qool200l8ool00`0?ooooo`0Xool00`2?oooo
o`04ool00`0?ooooo`0<ool00`0?ooooo`04ool00`0?ooooo`0Aool00`0?ooooo`03ool00`1ooooo
o`04ool00`0?ooooo`0/ool00`0?ooooo`0dool00`2?ooooo`0Zool00`0?ooooo`06ool00`2?oooo
o`0?ool00`0?ooooo`03ool00`0?ooooo`0Aool00`0?ooooo`09ool002_oo`0300oooooo02Soo`03
07oooooo00Coo`0300oooooo00goo`0300oooooo00;oo`0300oooooo01;oo`0300oooooo00?oo`03
08oooooo00Coo`0300oooooo02coo`0300oooooo03Coo`0307oooooo02[oo`0300oooooo00Koo`03
07oooooo00ooo`0300oooooo00Coo`0300oooooo013oo`0300oooooo00Woo`00:ooo00<03oooool0
:?oo00<0Soooool01?oo00<03oooool03_oo00D03oooooooo`0?01Goo`0300oooooo00;oo`0307oo
oooo00?oo`0300oooooo02goo`0300oooooo03Coo`0308oooooo02[oo`0300oooooo00Koo`0308oo
oooo00koo`0300oooooo00Goo`0300oooooo013oo`0300oooooo00Woo`00:ooo00<03oooool0:?oo
00<0Ooooool01?oo00<03oooool03_oo100?5_oo00<03oooool00_oo00<0Soooool00ooo00<03ooo
ool0;Ooo00<03oooool0=?oo00<0Ooooool0:_oo00<03oooool01_oo00<0Ooooool03_oo00<03ooo
ool01Ooo00<03oooool04?oo00<03oooool02Ooo000[ool00`0?ooooo`0Xool00`2?ooooo`04ool0
0`0?ooooo`0Xool00`0?ooooo`02ool00`1oooooo`03ool00`0?ooooo`0]ool00`0?ooooo`0dool0
0`2?ooooo`0Zool00`0?ooooo`06ool00`2?ooooo`0>ool00`0?ooooo`06ool00`0?ooooo`0?ool0
0`0?ooooo`09ool002_oo`803bWoo`0307oooooo00Coo`0300oooooo02Woo`0500ooooooool0S`05
ool00`0?ooooo`0]ool00`0?ooooo`0dool00`1oooooo`0Zool00`0?ooooo`06ool00`1oooooo`0=
ool00`0?ooooo`07ool00`0?ooooo`0>ool200l;ool002_oo`0300oooooo02Soo`0308oooooo00Co
o`0300oooooo02Woo`0500ooooooool0O`04ool00`0?ooooo`0^ool00`0?ooooo`0dool00`2?oooo
o`0[ool00`0?ooooo`05ool00`2?ooooo`0=ool00`0?ooooo`07ool00`0?ooooo`0?ool00`0?oooo
o`09ool002_oo`0300oooooo02Soo`0307oooooo00?oo`0300oooooo02[oo`0500ooooooool0S`04
ool00`0?ooooo`0^ool00`0?ooooo`0dool00`1oooooo`0[ool00`0?ooooo`05ool00`1oooooo`0=
ool00`0?ooooo`07ool00`0?ooooo`0?ool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0308oo
oooo00?oo`0300oooooo02_oo`0400oooooo07l3ool00`0?ooooo`0_ool00`0?ooooo`0dool00`2?
ooooo`0[ool00`0?ooooo`05ool00`2?ooooo`0=ool00`0?ooooo`08ool00`0?ooooo`0>ool00`0?
ooooo`09ool002_oo`0300oooooo02Soo`0307oooooo00?oo`0300oooooo02_oo`0400oooooo08l3
ool00`0?ooooo`0_ool00`0?ooooo`0dool00`1oooooo`0[ool00`0?ooooo`05ool00`1oooooo`0<
ool00`0?ooooo`09ool00`0?ooooo`0>ool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0308oo
oooo00?oo`0300oooooo02coo`0300ooo`1o00;oo`0300oooooo033oo`0300oooooo03Coo`0308oo
oooo02_oo`0300oooooo00Goo`0308oooooo00coo`0300oooooo00Woo`0300oooooo00koo`0300oo
oooo00Woo`00:ooo0P0?:Ooo00<0Ooooool00ooo00<03oooool0;?oo00<03ooo08l00_oo00<03ooo
ool0<?oo00<03oooool0=?oo00<0Ooooool0:ooo00<03oooool01Ooo00<0Ooooool03?oo00<03ooo
ool02Ooo00<03oooool03Ooo0P0?2ooo000[ool00`0?ooooo`0Xool00`2?ooooo`03ool00`0?oooo
o`0]ool0100?07ooo`0?<ooo00<03oooool0=?oo00<0Soooool0:ooo00<03oooool01Ooo00<0Sooo
ool03?oo00<03oooool02Ooo00<03oooool03_oo00<03oooool02Ooo000Bool200lGool00`0?oooo
o`0Xool00`1oooooo`03ool00`0?ooooo`0]ool400lcool00`0?ooooo`0dool00`1oooooo`0/ool0
0`0?ooooo`04ool00`1oooooo`0;ool00`0?ooooo`0;ool00`0?ooooo`0=ool00`0?ooooo`09ool0
017oo`0400oooooo00lFool00`0?ooooo`0Xool00`2?ooooo`02ool00`0?ooooo`0_ool00`1ooooo
o`0cool00`0?ooooo`0dool00`2?ooooo`0/ool00`0?ooooo`04ool00`2?ooooo`0;ool00`0?oooo
o`0;ool00`0?ooooo`0=ool00`0?ooooo`09ool0013oo`803`;oo`0300oooooo01Coo`0300oooooo
02Soo`0307oooooo00;oo`0300oooooo02ooo`0308oooooo03?oo`0300oooooo03Coo`0307oooooo
02coo`0300oooooo00Coo`0307oooooo00_oo`0300oooooo00_oo`0300oooooo00goo`0300oooooo
00Woo`003ooo1P0?5_oo00<03oooool0:?oo00<0Soooool00_oo00<03oooool0;ooo00<0Ooooool0
<ooo00<03oooool0=?oo00<0Soooool0;?oo00<03oooool01?oo00<0Soooool02ooo00<03oooool0
2ooo00<03oooool03Ooo00<03oooool02Ooo000Bool00`0?ool03`0Fool00`0?ooooo`0Xool00`1o
ooooo`02ool00`0?ooooo`0_ool00`2?ooooo`0cool00`0?ooooo`0dool00`1oooooo`0/ool00`0?
ooooo`04ool00`1oooooo`0;ool00`0?ooooo`0;ool00`0?ooooo`0=ool00`0?ooooo`09ool000oo
o`0300ooo`0?00<03aKoo`803bWoo`0308oooooo00;oo`0300oooooo02ooo`0307oooooo03?oo`03
00oooooo03Coo`0308oooooo02coo`0300oooooo00Coo`0308oooooo00[oo`0300oooooo00coo`03
00oooooo00coo`803`_oo`004_oo0`0?5_oo00<03oooool0:?oo00<0Ooooool00_oo00<03oooool0
;ooo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0;?oo00<03oooool01?oo00<0Ooooool0
2_oo00<03oooool03Ooo00<03oooool03?oo00<03oooool02Ooo000Aool0100?ooooo`0?5_oo00<0
3oooool0:?oo00<0Soooool00_oo00<03oooool0;ooo00<0Ooooool0<ooo00<03oooool0=?oo00<0
Soooool0;Ooo00<03oooool00ooo00<0Soooool02_oo00<03oooool03Ooo00<03oooool03?oo00<0
3oooool02Ooo000@ool200l2ool00`0?ooooo`0Dool00`0?ooooo`0Xool00`1oooooo`02ool00`0?
ooooo`0_ool00`2?ooooo`0cool00`0?ooooo`0dool00`1oooooo`0]ool00`0?ooooo`03ool00`1o
ooooo`0:ool00`0?ooooo`0=ool00`0?ooooo`0<ool00`0?ooooo`09ool000ooo`H03aKoo`0300oo
oooo02Soo`0308oooooo00;oo`0300oooooo02ooo`0307oooooo03?oo`0300oooooo03Coo`0308oo
oooo02goo`0300oooooo00?oo`0308oooooo00[oo`0300oooooo00goo`0300oooooo00coo`0300oo
oooo00Woo`004Ooo00<03oooool05ooo00<03oooool0:?oo00D0Ooooooooo`0?03;oo`0308oooooo
03?oo`0300oooooo03Coo`0307oooooo02goo`0300oooooo00?oo`0307oooooo00Woo`0300oooooo
00koo`0300oooooo00coo`0300oooooo00Woo`004Ooo0P0?6?oo0P0?:Ooo00D0Soooooooo`0?03;o
o`0307oooooo03?oo`0300oooooo03Coo`0308oooooo02goo`0300oooooo00?oo`0308oooooo00Wo
o`0300oooooo00koo`0300oooooo00_oo`803`_oo`004ooo0P0?5_oo00<03oooool0:?oo00D0Oooo
ooooo`0?03;oo`0308oooooo03?oo`0300oooooo03Coo`0307oooooo02goo`0300oooooo00?oo`03
07oooooo00Woo`0300oooooo00koo`0300oooooo00coo`0300oooooo00Woo`004Ooo0P0?6?oo00<0
3oooool0:?oo00D0Soooooooo`0?03;oo`0307oooooo03?oo`0300oooooo03Coo`0308oooooo02ko
o`0300oooooo00;oo`0308oooooo00Woo`0300oooooo00ooo`0300oooooo00_oo`0300oooooo00Wo
o`00:ooo00<03oooool0:?oo00D0Ooooooooo`0?03;oo`0308oooooo03?oo`0300oooooo03Coo`03
07oooooo02koo`0300oooooo00;oo`0307oooooo00Soo`0300oooooo013oo`0300oooooo00_oo`03
00oooooo00Woo`006ooo0`0?00?oo`0?ool00P0?2?oo00<03oooool0:?oo00D0Soooooooo`0?03;o
o`0307oooooo03?oo`0300oooooo03Coo`0308oooooo02koo`0300oooooo00;oo`0308oooooo00So
o`0300oooooo013oo`0300oooooo00_oo`0300oooooo00Woo`004_oo00<03ooo00l01ooo00<03ooo
ool01?oo00<03oooool01Ooo00<03oooool0:?oo00D0Ooooooooo`0?03;oo`0308oooooo03?oo`03
00oooooo03Coo`0307oooooo02koo`0300oooooo00;oo`0307oooooo00Soo`0300oooooo013oo`03
00oooooo00_oo`0300oooooo00Woo`003ooo00<03ooo00l00`0?1ooo00<03oooool00_oo0P0?2?oo
0`0?0?l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l002d0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o00l00`0?2ooo000Aool400l7ool00`0?ooooo`02ool00`0?ooooo`07ool00`0?ooooo`0X
ool01@1ooooooooo00l0<_oo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0;_oo00<03ooo
ool00_oo00<0Ooooool02?oo00<03oooool04?oo00<03oooool02ooo00<03oooool02Ooo000Aool0
100?ooooo`0?1_oo0P0?1?oo0`0?1ooo00<03oooool0:?oo00@0Soooool03c?oo`0307oooooo03?o
o`0300oooooo03Coo`0308oooooo02ooo`0500ooooooool0S`09ool00`0?ooooo`0Aool00`0?oooo
o`0;ool00`0?ooooo`09ool0017oo`0300oooooo01Ooo`0300oooooo02Soo`0407oooooo00lcool0
0`2?ooooo`0cool00`0?ooooo`0dool00`1oooooo`0_ool01@0?oooooooo07l02Ooo00<03oooool0
4_oo00<03oooool02_oo00<03oooool02Ooo000Bool300lFool00`0?ooooo`0Xool0102?ooooo`0?
<ooo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0;ooo00D03oooooooo`2?00Woo`0300oo
oooo01;oo`0300oooooo00[oo`0300oooooo00Woo`00:ooo00<03oooool0:?oo00@0Ooooool03c?o
o`0308oooooo03?oo`0300oooooo03Coo`0307oooooo02ooo`0500ooooooool0O`09ool00`0?oooo
o`0Bool00`0?ooooo`0:ool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0408oooooo00lcool0
0`1oooooo`0cool00`0?ooooo`0dool00`2?ooooo`0_ool01@0?oooooooo08l02Ooo00<03oooool0
4_oo00<03oooool02_oo00<03oooool02Ooo000Aool00`0?ool03`0Gool200lYool0101oooooo`0?
<ooo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0;ooo00D03oooooooo`1o00Soo`0300oo
oooo01?oo`0300oooooo00Woo`803`_oo`004Ooo0P0?00?oo`0?ool05Ooo00<03oooool0:?oo00@0
Soooool03c?oo`0307oooooo03?oo`0300oooooo03Coo`0308oooooo033oo`0400oooooo08l8ool0
0`0?ooooo`0Cool00`0?ooooo`0:ool00`0?ooooo`09ool001;oo`<03aKoo`0300oooooo02Soo`04
07oooooo00lcool00`2?ooooo`0cool00`0?ooooo`0dool00`1oooooo`0`ool0100?ooooo`1o2?oo
00<03oooool04ooo00<03oooool02_oo00<03oooool02Ooo000Dool00`0?ooooo`0Dool00`0?oooo
o`0Xool0102?ooooo`0?<ooo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0<?oo00@03ooo
ool0S`Soo`0300oooooo01Coo`0300oooooo00Woo`0300oooooo00Woo`00:ooo00<03oooool0:?oo
00@0Ooooool03c?oo`0308oooooo03?oo`0300oooooo03Coo`0307oooooo033oo`0400oooooo07l7
ool00`0?ooooo`0Eool00`0?ooooo`09ool00`0?ooooo`09ool001Coo`0300oooooo01Coo`0300oo
oooo02Soo`0408oooooo00lcool00`1oooooo`0cool00`0?ooooo`0dool00`2?ooooo`0`ool0100?
ooooo`2?1ooo00<03oooool05Ooo00<03oooool02Ooo00<03oooool02Ooo000Aool300lGool200lY
ool0101oooooo`0?<ooo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<?oo00@03oooool0
O`Ooo`0300oooooo01Goo`0300oooooo00Soo`803`_oo`005?oo00<03oooool05?oo00<03oooool0
:?oo00<0Sooo00l0=?oo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0<Ooo00<03ooo08l0
1ooo00<03oooool05Ooo00<03oooool02Ooo00<03oooool02Ooo000Aool400lFool00`0?ooooo`0X
ool00`1oool03`0dool00`2?ooooo`0cool00`0?ooooo`0dool00`1oooooo`0aool00`0?ool0O`06
ool00`0?ooooo`0Fool00`0?ooooo`09ool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0308oo
o`0?03Coo`0307oooooo03?oo`0300oooooo03Coo`0308oooooo037oo`0300ooo`2?00Koo`0300oo
oooo01Koo`0300oooooo00Woo`0300oooooo00Woo`00:ooo00<03oooool0:?oo00<0Oooo00l0=?oo
00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<Ooo00<03ooo07l01_oo00<03oooool05_oo
00<03oooool02Ooo00<03oooool02Ooo000Dool00`0?ooooo`0Dool00`0?ooooo`0Xool00`2?ool0
3`0dool00`1oooooo`0cool00`0?ooooo`0dool00`2?ooooo`0aool00`0?ool0S`06ool00`0?oooo
o`0Gool00`0?ooooo`08ool00`0?ooooo`09ool002_oo`803bWoo`0307ooo`0?03Coo`0308oooooo
03?oo`0300oooooo03Coo`0307oooooo03;oo`0300l0Oooo00Goo`0300oooooo01Ooo`0300oooooo
00Ooo`803`_oo`00:ooo00<03oooool0:?oo00<0Sooo00l0=?oo00<0Ooooool0<ooo00<03oooool0
=?oo00<0Soooool0<_oo00<03`2?ool01?oo00<03oooool06?oo00<03oooool02?oo00<03oooool0
2Ooo000[ool00`0?ooooo`0Xool00`1oool03`0dool00`2?ooooo`0cool00`0?ooooo`0dool00`1o
ooooo`0bool00`0?07ooo`04ool00`0?ooooo`0Hool00`0?ooooo`08ool00`0?ooooo`09ool002_o
o`0300oooooo02Soo`0308ooo`0?03Coo`0307oooooo03?oo`0300oooooo03Coo`0308oooooo03;o
o`0300l0Sooo00Coo`0300oooooo01Soo`0300oooooo00Soo`0300oooooo00Woo`00:ooo00<03ooo
ool0:?oo00<0Oooo00l0=?oo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<ooo00<03ooo
ool00_oo00<03oooool06Ooo00<03oooool02?oo00<03oooool02Ooo000[ool00`0?ooooo`0Xool0
0`2?ool03`0dool00`1oooooo`0cool00`0?ooooo`0dool00`2?ooooo`0cool00`0?ooooo`02ool0
0`0?ooooo`0Iool00`0?ooooo`08ool00`0?ooooo`09ool002_oo`803bWoo`0307ooo`0?03Coo`03
08oooooo03?oo`0300oooooo03Coo`0307oooooo03?oo`0300oooooo00;oo`0300oooooo01[oo`03
00oooooo00Koo`803`_oo`00:ooo00<03oooool0:?oo00<0Sooo00l0=?oo00<0Ooooool0<ooo00<0
3oooool0=?oo00<0Soooool0<ooo00D0S`0?ooooo`0?01goo`0300oooooo00Ooo`0300oooooo00Wo
o`00:ooo00<03oooool0:?oo00<0O`0?ool0=?oo00<0Soooool0<ooo00<03oooool0=?oo00<0Oooo
ool0<ooo00D0O`0?ooooo`0?01goo`0300oooooo00Ooo`0300oooooo00Woo`00:ooo00<03oooool0
:?oo00<0S`0?ool0=?oo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0<ooo00@0Sooo00l0
3akoo`0300oooooo00Ooo`0300oooooo00Woo`008Ooo0`0?1ooo00<03oooool0:?oo00<0O`0?ool0
=?oo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<ooo00<0Ooooool07ooo00<03oooool0
1ooo00<03oooool02Ooo000Qool00`0?ooooo`07ool00`0?ooooo`0Xool00`2?00ooo`0dool00`1o
ooooo`0cool00`0?ooooo`0dool00`2?ooooo`0cool00`2?ooooo`0Oool00`0?ooooo`07ool00`0?
ooooo`09ool002;oo`0300oooooo00Koo`0300oooooo02Soo`0307l03ooo03Coo`0308oooooo03?o
o`0300oooooo03Coo`0307oooooo03?oo`0307oooooo01ooo`0300oooooo00Ooo`0300oooooo00Wo
o`008Ooo00<03ooo00l01ooo0`0?0?l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l002d0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l00`0?2ooo000Rool200l7ool00`0?ooooo`0Xool00`1o
00ooo`0dool00`2?ooooo`0cool00`0?ooooo`0dool00`1oooooo`0cool00`1oooooo`0Pool00`0?
ooooo`06ool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0308l03ooo03Coo`0307oooooo03?o
o`0300oooooo03Coo`0308oooooo03?oo`0308oooooo023oo`0300oooooo00Koo`0300oooooo00Wo
o`00:ooo00<03oooool0:?oo00<0O`0?ool0=?oo00<0Soooool0<ooo00<03oooool0=?oo00<0Oooo
ool0<ooo00<0Ooooool08?oo00<03oooool01_oo00<03oooool02Ooo000[ool00`0?ooooo`0Xool0
0`2?00ooo`0dool00`1oooooo`0cool00`0?ooooo`0dool00`2?ooooo`0cool00`2?ooooo`0Pool0
0`0?ooooo`06ool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0307l03ooo03Coo`0308oooooo
03?oo`0300oooooo03Coo`0307oooooo03?oo`0307oooooo023oo`0300oooooo00Koo`0300oooooo
00Woo`00:ooo0P0?:Ooo00<0S`0?ool0=?oo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0
<ooo00<0Soooool08Ooo00<03oooool01?oo0P0?2ooo000[ool00`0?ooooo`0Xool00`1o00ooo`0d
ool00`2?ooooo`0cool00`0?ooooo`0dool00`1oooooo`0cool00`1oooooo`0Qool00`0?ooooo`05
ool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0308l03ooo03Coo`0307oooooo03?oo`0300oo
oooo03Coo`0308oooooo03?oo`0308oooooo027oo`0300oooooo00Goo`0300oooooo00Woo`00:ooo
00<03oooool0:?oo00<0O`0?ool0=?oo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<ooo
00<0Ooooool08Ooo00<03oooool01Ooo00<03oooool02Ooo000[ool00`0?ooooo`0Xool00`0?oooo
o`0dool00`1oooooo`0cool00`0?ooooo`0dool00`2?ooooo`0cool00`2?ooooo`0Qool00`0?oooo
o`05ool00`0?ooooo`09ool002_oo`0300oooooo02Soo`0300oooooo03Coo`0308oooooo03?oo`03
00oooooo03Coo`0307oooooo03?oo`0307oooooo027oo`0300oooooo00Goo`0300oooooo00Woo`00
:ooo0P0?:Ooo00<03oooool0=?oo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0<ooo00<0
Soooool08_oo00<03oooool00ooo0P0?2ooo000[ool00`0?ooooo`0Xool00`0?ooooo`0dool00`2?
ooooo`0cool00`0?ooooo`0dool00`1oooooo`0cool00`1oooooo`0Rool00`0?ooooo`04ool00`0?
ooooo`09ool002_oo`0300oooooo02Soo`0300oooooo03Coo`0307oooooo03?oo`0300oooooo03Co
o`0308oooooo03?oo`0308oooooo02;oo`0300oooooo00Coo`0300oooooo00Woo`00:ooo00<03ooo
ool0:?oo00<03oooool0=?oo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<ooo00<0Oooo
ool08_oo00<03oooool01?oo00<03oooool02Ooo000[ool00`0?ooooo`0Xool00`0?ooooo`0dool0
0`1oooooo`0cool00`0?ooooo`0dool00`2?ooooo`0cool00`2?ooooo`0Sool00`0?ooooo`03ool0
0`0?ooooo`09ool002_oo`0300oooooo02Soo`0300oooooo03Coo`0308oooooo03?oo`0300oooooo
03Coo`0307oooooo03?oo`0307oooooo02?oo`0300oooooo00?oo`0300oooooo00Woo`00:ooo00<0
3oooool0:?oo00<03oooool0=?oo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0<ooo00<0
Soooool08ooo00<03oooool00ooo00<03oooool02Ooo000[ool200lYool00`0?ooooo`0dool00`2?
ooooo`0cool00`0?ooooo`0dool00`1oooooo`0cool00`1oooooo`0Sool00`0?ooooo`02ool200l;
ool002_oo`0300oooooo02Soo`0300oooooo03Coo`0307oooooo03?oo`0300oooooo03Coo`0308oo
oooo03?oo`0308oooooo02Coo`0300oooooo00;oo`0300oooooo00Woo`00:ooo00<03oooool0:?oo
00<03oooool0=?oo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<ooo00<0Ooooool09?oo
00<03oooool00_oo00<03oooool02Ooo000[ool00`0?ooooo`0Xool00`0?ooooo`0dool00`1ooooo
o`0cool00`0?ooooo`0dool00`2?ooooo`0cool00`2?ooooo`0Tool00`0?ooooo`02ool00`0?oooo
o`09ool002_oo`0300oooooo02Soo`0300oooooo03Coo`0308oooooo03?oo`0300oooooo03Coo`03
07oooooo03?oo`0307oooooo02Coo`0300oooooo00;oo`0300oooooo00Woo`00:ooo00<03oooool0
:?oo00<03oooool0=?oo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0<ooo00<0Soooool0
9?oo0P0?0ooo00<03oooool02Ooo000[ool200lXool00`0?07ooo`0eool00`2?ooooo`0cool00`0?
ooooo`0dool00`1oooooo`0cool00`1oooooo`0Uool00`0?ooooo`0200l;ool002_oo`0300oooooo
02Ooo`0300l0Sooo03Goo`0307oooooo03?oo`0300oooooo03Coo`0308oooooo03?oo`0308oooooo
02Goo`0500ooooooool03`0;ool002_oo`0300oooooo02Ooo`0300l0Oooo03Goo`0308oooooo03?o
o`0300oooooo03Coo`0307oooooo03?oo`0307oooooo02Goo`0500ooooooool03`0;ool002_oo`03
00oooooo02Ooo`0300l0Sooo03Goo`0307oooooo03?oo`0300oooooo03Coo`0308oooooo03?oo`03
08oooooo02Goo`0500ooooooool03`0;ool001_oo`<03`03ool03ooo00803`Soo`0300oooooo02Oo
o`0300l0Oooo03Goo`0308oooooo03?oo`0300oooooo03Coo`0307oooooo03?oo`0307oooooo02Ko
o`0400oooooo00l;ool001_oo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo02Ooo`0300l0
Sooo03Goo`0307oooooo03?oo`0300oooooo03Coo`0308oooooo03?oo`0308oooooo02Koo`0400oo
oooo00l;ool001coo`0300oooooo00;oo`803`Soo`<03`3o07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o000/07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`@03`_oo`006ooo00<03ooo00l00ooo
00<03oooool01ooo00<03oooool09ooo00<03`2?ool0=Ooo00<0Ooooool0<ooo00<03oooool0=?oo
00<0Soooool0<ooo00<0Soooool09_oo00@03oooool03`_oo`007?oo0P0?0ooo0`0?1ooo00<03ooo
ool09ooo00<03`1oool0=Ooo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<ooo00<0Oooo
ool09_oo00@03oooool03`_oo`00:ooo00<03oooool09ooo00<03`2?ool0=Ooo00<0Ooooool0<ooo
00<03oooool0=?oo00<0Soooool0<ooo00<0Soooool09_oo00@03oooool03`_oo`00:ooo00<03ooo
ool09ooo00<03`1oool0=Ooo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<ooo00<0Oooo
ool09ooo00<03ooo00l02ooo000[ool00`0?ooooo`0Wool00`0?08ooo`0eool00`1oooooo`0cool0
0`0?ooooo`0dool00`2?ooooo`0cool00`2?ooooo`0Wool00`0?ool03`0;ool002_oo`803bSoo`03
00l0Oooo03Goo`0308oooooo03?oo`0300oooooo03Coo`0307oooooo03?oo`0307oooooo02Ooo`<0
3`_oo`00:ooo00<03oooool09ooo00<03`2?ool0=Ooo00<0Ooooool0<ooo00<03oooool0=?oo00<0
Soooool0<ooo00<0Soooool09ooo00<03ooo00l02ooo000[ool00`0?ooooo`0Wool00`0?07ooo`0e
ool00`2?ooooo`0cool00`0?ooooo`0dool00`1oooooo`0cool00`1oooooo`0Wool00`0?ool03`0;
ool002_oo`0300oooooo02Koo`0300ooo`2?03Koo`0307oooooo03?oo`0300oooooo03Coo`0308oo
oooo03?oo`0308oooooo02Ooo`0300ooo`0?00_oo`00:ooo00<03oooool09_oo00<03ooo07l0=_oo
00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<ooo00<0Ooooool0:?oo0P0?2ooo000[ool0
0`0?ooooo`0Vool00`0?ool0S`0fool00`1oooooo`0cool00`0?ooooo`0dool00`2?ooooo`0cool0
0`2?ooooo`0Xool200l;ool002_oo`0300oooooo02Koo`0300ooo`1o03Koo`0308oooooo03?oo`03
00oooooo03Coo`0307oooooo03?oo`0307oooooo02Soo`803`_oo`00:ooo0P0?9ooo00<03ooo08l0
=_oo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0<ooo00<0Soooool0:?oo0P0?2ooo000[
ool00`0?ooooo`0Vool00`0?ool0O`0fool00`2?ooooo`0cool00`0?ooooo`0dool00`1oooooo`0c
ool00`1oooooo`0Xool200l;ool002_oo`0300oooooo02Koo`0300ooo`2?03Koo`0307oooooo03?o
o`0300oooooo03Coo`0308oooooo03?oo`0308oooooo02Woo`0300oooooo00Woo`00:ooo00<03ooo
ool09_oo00<03ooo07l0=_oo00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<ooo00<0Oooo
ool0:Ooo00<03oooool02Ooo000[ool00`0?ooooo`0Vool00`0?ool0S`0fool00`1oooooo`0cool0
0`0?ooooo`0dool00`2?ooooo`0cool00`2?ooooo`0Yool00`0?ooooo`09ool002_oo`0300oooooo
02Koo`0300ooo`1o03Koo`0308oooooo03?oo`0300oooooo03Coo`0307oooooo03?oo`0307oooooo
02Woo`0300oooooo00Woo`00:ooo0P0?9ooo00<03ooo08l0=_oo00<0Ooooool0<ooo00<03oooool0
=?oo00<0Soooool0<ooo00<0Soooool0:?oo0P0?2ooo000[ool00`0?ooooo`0Vool00`0?ool0O`0f
ool00`2?ooooo`0cool00`0?ooooo`0dool00`1oooooo`0cool00`1oooooo`0Yool00`0?ooooo`09
ool002_oo`0300oooooo02Koo`0300ooo`2?03Koo`0307oooooo03?oo`0300oooooo03Coo`0308oo
oooo03?oo`0308oooooo02Woo`0300oooooo00Woo`00:ooo00<03oooool09_oo00<03ooo07l0=_oo
00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<ooo00<0Ooooool0:Ooo00<03oooool02Ooo
000[ool00`0?ooooo`0Uool0100?ooooo`2?=_oo00<0Ooooool0<ooo00<03oooool0=?oo00<0Sooo
ool0<ooo00<0Soooool0:Ooo00<03oooool02Ooo000[ool00`0?ooooo`0Uool0100?ooooo`1o=_oo
00<0Soooool0<ooo00<03oooool0=?oo00<0Ooooool0<ooo00<0Ooooool0:Ooo00<03oooool02Ooo
000[ool200lVool0100?ooooo`2?=_oo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0<ooo
00<0Soooool0:?oo0P0?2ooo000[ool00`0?ooooo`0Uool0100?ooooo`1o=_oo00<0Soooool0<ooo
00<03oooool0=?oo00<0Ooooool0<ooo00<0Ooooool0:Ooo00<03oooool02Ooo000[ool00`0?oooo
o`0Uool0100?ooooo`2?=_oo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0<ooo00<0Sooo
ool0:Ooo00<03oooool02Ooo000[ool00`0?ooooo`0Uool0100?ooooo`1o=_oo00<0Soooool0<ooo
00<03oooool0=?oo00<0Ooooool0<ooo00<0Ooooool0:Ooo00<03oooool02Ooo000Qool200l8ool0
0`0?ooooo`0Uool0100?ooooo`2?=_oo00<0Ooooool0<ooo00<03oooool0=?oo00<0Soooool0<ooo
00<0Soooool0:Ooo00<03oooool02Ooo000Sool00`0?ooooo`05ool00`0?ooooo`08ool00`0?oooo
o`08ool00`0?ooooo`07ool00`0?ooooo`05ool0100?ooooo`0?2_oo00<03oooool02?oo00<03ooo
ool02?oo00<03oooool02?oo00<03oooool02?oo00<03oooool02?oo00<03oooool02?oo00<03ooo
ool02?oo00<03oooool01ooo00<03oooool02?oo00<03oooool02?oo00<03oooool02?oo00<03ooo
ool02?oo00<03oooool02?oo00<03oooool02?oo00<03oooool02?oo00<03oooool02?oo00<03ooo
ool01ooo00<03oooool02?oo00<03oooool02?oo00<03oooool02?oo00<03oooool02?oo00<03ooo
ool02?oo00<03oooool02?oo00<03oooool02Ooo000Rool00`0?ooooo`06oooo00lc00l;ool002?o
o`0300oooooo0?oood?oo`008Ooo0P0?ooooA_oo003ooomYool00?ooofWoo`00ooooJOoo003ooomY
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.593837, -0.426622, 
  0.022944, 0.019888}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["$\\partial \\ln i/\\partial \\ln v$"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(dd = Max[tbli]\/100; \)\), 
    \(\(tbldlnidlnvv = 
      N[Table[{tblv\[LeftDoubleBracket]n\[RightDoubleBracket], 
            Abs[tbldidv\[LeftDoubleBracket]n\[RightDoubleBracket]\ 
                  tblv\[LeftDoubleBracket]n\[RightDoubleBracket]]
                \/\(Abs[tbli\[LeftDoubleBracket]n\[RightDoubleBracket]] + dd
                \)}, {n, 1, dim1}]]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(xlimit = .5; \)\), 
    \(\(ylimit = 110.; \)\), 
    \(\(dlnidlnvGraphics = 
      ListPlot[tbldlnidlnvv, 
        PlotRange \[Rule] {{\(-vmax\) + xlimit, vmax - xlimit}, {0, ylimit}}, 
        Frame \[Rule] True, PlotJoined \[Rule] True, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        GridLines \[Rule] Automatic, 
        FrameLabel \[Rule] {"\<Energy in eV\>", "\<dlogidlogv in a.u.\>"}, 
        DisplayFunction \[Rule] Identity]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Comparison of STS Results "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(tblx0 = {\(-3.33\), \(-4.36\), \(-6.05\), \(-7.22\), \(-7.34\)}; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(delE = 5.3; \)\), 
    \(tblx = tblx0 + delE\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({1.96999999999999975`, 0.939999999999999502`, \(-0.75`\), 
      \(-1.91999999999999992`\), \(-2.04000000000000003`\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(z0 = 100.; \)\), 
    \(\(tblxGraphics = 
      Plot[Evaluate[{
            z0\ fc[En, tblx\[LeftDoubleBracket]1\[RightDoubleBracket], 300.], 
            z0\ fc[En, tblx\[LeftDoubleBracket]2\[RightDoubleBracket], 300.], 
            z0\ fc[En, tblx\[LeftDoubleBracket]3\[RightDoubleBracket], 300.], 
            z0\ fc[En, tblx\[LeftDoubleBracket]4\[RightDoubleBracket], 300.], 
            z0\ fc[En, tblx\[LeftDoubleBracket]5\[RightDoubleBracket], 
                300.]}], {En, \(-2.5\), 2.5}, PlotRange \[Rule] All, 
        DisplayFunction \[Rule] Identity]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig12x6 = 
      Show[{dlnidlnvGraphics, tblxGraphics, 
          Graphics[{Thickness[0.01], 
              Text["\<t1g\>", {
                  tblx\[LeftDoubleBracket]1\[RightDoubleBracket], 95}], 
              Text["\<t1u\>", {
                  tblx\[LeftDoubleBracket]2\[RightDoubleBracket], 95}], 
              Text["\<hu\>", {tblx\[LeftDoubleBracket]3\[RightDoubleBracket], 
                  95}], Text[
                "\<hg\>", {
                  tblx\[LeftDoubleBracket]4\[RightDoubleBracket] + .1, 95}], 
              Text["\<gg\>", {
                  tblx\[LeftDoubleBracket]5\[RightDoubleBracket] - .1, 95}], 
              Line[{{tblx\[LeftDoubleBracket]1\[RightDoubleBracket], 80}, {
                    tblx\[LeftDoubleBracket]1\[RightDoubleBracket], 90}}], 
              Line[{{tblx\[LeftDoubleBracket]2\[RightDoubleBracket], 80}, {
                    tblx\[LeftDoubleBracket]2\[RightDoubleBracket], 90}}], 
              Line[{{tblx\[LeftDoubleBracket]3\[RightDoubleBracket], 80}, {
                    tblx\[LeftDoubleBracket]3\[RightDoubleBracket], 90}}], 
              Line[{{tblx\[LeftDoubleBracket]4\[RightDoubleBracket], 80}, {
                    tblx\[LeftDoubleBracket]4\[RightDoubleBracket], 90}}], 
              Line[{{tblx\[LeftDoubleBracket]5\[RightDoubleBracket], 80}, {
                    tblx\[LeftDoubleBracket]5\[RightDoubleBracket], 90}}]}]}, 
        Frame \[Rule] True, DisplayFunction \[Rule] $DisplayFunction]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.2 0 0.005618 [
[.1 -0.0125 -7 -12 ]
[.1 -0.0125 7 0 ]
[.3 -0.0125 -7 -12 ]
[.3 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.7 -0.0125 -4 -12 ]
[.7 -0.0125 4 0 ]
[.9 -0.0125 -4 -12 ]
[.9 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -23.5 -24 ]
[.5 -0.0125 23.5 -12 ]
[-0.0125 .11237 -12 -6 ]
[-0.0125 .11237 0 6 ]
[-0.0125 .22474 -12 -6 ]
[-0.0125 .22474 0 6 ]
[-0.0125 .33711 -12 -6 ]
[-0.0125 .33711 0 6 ]
[-0.0125 .44948 -12 -6 ]
[-0.0125 .44948 0 6 ]
[-0.0125 .56185 -16 -6 ]
[-0.0125 .56185 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -30.5 ]
[-0.01875 .30902 -16 30.5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .61803 L
s
.3 0 m
.3 .61803 L
s
.5 0 m
.5 .61803 L
s
.7 0 m
.7 .61803 L
s
.9 0 m
.9 .61803 L
s
0 .11237 m
1 .11237 L
s
0 .22474 m
1 .22474 L
s
0 .33711 m
1 .33711 L
s
0 .44948 m
1 .44948 L
s
0 .56185 m
1 .56185 L
s
0 g
.1 0 m
.1 .00625 L
s
gsave
.1 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.3 0 m
.3 .00625 L
s
gsave
.3 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7 0 m
.7 .00625 L
s
gsave
.7 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.9 0 m
.9 .00625 L
s
gsave
.9 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.14 0 m
.14 .00375 L
s
.18 0 m
.18 .00375 L
s
.22 0 m
.22 .00375 L
s
.26 0 m
.26 .00375 L
s
.34 0 m
.34 .00375 L
s
.38 0 m
.38 .00375 L
s
.42 0 m
.42 .00375 L
s
.46 0 m
.46 .00375 L
s
.54 0 m
.54 .00375 L
s
.58 0 m
.58 .00375 L
s
.62 0 m
.62 .00375 L
s
.66 0 m
.66 .00375 L
s
.74 0 m
.74 .00375 L
s
.78 0 m
.78 .00375 L
s
.82 0 m
.82 .00375 L
s
.86 0 m
.86 .00375 L
s
.06 0 m
.06 .00375 L
s
.02 0 m
.02 .00375 L
s
.94 0 m
.94 .00375 L
s
.98 0 m
.98 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -84.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Energy) show
88.000000 13.000000 moveto
(in) show
96.187500 13.000000 moveto
(eV) show
105.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .11237 m
.00625 .11237 L
s
gsave
-0.0125 .11237 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .22474 m
.00625 .22474 L
s
gsave
-0.0125 .22474 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .33711 m
.00625 .33711 L
s
gsave
-0.0125 .33711 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .44948 m
.00625 .44948 L
s
gsave
-0.0125 .44948 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .56185 m
.00625 .56185 L
s
gsave
-0.0125 .56185 -77 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -113.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
91.5 10 translate
90 rotate
-91.5 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dlogidlogv) show
99.562500 13.000000 moveto
(in) show
107.750000 13.000000 moveto
(a) show
111.250000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
113.250000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
117.250000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
119.250000 13.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.1 .61178 m
.1 .61803 L
s
.3 .61178 m
.3 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7 .61178 m
.7 .61803 L
s
.9 .61178 m
.9 .61803 L
s
.125 Mabswid
.14 .61428 m
.14 .61803 L
s
.18 .61428 m
.18 .61803 L
s
.22 .61428 m
.22 .61803 L
s
.26 .61428 m
.26 .61803 L
s
.34 .61428 m
.34 .61803 L
s
.38 .61428 m
.38 .61803 L
s
.42 .61428 m
.42 .61803 L
s
.46 .61428 m
.46 .61803 L
s
.54 .61428 m
.54 .61803 L
s
.58 .61428 m
.58 .61803 L
s
.62 .61428 m
.62 .61803 L
s
.66 .61428 m
.66 .61803 L
s
.74 .61428 m
.74 .61803 L
s
.78 .61428 m
.78 .61803 L
s
.82 .61428 m
.82 .61803 L
s
.86 .61428 m
.86 .61803 L
s
.06 .61428 m
.06 .61803 L
s
.02 .61428 m
.02 .61803 L
s
.94 .61428 m
.94 .61803 L
s
.98 .61428 m
.98 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .11237 m
1 .11237 L
s
.99375 .22474 m
1 .22474 L
s
.99375 .33711 m
1 .33711 L
s
.99375 .44948 m
1 .44948 L
s
.99375 .56185 m
1 .56185 L
s
.125 Mabswid
.99625 .02809 m
1 .02809 L
s
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .58994 m
1 .58994 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .29849 m
.00312 .30153 L
.00781 .30525 L
.0125 .30973 L
.01719 .31561 L
.02187 .32162 L
.02656 .32626 L
.03125 .32814 L
.03594 .32717 L
.04062 .32394 L
.04531 .31973 L
.05 .31527 L
.05469 .31052 L
.05937 .30458 L
.06406 .29693 L
.06875 .2879 L
.07344 .27838 L
.07813 .26885 L
.08281 .25859 L
.0875 .24611 L
.09219 .2299 L
.09687 .21 L
.10156 .18783 L
.10625 .16602 L
.11094 .14638 L
.11562 .12964 L
.12031 .11519 L
.125 .10242 L
.12969 .09121 L
.13437 .08208 L
.13906 .07576 L
.14375 .0724 L
.14844 .07176 L
.15312 .07324 L
.15781 .07662 L
.1625 .08161 L
.16719 .08783 L
.17188 .09447 L
.17656 .10079 L
.18125 .10644 L
.18594 .1113 L
.19063 .11532 L
.19531 .11799 L
.2 .11871 L
.20469 .11684 L
.20937 .11255 L
.21406 .1064 L
.21875 .09956 L
.22344 .09302 L
.22812 .08758 L
Mistroke
.23281 .08356 L
.2375 .08112 L
.24219 .08046 L
.24688 .08188 L
.25156 .08563 L
.25625 .09173 L
.26094 .09994 L
.26563 .10983 L
.27031 .12088 L
.275 .13276 L
.27969 .14569 L
.28438 .16009 L
.28906 .17627 L
.29375 .1936 L
.29844 .21111 L
.30312 .22817 L
.30781 .24552 L
.3125 .26452 L
.31719 .28599 L
.32188 .30852 L
.32656 .32868 L
.33125 .34313 L
.33594 .35146 L
.34062 .35656 L
.34531 .36162 L
.35 .36519 L
.35469 .3591 L
.35938 .33257 L
.36406 .28435 L
.36875 .22402 L
.37344 .1655 L
.37813 .11751 L
.38281 .08412 L
.3875 .06357 L
.39219 .05263 L
.39688 .04728 L
.40156 .04454 L
.40625 .04112 L
.41094 .03422 L
.41563 .02023 L
.42031 .00767 L
.425 .00019 L
.42969 .00443 L
.43438 .00676 L
.43906 .00937 L
.44375 .00969 L
.44844 .00912 L
.45313 .00741 L
.45781 .00475 L
.4625 .00107 L
Mistroke
.46719 .00238 L
.47188 .00398 L
.47656 .00381 L
.48125 .00291 L
.48594 .00197 L
.49063 .00104 L
.49531 .00035 L
.5 0 L
.50469 7e-05 L
.50938 .00054 L
.51406 .0012 L
.51875 .00152 L
.52344 .00093 L
.52812 .00023 L
.53281 .00056 L
.5375 .00072 L
.54219 .00233 L
.54688 .00254 L
.55156 .00018 L
.55625 .00429 L
.56094 .00752 L
.56563 .00661 L
.57031 .00041 L
.575 .01222 L
.57969 .02383 L
.58438 .03073 L
.58906 .03179 L
.59375 .02724 L
.59844 .0205 L
.60313 .01332 L
.60781 .00647 L
.6125 .00141 L
.61719 .01214 L
.62187 .02732 L
.62656 .04606 L
.63125 .06565 L
.63594 .08155 L
.64063 .08431 L
.64531 .08319 L
.65 .08135 L
.65469 .08226 L
.65938 .08868 L
.66406 .10209 L
.66875 .12301 L
.67344 .1498 L
.67813 .17929 L
.68281 .2066 L
.6875 .22972 L
.69219 .24675 L
.69688 .25783 L
Mistroke
.70156 .26225 L
.70625 .26197 L
.71094 .25841 L
.71563 .25279 L
.72031 .24386 L
.725 .23008 L
.72969 .21121 L
.73438 .1897 L
.73906 .16922 L
.74375 .15162 L
.74844 .13657 L
.75313 .12201 L
.75781 .10717 L
.7625 .09213 L
.76719 .07862 L
.77188 .06715 L
.77656 .05775 L
.78125 .04887 L
.78594 .04005 L
.79063 .03198 L
.79531 .0264 L
.8 .02445 L
.80469 .02553 L
.80938 .02936 L
.81406 .03608 L
.81875 .04817 L
.82344 .06729 L
.82813 .09463 L
.83281 .12877 L
.8375 .16743 L
.84219 .20801 L
.84688 .2493 L
.85156 .29081 L
.85625 .33113 L
.86094 .36769 L
.86563 .39719 L
.87031 .41769 L
.875 .42882 L
.87969 .43227 L
.88438 .4303 L
.88906 .4247 L
.89375 .41575 L
.89844 .40256 L
.90313 .38432 L
.90781 .36132 L
.9125 .33519 L
.91719 .308 L
.92188 .28154 L
.92656 .25688 L
.93125 .23449 L
Mistroke
.93594 .21442 L
.94063 .19625 L
.94531 .17957 L
.95 .16391 L
.95469 .14945 L
.95938 .13674 L
.96406 .12678 L
.96875 .11997 L
.97344 .11608 L
.97813 .11452 L
.98281 .11513 L
.9875 .11828 L
.99219 .12439 L
.99688 .13339 L
Mfstroke
.99688 .13339 m
1 .14083 L
s
0 0 m
.04057 0 L
.08481 0 L
.12636 0 L
.16632 0 L
.20885 0 L
.2498 0 L
.29331 0 L
.33524 0 L
.37557 0 L
.41848 0 L
.4598 0 L
.49953 0 L
.54183 0 L
.58254 0 L
.62583 0 L
.64745 0 L
.66752 0 L
.68693 0 L
.69252 0 L
.69778 0 L
.70008 0 L
.70251 0 L
.70378 0 L
.7045 0 L
.70517 0 L
.70762 0 L
.70895 0 L
.70962 0 L
.71035 0 L
.71166 0 L
.71288 0 L
.71433 0 L
.71586 0 L
.71717 0 L
.71791 0 L
.7186 0 L
.71986 0 L
.72102 0 L
.72235 0 L
.7236 0 L
.72486 0 L
.72619 0 L
.72765 0 L
.72899 0 L
.7302 0 L
.7313 0 L
.73258 0 L
.73379 0 L
.73593 0 L
Mistroke
.73715 0 L
.73827 0 L
.73961 0 L
.74087 0 L
.742 0 L
.74321 0 L
.74455 0 L
.74596 0 L
.74716 0 L
.74848 0 L
.74985 0 L
.75112 0 L
.75252 0 L
.754 0 L
.75528 0 L
.75648 0 L
.7578 0 L
.75922 0 L
.76041 0 L
.76171 0 L
.76307 0 L
.76433 0 L
.76659 0 L
.76786 0 L
.769 0 L
.77038 0 L
.77183 0 L
.77307 0 L
.77443 0 L
.7759 0 L
.77747 0 L
.77896 0 L
.78031 0 L
.78167 0 L
.78293 0 L
.78432 0 L
.78579 0 L
.78706 0 L
.78825 0 L
.78956 0 L
.79098 0 L
.79229 0 L
.79349 0 L
.79487 0 L
.79617 0 L
.79738 0 L
.79849 0 L
.79972 0 L
.80101 0 L
.80231 0 L
Mistroke
.80371 0 L
.80503 0 L
.80624 0 L
.80765 0 L
.80919 0 L
.81065 0 L
.812 0 L
.81339 0 L
.81489 0 L
.81631 0 L
.81762 0 L
.8188 0 L
.8201 0 L
.82145 0 L
.82272 0 L
.8242 0 L
.8256 0 L
.82686 0 L
.82823 0 L
.82972 0 L
.8313 0 L
.83265 0 L
.83414 1e-05 L
.83542 1e-05 L
.83661 1e-05 L
.83792 1e-05 L
.83931 1e-05 L
.84078 2e-05 L
.84216 2e-05 L
.8434 3e-05 L
.84475 4e-05 L
.84592 5e-05 L
.84721 7e-05 L
.84855 9e-05 L
.84981 .00011 L
.85206 .00017 L
.85332 .00021 L
.85447 .00027 L
.85582 .00035 L
.85726 .00046 L
.85862 .0006 L
.85985 .00076 L
.8613 .001 L
.86287 .00136 L
.86435 .0018 L
.86571 .00234 L
.86699 .003 L
.86819 .00376 L
.8695 .00483 L
.8709 .0063 L
Mistroke
.87237 .00832 L
.87377 .01079 L
.87502 .01359 L
.87638 .01742 L
.87884 .02698 L
.88022 .03419 L
.88149 .04214 L
.88628 .08417 L
.88896 .1117 L
.89037 .12447 L
.89114 .13027 L
.89188 .13469 L
.89257 .13781 L
.89332 .13986 L
.89463 .13994 L
.89597 .1355 L
.89719 .12787 L
.9027 .07423 L
.90574 .04769 L
.90723 .03747 L
.90861 .02967 L
.91128 .01853 L
.91269 .01434 L
.91419 .01088 L
.91535 .00876 L
.9166 .00692 L
.91798 .00533 L
.91927 .00417 L
.92043 .00334 L
.92167 .00264 L
.92303 .00203 L
.92429 .0016 L
.92572 .00121 L
.92706 .00094 L
.92827 .00074 L
.92958 .00058 L
.93081 .00045 L
.93197 .00036 L
.93317 .00029 L
.93449 .00022 L
.93668 .00015 L
.93791 .00012 L
.93903 9e-05 L
.94037 7e-05 L
.94179 5e-05 L
.94313 4e-05 L
.94435 3e-05 L
.94579 3e-05 L
.94734 2e-05 L
.94881 1e-05 L
Mistroke
.95016 1e-05 L
.95142 1e-05 L
.95261 1e-05 L
.95391 1e-05 L
.9553 0 L
.95675 0 L
.95814 0 L
.95937 0 L
.96072 0 L
.96297 0 L
.96424 0 L
.9654 0 L
.96754 0 L
.96861 0 L
.96978 0 L
.97107 0 L
.97229 0 L
.97369 0 L
.97496 0 L
.97609 0 L
.97727 0 L
.97858 0 L
.97978 0 L
.98101 0 L
.98218 0 L
.98353 0 L
.98476 0 L
.98699 0 L
.98824 0 L
.98941 0 L
.99058 0 L
.99185 0 L
.99324 0 L
.99454 0 L
.99593 0 L
.99739 0 L
.99863 0 L
1 0 L
Mfstroke
0 0 m
.04057 0 L
.08481 0 L
.12636 0 L
.16632 0 L
.20885 0 L
.2498 0 L
.29331 0 L
.33524 0 L
.37557 0 L
.41848 0 L
.43982 0 L
.4598 0 L
.47894 0 L
.48445 0 L
.48969 0 L
.4944 0 L
.49568 0 L
.49706 0 L
.49835 0 L
.49953 0 L
.50197 0 L
.50335 0 L
.50465 0 L
.50534 0 L
.5061 0 L
.50748 0 L
.50873 0 L
.51005 0 L
.51121 0 L
.51248 0 L
.51473 0 L
.51597 0 L
.51731 0 L
.51849 0 L
.51974 0 L
.52111 0 L
.52239 0 L
.52391 0 L
.52529 0 L
.52674 0 L
.5283 0 L
.52978 0 L
.53114 0 L
.53239 0 L
.53356 0 L
.53484 0 L
.53622 0 L
.53766 0 L
.53903 0 L
Mistroke
.54026 0 L
.5416 0 L
.543 0 L
.54429 0 L
.5457 0 L
.5472 0 L
.5485 0 L
.54971 0 L
.55104 0 L
.55246 0 L
.55373 0 L
.55511 0 L
.55641 0 L
.55761 0 L
.55988 0 L
.56103 0 L
.5623 0 L
.56369 0 L
.56516 0 L
.56641 0 L
.56777 0 L
.56925 0 L
.57083 0 L
.57232 0 L
.57367 0 L
.57504 0 L
.5763 0 L
.57769 0 L
.57916 0 L
.58043 0 L
.58162 0 L
.58293 0 L
.58433 0 L
.58561 0 L
.58702 0 L
.58849 0 L
.58987 0 L
.59116 0 L
.59234 0 L
.59363 0 L
.595 0 L
.59638 0 L
.59787 0 L
.59927 0 L
.60054 0 L
.60204 0 L
.60366 0 L
.60519 0 L
.60661 0 L
.60782 0 L
Mistroke
.60913 0 L
.61036 0 L
.61149 0 L
.61281 0 L
.61424 0 L
.6156 0 L
.61686 0 L
.61828 0 L
.61962 0 L
.62082 0 L
.62212 0 L
.62354 0 L
.62504 0 L
.62632 0 L
.62773 0 L
.6291 1e-05 L
.63037 1e-05 L
.63176 1e-05 L
.63324 1e-05 L
.63452 2e-05 L
.63572 2e-05 L
.63703 3e-05 L
.63845 4e-05 L
.63964 5e-05 L
.64094 6e-05 L
.64229 8e-05 L
.64355 .0001 L
.64581 .00016 L
.64708 .00021 L
.64823 .00026 L
.6496 .00033 L
.65105 .00044 L
.65229 .00056 L
.65365 .00073 L
.65512 .00097 L
.65669 .00131 L
.65817 .00174 L
.65953 .00226 L
.66089 .00294 L
.66215 .00374 L
.66353 .00486 L
.665 .00642 L
.66641 .00837 L
.66773 .01071 L
.67019 .01685 L
.67142 .02102 L
.67273 .0265 L
.6751 .03958 L
.67792 .06128 L
.68048 .08626 L
Mistroke
.68316 .11365 L
.68457 .12604 L
.68534 .13154 L
.68606 .13563 L
.68736 .13993 L
.68806 .14046 L
.6888 .13962 L
.69012 .1347 L
.69133 .12683 L
.69617 .07956 L
.69854 .05725 L
.70073 .04068 L
.70325 .02656 L
.70458 .02102 L
.70598 .01632 L
.70825 .01075 L
.70954 .00845 L
.71075 .00674 L
.71209 .00523 L
.71335 .00411 L
.71451 .0033 L
.71573 .00261 L
.71706 .00202 L
.71829 .00159 L
.71962 .00124 L
.72108 .00093 L
.72232 .00073 L
.72346 .00059 L
.72468 .00047 L
.72603 .00036 L
.72829 .00023 L
.72952 .00018 L
.73067 .00015 L
.73203 .00011 L
.73351 8e-05 L
.7349 6e-05 L
.73618 5e-05 L
.73734 4e-05 L
.73861 3e-05 L
.73994 2e-05 L
.74119 2e-05 L
.74264 1e-05 L
.74402 1e-05 L
.74526 1e-05 L
.74661 1e-05 L
.74807 1e-05 L
.74963 0 L
.7511 0 L
.75243 0 L
.75369 0 L
Mistroke
.75488 0 L
.75617 0 L
.75756 0 L
.75902 0 L
.76039 0 L
.76163 0 L
.76297 0 L
.76414 0 L
.76542 0 L
.76676 0 L
.76801 0 L
.77025 0 L
.77151 0 L
.77267 0 L
.77395 0 L
.77531 0 L
.77659 0 L
.77776 0 L
.77914 0 L
.78063 0 L
.78203 0 L
.78333 0 L
.78467 0 L
.78592 0 L
.7873 0 L
.78878 0 L
.79032 0 L
.79179 0 L
.79311 0 L
.79454 0 L
.79581 0 L
.79698 0 L
.79826 0 L
.79962 0 L
.80189 0 L
.80318 0 L
.80439 0 L
.8058 0 L
.80714 0 L
.80834 0 L
.80964 0 L
.81106 0 L
.81257 0 L
.81385 0 L
.81527 0 L
.81674 0 L
.81813 0 L
.81939 0 L
.82075 0 L
.82223 0 L
Mistroke
.82381 0 L
.8253 0 L
.82665 0 L
.82803 0 L
.82929 0 L
.83068 0 L
.83214 0 L
.83342 0 L
.83461 0 L
.83591 0 L
.83731 0 L
.83859 0 L
.84001 0 L
.84148 0 L
.84287 0 L
.84415 0 L
.84534 0 L
.84663 0 L
.848 0 L
.84939 0 L
.85088 0 L
.85228 0 L
.85355 0 L
.85505 0 L
.85667 0 L
.85821 0 L
.85962 0 L
.86084 0 L
.86215 0 L
.86328 0 L
.86451 0 L
.86595 0 L
.86732 0 L
.86865 0 L
.86989 0 L
.87131 0 L
.87265 0 L
.87385 0 L
.87515 0 L
.87657 0 L
.87807 0 L
.87935 0 L
.88075 0 L
.88213 0 L
.8834 0 L
.88479 0 L
.88627 0 L
.88756 0 L
.88876 0 L
.89008 0 L
Mistroke
.8915 0 L
.89275 0 L
.89412 0 L
.89541 0 L
.89661 0 L
.89887 0 L
.90013 0 L
.90128 0 L
.90266 0 L
.90411 0 L
.90535 0 L
.90672 0 L
.90818 0 L
.90976 0 L
.91124 0 L
.9126 0 L
.91396 0 L
.91522 0 L
.9166 0 L
.91807 0 L
.91934 0 L
.92054 0 L
.92185 0 L
.92326 0 L
.92458 0 L
.92577 0 L
.92715 0 L
.92846 0 L
.92958 0 L
.93078 0 L
.93209 0 L
.9333 0 L
.9346 0 L
.936 0 L
.93732 0 L
.93853 0 L
.93994 0 L
.94148 0 L
.94293 0 L
.94428 0 L
.94568 0 L
.94718 0 L
.9486 0 L
.94991 0 L
.95109 0 L
.95239 0 L
.95374 0 L
.95501 0 L
.95649 0 L
.95789 0 L
Mistroke
.95915 0 L
.96052 0 L
.96201 0 L
.96359 0 L
.96494 0 L
.96643 0 L
.96839 0 L
.96951 0 L
.97054 0 L
.97263 0 L
.9738 0 L
.97486 0 L
.97677 0 L
.97785 0 L
.97884 0 L
.98066 0 L
.98158 0 L
.98259 0 L
.98375 0 L
.98486 0 L
.98693 0 L
.98809 0 L
.98916 0 L
.99041 0 L
.99159 0 L
.99262 0 L
.99373 0 L
.99566 0 L
.99676 0 L
.99792 0 L
1 0 L
Mfstroke
0 0 m
.04057 0 L
.08481 0 L
.10632 0 L
.12636 0 L
.14567 0 L
.15122 0 L
.15396 0 L
.15648 0 L
.15877 0 L
.15992 0 L
.1612 0 L
.16247 0 L
.16384 0 L
.16513 0 L
.16632 0 L
.16889 0 L
.17016 0 L
.17132 0 L
.17267 0 L
.17412 0 L
.17543 0 L
.17666 0 L
.17773 0 L
.17888 0 L
.18132 0 L
.18265 0 L
.1839 0 L
.18503 0 L
.18625 0 L
.1876 0 L
.18886 0 L
.19024 0 L
.19173 0 L
.19321 0 L
.19477 0 L
.1961 0 L
.19756 0 L
.19893 0 L
.20017 0 L
.20161 0 L
.20297 0 L
.20423 0 L
.20539 0 L
.20666 0 L
.20801 0 L
.20928 0 L
.21067 0 L
.21198 0 L
.21319 0 L
Mistroke
.21548 0 L
.21676 0 L
.21792 0 L
.21929 0 L
.22056 0 L
.22194 0 L
.22341 0 L
.22468 0 L
.22587 0 L
.22717 0 L
.22857 0 L
.22985 0 L
.23104 0 L
.23235 0 L
.23374 0 L
.23494 0 L
.23606 0 L
.2373 0 L
.23863 0 L
.23974 0 L
.24096 0 L
.24223 0 L
.24341 0 L
.24553 0 L
.24672 0 L
.24779 0 L
.24897 0 L
.25023 0 L
.25161 0 L
.2529 0 L
.25435 0 L
.25573 0 L
.25696 0 L
.2583 0 L
.25946 0 L
.26074 0 L
.26207 0 L
.26333 0 L
.26556 0 L
.26682 0 L
.26798 0 L
.26925 0 L
.27061 0 L
.27189 0 L
.27306 0 L
.27443 0 L
.27592 0 L
.27732 0 L
.27862 0 L
.27996 0 L
Mistroke
.28121 0 L
.28258 0 L
.28406 0 L
.28561 0 L
.28707 0 L
.28839 0 L
.28983 0 L
.29123 1e-05 L
.29251 1e-05 L
.29393 1e-05 L
.29542 1e-05 L
.29671 2e-05 L
.29792 2e-05 L
.29925 3e-05 L
.30067 4e-05 L
.30194 5e-05 L
.30332 7e-05 L
.30461 9e-05 L
.30582 .00011 L
.30809 .00017 L
.30924 .00021 L
.3105 .00027 L
.31189 .00035 L
.31336 .00047 L
.31461 .0006 L
.31597 .00078 L
.31745 .00103 L
.31903 .0014 L
.32051 .00186 L
.32187 .00241 L
.32324 .00314 L
.3245 .00399 L
.32589 .0052 L
.32735 .00686 L
.32863 .00872 L
.32982 .01089 L
.33253 .01791 L
.33384 .02266 L
.33525 .02895 L
.33776 .04405 L
.34076 .069 L
.34347 .09653 L
.34604 .12171 L
.34674 .12741 L
.34749 .13248 L
.34882 .13864 L
.35006 .14046 L
.35122 .13854 L
.35249 .13264 L
.35385 .12269 L
Mistroke
.35876 .07369 L
.36145 .04989 L
.36397 .03311 L
.36611 .02284 L
.36731 .01842 L
.36841 .01508 L
.36962 .0121 L
.37093 .00948 L
.37216 .00753 L
.37331 .00605 L
.37473 .00463 L
.376 .00363 L
.37738 .00279 L
.37887 .00209 L
.38018 .00163 L
.38156 .00125 L
.38274 .001 L
.38404 .00078 L
.38555 .00058 L
.38694 .00044 L
.38854 .00033 L
.39005 .00024 L
.39145 .00019 L
.39275 .00014 L
.39417 .00011 L
.39568 8e-05 L
.39698 6e-05 L
.39817 5e-05 L
.39948 4e-05 L
.40086 3e-05 L
.40206 2e-05 L
.40318 2e-05 L
.4044 2e-05 L
.40572 1e-05 L
.40717 1e-05 L
.40853 1e-05 L
.40986 1e-05 L
.41109 0 L
.41241 0 L
.41387 0 L
.41539 0 L
.41682 0 L
.41813 0 L
.41953 0 L
.42085 0 L
.42204 0 L
.42345 0 L
.42498 0 L
.42642 0 L
.42774 0 L
Mistroke
.42899 0 L
.43015 0 L
.43142 0 L
.43279 0 L
.43422 0 L
.43557 0 L
.43679 0 L
.43811 0 L
.43923 0 L
.44044 0 L
.44177 0 L
.44302 0 L
.44434 0 L
.44574 0 L
.44692 0 L
.44822 0 L
.44943 0 L
.45057 0 L
.45188 0 L
.45307 0 L
.45523 0 L
.45645 0 L
.45757 0 L
.45889 0 L
.46014 0 L
.46128 0 L
.46249 0 L
.4638 0 L
.46502 0 L
.46633 0 L
.46777 0 L
.469 0 L
.47013 0 L
.47135 0 L
.47269 0 L
.47493 0 L
.47616 0 L
.4773 0 L
.47866 0 L
.48012 0 L
.48151 0 L
.48279 0 L
.48394 0 L
.48521 0 L
.48654 0 L
.48778 0 L
.48923 0 L
.4906 0 L
.49183 0 L
.49318 0 L
Mistroke
.49464 0 L
.49619 0 L
.49766 0 L
.49899 0 L
.50025 0 L
.50143 0 L
.50272 0 L
.50411 0 L
.50556 0 L
.50694 0 L
.50817 0 L
.50952 0 L
.51068 0 L
.51196 0 L
.51329 0 L
.51455 0 L
.51679 0 L
.51805 0 L
.5192 0 L
.52048 0 L
.52184 0 L
.52312 0 L
.52429 0 L
.52566 0 L
.52715 0 L
.52856 0 L
.52985 0 L
.53119 0 L
.53245 0 L
.53382 0 L
.5353 0 L
.53685 0 L
.53831 0 L
.53963 0 L
.54106 0 L
.54247 0 L
.54376 0 L
.54517 0 L
.54666 0 L
.54796 0 L
.54918 0 L
.55051 0 L
.55193 0 L
.5532 0 L
.55458 0 L
.55588 0 L
.55708 0 L
.55936 0 L
.5605 0 L
.56177 0 L
Mistroke
.56323 0 L
.56463 0 L
.56588 0 L
.56725 0 L
.56873 0 L
.5703 0 L
.57179 0 L
.57314 0 L
.57452 0 L
.57578 0 L
.57717 0 L
.57863 0 L
.57991 0 L
.5811 0 L
.5824 0 L
.58381 0 L
.58508 0 L
.58649 0 L
.58796 0 L
.58935 0 L
.59063 0 L
.59181 0 L
.59311 0 L
.59447 0 L
.59586 0 L
.59735 0 L
.59875 0 L
.60002 0 L
.60152 0 L
.60314 0 L
.60467 0 L
.60609 0 L
.6073 0 L
.60861 0 L
.60974 0 L
.61097 0 L
.61241 0 L
.61378 0 L
.61511 0 L
.61634 0 L
.61777 0 L
.6191 0 L
.62031 0 L
.6216 0 L
.62302 0 L
.62452 0 L
.6258 0 L
.62721 0 L
.62858 0 L
.62985 0 L
Mistroke
.63124 0 L
.63272 0 L
.634 0 L
.6352 0 L
.63652 0 L
.63794 0 L
.63913 0 L
.64042 0 L
.64178 0 L
.64304 0 L
.6453 0 L
.64657 0 L
.64772 0 L
.64909 0 L
.65054 0 L
.65178 0 L
.65314 0 L
.65461 0 L
.65618 0 L
.65766 0 L
.65902 0 L
.66038 0 L
.66164 0 L
.66302 0 L
.66449 0 L
.6659 0 L
.66722 0 L
.6684 0 L
.66968 0 L
.671 0 L
.67219 0 L
.67357 0 L
.67487 0 L
.676 0 L
.67719 0 L
.6785 0 L
.6797 0 L
.681 0 L
.6824 0 L
.68372 0 L
.68493 0 L
.68634 0 L
.68788 0 L
.68933 0 L
.69068 0 L
.69207 0 L
.69357 0 L
.69499 0 L
.6963 0 L
.69748 0 L
Mistroke
.69878 0 L
.70013 0 L
.7014 0 L
.70288 0 L
.70428 0 L
.70554 0 L
.70691 0 L
.7084 0 L
.70998 0 L
.71133 0 L
.71282 0 L
.7141 0 L
.71528 0 L
.71659 0 L
.71798 0 L
.71945 0 L
.72083 0 L
.72207 0 L
.72342 0 L
.72458 0 L
.72587 0 L
.72721 0 L
.72847 0 L
.73072 0 L
.73198 0 L
.73313 0 L
.73448 0 L
.73592 0 L
.73728 0 L
.7385 0 L
.73996 0 L
.74152 0 L
.743 0 L
.74436 0 L
.74564 0 L
.74684 0 L
.74815 0 L
.74955 0 L
.75103 0 L
.75242 0 L
.75367 0 L
.75503 0 L
.75631 0 L
.75749 0 L
.75878 0 L
.76013 0 L
.76124 0 L
.76242 0 L
.76372 0 L
.76492 0 L
Mistroke
.76633 0 L
.76786 0 L
.76931 0 L
.77064 0 L
.77184 0 L
.77316 0 L
.77454 0 L
.77583 0 L
.7772 0 L
.77869 0 L
.78009 0 L
.7814 0 L
.78256 0 L
.78386 0 L
.78521 0 L
.78648 0 L
.78787 0 L
.78934 0 L
.7906 0 L
.79197 0 L
.79345 0 L
.79504 0 L
.79654 0 L
.7979 0 L
.79915 0 L
.80032 0 L
.8016 0 L
.80298 0 L
.80442 0 L
.80579 0 L
.80702 0 L
.80836 0 L
.80963 0 L
.81079 0 L
.81212 0 L
.81337 0 L
.8156 0 L
.81686 0 L
.81802 0 L
.81928 0 L
.82063 0 L
.82191 0 L
.82308 0 L
.82444 0 L
.82593 0 L
.82733 0 L
.82863 0 L
.82996 0 L
.83122 0 L
.83259 0 L
Mistroke
.83407 0 L
.83554 0 L
.83708 0 L
.8384 0 L
.83984 0 L
.84123 0 L
.84251 0 L
.84391 0 L
.8454 0 L
.84669 0 L
.84789 0 L
.84922 0 L
.85064 0 L
.8519 0 L
.85327 0 L
.85456 0 L
.85576 0 L
.85803 0 L
.8593 0 L
.86044 0 L
.86183 0 L
.86329 0 L
.86453 0 L
.8659 0 L
.86737 0 L
.86894 0 L
.87043 0 L
.87178 0 L
.87315 0 L
.87441 0 L
.8758 0 L
.87726 0 L
.87854 0 L
.87973 0 L
.88104 0 L
.88245 0 L
.88384 0 L
.88511 0 L
.88657 0 L
.88794 0 L
.88922 0 L
.89039 0 L
.89168 0 L
.89305 0 L
.89442 0 L
.8959 0 L
.89729 0 L
.89857 0 L
.90005 0 L
.90168 0 L
Mistroke
.90321 0 L
.90462 0 L
.90583 0 L
.90713 0 L
.90825 0 L
.90948 0 L
.91085 0 L
.91228 0 L
.91361 0 L
.91485 0 L
.91626 0 L
.9176 0 L
.9188 0 L
.9201 0 L
.92152 0 L
.92302 0 L
.9243 0 L
.92571 0 L
.92707 0 L
.92833 0 L
.92971 0 L
.93118 0 L
.93259 0 L
.93391 0 L
.93509 0 L
.93638 0 L
.93755 0 L
.93885 0 L
.9402 0 L
.94145 0 L
.94371 0 L
.94497 0 L
.94612 0 L
.94748 0 L
.94893 0 L
.95016 0 L
.95152 0 L
.95298 0 L
.95455 0 L
.95603 0 L
.95739 0 L
.95868 0 L
.95987 0 L
.96119 0 L
.96259 0 L
.96406 0 L
.96545 0 L
.9667 0 L
.96805 0 L
.9699 0 L
Mistroke
.97093 0 L
.97188 0 L
.97371 0 L
.97545 0 L
.97643 0 L
.97747 0 L
.97934 0 L
.98038 0 L
.98135 0 L
.98242 0 L
.98358 0 L
.98558 0 L
.98668 0 L
.9877 0 L
.98952 0 L
.99055 0 L
.99148 0 L
.99358 0 L
.99476 0 L
.99586 0 L
.99787 0 L
.99888 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00706 0 L
.00829 0 L
.00942 0 L
.01057 0 L
.01181 0 L
.01317 0 L
.01444 0 L
.01586 0 L
.01721 0 L
.01842 0 L
.01975 0 L
.02116 0 L
.02249 0 L
.02368 0 L
.02497 0 L
.02638 0 L
.02787 0 L
.02915 0 L
.03054 0 L
.03185 0 L
.03305 0 L
.03442 0 L
.03573 0 L
.03693 0 L
.03805 0 L
.03927 0 L
.04057 0 L
.04189 0 L
.04329 0 L
.04448 0 L
.04579 0 L
.0472 0 L
.0487 0 L
.05012 0 L
.05141 0 L
.05272 0 L
.05393 0 L
.05525 0 L
.05665 1e-05 L
.05787 1e-05 L
.05901 1e-05 L
.06025 1e-05 L
.0616 2e-05 L
.06314 2e-05 L
.06457 3e-05 L
Mistroke
.06615 4e-05 L
.06782 5e-05 L
.06942 7e-05 L
.07092 9e-05 L
.07227 .00012 L
.07373 .00016 L
.07507 .0002 L
.07654 .00027 L
.07807 .00037 L
.0795 .00048 L
.08084 .00062 L
.08206 .00079 L
.08347 .00104 L
.08481 .00134 L
.08601 .00169 L
.0873 .00217 L
.08964 .00339 L
.091 .00439 L
.09242 .00576 L
.09364 .00725 L
.09497 .0093 L
.09639 .01211 L
.09768 .01534 L
.09916 .02007 L
.10056 .02571 L
.10306 .03927 L
.10576 .05983 L
.11065 .10871 L
.11184 .12001 L
.11312 .13011 L
.11385 .13458 L
.11452 .13763 L
.11583 .14043 L
.11702 .13912 L
.11811 .13476 L
.11931 .12696 L
.12059 .11602 L
.12511 .07027 L
.1276 .04869 L
.13023 .03166 L
.13248 .02141 L
.13375 .01703 L
.13493 .01372 L
.13631 .01063 L
.13761 .00834 L
.1388 .00667 L
.14005 .00526 L
.14142 .00406 L
.14268 .00319 L
.14404 .00246 L
Mistroke
.14553 .00185 L
.14681 .00144 L
.14802 .00114 L
.1503 .00074 L
.15158 .00058 L
.15276 .00046 L
.15405 .00036 L
.15544 .00027 L
.15664 .00022 L
.15794 .00017 L
.15909 .00013 L
.1603 .00011 L
.1614 9e-05 L
.1626 7e-05 L
.16471 5e-05 L
.16609 3e-05 L
.16735 3e-05 L
.16875 2e-05 L
.17022 2e-05 L
.1715 1e-05 L
.1727 1e-05 L
.17402 1e-05 L
.17544 1e-05 L
.17663 0 L
.17793 0 L
.17928 0 L
.18054 0 L
.1828 0 L
.18407 0 L
.18521 0 L
.18659 0 L
.18804 0 L
.18928 0 L
.19064 0 L
.1921 0 L
.19368 0 L
.19516 0 L
.19652 0 L
.19788 0 L
.19913 0 L
.20052 0 L
.20199 0 L
.20339 0 L
.20471 0 L
.2059 0 L
.20718 0 L
.20849 0 L
.20969 0 L
.21106 0 L
.21237 0 L
Mistroke
.21349 0 L
.21468 0 L
.21599 0 L
.2172 0 L
.2185 0 L
.21989 0 L
.22121 0 L
.22242 0 L
.22383 0 L
.22537 0 L
.22682 0 L
.22817 0 L
.22956 0 L
.23106 0 L
.23248 0 L
.23379 0 L
.23497 0 L
.23627 0 L
.23762 0 L
.23889 0 L
.24037 0 L
.24177 0 L
.24303 0 L
.2444 0 L
.24589 0 L
.24747 0 L
.24882 0 L
.25031 0 L
.25159 0 L
.25277 0 L
.25408 0 L
.25547 0 L
.25693 0 L
.25831 0 L
.25955 0 L
.2609 0 L
.26207 0 L
.26335 0 L
.2647 0 L
.26595 0 L
.2682 0 L
.26946 0 L
.27061 0 L
.27196 0 L
.2734 0 L
.27476 0 L
.27599 0 L
.27744 0 L
.279 0 L
.28048 0 L
Mistroke
.28184 0 L
.28313 0 L
.28432 0 L
.28563 0 L
.28703 0 L
.28851 0 L
.2899 0 L
.29115 0 L
.29251 0 L
.29379 0 L
.29497 0 L
.29626 0 L
.29761 0 L
.29872 0 L
.2999 0 L
.3012 0 L
.3024 0 L
.30381 0 L
.30534 0 L
.30679 0 L
.30812 0 L
.30932 0 L
.31064 0 L
.31202 0 L
.3133 0 L
.31467 0 L
.31616 0 L
.31757 0 L
.31887 0 L
.32004 0 L
.32133 0 L
.32268 0 L
.32395 0 L
.32534 0 L
.32681 0 L
.32807 0 L
.32944 0 L
.33093 0 L
.33251 0 L
.33401 0 L
.33537 0 L
.33662 0 L
.33779 0 L
.33907 0 L
.34045 0 L
.34189 0 L
.34326 0 L
.34449 0 L
.34583 0 L
.3471 0 L
Mistroke
.34825 0 L
.34958 0 L
.35084 0 L
.35307 0 L
.35433 0 L
.35548 0 L
.35675 0 L
.3581 0 L
.35938 0 L
.36054 0 L
.36191 0 L
.3634 0 L
.3648 0 L
.3661 0 L
.36743 0 L
.36868 0 L
.37005 0 L
.37153 0 L
.373 0 L
.37455 0 L
.37586 0 L
.37731 0 L
.37869 0 L
.37997 0 L
.38137 0 L
.38286 0 L
.38415 0 L
.38535 0 L
.38668 0 L
.3881 0 L
.38936 0 L
.39073 0 L
.39202 0 L
.39322 0 L
.39549 0 L
.39676 0 L
.3979 0 L
.39929 0 L
.40074 0 L
.40199 0 L
.40335 0 L
.40483 0 L
.4064 0 L
.40789 0 L
.40924 0 L
.41061 0 L
.41187 0 L
.41325 0 L
.41472 0 L
.41599 0 L
Mistroke
.41719 0 L
.4185 0 L
.4199 0 L
.4213 0 L
.42256 0 L
.42402 0 L
.4254 0 L
.42667 0 L
.42785 0 L
.42914 0 L
.4305 0 L
.43188 0 L
.43335 0 L
.43475 0 L
.43602 0 L
.43751 0 L
.43913 0 L
.44066 0 L
.44208 0 L
.44328 0 L
.44458 0 L
.4457 0 L
.44693 0 L
.4483 0 L
.44973 0 L
.45106 0 L
.4523 0 L
.45371 0 L
.45505 0 L
.45625 0 L
.45755 0 L
.45897 0 L
.46047 0 L
.46175 0 L
.46316 0 L
.46452 0 L
.46578 0 L
.46716 0 L
.46863 0 L
.47003 0 L
.47135 0 L
.47254 0 L
.47382 0 L
.475 0 L
.47629 0 L
.47764 0 L
.4789 0 L
.48115 0 L
.48241 0 L
.48356 0 L
Mistroke
.48493 0 L
.48637 0 L
.4876 0 L
.48896 0 L
.49042 0 L
.49199 0 L
.49347 0 L
.49483 0 L
.49612 0 L
.49731 0 L
.49863 0 L
.50003 0 L
.5015 0 L
.50289 0 L
.50414 0 L
.50549 0 L
.50679 0 L
.50798 0 L
.50934 0 L
.51064 0 L
.51175 0 L
.51294 0 L
.51424 0 L
.51545 0 L
.51687 0 L
.51841 0 L
.51986 0 L
.52119 0 L
.5224 0 L
.52372 0 L
.5251 0 L
.52639 0 L
.52776 0 L
.52926 0 L
.53067 0 L
.53198 0 L
.53315 0 L
.53445 0 L
.5358 0 L
.53706 0 L
.53854 0 L
.53994 0 L
.5412 0 L
.54257 0 L
.54405 0 L
.54564 0 L
.54713 0 L
.54849 0 L
.54975 0 L
.55093 0 L
Mistroke
.55222 0 L
.55361 0 L
.55506 0 L
.55643 0 L
.55767 0 L
.55901 0 L
.56017 0 L
.56145 0 L
.56279 0 L
.56404 0 L
.56628 0 L
.56754 0 L
.56869 0 L
.56997 0 L
.57133 0 L
.57261 0 L
.57378 0 L
.57515 0 L
.57664 0 L
.57805 0 L
.57934 0 L
.58068 0 L
.58193 0 L
.58331 0 L
.58479 0 L
.58633 0 L
.5878 0 L
.58912 0 L
.59055 0 L
.59195 0 L
.59324 0 L
.59466 0 L
.59615 0 L
.59745 0 L
.59866 0 L
.59999 0 L
.60141 0 L
.60268 0 L
.60406 0 L
.60536 0 L
.60656 0 L
.60883 0 L
.60998 0 L
.61125 0 L
.61264 0 L
.61411 0 L
.61536 0 L
.61672 0 L
.6182 0 L
.61978 0 L
Mistroke
.62127 0 L
.62262 0 L
.62399 0 L
.62525 0 L
.62664 0 L
.62811 0 L
.62938 0 L
.63057 0 L
.63188 0 L
.63328 0 L
.63456 0 L
.63596 0 L
.63743 0 L
.63882 0 L
.6401 0 L
.64128 0 L
.64258 0 L
.64394 0 L
.64533 0 L
.64681 0 L
.64821 0 L
.64949 0 L
.65098 0 L
.6526 0 L
.65414 0 L
.65555 0 L
.65677 0 L
.65807 0 L
.6592 0 L
.66043 0 L
.66187 0 L
.66324 0 L
.66457 0 L
.66581 0 L
.66723 0 L
.66857 0 L
.66977 0 L
.67107 0 L
.67249 0 L
.67399 0 L
.67527 0 L
.67667 0 L
.67804 0 L
.67931 0 L
.6807 0 L
.68218 0 L
.68346 0 L
.68466 0 L
.68598 0 L
.68739 0 L
Mistroke
.68858 0 L
.68988 0 L
.69123 0 L
.69249 0 L
.69475 0 L
.69602 0 L
.69717 0 L
.69854 0 L
.69999 0 L
.70123 0 L
.70259 0 L
.70406 0 L
.70563 0 L
.70711 0 L
.70847 0 L
.70983 0 L
.71109 0 L
.71247 0 L
.71394 0 L
.71534 0 L
.71667 0 L
.71785 0 L
.71913 0 L
.72044 0 L
.72164 0 L
.72301 0 L
.72432 0 L
.72544 0 L
.72663 0 L
.72794 0 L
.72915 0 L
.73045 0 L
.73184 0 L
.73316 0 L
.73437 0 L
.73578 0 L
.73732 0 L
.73877 0 L
.74012 0 L
.74151 0 L
.74301 0 L
.74443 0 L
.74574 0 L
.74692 0 L
.74821 0 L
.74957 0 L
.75083 0 L
.75231 0 L
.75372 0 L
.75497 0 L
Mistroke
.75635 0 L
.75783 0 L
.75942 0 L
.76077 0 L
.76226 0 L
.76353 0 L
.76472 0 L
.76602 0 L
.76741 0 L
.76888 0 L
.77026 0 L
.7715 0 L
.77285 0 L
.77401 0 L
.7753 0 L
.77664 0 L
.7779 0 L
.78014 0 L
.78141 0 L
.78256 0 L
.78391 0 L
.78534 0 L
.7867 0 L
.78793 0 L
.78938 0 L
.79095 0 L
.79243 0 L
.79379 0 L
.79507 0 L
.79626 0 L
.79757 0 L
.79898 0 L
.80045 0 L
.80184 0 L
.80309 0 L
.80445 0 L
.80573 0 L
.80691 0 L
.8082 0 L
.80955 0 L
.81066 0 L
.81184 0 L
.81314 0 L
.81434 0 L
.81575 0 L
.81728 0 L
.81872 0 L
.82005 0 L
.82126 0 L
.82258 0 L
Mistroke
.82395 0 L
.82524 0 L
.82661 0 L
.8281 0 L
.8295 0 L
.83081 0 L
.83198 0 L
.83327 0 L
.83462 0 L
.83589 0 L
.83728 0 L
.83875 0 L
.84001 0 L
.84138 0 L
.84286 0 L
.84445 0 L
.84595 0 L
.84731 0 L
.84856 0 L
.84973 0 L
.85101 0 L
.85239 0 L
.85383 0 L
.85519 0 L
.85642 0 L
.85777 0 L
.85904 0 L
.86019 0 L
.86152 0 L
.86277 0 L
.865 0 L
.86626 0 L
.86742 0 L
.86868 0 L
.87003 0 L
.87131 0 L
.87248 0 L
.87384 0 L
.87533 0 L
.87673 0 L
.87803 0 L
.87936 0 L
.88061 0 L
.88199 0 L
.88347 0 L
.88493 0 L
.88648 0 L
.8878 0 L
.88924 0 L
.89063 0 L
Mistroke
.8919 0 L
.89331 0 L
.89479 0 L
.89608 0 L
.89729 0 L
.89861 0 L
.90003 0 L
.90129 0 L
.90266 0 L
.90395 0 L
.90515 0 L
.90742 0 L
.90869 0 L
.90983 0 L
.91122 0 L
.91267 0 L
.91392 0 L
.91528 0 L
.91675 0 L
.91833 0 L
.91981 0 L
.92117 0 L
.92253 0 L
.92379 0 L
.92518 0 L
.92665 0 L
.92792 0 L
.92911 0 L
.93042 0 L
.93183 0 L
.93316 0 L
.93436 0 L
.93575 0 L
.93706 0 L
.93819 0 L
.93939 0 L
.9407 0 L
.94191 0 L
.94322 0 L
.94462 0 L
.94595 0 L
.94716 0 L
.94857 0 L
.95011 0 L
.95157 0 L
.95292 0 L
.95418 0 L
.95555 0 L
.95684 0 L
.95802 0 L
Mistroke
.95933 0 L
.96077 0 L
.96227 0 L
.96366 0 L
.96515 0 L
.96655 0 L
.96782 0 L
.96918 0 L
.97067 0 L
.97225 0 L
.9736 0 L
.97509 0 L
.97662 0 L
.9783 0 L
.97989 0 L
.98136 0 L
.98281 0 L
.98413 0 L
.98566 0 L
.98709 0 L
.98866 0 L
.99032 0 L
.99174 0 L
.99329 0 L
.99497 0 L
.99676 0 L
.99846 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00706 0 L
.00829 0 L
.00942 0 L
.01057 0 L
.01181 0 L
.01317 0 L
.01444 0 L
.01586 0 L
.01721 0 L
.01842 0 L
.01975 0 L
.02116 0 L
.02249 0 L
.02368 0 L
.02497 0 L
.02638 0 L
.02787 0 L
.02915 0 L
.03054 0 L
.03185 0 L
.03305 1e-05 L
.03442 1e-05 L
.03573 1e-05 L
.03693 1e-05 L
.03805 2e-05 L
.03927 2e-05 L
.04057 3e-05 L
.04189 3e-05 L
.04329 5e-05 L
.04448 6e-05 L
.04579 7e-05 L
.0472 .0001 L
.0487 .00013 L
.05012 .00017 L
.05141 .00022 L
.05272 .00028 L
.05393 .00036 L
.05525 .00046 L
.05665 .0006 L
.05787 .00076 L
.05901 .00095 L
.06025 .00121 L
.0616 .00156 L
.06314 .0021 L
.06457 .00276 L
Mistroke
.06615 .00373 L
.06782 .00513 L
.06942 .00695 L
.07092 .00921 L
.07227 .01184 L
.07373 .01548 L
.07507 .01973 L
.07654 .0256 L
.07797 .03276 L
.0795 .04223 L
.08225 .06425 L
.08481 .08965 L
.08751 .11698 L
.08887 .12836 L
.08965 .13344 L
.09038 .13705 L
.09167 .14032 L
.09285 .13951 L
.09415 .13455 L
.09552 .12538 L
.10155 .06611 L
.10449 .04231 L
.10577 .03425 L
.10715 .02702 L
.10846 .02146 L
.10967 .01728 L
.11204 .01118 L
.11325 .00893 L
.11458 .00696 L
.11596 .00535 L
.11726 .00418 L
.11869 .00319 L
.12004 .00246 L
.12126 .00195 L
.12258 .00151 L
.12402 .00114 L
.12555 .00085 L
.12685 .00066 L
.12829 .0005 L
.12957 .00039 L
.13075 .00031 L
.13205 .00024 L
.13344 .00019 L
.13491 .00014 L
.13629 .00011 L
.13753 8e-05 L
.13887 6e-05 L
.14004 5e-05 L
.14132 4e-05 L
.14267 3e-05 L
Mistroke
.14392 2e-05 L
.14617 2e-05 L
.14743 1e-05 L
.14858 1e-05 L
.14993 1e-05 L
.15137 1e-05 L
.15272 0 L
.15395 0 L
.1554 0 L
.15697 0 L
.15845 0 L
.15981 0 L
.16109 0 L
.16228 0 L
.16359 0 L
.16499 0 L
.16647 0 L
.16786 0 L
.16911 0 L
.17047 0 L
.17175 0 L
.17293 0 L
.17421 0 L
.17557 0 L
.17667 0 L
.17785 0 L
.17915 0 L
.18035 0 L
.18176 0 L
.18329 0 L
.18473 0 L
.18606 0 L
.18726 0 L
.18858 0 L
.18996 0 L
.19125 0 L
.19262 0 L
.1941 0 L
.19551 0 L
.19681 0 L
.1981 0 L
.19927 0 L
.20062 0 L
.20189 0 L
.20328 0 L
.20475 0 L
.20601 0 L
.20738 0 L
.20887 0 L
.21045 0 L
Mistroke
.21195 0 L
.21331 0 L
.21456 0 L
.21573 0 L
.21701 0 L
.21838 0 L
.21982 0 L
.22119 0 L
.22242 0 L
.22376 0 L
.22503 0 L
.22618 0 L
.22751 0 L
.22876 0 L
.23099 0 L
.23225 0 L
.23341 0 L
.23467 0 L
.23602 0 L
.2373 0 L
.23847 0 L
.23983 0 L
.24132 0 L
.24272 0 L
.24402 0 L
.24535 0 L
.2466 0 L
.24797 0 L
.24945 0 L
.25092 0 L
.25246 0 L
.25378 0 L
.25523 0 L
.25661 0 L
.25789 0 L
.25929 0 L
.26077 0 L
.26206 0 L
.26327 0 L
.26459 0 L
.26601 0 L
.26727 0 L
.26864 0 L
.26993 0 L
.27113 0 L
.2734 0 L
.27466 0 L
.27581 0 L
.27719 0 L
.27865 0 L
Mistroke
.27989 0 L
.28126 0 L
.28273 0 L
.2843 0 L
.28579 0 L
.28714 0 L
.2885 0 L
.28977 0 L
.29115 0 L
.29262 0 L
.29389 0 L
.29508 0 L
.29639 0 L
.2978 0 L
.29913 0 L
.30033 0 L
.30171 0 L
.30302 0 L
.30415 0 L
.30535 0 L
.30666 0 L
.30787 0 L
.30918 0 L
.31058 0 L
.31191 0 L
.31312 0 L
.31453 0 L
.31607 0 L
.31753 0 L
.31888 0 L
.32014 0 L
.32151 0 L
.3228 0 L
.32398 0 L
.32529 0 L
.32673 0 L
.32822 0 L
.32962 0 L
.3311 0 L
.33251 0 L
.33377 0 L
.33514 0 L
.33663 0 L
.33821 0 L
.33956 0 L
.34104 0 L
.3424 0 L
.34365 0 L
.34503 0 L
.3465 0 L
Mistroke
.3479 0 L
.34922 0 L
.35041 0 L
.35169 0 L
.35287 0 L
.35416 0 L
.3555 0 L
.35676 0 L
.35901 0 L
.36028 0 L
.36143 0 L
.36279 0 L
.36423 0 L
.36546 0 L
.36682 0 L
.36828 0 L
.36985 0 L
.37133 0 L
.37269 0 L
.37397 0 L
.37517 0 L
.37648 0 L
.37788 0 L
.37936 0 L
.38075 0 L
.382 0 L
.38335 0 L
.38465 0 L
.38583 0 L
.38719 0 L
.38849 0 L
.3896 0 L
.39079 0 L
.39209 0 L
.39329 0 L
.39472 0 L
.39625 0 L
.3977 0 L
.39903 0 L
.40024 0 L
.40156 0 L
.40294 0 L
.40423 0 L
.4056 0 L
.4071 0 L
.40851 0 L
.40981 0 L
.41099 0 L
.41228 0 L
.41363 0 L
Mistroke
.4149 0 L
.41637 0 L
.41777 0 L
.41903 0 L
.4204 0 L
.42189 0 L
.42347 0 L
.42497 0 L
.42633 0 L
.42758 0 L
.42876 0 L
.43005 0 L
.43144 0 L
.43289 0 L
.43426 0 L
.43549 0 L
.43684 0 L
.43799 0 L
.43927 0 L
.44061 0 L
.44186 0 L
.4441 0 L
.44536 0 L
.44652 0 L
.44779 0 L
.44915 0 L
.45043 0 L
.4516 0 L
.45297 0 L
.45446 0 L
.45586 0 L
.45716 0 L
.4585 0 L
.45975 0 L
.46112 0 L
.4626 0 L
.46415 0 L
.46561 0 L
.46693 0 L
.46837 0 L
.46977 0 L
.47105 0 L
.47247 0 L
.47396 0 L
.47525 0 L
.47647 0 L
.47779 0 L
.47922 0 L
.48048 0 L
.48186 0 L
Mistroke
.48316 0 L
.48436 0 L
.48663 0 L
.48778 0 L
.48905 0 L
.49044 0 L
.4919 0 L
.49315 0 L
.49452 0 L
.496 0 L
.49757 0 L
.49906 0 L
.50041 0 L
.50178 0 L
.50305 0 L
.50443 0 L
.5059 0 L
.50717 0 L
.50837 0 L
.50967 0 L
.51108 0 L
.51248 0 L
.51375 0 L
.51522 0 L
.5166 0 L
.51789 0 L
.51907 0 L
.52036 0 L
.52173 0 L
.52311 0 L
.52459 0 L
.52599 0 L
.52727 0 L
.52876 0 L
.53038 0 L
.53192 0 L
.53333 0 L
.53454 0 L
.53585 0 L
.53698 0 L
.53821 0 L
.53965 0 L
.54101 0 L
.54234 0 L
.54358 0 L
.545 0 L
.54634 0 L
.54754 0 L
.54884 0 L
.55026 0 L
Mistroke
.55176 0 L
.55304 0 L
.55445 0 L
.55581 0 L
.55708 0 L
.55847 0 L
.55995 0 L
.56122 0 L
.56242 0 L
.56374 0 L
.56516 0 L
.56634 0 L
.56764 0 L
.56899 0 L
.57025 0 L
.57251 0 L
.57378 0 L
.57493 0 L
.5763 0 L
.57775 0 L
.57898 0 L
.58035 0 L
.58181 0 L
.58338 0 L
.58487 0 L
.58622 0 L
.58758 0 L
.58884 0 L
.59022 0 L
.59169 0 L
.5931 0 L
.59442 0 L
.5956 0 L
.59689 0 L
.59819 0 L
.59939 0 L
.60076 0 L
.60206 0 L
.60319 0 L
.60438 0 L
.60568 0 L
.60689 0 L
.60819 0 L
.60958 0 L
.6109 0 L
.61211 0 L
.61345 0 L
.61491 0 L
.61644 0 L
.61786 0 L
Mistroke
.61925 0 L
.62075 0 L
.62217 0 L
.62347 0 L
.62465 0 L
.62595 0 L
.6273 0 L
.62856 0 L
.63004 0 L
.63145 0 L
.6327 0 L
.63408 0 L
.63556 0 L
.63715 0 L
.6385 0 L
.63999 0 L
.64126 0 L
.64245 0 L
.64375 0 L
.64514 0 L
.6466 0 L
.64798 0 L
.64922 0 L
.65057 0 L
.65173 0 L
.65302 0 L
.65436 0 L
.65562 0 L
.65786 0 L
.65912 0 L
.66027 0 L
.66162 0 L
.66306 0 L
.66441 0 L
.66564 0 L
.66709 0 L
.66866 0 L
.67014 0 L
.6715 0 L
.67278 0 L
.67397 0 L
.67528 0 L
.67669 0 L
.67816 0 L
.67955 0 L
.6808 0 L
.68216 0 L
.68344 0 L
.68462 0 L
.6859 0 L
Mistroke
.68726 0 L
.68836 0 L
.68954 0 L
.69084 0 L
.69204 0 L
.69345 0 L
.69498 0 L
.69642 0 L
.69775 0 L
.69895 0 L
.70027 0 L
.70165 0 L
.70294 0 L
.7043 0 L
.70579 0 L
.7072 0 L
.7085 0 L
.70979 0 L
.71096 0 L
.71231 0 L
.71358 0 L
.71497 0 L
.71644 0 L
.71769 0 L
.71907 0 L
.72055 0 L
.72214 0 L
.72364 0 L
.725 0 L
.72625 0 L
.72741 0 L
.72869 0 L
.73007 0 L
.73151 0 L
.73288 0 L
.7341 0 L
.73544 0 L
.73671 0 L
.73787 0 L
.73919 0 L
.74045 0 L
.74268 0 L
.74393 0 L
.74509 0 L
.74635 0 L
.74771 0 L
.74898 0 L
.75015 0 L
.75151 0 L
.753 0 L
Mistroke
.7544 0 L
.7557 0 L
.75703 0 L
.75828 0 L
.75965 0 L
.76113 0 L
.7626 0 L
.76415 0 L
.76546 0 L
.76691 0 L
.76829 0 L
.76957 0 L
.77097 0 L
.77245 0 L
.77374 0 L
.77495 0 L
.77627 0 L
.77769 0 L
.77894 0 L
.78031 0 L
.78161 0 L
.78281 0 L
.78507 0 L
.78634 0 L
.78749 0 L
.78887 0 L
.79032 0 L
.79157 0 L
.79293 0 L
.7944 0 L
.79598 0 L
.79746 0 L
.79882 0 L
.80018 0 L
.80144 0 L
.80283 0 L
.80429 0 L
.80557 0 L
.80676 0 L
.80807 0 L
.80948 0 L
.8108 0 L
.812 0 L
.81339 0 L
.8147 0 L
.81583 0 L
.81703 0 L
.81834 0 L
.81955 0 L
.82085 0 L
Mistroke
.82226 0 L
.82358 0 L
.82479 0 L
.8262 0 L
.82775 0 L
.8292 0 L
.83055 0 L
.83181 0 L
.83318 0 L
.83447 0 L
.83565 0 L
.83696 0 L
.8384 0 L
.83989 0 L
.84129 0 L
.84278 0 L
.84418 0 L
.84544 0 L
.84681 0 L
.8483 0 L
.84988 0 L
.85123 0 L
.85271 0 L
.85407 0 L
.85532 0 L
.8567 0 L
.85817 0 L
.85957 0 L
.86089 0 L
.86208 0 L
.86336 0 L
.86453 0 L
.86582 0 L
.86717 0 L
.86843 0 L
.87068 0 L
.87194 0 L
.8731 0 L
.87445 0 L
.8759 0 L
.87713 0 L
.87849 0 L
.87994 0 L
.88151 0 L
.883 0 L
.88435 0 L
.88564 0 L
.88684 0 L
.88815 0 L
.88955 0 L
Mistroke
.89102 0 L
.89242 0 L
.89366 0 L
.89502 0 L
.89631 0 L
.89749 0 L
.89886 0 L
.90015 0 L
.90127 0 L
.90245 0 L
.90375 0 L
.90496 0 L
.90638 0 L
.90791 0 L
.90936 0 L
.9107 0 L
.9119 0 L
.91322 0 L
.9146 0 L
.91589 0 L
.91727 0 L
.91876 0 L
.92017 0 L
.92148 0 L
.92265 0 L
.92394 0 L
.9253 0 L
.92656 0 L
.92796 0 L
.92943 0 L
.93069 0 L
.93206 0 L
.93355 0 L
.93513 0 L
.93663 0 L
.93799 0 L
.93925 0 L
.94042 0 L
.94171 0 L
.9431 0 L
.94455 0 L
.94592 0 L
.94715 0 L
.9485 0 L
.94965 0 L
.95093 0 L
.95227 0 L
.95352 0 L
.95576 0 L
.95702 0 L
Mistroke
.95817 0 L
.95944 0 L
.9608 0 L
.96209 0 L
.96325 0 L
.96462 0 L
.96611 0 L
.96752 0 L
.96881 0 L
.97015 0 L
.97141 0 L
.97278 0 L
.97426 0 L
.9758 0 L
.97727 0 L
.97859 0 L
.98003 0 L
.98128 0 L
.98264 0 L
.98392 0 L
.9851 0 L
.98734 0 L
.98846 0 L
.9897 0 L
.99104 0 L
.99227 0 L
.99369 0 L
.99503 0 L
.99626 0 L
.99741 0 L
.99867 0 L
1 0 L
Mfstroke
gsave
.894 .53376 -68.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t1g) show
73.187500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.688 .53376 -68.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t1u) show
73.187500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.35 .53376 -67 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(hu) show
71.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.136 .53376 -67 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(hg) show
71.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.072 .53376 -67 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(gg) show
71.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.01 w
.894 .44948 m
.894 .50566 L
s
.688 .44948 m
.688 .50566 L
s
.35 .44948 m
.35 .50566 L
s
.116 .44948 m
.116 .50566 L
s
.092 .44948 m
.092 .50566 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0000fQ000`40l00?003`ooooH_oo003ooomR
ool00;_oo`<03`03ool03ooo0:3oo`00^ooo00<03ooo00l00_oo00<03oooool0W_oo002/ool500l0
1?oo00oooooo0P0?00?oo`0?ool00_oo00D03oooooooo`0?00Coo`0500ooo`0?ool03`04ool200l0
0ooo00l03`2>ool00:goo`0800oooooo00ooo`0?ool03`?oo`0:00oooooo00ooo`0?ool03ooo00l3
ool01@0?ool03ooo00l00ooo00@03oooooooo`803hkoo`00[Ooo0P0?00Woo`0?ool03ooo00ooo`0?
ool00P0?00Soo`0?ool03ooo00ooo`0?0ooo00D03ooo00ooo`0?00?oo`0400ooo`0?00l2ool00`0?
ooooo`2;ool00:goo`0300oooooo00803`?oo`803`05ool03ooo00ooo`0200l01?oo00ooo`0?0ooo
00@03ooo00l03`Goo`<03`;oo`0300oooooo08_oo`00[?oo100?8?oo00@03oooool03hgoo`00aOoo
00<03oooool0VOoo003ooomRool00?ooof;oo`00ooooH_oo003ooomRool00?ooof;oo`00ooooH_oo
0017ool300ljool300liool00`0?ooooo`0iool300lkool300lTool004Ooo`0300oooooo03_oo`03
00oooooo03Ooo`0300ooo`0?03_oo`0300oooooo03[oo`0300oooooo02Coo`00@_oo0`0?0ooo00<0
3oooool0=Ooo0`0?0_oo00<03oooool0=ooo00<03ooo00l0>ooo00<03oooool0>ooo00<03oooool0
8ooo0017ool00`0?ool03`0kool00`0?ooooo`0gool00`0?ool03`0kool00`0?ooooo`0jool00`0?
ool03`0Tool004Soo`803c[oo`803c[oo`0300oooooo03Woo`803cgoo`803bCoo`00ooooH_oo003o
oomRool00?ooof;oo`00ooooH_oo003ooomRool00?ooof;oo`00ooooH_oo000Woooo00le00l6ool0
02Ooo`0300oooooo00?oo`0300oooooo00[oo`<03`Goo`803`;oo`0300oooooo00;oo`803`Goo`80
3`[oo`0300oooooo00[oo`0300oooooo00Woo`0300oooooo00Woo`0300oooooo00Coo`803`?oo`03
00oooooo00Soo`<03`_oo`803`03ool03ooo00Ooo`0300ooo`0?00D03`Goo`0300oooooo00Woo`<0
3`;oo`0800oooooo00ooo`0?ool03`Soo`803`03ool03ooo00_oo`803`[oo`0400ooooooool200l6
ool00`0?ooooo`09ool00`0?ooooo`0:ool00`0?ooooo`09ool0100?ool03`0?2?oo00<03oooool0
0ooo0P0?1Ooo00<03oooool02Ooo00<03oooool00ooo00<03oooool01?oo000Wool00`0?ooooo`0B
ool00`0?ooooo`04ool200l00ooo00ooo`02ool00`0?ooooo`04ool200l`ool00`0?ooooo`06ool0
0`0?ooooo`0:ool200l=ool0100?oooooooo0P0?1?oo0P0?3Ooo00<03oooool03ooo0`0?00?oo`0?
ool02Ooo00<03ooo00l03_oo0P0?2Ooo00@03oooool03c3oo`803`Ooo`0300oooooo00;oo`0300oo
oooo01Ooo`0300oooooo00Coo`009ooo00<03oooool04ooo00<03oooool01?oo00<03ooo08l00ooo
00<03oooool01?oo00<03oooool0;ooo00<0Ooooool01_oo00<03oooool02_oo00<03oooool03?oo
00<03oooool00ooo100?3ooo00<03oooool04ooo00<03oooool01ooo00@03oooool03`ooo`0300oo
oooo00Ooo`0308ooo`0?03;oo`0300oooooo00Goo`0307oooooo00;oo`0300oooooo01Ooo`0300oo
oooo00Coo`009ooo00<03oooool05?oo00<03oooool01?oo00D03`1oooooo`0?00Ooo`0300oooooo
02ooo`0308oooooo00Ooo`0300oooooo00Soo`803`goo`0300oooooo01Ooo`0300oooooo01Coo`03
00oooooo00Goo`0300oooooo00;oo`0300oooooo00coo`0300oooooo00Ooo`0307ooo`0?03?oo`03
00oooooo00Coo`0508ooooooool03`0Jool00`0?ooooo`04ool002Ooo`0300oooooo01Coo`0300oo
oooo00Coo`0500l0Soooool03`06ool00`0?ooooo`0`ool00`1oooooo`07ool00`0?ooooo`08ool0
0`0?ooooo`0<ool00`0?ooooo`0Gool00`0?ooooo`0Dool00`0?ooooo`05ool00`0?ooooo`02ool0
0`0?ooooo`0=ool00`0?ooooo`06ool00`2?ool03`0cool00`0?ooooo`04ool01@1ooooooooo00l0
6_oo00<03oooool01?oo000Wool00`0?ooooo`0Dool00`0?ooooo`05ool00`0?ool03`07ool00`0?
ooooo`0`ool00`2?ooooo`07ool00`0?ooooo`08ool00`0?ooooo`0<ool00`0?ooooo`0Gool00`0?
ooooo`0Eool00`0?ooooo`03ool00`0?ooooo`03ool00`0?ooooo`0=ool00`0?ooooo`06ool00`1o
00ooo`0cool00`0?ooooo`04ool01@2?oooooooo00l06_oo00<03oooool01?oo000Wool00`0?oooo
o`0Dool00`0?ooooo`05ool00`0?ool03`07ool00`0?ooooo`0`ool00`1oooooo`08ool00`0?oooo
o`06ool00`0?ooooo`0<ool00`0?ooooo`0Hool00`0?ooooo`0Eool00`0?ooooo`02ool00`0?oooo
o`05ool00`0?ooooo`0<ool00`0?ooooo`06ool00`2?00ooo`0Lool00`0?ooooo`0Eool00`0?oooo
o`03ool0101oooooo`0?6ooo00<03oooool01?oo000Wool200lFool00`0?ooooo`04ool00`0?ool0
3`06ool00`0?ooooo`0aool00`2?ooooo`08ool00`0?ooooo`06ool00`0?ooooo`0<ool00`0?oooo
o`0Hool00`0?ooooo`0Fool0100?ooooo`0?2?oo00<03oooool03Ooo00<03oooool01Ooo00<0O`0?
ool06_oo0P0?00?oo`0?00l05Ooo00<03oooool00ooo00@0Soooool03a[oo`803`Koo`009ooo00<0
3oooool05Ooo00<03oooool01?oo00<03ooo00l01_oo00<03oooool0<Ooo00<0Ooooool02?oo00<0
3oooool01_oo00<03oooool03?oo00<03oooool06?oo00<03oooool05_oo100?2?oo00<03oooool0
3Ooo00<03oooool01Ooo00<0S`0?ool06Ooo00<03oooool00ooo00<03oooool04_oo00<03oooool0
0ooo00@0Ooooool03a_oo`0300oooooo00Coo`009ooo00<03oooool05Ooo00<03oooool01?oo00<0
3ooo00l01_oo00<03oooool0<Ooo00<0Soooool02?oo00<03oooool01_oo00<03oooool02ooo00<0
3oooool06Ooo00<03oooool06?oo00<03oooool01ooo00<03oooool03Ooo00<03oooool01Ooo00<0
O`0?ool06Ooo00<03oooool00ooo00<03oooool04_oo00<03oooool00ooo00@0Soooool03a_oo`03
00oooooo00Coo`009ooo00<03oooool05Ooo00<03oooool01?oo00<0S`0?ool01_oo00<03oooool0
<Ooo00<0Ooooool02?oo00<03oooool01_oo00<03oooool02ooo00<03oooool06Ooo00<03oooool0
8ooo00<03oooool03?oo00<03oooool01Ooo00<03oooool06?oo00<03oooool01Ooo00<03oooool0
4Ooo00<03oooool00ooo00@0Ooooool03a_oo`0300oooooo00Coo`009ooo00<03oooool05Ooo00<0
3oooool01?oo00<0O`0?ool01_oo00<03oooool0<Ooo00<0Soooool02Ooo00<03oooool01Ooo00<0
3oooool02_oo00<03oooool06_oo00<03oooool08ooo00<03oooool03?oo00<03oooool01Ooo00<0
3oooool05ooo00<03oooool01_oo00<03oooool04_oo00<03oooool00_oo00<0Sooo00l07?oo00<0
3oooool01?oo000Wool00`0?ooooo`0Fool00`0?ooooo`03ool00`2?00ooo`06ool00`0?ooooo`0a
ool00`1oooooo`09ool00`0?ooooo`04ool00`0?ooooo`0:ool00`0?ooooo`0Kool00`0?ooooo`0S
ool00`0?ooooo`0<ool00`0?ooooo`05ool00`0?ooooo`0Gool00`0?ooooo`07ool00`0?ooooo`0A
ool00`0?ooooo`02ool00`1oool03`0Lool00`0?ooooo`04ool002Ooo`0300oooooo01Koo`0300oo
oooo00?oo`0307l03ooo00Goo`0300oooooo03;oo`0308oooooo00Woo`0300oooooo00Coo`0300oo
oooo00Soo`803akoo`0300oooooo02?oo`0300oooooo00goo`0300oooooo00Coo`0300oooooo01Ko
o`0300oooooo00Soo`0300oooooo017oo`0300oooooo00;oo`0308ooo`0?01coo`0300oooooo00Co
o`009ooo00<03oooool05_oo00<03oooool00ooo00<0S`0?ool01Ooo00<03oooool0<_oo00<0Oooo
ool02Ooo00<03oooool01?oo00<03oooool01ooo00<03oooool07_oo00<03oooool09?oo00<03ooo
ool03?oo00<03oooool01?oo00<03oooool05_oo00<03oooool02?oo00<03oooool04Ooo00<03ooo
ool00_oo00<0Oooo00l07?oo00<03oooool01?oo000Wool00`0?ooooo`0Fool00`0?ooooo`03ool0
0`1o00ooo`05ool00`0?ooooo`0bool00`2?ooooo`09ool00`0?ooooo`04ool00`0?ooooo`06ool0
0`0?ooooo`0Oool00`0?ooooo`0Tool00`0?ooooo`0<ool00`0?ooooo`04ool00`0?ooooo`0Eool0
0`0?ooooo`0:ool00`0?ooooo`0@ool00`0?ooooo`02ool00`2?ool03`0Lool00`0?ooooo`04ool0
02Ooo`803aOoo`0300oooooo00?oo`0308l03ooo00Goo`0300oooooo03;oo`0307oooooo00Woo`03
00oooooo00Coo`0300oooooo00Koo`0300oooooo01ooo`0300oooooo02Coo`0300oooooo00coo`03
00oooooo00?oo`0300l0Sooo01Koo`0300oooooo00[oo`0300oooooo013oo`0300oooooo00;oo`03
07ooo`0?01_oo`803`Koo`009ooo00<03oooool05_oo00<03oooool00ooo00<0O`0?00l01Ooo00<0
3oooool0<_oo00<0Soooool02Ooo00<03oooool01?oo00<03oooool01_oo00<03oooool07ooo00<0
3oooool09?oo00<03oooool03?oo00<03oooool00ooo00<03`1oool05Ooo00<03oooool02ooo00<0
3oooool04?oo00<03oooool00_oo00<0Sooo00l07?oo00<03oooool01?oo000Wool00`0?ooooo`0F
ool00`0?ooooo`03ool00`0?ool03`05ool00`0?ooooo`0bool00`1oooooo`09ool00`0?ooooo`04
ool00`0?ooooo`05ool00`0?ooooo`0Pool00`0?ooooo`0Uool00`0?ooooo`0;ool00`0?ooooo`03
ool00`0?08ooo`0Eool00`0?ooooo`0;ool00`0?ooooo`0@ool00`0?ooooo`02ool00`1oool03`0L
ool00`0?ooooo`04ool002Ooo`0300oooooo01Koo`0300oooooo00?oo`0300ooo`0?00Goo`0300oo
oooo03;oo`0308oooooo00[oo`0300oooooo00;oo`0300oooooo00Koo`0300oooooo023oo`0300oo
oooo02Goo`0300oooooo00_oo`0300oooooo00?oo`0300l0Oooo01Coo`0300oooooo00goo`0300oo
oooo00ooo`0300oooooo00;oo`0308l03ooo01coo`0300oooooo00Coo`009ooo00<03oooool05ooo
00<03oooool00_oo00<03ooo00l01Ooo00<03oooool0<_oo00<0Ooooool02_oo00<03oooool00_oo
00<03oooool01_oo00<03oooool08?oo00<03oooool09Ooo00<03oooool02ooo00<03oooool00ooo
00<03`2?ool05?oo00<03oooool03Ooo00<03oooool04?oo00H03oooooooo`1o00lMool00`0?oooo
o`04ool002Ooo`0300oooooo01Ooo`0300oooooo00;oo`0300ooo`0?00Coo`0300oooooo00?oo`@0
3bcoo`0308oooooo00[oo`0300oooooo00;oo`0300oooooo00Goo`0300oooooo027oo`0300oooooo
02Goo`0300oooooo00coo`0300oooooo00;oo`0300l0Oooo01?oo`0300oooooo00koo`0300oooooo
013oo`0600ooooooool0S`0?7Ooo00<03oooool01?oo000Wool00`0?ooooo`0Gool00`0?ooooo`02
ool00`0?ool03`04ool00`0?ooooo`02ool00`0?ooooo`02ool200lZool00`1oooooo`0:ool00`0?
ooooo`02ool00`0?ooooo`05ool00`0?ooooo`0Qool00`0?ooooo`0Vool00`0?ooooo`0;ool00`0?
ooooo`02ool00`0?08ooo`0Cool00`0?ooooo`0>ool00`0?ooooo`0@ool01P0?oooooooo07l03ago
o`0300oooooo00Coo`009ooo00<03oooool05ooo00<03oooool00_oo00<03ooo00l01?oo00D03ooo
ooooo`0?00Koo`0300oooooo02Soo`0308oooooo00[oo`0300oooooo00;oo`0300oooooo00Goo`03
00oooooo027oo`0300oooooo02Koo`0300oooooo00_oo`0300oooooo00;oo`0300l0Oooo01?oo`03
00oooooo00koo`0300oooooo013oo`0600ooooooool0S`0?7Ooo00<03oooool01?oo000Wool00`0?
ooooo`0Gool00`0?ooooo`02ool00`0?ool03`04ool0100?ooooo`0?2?oo00<03oooool04ooo1@0?
3ooo00<0Ooooool02_oo00<03oooool00_oo00<03oooool01Ooo00<03oooool08Ooo00<03oooool0
9_oo0P0?00?oo`0?00l00P0?1ooo00<03oooool00_oo00<03`2?ool04_oo00<03oooool04?oo00<0
3oooool03ooo00H03oooooooo`1o00lMool00`0?ooooo`04ool002Ooo`803aSoo`0300oooooo00;o
o`0300ooo`0?00Coo`0400oooooo00l9ool00`0?ooooo`0Aool00`0?ooooo`03ool00`0?ooooo`0<
ool00`2?ooooo`0:ool00`0?ooooo`02ool00`0?ooooo`05ool00`0?ooooo`0Qool00`0?ooooo`0X
ool00`0?ooooo`02ool00`0?ooooo`04ool00`0?ooooo`02ool00`0?07ooo`0Bool00`0?ooooo`0@
ool00`0?ooooo`0?ool01P0?oooooooo08l03acoo`803`Koo`009ooo00<03oooool05ooo00<03ooo
ool00_oo00<03ooo00l01?oo00<03ooo00l02_oo0P0?4Ooo00<03oooool01Ooo00<03oooool02ooo
00<0Ooooool02_oo00<03oooool00_oo00<03oooool01?oo00<03oooool08_oo00<03oooool0;Ooo
00<03oooool01?oo00L03oooooooo`0?ool0S`0Cool00`0?ooooo`0@ool00`0?ooooo`0?ool01P0?
oooooooo07l03agoo`0300oooooo00Coo`009ooo00<03oooool05ooo00H03oooooooo`0?07l2ool0
1`0?oooooooo00ooo`0?00_oo`0300oooooo00koo`0300oooooo00Ooo`0300oooooo00[oo`0308oo
oooo00[oo`0300oooooo00;oo`0300oooooo00Coo`0300oooooo02;oo`0300oooooo02koo`0300oo
oooo00?oo`0700ooooooool03ooo07l04_oo00<03oooool04Ooo00<03oooool03ooo00H03ooooooo
o`2?00lMool00`0?ooooo`04ool002Ooo`0300oooooo01Ooo`0600ooooooool03`2?0_oo00@03ooo
ooooo`803`goo`0300oooooo00coo`0300oooooo00Soo`0300oooooo00[oo`0307oooooo00_oo`05
00ooooooool03`06ool00`0?ooooo`0Rool00`0?ooooo`0^ool00`0?ooooo`03ool01`0?oooooooo
00ooo`2?01;oo`0300oooooo017oo`0300oooooo00ooo`0500ooooooool03`0Nool00`0?ooooo`04
ool002Ooo`0300oooooo01Ooo`0600ooooooool03`1o0_oo00@03oooooooo`803`koo`0300oooooo
00[oo`0300oooooo00[oo`0300oooooo00Woo`0308oooooo00_oo`0400oooooo00l7ool00`0?oooo
o`0Rool00`0?ooooo`0_ool00`0?ooooo`02ool01`0?oooooooo00ooo`1o01;oo`0300oooooo017o
o`0300oooooo013oo`0400oooooo00lNool00`0?ooooo`04ool002Ooo`0300oooooo01Soo`0500oo
oooo00l0S`02ool01@0?oooooooo00l03ooo00<03oooool02_oo00<03oooool02_oo00<03oooool0
2Ooo00<0Ooooool02ooo00@03oooool03`Ooo`0300oooooo02;oo`0300oooooo02ooo`0300oooooo
00;oo`0700ooooooool03ooo08l04Ooo00<03oooool04ooo00<03oooool03ooo00@03oooool03ako
o`0300oooooo00Coo`006_oo0`0?0_oo00<03oooool01Ooo00<03oooool06?oo00D03oooool03`1o
00;oo`0300oooooo00803a3oo`0300oooooo00Soo`0300oooooo00coo`0300oooooo00Soo`0308oo
oooo00_oo`0400oooooo00l7ool00`0?ooooo`0Rool00`0?ooooo`0_ool00`0?ooooo`03ool01P0?
ooooo`0?ool0Oa7oo`0300oooooo01?oo`0300oooooo00ooo`0400oooooo00lNool00`0?ooooo`04
ool001[oo`0700ooooooool03ooo00l01_oo00<03oooool06?oo00D03oooool03`2?00;oo`0300oo
oooo00803a7oo`0300oooooo00Koo`0300oooooo00goo`0300oooooo00Soo`0307oooooo00_oo`04
00oooooo00l7ool00`0?ooooo`0Rool00`0?ooooo`0_ool00`0?ooooo`03ool01P0?ooooo`0?ool0
Sa7oo`0300oooooo01?oo`0300oooooo00ooo`0400oooooo00lNool00`0?ooooo`04ool001_oo`06
00oooooo00ooo`0?1_oo0`0?0?l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l03`2?07l03`1o08l0O`0?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l03`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`0?08l0O`2?
07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`0?08l0O`2?07l03`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l002l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l03`1o08l0O`0?07l0
S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o00<03`Koo`006_oo00L03ooo00ooo`0?ool03`06ool0
0`0?ooooo`0Hool01@0?ooooo`0?08l00_oo00@03oooool03aCoo`803`Coo`0300oooooo00ooo`03
00oooooo00Ooo`0307oooooo00_oo`0400oooooo00l6ool00`0?ooooo`0Sool00`0?ooooo`0`ool0
0`0?ooooo`02ool01P0?ooooo`0?ool0Sa3oo`0300oooooo01Coo`0300oooooo00ooo`0400oooooo
00lFool400l4ool00`0?ooooo`04ool001_oo`803`;oo`0300oooooo00Goo`0300oooooo01Soo`05
00oooooo00l0O`02ool0100?ooooo`0?5_oo100?4ooo00<03oooool01_oo00<0Soooool02ooo00@0
3oooool03`Koo`0300oooooo02?oo`0300oooooo033oo`0300oooooo00;oo`0600oooooo00ooo`1o
4?oo00<03oooool05?oo00<03oooool03ooo00@03oooool03aGoo`0300oooooo00;oo`0500oooooo
ool03`06ool002Ooo`0300oooooo01Soo`0500oooooo00l0S`02ool0100?ool03`0?;Ooo00<03ooo
ool01_oo00<0Ooooool02ooo00@03oooool03`Koo`0300oooooo02?oo`0300oooooo033oo`0300oo
oooo00;oo`0300ooo`0?00;oo`0308oooooo00goo`0300oooooo01Goo`0300oooooo00ooo`0400oo
oooo00lDool00`0?ooooo`04ool0100?ooooo`0?1_oo000Wool00`0?ooooo`0Hool01@0?ool03ooo
07l00ooo0`0?;Ooo00<03oooool01_oo00<0Soooool02ooo00@03oooool03`Koo`0300oooooo02?o
o`0300oooooo033oo`0300oooooo00;oo`0300ooo`0?00;oo`0307oooooo00goo`0300oooooo01Ko
o`0300oooooo00koo`0400oooooo00lCool00`0?ooooo`06ool00`0?ool03`06ool002Ooo`0300oo
oooo01Soo`0500ooo`0?ool0S`03ool300l^ool00`0?ooooo`05ool00`1oooooo`0<ool00`0?ool0
3`06ool00`0?ooooo`0Sool00`0?ooooo`0aool01`0?oooooooo00ooo`0?00;oo`0308oooooo00go
o`0300oooooo01Koo`0300oooooo00koo`0400ooo`0?07lCool00`0?ooooo`06ool00`0?ool03`06
ool002Ooo`0300oooooo01Woo`803`03ool0Oooo00;oo`<03bkoo`0300oooooo00Goo`0308oooooo
00coo`803`Ooo`0300oooooo02?oo`0300oooooo037oo`0700ooooooool03ooo00l00_oo00<0Oooo
ool03?oo00<03oooool05ooo00<03oooool03ooo0P0?00<0Soooool04?oo00<03oooool02?oo0P0?
1_oo000Wool00`0?ooooo`0Iool200l00ooo08ooo`02ool200l`ool00`0?ooooo`04ool00`1ooooo
o`0<ool200l7ool00`0?ooooo`0Sool00`0?ooooo`0aool00`0?ooooo`02ool200l2ool00`2?oooo
o`0<ool00`0?ooooo`0Gool00`0?ooooo`0?ool200l00`1oooooo`0@ool00`0?ooooo`08ool200l6
ool002Ooo`0300oooooo01Woo`803`03ool0Oooo00;oo`803c3oo`0300oooooo00Coo`0308oooooo
00coo`803`Ooo`0300oooooo02?oo`0300oooooo037oo`0300oooooo00;oo`803`;oo`0307oooooo
00coo`0300oooooo01Ooo`0300oooooo00ooo`803`0308oooooo00ooo`803`_oo`0300oooooo00Co
o`009ooo0P0?6_oo0P0?00?oo`2?ool00_oo0P0?<?oo00<03oooool01?oo00<0Ooooool03Ooo00<0
3oooool01?oo00<03oooool09?oo00<03oooool0<Ooo00<03oooool00_oo0P0?0_oo00<0Soooool0
2ooo00<03oooool06?oo00<03oooool03ooo0P0?00<0Ooooool03ooo00<03oooool02Ooo0P0?1_oo
000Wool00`0?ooooo`0Lool0101oooooo`0?<ooo00<03oooool00ooo00<0Soooool05?oo00<03ooo
ool09?oo00<03oooool0<Ooo00<03oooool01_oo00<0Ooooool02ooo00<03oooool06?oo00<03ooo
ool04Ooo00<0Soooool03ooo00<03oooool02_oo00<03oooool01?oo000Wool00`0?ooooo`0Lool0
102?ooooo`0?<ooo00<03oooool00ooo00<0Ooooool05?oo00<03oooool09?oo00<03oooool0<_oo
00<03oooool01Ooo00<0Soooool02ooo00<03oooool06?oo00<03oooool04Ooo00<0Ooooool03_oo
00<03oooool02ooo00<03oooool01?oo000Wool00`0?ooooo`0Lool0101oooooo`0?<ooo00<03ooo
ool00ooo00<0Soooool05?oo00<03oooool09?oo00<03oooool0<_oo00<03oooool01Ooo00<0Oooo
ool02_oo00<03oooool06_oo00<03oooool04?oo00<0Soooool03_oo00<03oooool02ooo00<03ooo
ool01?oo000Wool00`0?ooooo`0Lool0102?ooooo`0?=?oo00<03oooool00_oo00<0Ooooool05?oo
00<03oooool09?oo00<03oooool0<_oo00<03oooool01Ooo00<0Soooool02_oo00<03oooool06_oo
00<03oooool04?oo00<0Ooooool03_oo00<03oooool02ooo00<03oooool01?oo000Wool00`0?oooo
o`0Lool00`1oool03`0eool00`0?ooooo`02ool00`2?ooooo`0Dool00`0?ooooo`0Tool00`0?oooo
o`0bool00`0?ooooo`05ool00`1oooooo`0:ool00`0?ooooo`0Jool00`0?ooooo`0@ool00`2?oooo
o`0=ool00`0?ooooo`0<ool00`0?ooooo`04ool002Ooo`0300oooooo01coo`0308ooo`0?03Goo`03
00oooooo00;oo`0307oooooo01Coo`0300oooooo02Coo`0300oooooo03;oo`0300oooooo00Goo`03
08oooooo00[oo`0300oooooo01[oo`0300oooooo013oo`0307oooooo00goo`0300oooooo00coo`03
00oooooo00Coo`009ooo00<03oooool07?oo00<0Oooo00l0=_oo00D03oooooooo`2?01Koo`0300oo
oooo02Coo`0300oooooo03;oo`0300oooooo00Goo`0307oooooo00Woo`0300oooooo01_oo`0300oo
oooo013oo`0308oooooo00goo`0300oooooo00coo`0300oooooo00Coo`009ooo00<03oooool07?oo
00<0Sooo00l0=_oo00D03oooooooo`1o01Koo`0300oooooo02Coo`0300oooooo03?oo`0300oooooo
00Coo`0308oooooo00Woo`0300oooooo01_oo`0300oooooo013oo`0307oooooo00coo`0300oooooo
00goo`0300oooooo00Coo`009ooo0P0?7Ooo00<0O`0?ool0=_oo00D03oooooooo`2?01Koo`0300oo
oooo02Coo`0300oooooo03?oo`0300oooooo00Coo`0307oooooo00Woo`0300oooooo01_oo`0300oo
oooo013oo`0308oooooo00coo`0300oooooo00coo`803`Koo`009ooo00<03oooool07?oo00<0S`0?
ool0=ooo00@03oooool0OaKoo`0300oooooo02Coo`0300oooooo03?oo`0300oooooo00Coo`0308oo
oooo00Woo`0300oooooo01_oo`0300oooooo013oo`0307oooooo00coo`0300oooooo00goo`0300oo
oooo00Coo`009ooo00<03oooool07?oo00<0O`0?ool0=ooo00@03oooool0SaGoo`0300oooooo02Go
o`0300oooooo03?oo`0300oooooo00Coo`0307oooooo00Soo`0300oooooo01coo`0300oooooo013o
o`0308oooooo00coo`0300oooooo00goo`0300oooooo00Coo`009ooo00<03oooool07?oo00<0S`0?
ool0=ooo00@03oooool0OaGoo`0300oooooo02Goo`0300oooooo03?oo`0300oooooo00Coo`0308oo
oooo00Soo`0300oooooo01goo`0300oooooo00ooo`0307oooooo00_oo`0300oooooo00koo`0300oo
oooo00Coo`009ooo00<03oooool07?oo00<0O`0?ool0=ooo00@03oooool0SaGoo`0300oooooo02Go
o`0300oooooo03?oo`0300oooooo00Coo`0307oooooo00Soo`0300oooooo01goo`0300oooooo00oo
o`0308oooooo00_oo`0300oooooo00koo`0300oooooo00Coo`009ooo00<03oooool07?oo00<03ooo
ool0>?oo00<03ooo07l05Ooo00<03oooool09Ooo00<03oooool0=?oo00<03oooool00ooo00<0Sooo
ool02?oo00<03oooool07Ooo00<03oooool03ooo00<0Ooooool02ooo00<03oooool03_oo00<03ooo
ool01?oo000Wool00`0?ooooo`0Lool00`0?ooooo`0hool00`0?ool0S`0Eool00`0?ooooo`0Uool0
0`0?ooooo`0dool00`0?ooooo`03ool00`1oooooo`07ool00`0?ooooo`0Nool00`0?ooooo`0?ool0
0`2?ooooo`0:ool00`0?ooooo`0?ool00`0?ooooo`04ool002Ooo`0300oooooo01coo`0300oooooo
03Soo`0300ooo`1o01Goo`0300oooooo02Goo`0300oooooo03Coo`0300oooooo00?oo`0308oooooo
00Ooo`0300oooooo01koo`0300oooooo00ooo`0307oooooo00[oo`0300oooooo00ooo`0300oooooo
00Coo`009ooo0P0?7Ooo00<03oooool0>?oo00<03ooo08l05Ooo00<03oooool09Ooo00<03oooool0
=?oo00<03oooool00ooo00<0Ooooool01ooo00<03oooool07_oo00<03oooool03ooo00<0Soooool0
2_oo00<03oooool03_oo0P0?1_oo000Wool00`0?ooooo`0Lool00`0?ooooo`0iool00`0?07ooo`0D
ool00`0?ooooo`0Uool00`0?ooooo`0dool00`0?ooooo`03ool00`2?ooooo`07ool00`0?ooooo`0N
ool00`0?ooooo`0?ool00`1oooooo`0:ool00`0?ooooo`0?ool00`0?ooooo`04ool002Ooo`0300oo
oooo01_oo`0300l0Oooo03[oo`0300l0Sooo01Coo`0300oooooo02Goo`0300oooooo03Coo`0300oo
oooo00?oo`0307oooooo00Ooo`0300oooooo01koo`0300oooooo00ooo`0308oooooo00Woo`0300oo
oooo013oo`0300oooooo00Coo`009ooo00<03oooool06ooo00<03`2?ool0>_oo00<03`1oool05?oo
00<03oooool09Ooo00<03oooool0=Ooo00<03oooool00_oo00<0Soooool01_oo00<03oooool07ooo
00<03oooool03ooo00<0Ooooool02Ooo00<03oooool04?oo00<03oooool01?oo000Wool00`0?oooo
o`0Kool00`0?07ooo`0kool00`0?ooooo`0Cool00`0?ooooo`0Uool00`0?ooooo`0eool00`0?oooo
o`02ool00`1oooooo`06ool00`0?ooooo`0Pool00`0?ooooo`0>ool00`2?ooooo`09ool00`0?oooo
o`0@ool00`0?ooooo`04ool002Ooo`0300oooooo01_oo`0300l0Sooo03_oo`0300oooooo01?oo`03
00oooooo02Goo`0300oooooo03Goo`0300oooooo00;oo`0308oooooo00Koo`0300oooooo023oo`03
00oooooo00koo`0307oooooo00Woo`0300oooooo013oo`0300oooooo00Coo`007?oo00@03oooool0
3`Ooo`0300oooooo01[oo`0300ooo`1o03coo`0300oooooo01;oo`0300oooooo02Koo`0300oooooo
03Goo`0300oooooo00;oo`0307oooooo00Koo`0300oooooo023oo`0300oooooo00koo`0308oooooo
00Soo`0300oooooo017oo`0300oooooo00Coo`003?oo0P0?3?oo0`0?00Coo`0?ool03`Koo`0300oo
oooo01[oo`0300ooo`2?03coo`0300oooooo01;oo`0300oooooo02Koo`0300oooooo03Goo`0300oo
oooo00;oo`0308oooooo00Goo`0300oooooo027oo`0300oooooo00koo`0307oooooo00Soo`0300oo
oooo017oo`0300oooooo00Coo`002ooo00@03oooool03`_oo`0700ooo`0?ool03ooo00l01_oo00<0
3oooool06_oo00<03ooo07l0??oo00<0S`0?ool04_oo00<03oooool09_oo00<03oooool0=_oo00D0
3oooooooo`1o00Ooo`0300oooooo027oo`0300oooooo00koo`0308oooooo00Soo`0300oooooo017o
o`0300oooooo00Coo`002_oo0P0?0_oo00<03oooool02_oo0P0?00Coo`0?ool03`Koo`<03`3o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
3`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0
O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?000_08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`0300l6ool000Woo`H03`goo`0400oooooo00l7ool00`0?ooooo`0Iool0100?ooooo`1o??oo
00<0S`0?ool04_oo00<03oooool09_oo00<03oooool0=_oo00D03oooooooo`1o00Ooo`0300oooooo
027oo`0300oooooo00koo`0308oooooo00Ooo`0300oooooo01;oo`0300oooooo00Coo`002_oo00D0
3oooooooo`0?01Soo`0300oooooo01Woo`0400oooooo08llool00`1o00ooo`0Bool00`0?ooooo`0V
ool00`0?ooooo`0fool01@0?oooooooo08l01_oo00<03oooool08_oo00<03oooool03_oo00<0Oooo
ool01ooo00<03oooool04_oo00<03oooool01?oo0009ool600lHool00`0?ooooo`0Iool0100?oooo
o`1o??oo00<0Sooo00l04_oo00<03oooool09_oo00<03oooool0=ooo00@03oooool0O`Koo`0300oo
oooo02?oo`0300oooooo00goo`0308oooooo00Ooo`0300oooooo01;oo`0300oooooo00Coo`003?oo
0`0?6?oo00<03oooool06Ooo00@03oooool0Sccoo`0307ooo`0?01;oo`0300oooooo02Koo`0300oo
oooo03Ooo`0400oooooo08l6ool00`0?ooooo`0Sool00`0?ooooo`0=ool00`1oooooo`07ool00`0?
ooooo`0Bool00`0?ooooo`04ool000_oo`0400oooooo00lHool00`0?ooooo`0Hool01@0?oooooooo
07l0??oo00<0Sooo00l04_oo00<03oooool09_oo00<03oooool0=ooo00@03oooool0O`Goo`0300oo
oooo02Coo`0300oooooo00goo`0308oooooo00Koo`0300oooooo01?oo`0300oooooo00Coo`002ooo
00@03oooool03aSoo`0300oooooo01Soo`0500ooooooool0S`0lool0101oooooo`0?4Ooo00<03ooo
ool09_oo00<03oooool0=ooo00@03oooool0S`Goo`0300oooooo02Coo`0300oooooo00goo`0307oo
oooo00Koo`0300oooooo01?oo`0300oooooo00Coo`003?oo0P0?6Ooo00<03oooool06?oo00D03ooo
ooooo`1o03coo`0408oooooo00lAool00`0?ooooo`0Vool00`0?ooooo`0hool00`0?ool0O`04ool0
0`0?ooooo`0Uool00`0?ooooo`0=ool00`2?ooooo`06ool00`0?ooooo`0Cool00`0?ooooo`04ool0
00coo`0400ooo`0?00lGool200lHool00`0?ooooo`02ool00`2?ooooo`0jool0101oooooo`0?4Ooo
00<03oooool09_oo00<03oooool0>?oo00<03ooo08l01?oo00<03oooool09Ooo00<03oooool03Ooo
00<0Ooooool01_oo00<03oooool04_oo0P0?1_oo000;ool01P0?ool03`0?ool03aKoo`0300oooooo
01Ooo`0300oooooo00;oo`0307oooooo03[oo`0408oooooo00lAool00`0?ooooo`0Vool00`0?oooo
o`0iool00`0?07ooo`02ool00`0?ooooo`0Vool00`0?ooooo`0=ool00`2?ooooo`06ool00`0?oooo
o`0Cool00`0?ooooo`04ool000coo`0500ooo`0?ool03`0Fool00`0?ooooo`0Gool00`0?ooooo`02
ool00`2?ooooo`0jool01@1ooooooooo00l03ooo00<03oooool09ooo00<03oooool0>Ooo00D03`2?
ooooo`0?02Woo`0300oooooo00goo`0307oooooo00Goo`0300oooooo01Coo`0300oooooo00Coo`00
3?oo00@03oooool03aOoo`0300oooooo01Koo`0300oooooo00?oo`0307oooooo03[oo`0508oooooo
ool03`0?ool00`0?ooooo`0Wool00`0?ooooo`0jool300lZool00`0?ooooo`0=ool00`2?ooooo`05
ool00`0?ooooo`0Dool00`0?ooooo`04ool000coo`0300ooo`0?01Soo`0300oooooo01Koo`0300oo
oooo00?oo`0308oooooo03[oo`0507ooooooool03`0?ool00`0?ooooo`0Wool00`0?ooooo`0jool0
0`2?ooooo`0[ool00`0?ooooo`0<ool00`1oooooo`05ool00`0?ooooo`0Dool00`0?ooooo`04ool0
00Woo`0300ooo`0?00<03aSoo`0300oooooo01Goo`0300oooooo00Coo`0307oooooo03[oo`0508oo
ooooool03`0?ool00`0?ooooo`0Wool00`0?ooooo`0jool00`1oooooo`0[ool00`0?ooooo`0<ool0
0`2?ooooo`05ool00`0?ooooo`0Dool00`0?ooooo`04ool000coo`<03aSoo`0300oooooo01Goo`03
00oooooo00Coo`0308oooooo03[oo`0507ooooooool03`0?ool00`0?ooooo`0Wool00`0?ooooo`0j
ool00`2?ooooo`0[ool00`0?ooooo`0<ool00`1oooooo`05ool00`0?ooooo`0Dool00`0?ooooo`04
ool000_oo`0400oooooo00lHool00`0?ooooo`0Dool00`0?ooooo`05ool00`1oooooo`0jool00`2?
ooooo`02ool00`0?ooooo`0<ool00`0?ooooo`0Wool00`0?ooooo`0jool00`1oooooo`0[ool00`0?
ooooo`0<ool00`2?ooooo`04ool00`0?ooooo`0Eool00`0?ooooo`04ool000[oo`803`;oo`0300oo
oooo01Koo`0300oooooo01Coo`0300oooooo00Goo`0308oooooo03[oo`0307oooooo00;oo`0300oo
oooo00coo`0300oooooo02Ooo`0300oooooo03[oo`0308oooooo02_oo`0300oooooo00coo`0307oo
oooo00Coo`0300oooooo01Goo`0300oooooo00Coo`002Ooo1P0?6?oo0P0?5?oo00<03oooool01_oo
00<0Ooooool0>_oo00<0Soooool00_oo00<03oooool03?oo00<03oooool09ooo00<03oooool0>_oo
00<0Ooooool0:ooo00<03oooool03?oo00<0Soooool01?oo00<03oooool05?oo0P0?1_oo000:ool0
1@0?oooooooo00l06?oo00<03oooool04ooo00<03oooool01_oo00<0Soooool0>_oo00<0Ooooool0
0_oo00<03oooool03?oo00<03oooool09ooo00<03oooool0>_oo00<0Soooool0:ooo00<03oooool0
3?oo00<0Ooooool01?oo00<03oooool05Ooo00<03oooool01?oo0009ool600lHool00`0?ooooo`0B
ool00`0?ooooo`07ool00`1oooooo`0jool00`2?ooooo`02ool200l=ool00`0?ooooo`0Wool00`0?
ooooo`0jool00`1oooooo`0[ool00`0?ooooo`0<ool00`2?ooooo`04ool00`0?ooooo`0Eool00`0?
ooooo`04ool000coo`<03aSoo`0300oooooo01;oo`0300oooooo00Ooo`0308oooooo03[oo`0307oo
oooo00?oo`0300oooooo00_oo`0300oooooo02Ooo`0300oooooo03[oo`0308oooooo02_oo`0300oo
oooo00coo`0307oooooo00Coo`0300oooooo01Goo`0300oooooo00Coo`002ooo00@03oooool03aSo
o`0300oooooo017oo`0300oooooo00Soo`0307oooooo03[oo`0308oooooo00?oo`0300oooooo00_o
o`0300oooooo02Ooo`0300oooooo03[oo`0307oooooo02coo`0300oooooo00_oo`0308oooooo00?o
o`0300oooooo01Koo`0300oooooo00Coo`002ooo00@03oooool03aSoo`0300oooooo017oo`0300oo
oooo00Soo`0308oooooo03[oo`0307oooooo00?oo`0300oooooo00[oo`0300oooooo02Soo`0300oo
oooo03[oo`0308oooooo02coo`0300oooooo00_oo`0307oooooo00?oo`0300oooooo01Koo`0300oo
oooo00Coo`003?oo0P0?6Ooo0P0?4Ooo00<03oooool02Ooo00<0Ooooool0>_oo00<0Soooool00ooo
00<03oooool02_oo00<03oooool0:?oo00<03oooool0>_oo00<0Ooooool0;?oo00<03oooool02ooo
00<0Soooool00ooo00<03oooool05_oo00<03oooool01?oo000<ool0100?ool03`0?5ooo00<03ooo
00l03ooo00<03oooool02_oo00<0Soooool0>_oo00<0Ooooool01?oo00<03oooool02Ooo00<03ooo
ool0:?oo00<03oooool0>_oo00<0Soooool0;?oo00<03oooool02ooo00<0Ooooool00ooo00<03ooo
ool05_oo00<03oooool01?oo000;ool01P0?ool03`0?ool03aKoo`0400oooooo00l>ool00`0?oooo
o`0:ool00`1oooooo`0jool00`2?ooooo`04ool00`0?ooooo`09ool00`0?ooooo`0Xool00`0?oooo
o`0jool00`1oooooo`0/ool00`0?ooooo`0;ool00`2?ooooo`03ool00`0?ooooo`0Fool00`0?oooo
o`04ool000coo`0500ooo`0?ool03`0Fool200l2ool00`0?ooooo`0:ool00`0?ooooo`0;ool00`2?
ooooo`0jool00`1oooooo`04ool00`0?ooooo`09ool00`0?ooooo`0Xool00`0?ooooo`0jool00`2?
ooooo`0/ool00`0?ooooo`0;ool00`1oooooo`02ool00`0?ooooo`0Fool200l6ool000coo`0400oo
oooo00lGool00`0?ooooo`02ool00`0?ooooo`08ool00`0?ooooo`0<ool00`1oooooo`0jool00`2?
ooooo`04ool00`0?ooooo`09ool00`0?ooooo`0Xool00`0?ooooo`0jool00`1oooooo`0/ool00`0?
ooooo`0;ool00`2?ooooo`02ool00`0?ooooo`0Gool00`0?ooooo`04ool000_oo`0300oooooo01Wo
o`0300oooooo00;oo`803`Soo`0300oooooo00goo`0308oooooo03[oo`0307oooooo00Coo`0300oo
oooo00Woo`0300oooooo02Soo`0300oooooo03[oo`0308oooooo02coo`0300oooooo00_oo`0307oo
oooo00;oo`0300oooooo01Ooo`0300oooooo00Coo`002ooo0P0?6_oo00<03oooool00ooo00<03ooo
ool01Ooo00<03oooool03_oo00<0Ooooool0>_oo00<0Soooool01Ooo00<03oooool02?oo00<03ooo
ool0:?oo00<03oooool0>_oo00<0Ooooool0;?oo00<03oooool02ooo00<0Soooool00_oo00<03ooo
ool05ooo00<03oooool01?oo000=ool200lHool00`0?ooooo`04ool00`0?ooooo`03ool00`0?oooo
o`0?ool00`2?ooooo`0jool00`1oooooo`05ool00`0?ooooo`08ool00`0?ooooo`0Xool00`0?oooo
o`0jool00`2?ooooo`0]ool00`0?ooooo`0:ool00`1oooooo`02ool00`0?ooooo`0Gool00`0?oooo
o`04ool000_oo`803a[oo`0300oooooo00Goo`D03a;oo`0307oooooo03[oo`0308oooooo00Goo`03
00oooooo00Soo`0300oooooo02Soo`0300oooooo03[oo`0307oooooo02goo`0300oooooo00[oo`03
08oooooo00;oo`0300oooooo01Ooo`0300oooooo00Coo`006ooo00D03oooooooo`0?00Ooo`0300oo
oooo00Ooo`0300oooooo01;oo`0308oooooo03[oo`0307oooooo00Goo`0300oooooo00Ooo`0300oo
oooo02Woo`0300oooooo03[oo`0308oooooo02goo`0300oooooo00[oo`0507ooooooool03`0Jool0
0`0?ooooo`04ool001[oo`0700ooo`0?ool03ooo00l01_oo00<03oooool07?oo00<0Ooooool0>_oo
00<0Soooool01_oo00<03oooool01_oo00<03oooool0:Ooo00<03oooool0>_oo00<0Ooooool0;Ooo
00<03oooool02_oo00D0Soooooooo`0?01[oo`0300oooooo00Coo`003?oo00<03ooo00l02ooo0P0?
0_oo00<03ooo00l01_oo0`0?0?l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?00l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l002l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00<03`Koo`002Ooo00<03ooo00l00`0?2ooo00L03ooo
ooooo`0?ool03`06ool00`0?ooooo`0Lool00`1oooooo`0jool00`2?ooooo`06ool00`0?ooooo`06
ool00`0?ooooo`0Yool00`0?ooooo`0jool00`1oooooo`0]ool00`0?ooooo`0:ool01@2?oooooooo
00l06_oo00<03oooool01?oo000;ool400l<ool200l2ool00`0?ooooo`05ool00`0?ooooo`0Lool0
0`2?ooooo`0jool00`1oooooo`07ool00`0?ooooo`05ool00`0?ooooo`0Yool00`0?ooooo`0jool0
0`2?ooooo`0]ool00`0?ooooo`0:ool01@1ooooooooo00l06_oo00<03oooool01?oo000;ool0100?
ooooo`0?6?oo00<03oooool07?oo00<0Ooooool0>_oo00<0Soooool01ooo00<03oooool01Ooo00<0
3oooool0:Ooo00<03oooool0>_oo00<0Ooooool0;Ooo00<03oooool02_oo00D0Soooooooo`0?01[o
o`0300oooooo00Coo`002ooo00<03oooool06Ooo00<03oooool07?oo00<0Soooool0>_oo00<0Oooo
ool02?oo00<03oooool01?oo00<03oooool0:Ooo00<03oooool0>_oo00<0Soooool0;_oo00<03ooo
ool02Ooo00@0Ooooool03a_oo`0300oooooo00Coo`003?oo0`0?6?oo00<03oooool07?oo00<0Oooo
ool0>_oo00<0Soooool02?oo00<03oooool00ooo00<03oooool0:_oo00<03oooool0>_oo00<0Oooo
ool0;_oo00<03oooool02Ooo00@0Soooool03a_oo`0300oooooo00Coo`009ooo00<03oooool07?oo
00<0Soooool0>_oo00<0Ooooool02Ooo0P0?0ooo00<03oooool0:_oo00<03oooool0>_oo00<0Sooo
ool0;_oo00<03oooool02Ooo00@0Ooooool03a_oo`0300oooooo00Coo`009ooo00<03oooool07?oo
00<0Ooooool0>_oo00<0Soooool02_oo00D03oooooooo`0?02coo`0300oooooo03[oo`0307oooooo
02koo`0300oooooo00Woo`0408oooooo00lKool00`0?ooooo`04ool000_oo`0300ooo`0?01Woo`03
00oooooo01coo`0308oooooo03[oo`0307oooooo00_oo`0300ooo`0?02goo`0300oooooo03[oo`03
08oooooo02koo`0300oooooo00Woo`0407oooooo00lKool00`0?ooooo`04ool000_oo`803`03ool0
3ooo01Ooo`803agoo`0307oooooo03[oo`0308oooooo00coo`803bgoo`0300oooooo03[oo`0307oo
oooo02koo`0300oooooo00Woo`0308ooo`0?01_oo`803`Koo`003?oo0`0?6?oo00<03oooool07?oo
00<0Soooool0>_oo00<0Ooooool0>ooo00<03oooool0>_oo00<0Soooool0;_oo00<03oooool02Ooo
00<0Oooo00l07?oo00<03oooool01?oo000>ool00`0?ooooo`0Fool00`0?ooooo`0Lool00`1ooooo
o`0jool00`2?ooooo`0kool00`0?ooooo`0jool00`1oooooo`0_ool00`0?ooooo`08ool00`2?ool0
3`0Lool00`0?ooooo`04ool002Ooo`0300oooooo01coo`0308oooooo03[oo`0307oooooo03_oo`03
00oooooo03[oo`0308oooooo02ooo`0300oooooo00Soo`0307ooo`0?01coo`0300oooooo00Coo`00
3_oo00<03oooool05_oo00<03oooool07?oo00<0Ooooool0>_oo00<0Soooool0>ooo00<03oooool0
>_oo00<0Ooooool0;ooo00<03oooool02?oo00<0Sooo00l07?oo00<03oooool01?oo000;ool300lI
ool00`0?ooooo`0Lool00`2?ooooo`0jool00`1oooooo`0kool00`0?ooooo`0jool00`2?ooooo`0_
ool00`0?ooooo`08ool00`1o00ooo`0Lool00`0?ooooo`04ool000koo`0300oooooo01Koo`0300oo
oooo01coo`0307oooooo03[oo`0308oooooo03_oo`0300oooooo03[oo`0307oooooo02ooo`0300oo
oooo00Soo`0308l03ooo01coo`0300oooooo00Coo`002ooo100?6?oo00<03oooool07?oo00<0Sooo
ool0>_oo00<0Ooooool0>ooo00<03oooool0>_oo00<0Soooool0;ooo00<03oooool02?oo00<0O`0?
ool07?oo00<03oooool01?oo000Wool00`0?ooooo`0Lool00`1oooooo`0jool00`2?ooooo`0kool0
0`0?ooooo`0jool00`1oooooo`0_ool00`0?ooooo`08ool00`2?00ooo`0Lool00`0?ooooo`04ool0
02Ooo`803agoo`0308oooooo03[oo`0307oooooo03_oo`0300oooooo03[oo`0308oooooo033oo`03
00oooooo00Ooo`0300oooooo01_oo`803`Koo`003_oo00<03oooool05_oo00<03oooool07?oo00<0
Ooooool0>_oo00<0Soooool0>ooo00<03oooool0>_oo00<0Ooooool0<?oo00<03oooool01ooo00<0
3oooool07?oo00<03oooool01?oo000Wool00`0?ooooo`0Lool00`2?ooooo`0jool00`1oooooo`0k
ool00`0?ooooo`0jool00`2?ooooo`0`ool00`0?ooooo`07ool00`0?ooooo`0Lool00`0?ooooo`04
ool002Ooo`0300oooooo01coo`0307oooooo03[oo`0308oooooo03_oo`0300oooooo03[oo`0307oo
oooo033oo`0300oooooo00Ooo`0300oooooo01coo`0300oooooo00Coo`009ooo00<03oooool07?oo
00<0Soooool0>_oo00<0Ooooool0>ooo00<03oooool0>_oo00<0Soooool0<Ooo00<03oooool01Ooo
00<03`1oool07Ooo00<03oooool01?oo000Wool00`0?ooooo`0Lool00`1oooooo`0jool00`2?oooo
o`0kool00`0?ooooo`0jool00`1oooooo`0aool00`0?ooooo`05ool00`0?08ooo`0Mool00`0?oooo
o`04ool002Ooo`0300oooooo01coo`0308oooooo03[oo`0307oooooo03_oo`0300oooooo03[oo`03
08oooooo037oo`0300oooooo00Coo`0300ooo`1o01koo`0300oooooo00Coo`009ooo00<03oooool0
7?oo00<0Ooooool0>_oo00<0Soooool0>ooo00<03oooool0>_oo00<0Ooooool0<Ooo00<03oooool0
1?oo00<03ooo08l07_oo00<03oooool01?oo000Wool200lMool00`2?ooooo`0jool00`1oooooo`0k
ool00`0?ooooo`0jool00`2?ooooo`0bool00`0?ooooo`03ool00`0?ool0O`0Mool200l6ool002Oo
o`0300oooooo01coo`0307oooooo03[oo`0308oooooo03_oo`0300oooooo03[oo`0307oooooo03;o
o`0300oooooo00;oo`0400oooooo08lNool00`0?ooooo`04ool002Ooo`0300oooooo01coo`0308oo
oooo03[oo`0307oooooo03_oo`0300oooooo03[oo`0308oooooo03?oo`0400oooooo00l3ool00`1o
ooooo`0Lool00`0?ooooo`04ool002Ooo`0300oooooo01coo`0307oooooo03[oo`0308oooooo03_o
o`0300oooooo03[oo`0307oooooo03?oo`@03`?oo`0308oooooo01coo`0300oooooo00Coo`009ooo
00<03oooool07?oo00<0Soooool0>_oo00<0Ooooool0>ooo00<03oooool0>_oo00<0Soooool0>_oo
00<0Ooooool07?oo00<03oooool01?oo000Wool00`0?ooooo`0Lool00`1oooooo`0jool00`2?oooo
o`0kool00`0?ooooo`0jool00`1oooooo`0jool00`2?ooooo`0Lool00`0?ooooo`04ool001_oo`05
00ooooooool03`07ool00`0?ooooo`0Lool00`2?ooooo`0jool00`1oooooo`0kool00`0?ooooo`0j
ool00`2?ooooo`0jool00`1oooooo`0Lool00`0?ooooo`04ool001[oo`0700ooo`0?ool03ooo00l0
1_oo00<03oooool07?oo00<0Ooooool0>_oo00<0Soooool0>ooo00<03oooool0>_oo00<0Ooooool0
>_oo00<0Soooool07?oo00<03oooool01?oo000Kool01P0?ooooo`0?ool03`Koo`0300oooooo01Wo
o`0400oooooo08l4ool00`0?ooooo`0eool00`1oooooo`0=ool00`0?ooooo`0[ool00`0?ooooo`0f
ool01@0?oooooooo08l0>_oo00<03ooo07l07_oo00<03oooool01?oo000Jool01`0?ool03ooo00oo
o`0?00Koo`<03`0H07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
0`0?00D0S`1o08l0O`2?00<03`1508l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00<03`1T08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l300l0?01o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`<03`0M08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`0300l6ool001_oo`0500ooooooool03`07ool00`0?ooooo`0Hool300l00ooo
08ooo`02ool300lfool00`1oooooo`0<ool300l/ool00`0?ooooo`0eool300l2ool00`2?ooooo`0g
ool300l00`1oooooo`0Lool00`0?ooooo`04ool002Ooo`0300oooooo01Soo`<03`03ool0Oooo00;o
o`<03cKoo`0308oooooo00coo`<03bcoo`0300oooooo03Goo`<03`;oo`0307oooooo03Ooo`<03`03
08oooooo01coo`0300oooooo00Coo`009ooo00<03oooool06?oo0`0?00?oo`2?ool00_oo0`0?=_oo
00<0Ooooool03?oo0`0?;?oo00<03oooool0=Ooo0`0?0_oo00<0Soooool0=ooo0`0?00<0Ooooool0
7?oo00<03oooool01?oo000Wool00`0?ooooo`0Hool300l00ooo07ooo`02ool300lfool00`2?oooo
o`0<ool300l/ool00`0?ooooo`0eool300l2ool00`1oooooo`0gool300l00`2?ooooo`0Lool00`0?
ooooo`04ool002Ooo`0300oooooo01Soo`<03`03ool0Sooo00;oo`<03cKoo`0307oooooo00coo`<0
3bcoo`0300oooooo03Goo`<03`;oo`0308oooooo03Ooo`<03`0307oooooo01coo`0300oooooo00Co
o`009ooo00<03oooool06?oo0`0?00?oo`1oool00_oo0`0?=_oo00<0Soooool03?oo0`0?;?oo00<0
3oooool0=Ooo0`0?0_oo00<0Ooooool0=ooo0`0?00<0Soooool07?oo00<03oooool01?oo000Wool0
0`0?ooooo`0Hool300l00ooo08ooo`02ool300lfool00`1oooooo`0<ool300l/ool00`0?ooooo`0e
ool300l2ool00`2?ooooo`0gool300l00`1oooooo`0Lool00`0?ooooo`04ool002Ooo`803aWoo`<0
3`03ool0Oooo00;oo`<03cKoo`0308oooooo00coo`<03bcoo`0300oooooo03Goo`<03`;oo`0307oo
oooo03Ooo`<03`0308oooooo01_oo`803`Koo`009ooo00<03oooool06?oo0`0?00?oo`2?ool00_oo
0`0?=_oo00<0Ooooool03?oo0`0?;?oo00<03oooool0=Ooo0`0?0_oo00<0Soooool0=ooo0`0?00<0
Ooooool07?oo00<03oooool01?oo000Wool00`0?ooooo`0Hool300l00ooo07ooo`02ool300lfool0
0`2?ooooo`0<ool300l/ool00`0?ooooo`0eool300l2ool00`1oooooo`0gool300l00`2?ooooo`0L
ool00`0?ooooo`04ool002Ooo`0300oooooo01Soo`<03`03ool0Sooo00;oo`<03cKoo`0307oooooo
00coo`<03bcoo`0300oooooo03Goo`<03`;oo`0308oooooo03Ooo`<03`0307oooooo01coo`0300oo
oooo00Coo`009ooo00<03oooool06?oo0`0?00?oo`1oool00_oo0`0?=_oo00<0Soooool03?oo0`0?
;?oo00<03oooool0=Ooo0`0?0_oo00<0Ooooool0=ooo0`0?00<0Soooool07?oo00<03oooool01?oo
000Wool00`0?ooooo`0Hool300l00ooo08ooo`02ool300lfool00`1oooooo`0<ool300l/ool00`0?
ooooo`0eool300l2ool00`2?ooooo`0gool300l00`1oooooo`0Lool00`0?ooooo`04ool002Ooo`03
00oooooo01Soo`<03`03ool0Oooo00;oo`<03cKoo`0308oooooo00coo`<03bcoo`0300oooooo03Go
o`<03`;oo`0307oooooo03Ooo`<03`0308oooooo01coo`0300oooooo00Coo`009ooo00<03oooool0
6?oo0`0?00?oo`2?ool00_oo0`0?=_oo00<0Ooooool03?oo0`0?;?oo00<03oooool0=Ooo0`0?0_oo
00<0Soooool0=ooo0`0?00<0Ooooool07?oo00<03oooool01?oo000Wool00`0?ooooo`0Hool300l0
0ooo07ooo`02ool300lfool00`2?ooooo`0<ool300l/ool00`0?ooooo`0eool300l2ool00`1ooooo
o`0gool300l00`2?ooooo`0Lool00`0?ooooo`04ool002Ooo`803aWoo`<03`03ool0Sooo00;oo`<0
3cKoo`0307oooooo00coo`<03bcoo`0300oooooo03Goo`<03`;oo`0308oooooo03Ooo`<03`0307oo
oooo01_oo`803`Koo`009ooo00<03oooool06Ooo00@03oooool0O`Coo`0300oooooo03Goo`0308oo
oooo00goo`0300oooooo02_oo`0300oooooo03Koo`0500ooooooool0O`0jool00`0?ool0S`0Nool0
0`0?ooooo`04ool002Ooo`0300oooooo01coo`0308oooooo03[oo`0307oooooo03_oo`0300oooooo
03[oo`0308oooooo03[oo`0307oooooo01coo`0300oooooo00Coo`009ooo00<03oooool07?oo00<0
Ooooool0>_oo00<0Soooool0>ooo00<03oooool0>_oo00<0Ooooool0>_oo00<0Soooool07?oo00<0
3oooool01?oo000Wool00`0?ooooo`0@ool300l01?oo00l03`0?1Ooo00<0Soooool02?oo0`0?;ooo
00<0Ooooool0>ooo00<03oooool0>_oo00<0Soooool0>_oo0`0?7?oo00<03oooool01?oo000Wool0
0`0?ooooo`0@ool01`0?ool03ooo00ooo`0?00Goo`0307oooooo00Soo`0300ooo`0?02ooo`0308oo
oooo03_oo`0300oooooo03[oo`0307oooooo03[oo`0300ooo`0?01coo`0300oooooo00Coo`009ooo
00<03oooool04Ooo00D03oooooooo`0?00Koo`0308oooooo00Coo`0300ooo`0?00;oo`0300oooooo
02koo`0307oooooo00Woo`0300ooo`0?00;oo`803b_oo`0300oooooo037oo`0300ooo`0?00803`;o
o`803`0308oooooo03?oo`0300oooooo00<03`03ool0O`0?01goo`0300oooooo00Coo`009ooo00<0
3oooool04?oo00L03ooo00ooo`0?ool03`05ool00`1oooooo`04ool01`0?ool03ooo00ooo`0?02oo
o`0308oooooo00Woo`0700ooo`0?ool03ooo00l0:ooo00<03oooool0<Ooo00@03oooool03`;oo`04
00ooo`0?07leool01@0?oooooooo00l00_oo00<03ooo00l07?oo00<03oooool01?oo000Wool00`0?
ooooo`0@ool01`0?ool03ooo00ooo`0?00Goo`0308oooooo00Coo`0700ooo`0?ool03ooo00l0;ooo
00<0Ooooool02Ooo00L03ooo00ooo`0?ool03`0[ool00`0?ooooo`0aool0100?ooooo`0?0_oo00@0
3ooo00l0ScGoo`0500ooooooool03`02ool00`0?ool03`0Lool00`0?ooooo`04ool002Ooo`803a;o
o`803`;oo`803`Goo`0307oooooo00Coo`803`?oo`803booo`0308oooooo00Woo`803`;oo`0300oo
o`0?02_oo`0300oooooo033oo`<03`08ool03oooool03ooo00l0OcCoo`<03`;oo`0400oooooo08l2
00lKool200l6ool002Ooo`0300oooooo01coo`0308oooooo00Coo`0300oooooo03?oo`0307oooooo
00Woo`0300oooooo02ooo`0300oooooo037oo`0400ooo`0?00l5ool00`2?ooooo`0cool00`0?oooo
o`0200l2ool00`1oooooo`0Lool00`0?ooooo`04ool002Ooo`0300oooooo01coo`0307oooooo03[o
o`0308oooooo03_oo`0300oooooo03[oo`0307oooooo03[oo`0308oooooo01coo`0300oooooo00Co
o`009ooo00<03oooool07?oo00<0Soooool0>_oo00<0Ooooool0>ooo00<03oooool0>_oo00<0Sooo
ool0>_oo00<0Ooooool07?oo00<03oooool01?oo000Wool00`0?ooooo`0Lool00`1oooooo`0jool0
0`2?ooooo`0kool00`0?ooooo`0jool00`1oooooo`0jool00`2?ooooo`0Lool00`0?ooooo`04ool0
02Ooo`0300oooooo01coo`0308oooooo03[oo`0307oooooo03_oo`0300oooooo03[oo`0308oooooo
03[oo`0307oooooo01coo`0300oooooo00Coo`005_oo0`0?0_oo00D03oooooooo`0?00Ooo`0300oo
oooo01coo`0307oooooo03[oo`0308oooooo03_oo`0300oooooo03[oo`0307oooooo03[oo`0308oo
oooo01coo`0300oooooo00Coo`005ooo00X03oooool03ooo00ooo`0?ool03`Koo`0300oooooo01co
o`0308oooooo03[oo`0307oooooo03_oo`0300oooooo03[oo`0308oooooo03[oo`0307oooooo01co
o`0300oooooo00Coo`005ooo00X03oooool03ooo00ooo`0?ool03`Koo`<03`3o07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o000_07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0300l6
ool001Ooo`0:00oooooo00ooo`0?ool03ooo00l6ool00`0?ooooo`0Lool00`2?ooooo`0jool00`1o
ooooo`0kool00`0?ooooo`0jool00`2?ooooo`0jool00`1oooooo`0Lool00`0?ooooo`04ool001Ko
o`803`?oo`0500ooooooool03`07ool00`0?ooooo`0Lool00`1oooooo`0jool00`2?ooooo`0kool0
0`0?ooooo`0jool00`1oooooo`0jool00`2?ooooo`0Lool00`0?ooooo`04ool002Ooo`0300oooooo
01coo`0308oooooo03[oo`0307oooooo03_oo`0300oooooo03[oo`0308oooooo03[oo`0307oooooo
01coo`0300oooooo00Coo`009ooo00<03oooool07?oo00<0Ooooool0>_oo00<0Soooool0>ooo00<0
3oooool0>_oo00<0Ooooool0>_oo00<0Soooool07?oo00<03oooool01?oo000Wool00`0?ooooo`0L
ool00`2?ooooo`0jool00`1oooooo`0kool00`0?ooooo`0jool00`2?ooooo`0jool00`1oooooo`0L
ool00`0?ooooo`04ool002Ooo`0300oooooo01coo`0307oooooo03[oo`0308oooooo03_oo`0300oo
oooo03[oo`0307oooooo03[oo`0308oooooo01coo`0300oooooo00Coo`009ooo00<03oooool07?oo
00<0Soooool0>_oo00<0Ooooool0>ooo00<03oooool0>_oo00<0Soooool0>_oo00<0Ooooool07?oo
00<03oooool01?oo000Wool00`0?ooooo`0Lool00`1oooooo`0jool00`2?ooooo`0kool00`0?oooo
o`0jool00`1oooooo`0jool00`2?ooooo`0Lool00`0?ooooo`04ool002Ooo`803agoo`0308oooooo
03[oo`0307oooooo03_oo`0300oooooo03[oo`0308oooooo03[oo`0307oooooo01_oo`803`Koo`00
9ooo00<03oooool07?oo00<0Ooooool0>_oo00<0Soooool0>ooo00<03oooool0>_oo00<0Ooooool0
>_oo00<0Soooool07?oo00<03oooool01?oo000Wool00`0?ooooo`0Lool00`2?ooooo`0jool00`1o
ooooo`0kool00`0?ooooo`0jool00`2?ooooo`0jool00`1oooooo`0Lool00`0?ooooo`04ool002Oo
o`0300oooooo01coo`0307oooooo03[oo`0308oooooo03_oo`0300oooooo03[oo`0307oooooo03[o
o`0308oooooo01coo`0300oooooo00Coo`009ooo00<03oooool07?oo00<0Soooool0>_oo00<0Oooo
ool0>ooo00<03oooool0>_oo00<0Soooool0>_oo00<0Ooooool07?oo00<03oooool01?oo000Wool0
0`0?ooooo`0Lool00`1oooooo`0jool00`2?ooooo`0kool00`0?ooooo`0jool00`1oooooo`0jool0
0`2?ooooo`0Lool00`0?ooooo`04ool002Ooo`0300oooooo01coo`0308oooooo03[oo`0307oooooo
03_oo`0300oooooo03[oo`0308oooooo03[oo`0307oooooo01coo`0300oooooo00Coo`009ooo00<0
3oooool00ooo00<03oooool02_oo00<03oooool02Ooo00<03oooool02Ooo00<03oooool02Ooo00<0
3oooool02_oo00<03oooool02Ooo00<03oooool02Ooo00<03oooool02Ooo00<03oooool02_oo00<0
3oooool02Ooo00<03oooool02Ooo00<03oooool02_oo00<03oooool02Ooo00<03oooool02Ooo00<0
3oooool02Ooo00<03oooool02_oo00<03oooool02Ooo00<03oooool02Ooo00<03oooool02Ooo00<0
3oooool02_oo00<03oooool02Ooo00<03oooool02Ooo00<03oooool02_oo00<03oooool02Ooo00<0
3oooool00ooo00<03oooool01?oo000Woooo00le00l6ool00001\
\>"],
  ImageRangeCache->{{{0, 351.5}, {216.5, 0}} -> {-3.145586, -15.566151, 
  0.020366, 0.725032}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"NeXT 3.0",
ScreenRectangle->{{0, 957}, {0, 768}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{682, 641},
WindowMargins->{{Automatic, 49}, {38, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"NeXTAutomaticEncoding",
Magnification->1.25
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 106, 2, 169, "Title"],

Cell[CellGroupData[{
Cell[1862, 57, 55, 1, 31, "Input"],
Cell[1920, 60, 123, 2, 27, "Message"]
}, Open  ]],
Cell[2058, 65, 87, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[2170, 71, 85, 2, 64, "Section"],
Cell[2258, 75, 1790, 36, 717, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4085, 116, 89, 2, 64, "Section"],
Cell[4177, 120, 111, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[4313, 126, 102, 2, 54, "Subsection"],
Cell[4418, 130, 185, 5, 90, "Input"],
Cell[4606, 137, 88, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[4719, 143, 422, 8, 82, "Input"],
Cell[5144, 153, 48013, 1644, 233, 22710, 1327, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53194, 1802, 367, 8, 82, "Input"],
Cell[53564, 1812, 52312, 1597, 233, 21094, 1207, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105913, 3414, 186, 4, 55, "Input"],
Cell[106102, 3420, 245, 5, 27, "Print"]
}, Open  ]],
Cell[106362, 3428, 160, 4, 48, "Input"],

Cell[CellGroupData[{
Cell[106547, 3436, 437, 9, 82, "Input"],
Cell[106987, 3447, 52976, 1774, 233, 23806, 1409, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[159990, 5225, 101, 2, 54, "Subsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160128, 5232, 89, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[160242, 5238, 94, 2, 54, "Subsection"],
Cell[160339, 5242, 141, 3, 48, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160517, 5250, 101, 2, 54, "Subsection"],
Cell[160621, 5254, 182, 5, 48, "Input"],

Cell[CellGroupData[{
Cell[160828, 5263, 570, 12, 213, "Input"],
Cell[161401, 5277, 151, 3, 27, "Print"],
Cell[161555, 5282, 171, 3, 27, "Print"],
Cell[161729, 5287, 161, 3, 27, "Print"],
Cell[161893, 5292, 163, 3, 27, "Print"],
Cell[162059, 5297, 157, 3, 27, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[162277, 5307, 93, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[162395, 5313, 89, 2, 54, "Subsection"],
Cell[162487, 5317, 597, 14, 158, "Input"],

Cell[CellGroupData[{
Cell[163109, 5335, 236, 5, 65, "Input"],
Cell[163348, 5342, 151, 3, 27, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[163548, 5351, 93, 2, 54, "Subsection"],
Cell[163644, 5355, 273, 6, 88, "Input"],

Cell[CellGroupData[{
Cell[163942, 5365, 622, 13, 211, "Input"],
Cell[164567, 5380, 151, 3, 27, "Print"],
Cell[164721, 5385, 199, 4, 27, "Print"],
Cell[164923, 5391, 192, 4, 27, "Print"],
Cell[165118, 5397, 151, 3, 27, "Print"],
Cell[165272, 5402, 151, 3, 27, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[165472, 5411, 99, 2, 54, "Subsection"],
Cell[165574, 5415, 117, 3, 74, "Input"],
Cell[165694, 5420, 164, 4, 88, "Input"],

Cell[CellGroupData[{
Cell[165883, 5428, 141, 3, 31, "Input"],
Cell[166027, 5433, 154, 3, 27, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[166242, 5443, 95, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[166362, 5449, 86, 2, 54, "Subsection"],
Cell[166451, 5453, 224, 5, 31, "Input"],

Cell[CellGroupData[{
Cell[166700, 5462, 449, 11, 133, "Input"],
Cell[167152, 5475, 35442, 1242, 142, 16985, 1008, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[202643, 6723, 105, 2, 54, "Subsection"],
Cell[202751, 6727, 369, 8, 110, "Input"],

Cell[CellGroupData[{
Cell[203145, 6739, 203, 5, 48, "Input"],
Cell[203351, 6746, 151, 3, 27, "Print"]
}, Open  ]],
Cell[203517, 6752, 230, 5, 31, "Input"],

Cell[CellGroupData[{
Cell[203772, 6761, 455, 11, 133, "Input"],
Cell[204230, 6774, 53225, 1453, 233, 17171, 1003, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[257504, 8233, 115, 2, 54, "Subsection"],
Cell[257622, 8237, 429, 8, 123, "Input"],
Cell[258054, 8247, 516, 11, 150, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[258607, 8263, 106, 2, 54, "Subsection"],
Cell[258716, 8267, 133, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[258874, 8274, 107, 3, 48, "Input"],
Cell[258984, 8279, 152, 2, 32, "Output"]
}, Open  ]],
Cell[259151, 8284, 630, 11, 116, "Input"],

Cell[CellGroupData[{
Cell[259806, 8299, 1528, 26, 201, "Input"],
Cell[261337, 8327, 95327, 4398, 228, 52462, 3863, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

