(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    301756,       9381]*)
(*NotebookOutlinePosition[    302676,       9413]*)
(*  CellTagsIndexPosition[    302632,       9409]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["DENSITY OF STATES"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Remove["\<Global`*\>"]\)], "Input"],

Cell[TextData["Highlights"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Abstract"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Introduction"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Off[General::"\<spell\>", General::"\<spell1\>"]; \)\), 
    \(\(Needs["\<Graphics`Arrow`\>"]; \)\), 
    \(tera = 10\^12; micro = 1\/10\^6; \), 
    \(giga = 10\^9; nano = 1\/10\^9; \), 
    \(mega = 10\^6; pico = 1\/10\^12; \), 
    \(kilo = 10\^3; femto = 1\/10\^15; \), 
    \(milli = 1\/10.\^3; atto = 1\/10\^18; \), 
    \(\(NSub
       = {c \[Rule] 2.99792458\ 10\^8, e \[Rule] 1.6021773\/10\^19, 
        h \[Rule] 6.6260755\/10.\^34, hbar \[Rule] 1.05457\/10.\^34, 
        K \[Rule] 1.380658\/10\^23, me \[Rule] 9.109389\/10\^31, 
        mu0 \[Rule] \(4.\ \[Pi]\)\/10\^7, eps0 \[Rule] 8.85419\/10\^12}; \)\),
   
    \(ESi = 0.179\ tera; rhoSi = 2330; nuSi = 0.28; \), 
    \(ESiO2 = 0.06\ tera; rhoSiO2 = 2200; nuSiO2 = 0.3; \), 
    \(ESi3N4 = 0.15\ tera; rhoSi3N4 = 3100; nuSi3N4 = 0.24; \), 
    \(EAu = 0.08\ tera; rhoAu = 19300; nuAu = 0.42; \), 
    \(ENi = 0.207\ tera; rhoNi = 8900; nuNi = 0.41; \), 
    \(EW = 0.345\ tera; rhoW = 19300; nuW = 0.28; \), 
    \(EPt = 0.17\ tera; rhoPt = 21400; nuPt = 0.39; \), 
    \(EIr = 0.52\ tera; rhoIr = 22500; nuIr = 0.3; \), 
    \(EHOPG = 0.2\ tera; rhoHOPG = 2250; nuHOPG = 0.3; \), 
    \(EPol = 0.001\ tera; rhoPol = 1000; nuPol = 0.3; \), 
    \(\(xx = 0.8; \)\), 
    \(\(EPtIr = xx\ 0.8\ EPt + \((1 - xx)\)\ EIr; \)\), 
    \(\(rhoPtIr = xx\ rhoPt + \((1 - xx)\)\ rhoIr; \)\), 
    \(\(nuPtIr = 0.3; \)\), 
    \(\(opt
       = {PlotRange \[Rule] All, AxesOrigin \[Rule] {0, 0}, 
        Frame \[Rule] True, GridLines \[Rule] Automatic, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        PlotStyle 
          \[Rule] {Dashing[{.0001}], Dashing[{.0200}], Dashing[{.0200}], 
            Dashing[{.0200}], Dashing[{.0200}], Dashing[{.0001}]}}; \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(case1 = {L \[Rule] 1\ nano}; \)\), 
    \(\(case = Join[NSub, case1]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Sphere in Arbitrary Dimensions"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Volume"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Vs]; \)\), 
    \(\(Vs[d_, r_] := \(r\^d\ \[Pi]\^\(d/2\)\)\/Gamma[1 + d\/2]; \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(tbl1 = Table[Vs[d, r], {d, 0, 3, 1}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({1, 2\ r, \[Pi]\ r\^2, \(4\ \[Pi]\ r\^3\)\/3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig14x1 = 
      Plot[{Vs[d, 1.1], Vs[d, 1.2]}, {d, 0, 20}, 
        FrameLabel \[Rule] {"\<d\>", "\<V\>"}, Evaluate[opt]]; \)\)], "Input",\

  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.023809 0.047619 0.008801 0.034066 [
[.02381 -0.0125 -4 -12 ]
[.02381 -0.0125 4 0 ]
[.2619 -0.0125 -4 -12 ]
[.2619 -0.0125 4 0 ]
[.5 -0.0125 -6 -12 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -12 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -12 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4 -24 ]
[.5 -0.0125 4 -12 ]
[-0.0125 .0088 -8 -6 ]
[-0.0125 .0088 0 6 ]
[-0.0125 .09396 -14 -6 ]
[-0.0125 .09396 0 6 ]
[-0.0125 .17913 -8 -6 ]
[-0.0125 .17913 0 6 ]
[-0.0125 .26429 -14 -6 ]
[-0.0125 .26429 0 6 ]
[-0.0125 .34946 -12 -6 ]
[-0.0125 .34946 0 6 ]
[-0.0125 .43462 -18 -6 ]
[-0.0125 .43462 0 6 ]
[-0.0125 .51979 -12 -6 ]
[-0.0125 .51979 0 6 ]
[-0.0125 .60495 -18 -6 ]
[-0.0125 .60495 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30 -12 ]
[-0.01875 .30902 -18 12 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .09396 m
1 .09396 L
s
0 .17913 m
1 .17913 L
s
0 .26429 m
1 .26429 L
s
0 .34946 m
1 .34946 L
s
0 .43462 m
1 .43462 L
s
0 .51979 m
1 .51979 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .0088 m
.00625 .0088 L
s
gsave
-0.0125 .0088 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .09396 m
.00625 .09396 L
s
gsave
-0.0125 .09396 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .17913 m
.00625 .17913 L
s
gsave
-0.0125 .17913 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .26429 m
.00625 .26429 L
s
gsave
-0.0125 .26429 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .34946 m
.00625 .34946 L
s
gsave
-0.0125 .34946 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .43462 m
.00625 .43462 L
s
gsave
-0.0125 .43462 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .51979 m
.00625 .51979 L
s
gsave
-0.0125 .51979 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60495 m
.00625 .60495 L
s
gsave
-0.0125 .60495 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(17.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .02583 m
.00375 .02583 L
s
0 .04287 m
.00375 .04287 L
s
0 .0599 m
.00375 .0599 L
s
0 .07693 m
.00375 .07693 L
s
0 .111 m
.00375 .111 L
s
0 .12803 m
.00375 .12803 L
s
0 .14506 m
.00375 .14506 L
s
0 .1621 m
.00375 .1621 L
s
0 .19616 m
.00375 .19616 L
s
0 .21319 m
.00375 .21319 L
s
0 .23023 m
.00375 .23023 L
s
0 .24726 m
.00375 .24726 L
s
0 .28133 m
.00375 .28133 L
s
0 .29836 m
.00375 .29836 L
s
0 .31539 m
.00375 .31539 L
s
0 .33242 m
.00375 .33242 L
s
0 .36649 m
.00375 .36649 L
s
0 .38352 m
.00375 .38352 L
s
0 .40056 m
.00375 .40056 L
s
0 .41759 m
.00375 .41759 L
s
0 .45165 m
.00375 .45165 L
s
0 .46869 m
.00375 .46869 L
s
0 .48572 m
.00375 .48572 L
s
0 .50275 m
.00375 .50275 L
s
0 .53682 m
.00375 .53682 L
s
0 .55385 m
.00375 .55385 L
s
0 .57088 m
.00375 .57088 L
s
0 .58792 m
.00375 .58792 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -97 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
73 10 translate
90 rotate
-73 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(V) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
68.750000 13.000000 moveto
(H) show
71.750000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
75.750000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
77.750000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(r) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
80.375000 13.000000 moveto
(L) show
82.937500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0088 m
1 .0088 L
s
.99375 .09396 m
1 .09396 L
s
.99375 .17913 m
1 .17913 L
s
.99375 .26429 m
1 .26429 L
s
.99375 .34946 m
1 .34946 L
s
.99375 .43462 m
1 .43462 L
s
.99375 .51979 m
1 .51979 L
s
.99375 .60495 m
1 .60495 L
s
.125 Mabswid
.99625 .02583 m
1 .02583 L
s
.99625 .04287 m
1 .04287 L
s
.99625 .0599 m
1 .0599 L
s
.99625 .07693 m
1 .07693 L
s
.99625 .111 m
1 .111 L
s
.99625 .12803 m
1 .12803 L
s
.99625 .14506 m
1 .14506 L
s
.99625 .1621 m
1 .1621 L
s
.99625 .19616 m
1 .19616 L
s
.99625 .21319 m
1 .21319 L
s
.99625 .23023 m
1 .23023 L
s
.99625 .24726 m
1 .24726 L
s
.99625 .28133 m
1 .28133 L
s
.99625 .29836 m
1 .29836 L
s
.99625 .31539 m
1 .31539 L
s
.99625 .33242 m
1 .33242 L
s
.99625 .36649 m
1 .36649 L
s
.99625 .38352 m
1 .38352 L
s
.99625 .40056 m
1 .40056 L
s
.99625 .41759 m
1 .41759 L
s
.99625 .45165 m
1 .45165 L
s
.99625 .46869 m
1 .46869 L
s
.99625 .48572 m
1 .48572 L
s
.99625 .50275 m
1 .50275 L
s
.99625 .53682 m
1 .53682 L
s
.99625 .55385 m
1 .55385 L
s
.99625 .57088 m
1 .57088 L
s
.99625 .58792 m
1 .58792 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .04287 m
.06244 .07482 L
.10458 .12067 L
.14415 .17005 L
.18221 .21803 L
.22272 .26369 L
.26171 .29745 L
.27193 .3042 L
.28302 .31044 L
.2926 .31491 L
.30316 .31882 L
.30809 .32029 L
.3134 .3216 L
.31798 .32252 L
.32299 .3233 L
.32591 .32365 L
.32862 .32389 L
.33121 .32407 L
.33266 .32414 L
.33397 .32418 L
.33527 .32421 L
.33646 .32423 L
.33777 .32423 L
.33843 .32422 L
.33915 .32421 L
.34036 .32419 L
.34167 .32414 L
.3429 .32408 L
.34402 .32402 L
.34631 .32385 L
.34883 .32362 L
.35394 .32297 L
.35867 .32217 L
.36311 .32125 L
.3731 .31858 L
.38387 .31483 L
.40391 .30563 L
.42501 .29321 L
.46312 .26532 L
.50368 .2309 L
.54272 .19624 L
.58422 .16056 L
.6242 .12919 L
.66267 .10282 L
.70359 .07931 L
.74299 .06103 L
.78088 .04717 L
.82122 .03587 L
.86004 .02778 L
.87979 .02453 L
Mistroke
.90132 .02156 L
.94108 .01735 L
.97619 .01472 L
Mfstroke
[ .02 ] 0 setdash
.02381 .04287 m
.04262 .05875 L
.06244 .07965 L
.10458 .13846 L
.14264 .20674 L
.18314 .29027 L
.22214 .37418 L
.26358 .45818 L
.30351 .52583 L
.32179 .55063 L
.34193 .57271 L
.36176 .58874 L
.37262 .59503 L
.38279 .59931 L
.38776 .60084 L
.39038 .6015 L
.39317 .60209 L
.39586 .60255 L
.39829 .60287 L
.39947 .60299 L
.40074 .60311 L
.40193 .60319 L
.40304 .60325 L
.40412 .60329 L
.40528 .60331 L
.40656 .60332 L
.40773 .6033 L
.40895 .60326 L
.40964 .60323 L
.41028 .6032 L
.41269 .60301 L
.41473 .60279 L
.41699 .60248 L
.42157 .60163 L
.42648 .60039 L
.43166 .59873 L
.44091 .59488 L
.45087 .5895 L
.46177 .58225 L
.50233 .54408 L
.54137 .49446 L
.58287 .43341 L
.62285 .37149 L
.66132 .31291 L
.70224 .25477 L
.74164 .20477 L
.77953 .16318 L
.81987 .12611 L
.85869 .09716 L
.89997 .0729 L
Mistroke
.93973 .055 L
.97619 .0425 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.9375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000ga000`40l00?003`ooooJOoo003ooomY
ool00?ooofWoo`00ooooJOoo0035ool200nQool00<Coo`0300ooo`0?0:7oo`00a?oo00<03ooo00l0
XOoo0035ool200nQool00<Koo`0300oooooo09ooo`00ooooJOoo003ooomYool00?ooofWoo`00oooo
JOoo003ooomYool00?ooofWoo`00ooooJOoo000`ool00`0?ooooo`17ool200m6ool300l2ool00`0?
ooooo`12ool300l00ooo00l03`14ool300l2ool00`0?ooooo`0:ool002ooo`0300ooo`0?04[oo`03
00oooooo04Coo`0600oooooo00ooo`0?A?oo00<03oooool00_oo00<03oooool0@Ooo00L03ooooooo
o`0?ool03`0;ool002ooo`0300ooo`0?04Soo`803dOoo`0600oooooo00ooo`0?A?oo00<03oooool0
0P0?AOoo00H03oooool03ooo00l;ool002ooo`0300ooo`0?04Soo`0300oooooo04Koo`0600oooooo
00ooo`0?A?oo00@03oooool03dGoo`0700ooo`0?ool03ooo00l02ooo000`ool00`0?ooooo`17ool3
00m5ool200l3ool00`0?ooooo`12ool200l2ool300m4ool200l2ool00`0?ooooo`0:ool00?ooofWo
o`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`008Ooo00<03ooo
ool01_ooo`0?>@0?1_oo000Pool00`0?ool03`07ool00`0?ooooo`04ool00`0?ooooo`0<ool00`0?
ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0;ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?
ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0;ool00`0?ooooo`0<ool00`0?
ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0;ool00`0?
ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`04ool00`0?
ooooo`04ool0023oo`0300ooo`0?00Ooo`0300oooooo00Coo`0300oooooo04Ooo`0300oooooo04Oo
o`0300oooooo04Soo`0300oooooo04Ooo`0300oooooo00Coo`0300oooooo00Coo`008?oo00<03ooo
00l01ooo0`0?C_oo00<0Soooool0Aooo00<0Soooool0B?oo00<0Ooooool0C?oo0`0?1_oo000Qool0
0`0?ooooo`06ool00`0?ooooo`1>ool00`1oooooo`17ool00`1oooooo`18ool00`2?ooooo`1>ool0
0`0?ooooo`04ool002[oo`0300oooooo04koo`0308oooooo04Ooo`0308oooooo04Soo`0307oooooo
03_oo`d03`Koo`0300oooooo00Coo`00:_oo00<03oooool0C_oo00<0Ooooool0Aooo00<0Ooooool0
B?oo00<0Soooool0<_oo2P0?4_oo00<03oooool01?oo000Zool00`0?ooooo`1>ool00`2?ooooo`17
ool00`2?ooooo`18ool00`1oooooo`0Zool900lKool00`0?ooooo`04ool002[oo`803dooo`0307oo
oooo04Ooo`0307oooooo04Soo`0308oooooo02Coo`L03b;oo`803`Koo`00:_oo00<03oooool0C_oo
00<0Soooool0Aooo00<0Soooool0B?oo00<0Ooooool07ooo1P0?:Ooo00<03oooool01?oo000Zool0
0`0?ooooo`1>ool00`1oooooo`17ool00`1oooooo`18ool00`2?ooooo`0Jool600l^ool00`0?oooo
o`04ool002[oo`0300oooooo04koo`0308oooooo04Ooo`0308oooooo04Soo`0307oooooo01Goo`H0
3c?oo`0300oooooo00Coo`00:_oo00<03oooool0C_oo00<0Ooooool0Aooo00<0Ooooool0B?oo00<0
Soooool04_oo100?>?oo00<03oooool01?oo000Zool200l5ool00`0?ooooo`17ool00`2?ooooo`17
ool00`2?ooooo`18ool00`1oooooo`0>ool500ljool200l6ool002[oo`0300oooooo00Coo`803dSo
o`0307oooooo04Ooo`0307oooooo04Soo`0308oooooo00_oo`@03cooo`0300oooooo00Coo`00:_oo
00<03oooool01Ooo0`0?A_oo00<0Soooool0Aooo00<0Soooool0B?oo00<0Ooooool02?oo100?=Ooo
0P0?2ooo00<03oooool01?oo000Zool00`0?ooooo`07ool200m5ool00`1oooooo`17ool00`1ooooo
o`18ool00`2?ooooo`05ool400leool300l=ool00`0?ooooo`04ool002[oo`0300oooooo00Soo`80
3dCoo`0308oooooo04Ooo`0308oooooo04Soo`0307oooooo00;oo`@03cKoo`803a3oo`0300oooooo
00Coo`00:_oo00<03oooool02Ooo0P0?@ooo00<0Ooooool0Aooo00<0Ooooool0B?oo00<0Soooool0
0`0?Booo00<03oooool01?oo000Zool200l;ool200m2ool00`2?ooooo`17ool00`2?ooooo`18ool4
00leool00`0?ooooo`0Dool200l6ool002[oo`0300oooooo00_oo`<03d3oo`0307oooooo04Ooo`03
07oooooo04Koo`<03cKoo`<03aOoo`0300oooooo00Coo`00:_oo00<03oooool03Ooo0P0??ooo00<0
Soooool0Aooo00<0Soooool0A?oo0`0?00?oo`1oool0<ooo0P0?6_oo00<03oooool01?oo000Zool0
0`0?ooooo`0=ool300lnool00`1oooooo`17ool00`1oooooo`12ool300l3ool00`2?ooooo`0aool0
0`0?ooooo`0Jool00`0?ooooo`04ool002[oo`0300oooooo00koo`<03cgoo`0308oooooo04Ooo`03
08oooooo03ooo`@03`Goo`0307oooooo04koo`0300oooooo00Coo`00:_oo0P0?4?oo0`0???oo00<0
Ooooool0Aooo00<0Ooooool0?Ooo0`0?2?oo00<0Soooool0COoo0P0?1_oo000Zool00`0?ooooo`0@
ool300lkool00`2?ooooo`17ool00`2?ooooo`0kool300l:ool00`1oooooo`0[ool00`0?ooooo`0P
ool00`0?ooooo`04ool002[oo`0300oooooo017oo`<03c[oo`0307oooooo04Ooo`0307oooooo03[o
o`803`coo`0308oooooo02Woo`803b?oo`0300oooooo00Coo`006_oo0`0?00?oo`0?ool00P0?2?oo
00<03oooool04Ooo00@03ooo00l03cWoo`0308oooooo04Ooo`0308oooooo03Soo`<03`goo`0307oo
oooo02Ooo`803bGoo`0300oooooo00Coo`006_oo00<03oooool01Ooo00<03oooool01Ooo00<03ooo
ool05?oo0P0?>?oo00<0Ooooool0Aooo00<0Ooooool0=_oo0`0?3ooo00<0Soooool09_oo00<03ooo
ool09Ooo00<03oooool01?oo000Kool00`0?ooooo`02ool200l8ool300l05@2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0200l0^@1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l00P0?0600S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l300l6ool001[oo`0300ooo`0?00?oo`0300oooooo00Ooo`0300oooooo01Koo`803cKoo`0307oo
oooo04Ooo`0307oooooo03?oo`803a?oo`0308oooooo04koo`0300oooooo00Coo`006ooo0P0?0ooo
0`0?1ooo00<03oooool05ooo0P0?=Ooo00<0Soooool0Aooo00<0Soooool0<Ooo0`0?5?oo00<0Oooo
ool08Ooo00<03oooool0:_oo00<03oooool01?oo000Zool00`0?ooooo`0Eool0100?ooooo`0?=Ooo
00<0Ooooool0Aooo00<0Ooooool0;ooo0`0?5_oo00<0Soooool08?oo00<03oooool0:ooo00<03ooo
ool01?oo000Zool00`0?ooooo`0Fool0100?ool03`0?=?oo00<0Soooool0Aooo00<0Soooool0;_oo
0P0?6?oo00<0Ooooool07_oo0P0?;_oo00<03oooool01?oo000Zool00`0?ooooo`0Gool0100?ool0
3`0?<ooo00<0Ooooool0Aooo00<0Ooooool0;?oo0`0?6Ooo00<0Soooool07Ooo00<03oooool0;_oo
00<03oooool01?oo000Zool200lHool00`0?ooooo`0200lbool00`2?ooooo`17ool00`2?ooooo`0[
ool200lKool00`1oooooo`0Lool00`0?ooooo`0^ool200l6ool002[oo`0300oooooo01Soo`0300oo
oooo00803c7oo`0307oooooo04Ooo`0307oooooo02[oo`803acoo`0308oooooo04koo`0300oooooo
00Coo`00:_oo00<03oooool06?oo00@03oooooooo`803c3oo`0308oooooo04Ooo`0308oooooo02So
o`<03agoo`0307oooooo04koo`0300oooooo00Coo`00:_oo00<03oooool07Ooo0P0?;ooo00<0Oooo
ool0Aooo00<0Ooooool09ooo0P0?7ooo00<0Soooool0C_oo00<03oooool01?oo000Zool00`0?oooo
o`0Nool200l^ool00`2?ooooo`17ool00`2?ooooo`0Uool300lPool00`1oooooo`0Fool200lfool0
0`0?ooooo`04ool002[oo`803b3oo`0300oooooo02coo`0307oooooo04Ooo`0307oooooo02Coo`80
3b;oo`0308oooooo01Goo`0300oooooo03Goo`803`Koo`00:_oo00<03oooool07ooo0P0?;Ooo00<0
Soooool0Aooo00<0Soooool08_oo0`0?8ooo00<0Ooooool05?oo00<03oooool0=ooo00<03oooool0
1?oo000Zool00`0?ooooo`0Lool0100?oooooooo0P0?;?oo00<0Ooooool0Aooo00<0Ooooool08Ooo
0P0?9Ooo00<0Soooool04ooo00<03oooool0>?oo00<03oooool01?oo000Zool00`0?ooooo`0Mool0
100?oooooooo0P0?:ooo00<0Soooool0Aooo00<0Soooool08?oo0P0?9_oo00<0Ooooool04_oo00<0
3oooool0>Ooo00<03oooool01?oo000Zool00`0?ooooo`0Nool0100?oooooooo0P0?:_oo00<0Oooo
ool0Aooo00<0Ooooool07ooo0P0?9ooo00<0Soooool0C_oo00<03oooool01?oo000Zool200lOool0
0`0?ooooo`02ool00`0?ooooo`0Xool00`2?ooooo`17ool00`2?ooooo`0Mool300lXool00`1ooooo
o`1=ool200l6ool002[oo`0300oooooo01ooo`0400ooooooool200lYool00`1oooooo`17ool00`1o
ooooo`0Lool200lZool00`2?ooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo01ooo`0300oo
oooo00;oo`803bSoo`0308oooooo04Ooo`0308oooooo01_oo`803b_oo`0307oooooo00goo`0300oo
oooo03koo`0300oooooo00Coo`00:_oo00<03oooool09Ooo0P0?9ooo00<0Ooooool0Aooo00<0Oooo
ool06_oo0P0?;?oo00<0Soooool03Ooo00<03oooool0?_oo00<03oooool01?oo000Zool00`0?oooo
o`0Vool200lVool00`2?ooooo`17ool00`2?ooooo`0Hool300l]ool00`1oooooo`0;ool200m1ool0
0`0?ooooo`04ool002[oo`0300oooooo02Ooo`0300oooooo02Coo`0307oooooo04Ooo`0307oooooo
01Ooo`803booo`0308oooooo00[oo`0300oooooo047oo`0300oooooo00Coo`00:_oo0P0?:Ooo00<0
3oooool08ooo00<0Soooool0Aooo00<0Soooool05_oo0P0?<?oo00<0Ooooool02Ooo00<03oooool0
@Ooo0P0?1_oo000Zool00`0?ooooo`0Rool00`0?ooooo`03ool200lTool00`1oooooo`17ool00`1o
ooooo`0Eool200laool00`2?ooooo`09ool00`0?ooooo`12ool00`0?ooooo`04ool0023oo`803`So
o`0300oooooo02?oo`0300oooooo00?oo`803b?oo`0308oooooo04Ooo`0308oooooo01Coo`803c;o
o`0307oooooo04koo`0300oooooo00Coo`008_oo00<03oooool01Ooo00<03oooool08ooo00<03ooo
ool01?oo0P0?8_oo00<0Ooooool0Aooo00<0Ooooool04_oo0`0?<ooo00<0Soooool0C_oo00<03ooo
ool01?oo000Pool200l8ool00`0?ooooo`0Tool00`0?ooooo`04ool00`0?ooooo`0Pool00`2?oooo
o`17ool00`2?ooooo`0Aool200leool00`1oooooo`1>ool00`0?ooooo`04ool0023oo`0300oooooo
00Ooo`<03`0[07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l00P0?07h0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l200l0Q@2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?00<03`Koo`008?oo0`0?1ooo00<03oooool09Ooo00<03ooo
ool01?oo0P0?8?oo00<0Soooool0Aooo00<0Soooool03ooo0P0?=ooo00<0Ooooool01?oo00<03ooo
ool0Aooo00<03oooool01?oo000Zool00`0?ooooo`0Uool00`0?ooooo`05ool200lOool00`1ooooo
o`17ool00`1oooooo`0>ool200lhool00`2?ooooo`03ool00`0?ooooo`18ool00`0?ooooo`04ool0
02[oo`0300oooooo02koo`803akoo`0308oooooo04Ooo`0308oooooo00goo`803cWoo`0307oooooo
00;oo`0300oooooo04Woo`0300oooooo00Coo`00:_oo00<03oooool0;ooo00<03oooool07?oo00<0
Ooooool0Aooo00<0Ooooool02ooo0`0?>_oo00D0Soooooooo`0?04coo`0300oooooo00Coo`00:_oo
0P0?<?oo0P0?7Ooo00<0Soooool0Aooo00<0Soooool02_oo0P0???oo00@0Ooooool03dcoo`803`Ko
o`00:_oo00<03oooool0<?oo0P0?7?oo00<0Ooooool0Aooo00<0Ooooool02Ooo0P0??Ooo00<0Sooo
ool0C_oo00<03oooool01?oo000Zool00`0?ooooo`0Xool00`0?ooooo`06ool200lKool00`2?oooo
o`17ool00`2?ooooo`08ool200lnool00`1oooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo
02Woo`0300oooooo00Koo`803a[oo`0307oooooo04Ooo`0307oooooo00Ooo`803cooo`0308oooooo
04koo`0300oooooo00Coo`00:_oo00<03oooool0:Ooo00<03oooool01ooo00<03oooool06?oo00<0
Soooool0Aooo00<0Soooool01_oo0P0??ooo00<03`1oool0Cooo00<03oooool01?oo000Zool200l[
ool00`0?ooooo`06ool200lIool00`1oooooo`17ool00`1oooooo`05ool200m0ool00`0?08ooo`1>
ool200l6ool002[oo`0300oooooo02[oo`0300oooooo00Ooo`803aSoo`0308oooooo04Ooo`0308oo
oooo00Coo`803d3oo`0300ooo`1o053oo`0300oooooo00Coo`00:_oo00<03oooool0:ooo00<03ooo
ool01ooo0P0?5ooo00<0Ooooool0Aooo00<0Ooooool00_oo0`0?@?oo00@03oooool0Se3oo`0300oo
oooo00Coo`00:_oo00<03oooool0:ooo00<03oooool02?oo0P0?5_oo00<0Soooool0Aooo00@0Sooo
ooooo`803d;oo`0400oooooo07m@ool00`0?ooooo`04ool002[oo`0300oooooo03Ooo`803aGoo`03
07oooooo04Ooo`0307oooooo00803d7oo`803`?oo`0308oooooo04koo`0300oooooo00Coo`00:_oo
00<03oooool0>?oo00<03oooool04ooo00<0Soooool0Aooo00@0Sooo00l03dOoo`0307oooooo04ko
o`0300oooooo00Coo`00:_oo0P0?>_oo00<03oooool04_oo00<0Ooooool0Aooo00<0O`0?00l0B?oo
00<0Soooool0COoo0P0?1_oo000Zool00`0?ooooo`0iool200lCool00`2?ooooo`17ool200m9ool0
0`1oooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo03[oo`803a;oo`0307oooooo04Koo`80
3d[oo`0308oooooo04koo`0300oooooo00Coo`00:_oo00<03oooool0;_oo00<03oooool02_oo0P0?
4Ooo00<0Soooool0A?oo0P0?00?oo`2?ool0@Ooo00<03oooool01Ooo00<0Ooooool0C_oo00<03ooo
ool01?oo000Zool00`0?ooooo`0_ool00`0?ooooo`0:ool200l@ool00`1oooooo`13ool200l2ool0
0`1oooooo`0oool00`0?ooooo`06ool00`2?ooooo`1>ool00`0?ooooo`04ool002[oo`803c3oo`03
00oooooo00_oo`803`ooo`0308oooooo04;oo`803`?oo`0308oooooo03koo`0300oooooo00Ooo`03
07oooooo04goo`803`Koo`00:_oo00<03oooool0<?oo00<03oooool02ooo0P0?3_oo00<0Ooooool0
@Ooo0P0?1?oo00<0Ooooool0?Ooo00<03oooool02?oo00<0Soooool0C_oo00<03oooool01?oo000Z
ool00`0?ooooo`0`ool00`0?ooooo`0<ool200l=ool00`2?ooooo`10ool200l5ool00`2?ooooo`0l
ool00`0?ooooo`09ool00`1oooooo`1>ool00`0?ooooo`04ool001_oo`0500oooooo00ooo`0200l8
ool00`0?ooooo`0aool00`0?ooooo`0<ool00`0?ooooo`0;ool00`1oooooo`0nool300l6ool00`1o
ooooo`0lool00`0?ooooo`09ool00`2?ooooo`1>ool00`0?ooooo`04ool001_oo`0300oooooo00Co
o`0300oooooo00Goo`0300oooooo043oo`803`coo`0308oooooo03goo`803`Soo`0308oooooo04So
o`0307oooooo04koo`0300oooooo00Coo`007?oo00@03oooooooo`803`Soo`<03`1107l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`0200l0BP2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l200l0X`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?00<03`Koo`007?oo00D03oooooooo`0?00Woo`0300oooooo04;oo`803`[oo`0308oooooo
03_oo`803`[oo`0308oooooo04Soo`0307oooooo04koo`0300oooooo00Coo`006_oo0`0?0ooo0`0?
1ooo00<03oooool0A?oo0P0?2?oo00<0Ooooool0>Ooo0`0?2ooo00<0Ooooool0B?oo00<0Soooool0
C_oo00<03oooool01?oo000Zool00`0?ooooo`15ool200l7ool00`2?ooooo`0hool200l=ool00`2?
ooooo`0hool00`0?ooooo`0=ool00`1oooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo03?o
o`0300oooooo013oo`803`Koo`0307oooooo03Ooo`803`koo`0307oooooo03Soo`0300oooooo00go
o`0308oooooo04koo`0300oooooo00Coo`002Ooo00<03oooool07_oo00<03oooool0=?oo00<03ooo
ool04?oo0P0?1Ooo00<0Soooool0=Ooo0`0?3ooo00<0Soooool0=ooo00<03oooool03_oo00<0Oooo
ool0C_oo00<03oooool01?oo0009ool300lNool200leool00`0?ooooo`0Aool200l4ool00`1ooooo
o`0dool200lAool00`1oooooo`0fool00`0?ooooo`0?ool00`2?ooooo`1=ool200l6ool000coo`<0
3a_oo`0300oooooo03Goo`0300oooooo017oo`803`?oo`0308oooooo03?oo`803a;oo`0308oooooo
03Koo`0300oooooo00ooo`0307oooooo04koo`0300oooooo00Coo`002Ooo00@03ooo00l03agoo`03
00oooooo03Koo`0300oooooo017oo`<03`03ool0Oooo03;oo`<03a?oo`0307oooooo03Goo`0300oo
oooo013oo`0308oooooo04koo`0300oooooo00Coo`002Ooo0P0?7ooo00<03oooool0=_oo00<03ooo
ool04ooo0P0?00<0Soooool0<?oo0P0?5Ooo00<0Soooool0B?oo00<0Ooooool0C_oo00<03oooool0
1?oo000Zool00`0?ooooo`1=ool200l`ool300lFool00`1oooooo`18ool00`2?ooooo`1>ool00`0?
ooooo`04ool000[oo`0500ooooooool03`0Kool200m?ool200l]ool300lHool00`2?ooooo`18ool0
0`1oooooo`1=ool200l6ool000[oo`D03a_oo`0300oooooo04koo`0407l03`0?00lZool200lJool0
0`1oooooo`18ool00`2?ooooo`1>ool00`0?ooooo`04ool000coo`0300oooooo01_oo`0300oooooo
04koo`0308oooooo00<03bKoo`<03a_oo`0308oooooo037oo`0300oooooo01Coo`0307oooooo04ko
o`0300oooooo00Coo`002_oo1@0?6ooo00<03oooool0C_oo00<0Ooooool00_oo0P0?8ooo0`0?7Ooo
00<0Ooooool0<Ooo00<03oooool05?oo00<0Soooool0C_oo00<03oooool01?oo000:ool200l2ool0
0`0?ooooo`0Iool00`0?ooooo`0iool00`0?ooooo`0Bool00`2?ooooo`03ool300lOool300lOool0
0`2?ooooo`0`ool00`0?ooooo`0Eool00`1oooooo`1>ool00`0?ooooo`04ool000[oo`803`;oo`03
00oooooo01Woo`803c[oo`0300oooooo01;oo`0307oooooo00Goo`@03aWoo`<03b;oo`0307oooooo
02ooo`803aOoo`0308oooooo04goo`803`Koo`002Ooo1P0?6ooo00<03oooool0>_oo00<03oooool0
4Ooo00<0Soooool02?oo100?4ooo100?9?oo00<0Soooool0;ooo00<03oooool05_oo00<0Ooooool0
C_oo00<03oooool01?oo000>ool200lJool00`0?ooooo`0jool00`0?ooooo`0Aool00`1oooooo`0;
ool500l;ool500lWool00`1oooooo`0^ool00`0?ooooo`0Gool00`2?ooooo`1>ool00`0?ooooo`04
ool000koo`0300oooooo01Woo`0300oooooo03_oo`0300oooooo013oo`0308oooooo00ooo`d03b_o
o`0308oooooo02koo`0300oooooo01Ooo`0307oooooo04koo`0300oooooo00Coo`002ooo100?6ooo
00<03oooool0>ooo00<03oooool04?oo00<0Ooooool0Aooo00<0Ooooool0B?oo00<0Soooool0C_oo
00<03oooool01?oo000;ool0100?ooooo`0?6ooo00<03oooool0>ooo00<03oooool04?oo00<0Sooo
ool0Aooo00<0Soooool0B?oo00<0Ooooool0C_oo00<03oooool01?oo000:ool01@0?oooooooo00l0
6ooo0P0?Cooo00<0Ooooool0Aooo00<0Ooooool0B?oo00<0Soooool0COoo0P0?1_oo000:ool500lK
ool00`0?ooooo`1>ool00`2?ooooo`17ool00`2?ooooo`18ool00`1oooooo`1>ool00`0?ooooo`04
ool000[oo`0500ooooooool03`0=ool300l2ool00`0?ooooo`06ool00`0?ooooo`1>ool00`1ooooo
o`17ool00`1oooooo`0Zool00`0?ooooo`0Kool00`2?ooooo`1>ool00`0?ooooo`04ool000koo`03
00oooooo00coo`0600oooooo00ooo`0?1ooo00<03oooool0C_oo00<0Soooool0Aooo00<0Soooool0
:Ooo00<03oooool07?oo00<0Ooooool0C_oo00<03oooool01?oo000=ool200l>ool01P0?ooooo`0?
ool03`Ooo`0300oooooo03koo`0300oooooo00goo`0307oooooo04Ooo`0307oooooo02Woo`0300oo
oooo01coo`0308oooooo04koo`0300oooooo00Coo`007Ooo00H03oooool03ooo00l7ool300l0o`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`00<`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`0300l6ool001coo`803`?oo`0300oooooo00Koo`0300oooooo03ooo`0300oo
oooo00coo`0307oooooo04Ooo`0307oooooo02Ooo`0300oooooo01koo`0308oooooo04koo`0300oo
oooo00Coo`00:_oo00<03oooool0?ooo00<03oooool03?oo00<0Soooool0Aooo00<0Soooool09ooo
00<03oooool07_oo00<0Ooooool0C_oo00<03oooool01?oo000Zool00`0?ooooo`10ool00`0?oooo
o`0;ool00`1oooooo`17ool00`1oooooo`18ool00`2?ooooo`1>ool00`0?ooooo`04ool002[oo`03
00oooooo043oo`0300oooooo00_oo`0308oooooo04Ooo`0308oooooo04Soo`0307oooooo04koo`03
00oooooo00Coo`00:_oo0P0?@_oo00<03oooool02_oo00<0Ooooool0Aooo00<0Ooooool0B?oo00<0
Soooool0COoo0P0?1_oo000Zool00`0?ooooo`1>ool00`2?ooooo`17ool00`2?ooooo`18ool00`1o
ooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo04koo`0307oooooo04Ooo`0307oooooo02?o
o`0300oooooo02;oo`0308oooooo04koo`0300oooooo00Coo`00:_oo00<03oooool0C_oo00<0Sooo
ool0Aooo00<0Soooool08ooo00<03oooool08_oo00<0Ooooool0C_oo00<03oooool01?oo000Zool0
0`0?ooooo`1>ool00`1oooooo`17ool00`1oooooo`0Rool00`0?ooooo`0Sool00`2?ooooo`1>ool0
0`0?ooooo`04ool002[oo`0300oooooo04koo`0308oooooo04Ooo`0308oooooo02;oo`0300oooooo
02?oo`0307oooooo04koo`0300oooooo00Coo`00:_oo0P0?A?oo00<03oooool02?oo00<0Ooooool0
Aooo00<0Ooooool08Ooo00<03oooool09?oo00<0Soooool0COoo0P0?1_oo000Zool00`0?ooooo`14
ool00`0?ooooo`07ool00`2?ooooo`17ool00`2?ooooo`0Pool00`0?ooooo`0Uool00`1oooooo`1>
ool00`0?ooooo`04ool002[oo`0300oooooo04Coo`0300oooooo00Ooo`0307oooooo04Ooo`0307oo
oooo023oo`0300oooooo02Goo`0308oooooo04koo`0300oooooo00Coo`00:_oo00<03oooool0AOoo
00<03oooool01_oo00<0Soooool0Aooo00<0Soooool0B?oo00<0Ooooool0C_oo00<03oooool01?oo
000Zool00`0?ooooo`15ool00`0?ooooo`06ool00`1oooooo`17ool00`1oooooo`18ool00`2?oooo
o`1>ool00`0?ooooo`04ool002[oo`803dOoo`0300oooooo00Goo`0308oooooo04Ooo`0308oooooo
04Soo`0307oooooo04goo`803`Koo`00:_oo00<03oooool0C_oo00<0Ooooool0Aooo00<0Ooooool0
B?oo00<0Soooool0C_oo00<03oooool01?oo000Zool00`0?ooooo`1>ool00`2?ooooo`17ool00`2?
ooooo`0Lool200lZool00`1oooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo04koo`0307oo
oooo04Ooo`0307oooooo01coo`0300oooooo02Woo`0308oooooo04koo`0300oooooo00Coo`00:_oo
00<03oooool0C_oo00<0Soooool0Aooo00<0Soooool06ooo00<03oooool0:_oo00<0Ooooool0C_oo
00<03oooool01?oo000Zool200m?ool00`1oooooo`17ool00`1oooooo`0Jool00`0?ooooo`0[ool0
0`2?ooooo`1=ool200l6ool002[oo`0300oooooo04Woo`0300oooooo00;oo`0308oooooo04Ooo`03
08oooooo01[oo`0300oooooo02_oo`0307oooooo04koo`0300oooooo00Coo`00:_oo00<03oooool0
BOoo00<03oooool00_oo00<0Ooooool0Aooo00<0Ooooool06Ooo00<03oooool0;?oo00<0Soooool0
C_oo00<03oooool01?oo000Fool300l01ooo00l03`0?ool03ooo00803`Soo`0300oooooo04[oo`05
00ooooooool0S`19ool00`2?ooooo`18ool00`1oooooo`1>ool00`0?ooooo`04ool001Ooo`0400oo
oooo00l7ool00`0?ooooo`05ool00`0?ooooo`1:ool01@0?oooooooo07l0BOoo00<0Ooooool0B?oo
00<0Soooool0C_oo00<03oooool01?oo000Gool01@0?oooooooo00l01?oo0P0?2?oo0`0?0?l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l003<0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l00`0?1_oo000Gool01P0?ooooo`0?ool03`?oo`0300oooooo00Ooo`0300oooooo
04coo`0300ooo`1o04Woo`0307oooooo04Soo`0308oooooo04koo`0300oooooo00Coo`005_oo0P0?
0ooo0P0?0ooo0`0?1ooo00<03oooool0C_oo00<0Soooool0Aooo00<0Soooool05_oo00<03oooool0
;ooo00<0Ooooool0C_oo00<03oooool01?oo000Zool00`0?ooooo`1>ool00`1oooooo`17ool00`1o
ooooo`0Eool00`0?ooooo`0`ool00`2?ooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo04ko
o`0308oooooo04Ooo`0308oooooo01Coo`0300oooooo037oo`0307oooooo04koo`0300oooooo00Co
o`00:_oo00<03oooool0C_oo00<0Ooooool0Aooo00<0Ooooool05?oo00<03oooool0<Ooo00<0Sooo
ool0C_oo00<03oooool01?oo000Zool200m?ool00`2?ooooo`17ool00`2?ooooo`0Cool00`0?oooo
o`0bool00`1oooooo`1=ool200l6ool002[oo`0300oooooo04koo`0300oooooo04Ooo`0307oooooo
01;oo`0300oooooo03?oo`0308oooooo04koo`0300oooooo00Coo`00:_oo00<03oooool0C_oo00<0
S`0?ool0Aooo00<0Soooool0B?oo00<0Ooooool0C_oo00<03oooool01?oo000Zool00`0?ooooo`1>
ool00`1o00ooo`17ool00`1oooooo`18ool00`2?ooooo`1>ool00`0?ooooo`04ool002[oo`0300oo
oooo04koo`0308ooo`0?04Ooo`0308oooooo04Soo`0307oooooo04koo`0300oooooo00Coo`00:_oo
0P0?Cooo00@0Ooooool03dKoo`0307oooooo04Soo`0308oooooo04goo`803`Koo`00:_oo00<03ooo
ool0C_oo00@0Soooool03dKoo`0308oooooo00ooo`0300oooooo03Koo`0307oooooo04koo`0300oo
oooo00Coo`00:_oo00<03oooool0C_oo00<0Ooooool0Aooo00<0Ooooool03_oo00<03oooool0=ooo
00<0Soooool0C_oo00<03oooool01?oo000Zool00`0?ooooo`1>ool00`2?ooooo`17ool00`2?oooo
o`0>ool00`0?ooooo`0gool00`1oooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo04koo`03
07oooooo04Ooo`0307oooooo00goo`0300oooooo03Soo`0308oooooo04koo`0300oooooo00Coo`00
:_oo0P0?Cooo00<0Soooool0Aooo00<0Soooool03?oo00<03oooool0>Ooo00<0Ooooool0COoo0P0?
1_oo000Zool00`0?ooooo`1>ool00`1oooooo`17ool00`1oooooo`0<ool00`0?ooooo`0iool00`2?
ooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo04koo`0308oooooo00Coo`0300oooooo043o
o`0308oooooo00_oo`0300oooooo03[oo`0307oooooo04koo`0300oooooo00Coo`00:_oo00<03ooo
ool0C_oo00<0Ooooool01?oo00<03oooool0@?oo00<0Ooooool0B?oo00<0Soooool0C_oo00<03ooo
ool01?oo000Zool00`0?ooooo`1>ool00`2?ooooo`05ool00`0?ooooo`0oool00`2?ooooo`18ool0
0`1oooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo04koo`0307oooooo00Koo`0300oooooo
03koo`0307oooooo04Soo`0308oooooo04koo`0300oooooo00Coo`00:_oo0P0?Cooo00<0Soooool0
1_oo00<03oooool0?_oo00<0Soooool0B?oo00<0Ooooool0COoo0P0?1_oo000Zool00`0?ooooo`1>
ool00`1oooooo`07ool00`0?ooooo`0mool00`1oooooo`07ool00`0?ooooo`0nool00`2?ooooo`1>
ool00`0?ooooo`04ool001coo`<03`03ool03`0?00Soo`0300oooooo04koo`0308oooooo04Ooo`03
08oooooo00Koo`0300oooooo03ooo`0307oooooo04koo`0300oooooo00Coo`007Ooo00<03oooool0
0_oo00<03oooool01Ooo00<03oooool0C_oo00<0Ooooool0Aooo00<0Ooooool01_oo00<03oooool0
?ooo00<0Soooool0C_oo00<03oooool01?oo000Mool00`0?ooooo`0200l8ool00`0?ooooo`1>ool0
0`2?ooooo`17ool00`2?ooooo`05ool00`0?ooooo`10ool00`1oooooo`1>ool00`0?ooooo`04ool0
01goo`0400oooooo00l9ool300l0o`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`00<`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0300l6ool001coo`803`;oo`<03`Oo
o`0300oooooo04koo`0308oooooo00[oo`0300oooooo03[oo`0308oooooo00Coo`0300oooooo047o
o`0307oooooo04koo`0300oooooo00Coo`00:_oo00<03oooool0C_oo00<0Ooooool02_oo00<03ooo
ool0>_oo00<0Ooooool0B?oo00<0Soooool0C_oo00<03oooool01?oo000Zool00`0?ooooo`1>ool0
0`2?ooooo`0;ool00`0?ooooo`0iool00`2?ooooo`18ool00`1oooooo`1>ool00`0?ooooo`04ool0
02[oo`0300oooooo04koo`0307oooooo00coo`0300oooooo03Soo`0307oooooo04Soo`0308oooooo
04koo`0300oooooo00Coo`00:_oo0P0?Cooo00<0Soooool03?oo00<03oooool0>?oo00@0Soooool0
3dOoo`0307oooooo04goo`803`Koo`00:_oo00<03oooool0C_oo00<0Ooooool03Ooo0P0?>?oo00<0
Oooo00l0B?oo00<0Soooool0C_oo00<03oooool01?oo000Zool00`0?ooooo`1>ool00`2?ooooo`17
ool00`2?ool03`18ool00`1oooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo04koo`0307oo
oooo04Ooo`0307l03ooo04Soo`0308oooooo04koo`0300oooooo00Coo`00:_oo00<03oooool0C_oo
00<0Soooool0A_oo0P0?B_oo00<0Ooooool0C_oo00<03oooool01?oo000Zool00`0?ooooo`1>ool0
0`1oooooo`16ool00`0?07ooo`19ool00`2?ooooo`1>ool00`0?ooooo`04ool002[oo`803dooo`03
08oooooo017oo`0300oooooo03?oo`0308oooooo04Soo`0307oooooo04goo`803`Koo`00:_oo00<0
3oooool0C_oo00<0Ooooool04_oo00<03oooool0<_oo00<0Ooooool0B?oo00<0Soooool0C_oo00<0
3oooool01?oo000Zool00`0?ooooo`1>ool00`2?ooooo`0Cool00`0?ooooo`0aool00`2?ooooo`18
ool00`1oooooo`1>ool00`0?ooooo`04ool002[oo`0300oooooo04koo`0307oooooo01Coo`0300oo
oooo02[oo`0300oooooo00?oo`0307oooooo04Soo`0308oooooo04koo`0300oooooo00Coo`00:_oo
00<03oooool0C_oo00<0Soooool05Ooo00<03oooool0:?oo00<03oooool01?oo00<0Soooool0B?oo
00<0Ooooool0C_oo00<03oooool01?oo000Zool200m?ool00`1oooooo`0Fool00`0?ooooo`0Vool0
0`0?ooooo`05ool00`1oooooo`18ool00`2?ooooo`1=ool200l6ool002[oo`0300oooooo04koo`03
08oooooo03koo`0300oooooo00Koo`0308oooooo04Soo`0307oooooo04koo`0300oooooo00Coo`00
:_oo00<03oooool0C_oo00<0Ooooool0??oo0P0?2Ooo00<0Ooooool0B?oo00<0Soooool0C_oo00<0
3oooool01?oo000Zool00`0?ooooo`1>ool00`2?ooooo`17ool00`2?ooooo`18ool00`1oooooo`1>
ool00`0?ooooo`04ool002[oo`0300oooooo04koo`0307oooooo01[oo`803b_oo`0307oooooo04So
o`0308oooooo04koo`0300oooooo00Coo`00:_oo0P0?Cooo00<0Soooool07?oo00<03oooool0:?oo
00<0Soooool0B?oo00<0Ooooool0COoo0P0?1_oo000Zool00`0?ooooo`1>ool00`1oooooo`0Mool2
00lHool00`0?ooooo`0=ool00`1oooooo`18ool00`2?ooooo`1>ool00`0?ooooo`04ool002[oo`03
00oooooo04koo`0308oooooo01ooo`803aCoo`803a3oo`0308oooooo04Soo`0307oooooo04koo`03
00oooooo00Coo`005_oo0`0?0_oo00D03oooool03ooo00803`Soo`0300oooooo04koo`0307oooooo
03?oo`803a;oo`0307oooooo04Soo`0308oooooo04koo`0300oooooo00Coo`005ooo00D03ooooooo
o`0?00Koo`0300oooooo00Goo`0300oooooo04koo`0308oooooo02Goo`0300oooooo00[oo`0300oo
oooo01;oo`0308oooooo04Soo`0307oooooo04koo`0300oooooo00Coo`005ooo00<03oooool00_oo
00@03oooooooo`803`Soo`<03dkoo`0307oooooo02Koo`L03a[oo`0307oooooo04Soo`0308oooooo
04coo`<03`Koo`005ooo00<03oooool00_oo00D03oooooooo`0?00Woo`0300oooooo04koo`0308oo
oooo04Ooo`0308oooooo04Soo`0307oooooo04koo`0300oooooo00Coo`005_oo0P0?0_oo0`0?0ooo
0`0?1ooo00<03oooool0C_oo00<0Ooooool0Aooo00<0Ooooool0B?oo00<0Soooool0C_oo00<03ooo
ool01?oo000Zool00`0?ooooo`04ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool0
0`0?ooooo`0;ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool0
0`0?ooooo`0<ool00`0?ooooo`0;ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool0
0`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0;ool00`0?ooooo`0<ool00`0?ooooo`0<ool0
0`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`04ool00`0?ooooo`04ool002[oo`0300oooooo
00Coo`0300oooooo00coo`0300oooooo00coo`0300oooooo00coo`0300oooooo00_oo`0300oooooo
00coo`0300oooooo00coo`0300oooooo00coo`0300oooooo00coo`0300oooooo00coo`0300oooooo
00_oo`0300oooooo00coo`0300oooooo00coo`0300oooooo00coo`0300oooooo00coo`0300oooooo
00coo`0300oooooo00_oo`0300oooooo00coo`0300oooooo00coo`0300oooooo00coo`0300oooooo
00coo`0300oooooo00Coo`0300oooooo00Coo`00:_ooo`0?>@0?1_oo003ooomYool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.336166, -2.792403, 
  0.084253, 0.117773}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[dVs]; \)\), 
    \(\(dVs[d_, r_] = \[PartialD]\_{d, 1}Vs[d, r]; \)\), 
    \(\(Clear[damx]; \)\), 
    \(dmax[r_] := 
      \(FindRoot[dVs[d, r], {d, 5}]\)\[LeftDoubleBracket]1, 2
        \[RightDoubleBracket]\), 
    \(Print["\<dmax = \>", dmax[1.1]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[\("dmax = "\[InvisibleSpace]6.5808965543904625`\),
      SequenceForm[ "dmax = ", 6.58089655439046251],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Area"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[As]; \)\), 
    \(\(As[d_, r_] := \[PartialD]\_r Vs[d, r]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(tbl2 = Table[As[d, r], {d, 0, 3, 1}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, 2, 2\ \[Pi]\ r, 4\ \[Pi]\ r\^2}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Solid Angle"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[thetas, r]; \)\), 
    \(\(thetas[d_] = \[PartialD]\_r Vs[d, r]\/r\^\(d - 1\); \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(tbl3 = Table[thetas[d], {d, 0, 3, 1}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, 2, 2\ \[Pi], 4\ \[Pi]}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Density of States in Arbitrary Dimensions"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Volume in k-Space"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Vk, k]; \)\), 
    \(Vk[d_, k_] := Vs[d, r] /. r \[Rule] k\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(tbl4 = Table[Vk[d, k], {d, 1, 3, 1}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2\ k, k\^2\ \[Pi], \(4\ k\^3\ \[Pi]\)\/3}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Energy in the Parabolic Approximation"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[En, k]; \)\), 
    \(\(En[k_] := \(hbar\^2\ k\^2\)\/\(2\ me\); \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(kEn = 
      \(Solve[En[k] == En, k]\)\[LeftDoubleBracket]2, 1, 2
        \[RightDoubleBracket]; \)\), 
    \(Print["\<kEn = \>", kEn]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[\("kEn = "\[InvisibleSpace]\(\@2\ \@En\ \@me\)\/hbar\),
      SequenceForm[ "kEn = ", 
        Times[ 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ En, 
            Rational[ 1, 2]], 
          Power[ hbar, -1], 
          Power[ me, 
            Rational[ 1, 2]]]],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Density of States"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[nk]; \)\), 
    \(nk[d_, k_] := \(2\ Vk[d, k]\)\/\((2\ \[Pi])\)\^d\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[nkEn]; \)\), 
    \(\(nkEn[d_, En_] := nk[d, k] /. k \[Rule] kEn; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[rho]; \)\), 
    \(\(rho[d_, En_] = \[PartialD]\_En nkEn[d, En]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Print["\<dos in 1-d = \>", rho[1, En]]\), 
    \(Print["\<dos in 2-d = \>", rho[2, En]]\), 
    \(Print["\<dos in 3-d = \>", rho[3, En]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("dos in 1-d = "\[InvisibleSpace]\(\@2\ \@me\)\/\(\@En\ hbar\ 
            \[Pi]\)\),
      SequenceForm[ "dos in 1-d = ", 
        Times[ 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ En, 
            Rational[ -1, 2]], 
          Power[ hbar, -1], 
          Power[ me, 
            Rational[ 1, 2]], 
          Power[ Pi, -1]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("dos in 2-d = "\[InvisibleSpace]me\/\(hbar\^2\ \[Pi]\)\),
      SequenceForm[ "dos in 2-d = ", 
        Times[ 
          Power[ hbar, -2], me, 
          Power[ Pi, -1]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("dos in 3-d = "\[InvisibleSpace]\(\@2\ \@En\ 
            me\^\(3/2\)\)\/\(hbar\^3\ \[Pi]\^2\)\),
      SequenceForm[ "dos in 3-d = ", 
        Times[ 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ En, 
            Rational[ 1, 2]], 
          Power[ hbar, -3], 
          Power[ me, 
            Rational[ 3, 2]], 
          Power[ Pi, -2]]],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig14x2 = 
      Plot[{atto\ L\ rho[1, e\ En] /. case, 
          atto\ L\^2\ rho[2, e\ En] /. case, 
          atto\ L\^3\ rho[3, e\ En] /. case}, {En, 0.01, 2}, 
        AxesOrigin \[Rule] {0, 0}, 
        FrameLabel \[Rule] {"\<E in eV\>", "\<DOS\>"}, Evaluate[opt]]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.019024 0.478583 -0.010945 0.006035 [
[.01902 -0.0125 -4 -12 ]
[.01902 -0.0125 4 0 ]
[.25832 -0.0125 -7 -12 ]
[.25832 -0.0125 7 0 ]
[.49761 -0.0125 -4 -12 ]
[.49761 -0.0125 4 0 ]
[.7369 -0.0125 -7 -12 ]
[.7369 -0.0125 7 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14.5 -24 ]
[.5 -0.0125 14.5 -12 ]
[-0.0125 .10976 -12 -6 ]
[-0.0125 .10976 0 6 ]
[-0.0125 .23046 -12 -6 ]
[-0.0125 .23046 0 6 ]
[-0.0125 .35116 -12 -6 ]
[-0.0125 .35116 0 6 ]
[-0.0125 .47186 -12 -6 ]
[-0.0125 .47186 0 6 ]
[-0.0125 .59256 -16 -6 ]
[-0.0125 .59256 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -10 ]
[-0.01875 .30902 -16 10 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.25832 0 m
.25832 .61803 L
s
.49761 0 m
.49761 .61803 L
s
.7369 0 m
.7369 .61803 L
s
0 .10976 m
1 .10976 L
s
0 .23046 m
1 .23046 L
s
0 .35116 m
1 .35116 L
s
0 .47186 m
1 .47186 L
s
0 g
.01902 0 m
.01902 .00625 L
s
gsave
.01902 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25832 0 m
.25832 .00625 L
s
gsave
.25832 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.49761 0 m
.49761 .00625 L
s
gsave
.49761 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7369 0 m
.7369 .00625 L
s
gsave
.7369 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06688 0 m
.06688 .00375 L
s
.11474 0 m
.11474 .00375 L
s
.1626 0 m
.1626 .00375 L
s
.21046 0 m
.21046 .00375 L
s
.30617 0 m
.30617 .00375 L
s
.35403 0 m
.35403 .00375 L
s
.40189 0 m
.40189 .00375 L
s
.44975 0 m
.44975 .00375 L
s
.54547 0 m
.54547 .00375 L
s
.59332 0 m
.59332 .00375 L
s
.64118 0 m
.64118 .00375 L
s
.68904 0 m
.68904 .00375 L
s
.78476 0 m
.78476 .00375 L
s
.83262 0 m
.83262 .00375 L
s
.88047 0 m
.88047 .00375 L
s
.92833 0 m
.92833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(E) show
69.875000 13.000000 moveto
(in) show
78.062500 13.000000 moveto
(eV) show
87.312500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .10976 m
.00625 .10976 L
s
gsave
-0.0125 .10976 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .23046 m
.00625 .23046 L
s
gsave
-0.0125 .23046 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .35116 m
.00625 .35116 L
s
gsave
-0.0125 .35116 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .47186 m
.00625 .47186 L
s
gsave
-0.0125 .47186 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .59256 m
.00625 .59256 L
s
gsave
-0.0125 .59256 -77 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .13993 m
.00375 .13993 L
s
0 .17011 m
.00375 .17011 L
s
0 .20028 m
.00375 .20028 L
s
0 .26063 m
.00375 .26063 L
s
0 .29081 m
.00375 .29081 L
s
0 .32098 m
.00375 .32098 L
s
0 .38133 m
.00375 .38133 L
s
0 .41151 m
.00375 .41151 L
s
0 .44168 m
.00375 .44168 L
s
0 .50203 m
.00375 .50203 L
s
0 .53221 m
.00375 .53221 L
s
0 .56238 m
.00375 .56238 L
s
0 .07958 m
.00375 .07958 L
s
0 .04941 m
.00375 .04941 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -93 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
71 10 translate
90 rotate
-71 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(DOS) show
78.937500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.01902 .61178 m
.01902 .61803 L
s
.25832 .61178 m
.25832 .61803 L
s
.49761 .61178 m
.49761 .61803 L
s
.7369 .61178 m
.7369 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06688 .61428 m
.06688 .61803 L
s
.11474 .61428 m
.11474 .61803 L
s
.1626 .61428 m
.1626 .61803 L
s
.21046 .61428 m
.21046 .61803 L
s
.30617 .61428 m
.30617 .61803 L
s
.35403 .61428 m
.35403 .61803 L
s
.40189 .61428 m
.40189 .61803 L
s
.44975 .61428 m
.44975 .61803 L
s
.54547 .61428 m
.54547 .61803 L
s
.59332 .61428 m
.59332 .61803 L
s
.64118 .61428 m
.64118 .61803 L
s
.68904 .61428 m
.68904 .61803 L
s
.78476 .61428 m
.78476 .61803 L
s
.83262 .61428 m
.83262 .61803 L
s
.88047 .61428 m
.88047 .61803 L
s
.92833 .61428 m
.92833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .10976 m
1 .10976 L
s
.99375 .23046 m
1 .23046 L
s
.99375 .35116 m
1 .35116 L
s
.99375 .47186 m
1 .47186 L
s
.99375 .59256 m
1 .59256 L
s
.125 Mabswid
.99625 .13993 m
1 .13993 L
s
.99625 .17011 m
1 .17011 L
s
.99625 .20028 m
1 .20028 L
s
.99625 .26063 m
1 .26063 L
s
.99625 .29081 m
1 .29081 L
s
.99625 .32098 m
1 .32098 L
s
.99625 .38133 m
1 .38133 L
s
.99625 .41151 m
1 .41151 L
s
.99625 .44168 m
1 .44168 L
s
.99625 .50203 m
1 .50203 L
s
.99625 .53221 m
1 .53221 L
s
.99625 .56238 m
1 .56238 L
s
.99625 .07958 m
1 .07958 L
s
.99625 .04941 m
1 .04941 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .60332 m
.02499 .53943 L
.02605 .49584 L
.02721 .45883 L
.02846 .42659 L
.03068 .38262 L
.03279 .35129 L
.03527 .32248 L
.0379 .29837 L
.04262 .26571 L
.04749 .24093 L
.05205 .22288 L
.06244 .19299 L
.06788 .18131 L
.07305 .17189 L
.08274 .1574 L
.09331 .14496 L
.10458 .13434 L
.12439 .11997 L
.14277 .10985 L
.16275 .10115 L
.18435 .09357 L
.22442 .08282 L
.26542 .07466 L
.30491 .06853 L
.34288 .06373 L
.38331 .05946 L
.42222 .05598 L
.46358 .05279 L
.50342 .05011 L
.54175 .04783 L
.58253 .04566 L
.6218 .04379 L
.65955 .04215 L
.69975 .04056 L
.73844 .03916 L
.77958 .03778 L
.81921 .03656 L
.85731 .03547 L
.89788 .03438 L
.93692 .03341 L
.97619 .03249 L
s
[ .02 ] 0 setdash
.02381 .1464 m
.06244 .1464 L
.10458 .1464 L
.14415 .1464 L
.18221 .1464 L
.22272 .1464 L
.26171 .1464 L
.30316 .1464 L
.34309 .1464 L
.3815 .1464 L
.42237 .1464 L
.46172 .1464 L
.49955 .1464 L
.53984 .1464 L
.57861 .1464 L
.61984 .1464 L
.65954 .1464 L
.69774 .1464 L
.73838 .1464 L
.77751 .1464 L
.81909 .1464 L
.85916 .1464 L
.89771 .1464 L
.93871 .1464 L
.97619 .1464 L
s
.02381 .01472 m
.02846 .02508 L
.03279 .03257 L
.04262 .04603 L
.06244 .06635 L
.10458 .09755 L
.14357 .11996 L
.18502 .14018 L
.22495 .15737 L
.26336 .1724 L
.30423 .18714 L
.34358 .20037 L
.38141 .21234 L
.4217 .22443 L
.46047 .2355 L
.5017 .24675 L
.54141 .25714 L
.5796 .26677 L
.62025 .27666 L
.65938 .28587 L
.70096 .29536 L
.74102 .30423 L
.77957 .31253 L
.82058 .32114 L
.86007 .32922 L
.89804 .33681 L
.93846 .34472 L
.97619 .35194 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{172, 106},
  ImageMargins->{{109, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003G0000QA000`40l00?003`eooo003Gool00=Oo
o`00eooo001_ool400l2ool01P0?ooooo`0?ool03`Coo`803`03ool03`0?05?oo`00L?oo00<03ooo
ool00_oo00H03oooool03ooo00l3ool0100?oooooooo0P0?Dooo001`ool200l3ool01P0?ooooo`0?
ool03`?oo`0400ooo`0?00l2ool00`0?ooooo`1@ool0073oo`0300oooooo00;oo`0300oooooo0080
3`Goo`<03`;oo`0300oooooo053oo`00Kooo100?3_oo00@03oooool03e;oo`00MOoo00<03oooool0
Gooo003Gool00=Ooo`00eooo003Gool00=Ooo`00eooo000Yool00`0?ooooo`0Rool01@0?ooooo`0?
ool00P0?9?oo0`0?8_oo0`0?00?oo`0?ool00P0?9?oo0`0?2_oo000Xool00`0?ool03`0Rool00`0?
ool03`05ool00`0?ooooo`0Rool00`0?ooooo`0Rool00`0?ooooo`04ool00`0?ooooo`0Qool00`0?
ooooo`0:ool002Soo`0300ooo`0?02;oo`0300ooo`0?00?oo`803bGoo`0300oooooo02;oo`0300oo
oooo00;oo`803bGoo`0300oooooo00Woo`00:?oo00<03ooo00l08_oo00<03ooo00l00ooo00<03ooo
ool09?oo00<03oooool08_oo00<03oooool00_oo00<03oooool08ooo00<03ooo00l02_oo000Yool0
0`0?ooooo`0Rool00`0?ooooo`02ool300lSool200lSool200l4ool300lTool200l:ool00=Ooo`00
eooo003Gool00=Ooo`00eooo000VoonZ00l7ool002Koo`0400oooooo00l7ool00`0?ooooo`05ool0
0`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`06ool00`0?ooooo`05ool00`0?ooooo`05ool0
0`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05ool0
0`0?ooooo`05ool00`0?ooooo`06ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05ool0
0`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05ool01@0?oooooooo00l01ooo000Vool00`0?
ooooo`0Yool00`2?ooooo`0Uool00`2?ooooo`0Vool00`1oooooo`0Yool00`0?ooooo`05ool002Ko
o`0500ooooooool03`0Wool00`1oooooo`0Uool00`1oooooo`0Vool00`2?ooooo`0Yool00`0?oooo
o`05ool002Koo`0300oooooo00;oo`0300oooooo02Coo`0308oooooo02Goo`0308oooooo02Koo`03
07oooooo02Woo`0300oooooo00Goo`009_oo00<03oooool00_oo00<03oooool09?oo00<0Ooooool0
9Ooo00<0Ooooool09_oo00<0Soooool0:Ooo00<03oooool01Ooo000Vool00`0?ooooo`02ool00`0?
ooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Vool00`1oooooo`04oolR00l3ool00`0?ooooo`05
ool002Koo`0300oooooo02Woo`0307oooooo02Goo`0307oooooo01?ooa/03bCoo`0300oooooo00Go
o`009_oo00<03oooool01?oo00<03oooool08_oo00<0Soooool09Ooo00<0Soooool0500?4_oo00<0
Ooooool0:Ooo00<03oooool01Ooo000Vool00`0?ooooo`05ool00`0?ooooo`0Qool00`1oooooo`0J
ool?00lUool00`2?ooooo`0Yool00`0?ooooo`05ool002Koo`0300oooooo00Koo`0300oooooo023o
o`0308oooooo00ooo``03`[oo`0308oooooo02Koo`0307oooooo02Woo`0300oooooo00Goo`009_oo
00<03oooool01ooo00<03oooool07ooo00<0Ooooool01_oo2P0?5Ooo00<0Ooooool09_oo00<0Sooo
ool0:Ooo00<03oooool01Ooo000Vool00`0?ooooo`0Yool00`2?ooooo`0700lNool00`2?ooooo`0V
ool00`1oooooo`0Yool00`0?ooooo`05ool002Koo`0300oooooo00Woo`803a_oo`H03bGoo`0307oo
oooo02Koo`0308oooooo02Woo`0300oooooo00Goo`009_oo00<03oooool02ooo00<03oooool05?oo
1@0?0_oo00<0Soooool09Ooo00<0Soooool09_oo00<0Ooooool0:Ooo00<03oooool01Ooo000Vool0
0`0?ooooo`0<ool00`0?ooooo`0?ool500l6ool00`1oooooo`0Uool00`1oooooo`0Vool00`2?oooo
o`0Yool00`0?ooooo`05ool001[oo`<03`;oo`0300oooooo00Coo`0300oooooo01_oo`@03`[oo`03
08oooooo02Goo`0308oooooo02Koo`0307oooooo02Woo`0300oooooo00Goo`006_oo00L03ooooooo
o`0?ool03`05ool00`0?ooooo`0?ool200l7ool400l=ool00`1oooooo`0Uool00`1oooooo`0Vool0
0`2?ooooo`0Yool00`0?ooooo`05ool001_oo`0600oooooo00ooo`0?1Ooo00<03oooool04Ooo00<0
3oooool00_oo0`0?4?oo00<0Soooool09Ooo00<0Soooool09_oo00<0Ooooool0:Ooo00<03oooool0
1Ooo000Jool01`0?ool03ooo00ooo`0?00Goo`803`0E07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l03`1o00<03`2>07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l200l7ool001_oo`803`;oo`0300oooooo00Coo`0300oooooo01;oo`@03a?oo`0308oooooo
02Goo`0308oooooo02Koo`0307oooooo02Woo`0300oooooo00Goo`009_oo00<03oooool04?oo0`0?
0ooo0P0?4Ooo00<0Ooooool09Ooo00<0Ooooool09_oo00<0Soooool0:Ooo00<03oooool01Ooo000V
ool00`0?ooooo`0?ool200l7ool00`0?ooooo`0>ool00`2?ooooo`0Uool00`2?ooooo`0Vool00`1o
ooooo`0Yool00`0?ooooo`05ool002Koo`0300oooooo00koo`803`_oo`0300oooooo00_oo`0307oo
oooo02Goo`0307oooooo02Koo`0308oooooo02Woo`0300oooooo00Goo`009_oo00<03oooool03Ooo
0P0?3Ooo0P0?2ooo00<0Soooool09Ooo00<0Soooool09_oo00<0Ooooool0:Ooo00<03oooool01Ooo
000Vool0100?oooooooo100?0ooo2`0?0_oo1@0?0_oo100?0ooo100?0_oo00<0O`0?00l00P0?0_oo
1@0?0_oo100?0ooo100?0ooo100?0_oo1@0?00?oo`1o00l0100?0_oo100?0ooo100?0_oo1@0?0_oo
1@0?0_oo100?0_oo00<0S`0?00l00P0?0ooo100?0_oo1@0?0_oo1@0?0_oo100?0ooo100?1Ooo00<0
3oooool01Ooo000Vool00`0?ooooo`0;ool200lDool200l6ool00`2?ooooo`0Uool00`2?ooooo`0V
ool00`1oooooo`0Yool00`0?ooooo`05ool002Koo`0300oooooo00[oo`803aOoo`803`Coo`0307oo
oooo02Goo`0307oooooo02Koo`0308oooooo02Woo`0300oooooo00Goo`009_oo00<03oooool02_oo
00<03oooool07?oo00<0Soooool09Ooo00<0Soooool09_oo00<0Ooooool0:Ooo00<03oooool01Ooo
000Vool00`0?ooooo`09ool200lLool300lWool00`1oooooo`0Vool00`2?ooooo`0Yool00`0?oooo
o`05ool002Koo`0300oooooo00Woo`0300oooooo01goo`0308l03`0?02Goo`0308oooooo02Koo`03
07oooooo02Woo`0300oooooo00Goo`009_oo00<03oooool02?oo0P0?7ooo00<0Ooooool00_oo0P0?
8Ooo00<0Ooooool09_oo00<0Soooool0:Ooo00<03oooool01Ooo000Vool00`0?ooooo`08ool00`0?
ooooo`0Nool00`2?ooooo`04ool200lOool00`2?ooooo`0Vool00`1oooooo`0Yool00`0?ooooo`05
ool002Koo`0300oooooo00Ooo`803b3oo`0307oooooo00Soo`803a_oo`0307oooooo02Koo`0308oo
oooo02Woo`0300oooooo00Goo`009_oo00<03oooool01ooo00<03oooool07ooo00<0Soooool02_oo
0P0?6Ooo00<0Soooool09_oo00<0Ooooool0:Ooo00<03oooool01Ooo000Vool00`0?ooooo`06ool2
00lQool00`1oooooo`0?ool00`0?ooooo`0Cool00`1oooooo`0Vool00`2?ooooo`0Yool00`0?oooo
o`05ool002Koo`0300oooooo00Koo`0300oooooo023oo`0308oooooo013oo`<03a;oo`0308oooooo
02Koo`0307oooooo02Woo`0300oooooo00Goo`007?oo00@03oooool03`Koo`0300oooooo00Koo`03
00oooooo023oo`0307oooooo01Goo`803`koo`0307oooooo02Koo`0308oooooo02Woo`0300oooooo
00Goo`006_oo0`0?00Coo`0?ool03`Goo`0300oooooo00Goo`803b;oo`0308oooooo01Ooo`803`co
o`0308oooooo02Koo`0307oooooo02Woo`0300oooooo00Goo`006_oo00L03ooo00ooo`0?ool03`05
ool200l0B@1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00803`1K08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l00P0?1ooo000Kool200l01?oo
00ooo`0?1Ooo00<03oooool01Ooo00<03oooool08Ooo00<0Soooool07_oo0P0?1Ooo00<0Soooool0
9_oo00<0Ooooool0:Ooo00<03oooool01Ooo000Lool0100?ooooo`0?1_oo00<03oooool01Ooo00<0
3oooool08Ooo00<0Ooooool08_oo0`0?00<0Ooooool09_oo00<0Soooool0:Ooo00<03oooool01Ooo
000Vool00`0?ooooo`05ool00`0?ooooo`0Qool00`2?ooooo`0Uool00`0?ooooo`0Vool00`1ooooo
o`0Yool00`0?ooooo`05ool002Koo`0300oooooo00Coo`803b?oo`0307oooooo02Goo`0407oooooo
ool300lRool00`2?ooooo`0Yool00`0?ooooo`05ool002Koo`0300oooooo00Coo`0300oooooo02;o
o`0308oooooo02Goo`0308oooooo00Coo`0400oooooo00lNool00`1oooooo`0Yool00`0?ooooo`05
ool000[oo`0300oooooo00;oo`0300oooooo01Coo`0300oooooo00Coo`0300oooooo02;oo`0307oo
oooo02Goo`0307oooooo00Soo`<03a_oo`0308oooooo02Woo`0300oooooo00Goo`002_oo1P0?5_oo
00<03oooool01?oo00<03oooool08_oo00<0Soooool09Ooo00<0Soooool03_oo0P0?5_oo00<0Oooo
ool0:Ooo00<03oooool01Ooo000:ool00`0?ooooo`02ool00`0?ooooo`0Dool00`0?ooooo`04ool0
0`0?ooooo`0Rool00`1oooooo`0Uool00`1oooooo`0@ool200lDool00`2?ooooo`0Yool00`0?oooo
o`05ool000[oo`0300oooooo00;oo`0300oooooo01Coo`0300oooooo00Coo`0300oooooo02;oo`03
08oooooo02Goo`0308oooooo01Coo`D03`goo`0307oooooo02Woo`0300oooooo00Goo`002ooo00@0
3oooool03aOoo`0300oooooo00?oo`803bCoo`0307oooooo02Goo`0307oooooo01_oo`803`Woo`03
08oooooo02Woo`0300oooooo00Goo`003?oo0P0?6?oo00<03oooool00ooo00<03oooool08ooo00<0
Soooool09Ooo00<0Soooool07Ooo0P0?1ooo00<0Ooooool0:Ooo00<03oooool01Ooo000<ool200lH
ool00`0?ooooo`03ool00`0?ooooo`0Sool00`1oooooo`0Uool00`1oooooo`0Rool400l00`2?oooo
o`0Yool00`0?ooooo`05ool000_oo`0300oooooo00803aKoo`0300oooooo00?oo`0300oooooo02?o
o`0308oooooo02Goo`0308oooooo02Koo`0307ooo`0?00803bOoo`0300oooooo00Goo`002_oo00<0
3oooool00_oo00<03oooool05?oo00<03oooool00ooo00<03oooool08ooo00<0Ooooool09Ooo00<0
Ooooool09_oo00<0Soooool00_oo00D03oooooooo`0?02;oo`0300oooooo00Goo`002_oo00<03ooo
ool00_oo00<03oooool05?oo00<03oooool00ooo00<03oooool08ooo00<0Soooool09Ooo00<0Sooo
ool09_oo00<0Ooooool01_oo100?7ooo00<03oooool01Ooo000;ool00`0?ooooo`0200lFool00`0?
ooooo`03ool00`0?ooooo`0Sool00`1oooooo`0Uool00`1oooooo`0Vool00`2?ooooo`0<ool400lI
ool00`0?ooooo`05ool000coo`803aSoo`0300oooooo00?oo`0300oooooo02?oo`0308oooooo02Go
o`0308oooooo02Koo`0307oooooo013oo`0300oooooo00803aCoo`0300oooooo00Goo`002ooo00<0
3oooool00P0?2ooo00D03oooooooo`0?00Koo`0300oooooo00?oo`0300oooooo02?oo`0307oooooo
02Goo`0307oooooo02Koo`0308oooooo01Goo`803a;oo`0300oooooo00Goo`002_oo00<03ooo00l0
0_oo00<03oooool02?oo00L03ooo00ooo`0?ool03`05ool00`0?ooooo`02ool200lUool00`2?oooo
o`0Uool00`2?ooooo`0Vool00`1oooooo`0Jool400l;ool00`0?ooooo`05ool000[oo`0600oooooo
00ooo`0?2_oo0P0?0_oo00<03ooo00l01Ooo00<03oooool00_oo00<03oooool09?oo00<0Ooooool0
9Ooo00<0Ooooool09_oo00<0Soooool08?oo1@0?1?oo00<03oooool01Ooo000:ool200l2ool00`0?
ooooo`09ool01`0?oooooooo00ooo`0?00Goo`803`2V08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l200l7ool001_oo`803`;oo`0300oooooo00Coo`0300oooooo00;oo`0300oooooo02Coo`03
07oooooo02Goo`0307oooooo02Koo`0308oooooo02Woo`0300oooooo00Goo`009_oo00<03oooool0
0_oo00<03oooool09?oo00<0Soooool09Ooo00<0Soooool09_oo00<0Ooooool0:Ooo00<03oooool0
1Ooo000Vool00`0?ooooo`02ool00`0?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Vool00`2?
ooooo`0Yool00`0?ooooo`05ool002Koo`0300oooooo00;oo`0300oooooo02Coo`0308oooooo02Go
o`0308oooooo02Koo`0307oooooo02Woo`0300oooooo00Goo`009_oo00<03oooool00_oo00<03ooo
ool09?oo00<0Ooooool09Ooo00<0Ooooool09_oo00<0Soooool0:Ooo00<03oooool01Ooo000Vool0
0`0?ooooo`02ool00`0?ooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Vool00`1oooooo`0Yool0
0`0?ooooo`05ool002Koo`0300oooooo00;oo`0300oooooo02Coo`0307oooooo02Goo`0307oooooo
02Koo`0308oooooo02Woo`0300oooooo00Goo`009_oo00<03oooool00_oo00<03oooool09?oo00<0
Soooool09Ooo00<0Soooool09_oo00<0Ooooool0:Ooo00<03oooool01Ooo000Vool00`0?ooooo`02
ool00`0?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Vool00`2?ooooo`0Yool00`0?ooooo`05
ool002Koo`0300oooooo00;oo`0300oooooo02Coo`0308oooooo02Goo`0308oooooo02Koo`0307oo
oooo02Woo`0300oooooo00Goo`009_oo00<03oooool00_oo00<03oooool09?oo00<0Ooooool09Ooo
00<0Ooooool09_oo00<0Soooool0:Ooo00<03oooool01Ooo000Vool00`0?ooooo`02ool00`0?oooo
o`0Tool00`2?ooooo`0Uool00`2?ooooo`0Vool00`1oooooo`0Yool00`0?ooooo`05ool002Koo`03
00oooooo00;oo`0300oooooo02Coo`0307oooooo02Goo`0307oooooo02Koo`0308oooooo02Woo`03
00oooooo00Goo`009_oo00<03oooool00_oo00<03oooool09?oo00<0Soooool09Ooo00<0Soooool0
9_oo00<0Ooooool0:Ooo00<03oooool01Ooo000Vool00`0?ooooo`02ool00`0?ooooo`0Tool00`1o
ooooo`0Uool00`1oooooo`0Vool00`2?ooooo`0Yool00`0?ooooo`05ool002Koo`0400ooooooool2
00lVool00`2?ooooo`0Uool00`2?ooooo`0Vool00`1oooooo`0Yool00`0?ooooo`05ool002Koo`05
00ooooooool03`0Wool00`1oooooo`0Uool00`1oooooo`0Vool00`2?ooooo`0Yool00`0?ooooo`05
ool001_oo`0500ooooooool03`06ool01@0?oooooooo00l09ooo00<0Soooool09Ooo00<0Soooool0
9_oo00<0Ooooool0:Ooo00<03oooool01Ooo000Jool01`0?ool03ooo00ooo`0?00Goo`0500oooooo
ool03`0Wool00`1oooooo`0Uool00`1oooooo`0Vool00`2?ooooo`0Yool00`0?ooooo`05ool001_o
o`0600oooooo00ooo`0?1Ooo0P0?0:H0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`803`Oo
o`006_oo00L03ooo00ooo`0?ool03`05ool01@0?oooooooo00l09ooo00<0Ooooool09Ooo00<0Oooo
ool09_oo00<0Soooool0:Ooo00<03oooool01Ooo000Kool01@0?oooooooo00l01_oo00D03ooooooo
o`0?02Ooo`0308oooooo02Goo`0308oooooo02Koo`0307oooooo02Woo`0300oooooo00Goo`009_oo
00D03oooooooo`0?02Ooo`0307oooooo02Goo`0307oooooo02Koo`0308oooooo02Woo`0300oooooo
00Goo`009_oo00D03oooooooo`0?02Ooo`0308oooooo02Goo`0308oooooo02Koo`0307oooooo02Wo
o`0300oooooo00Goo`009_oo00D03oooooooo`0?02Ooo`0307oooooo02Goo`0307oooooo02Koo`03
08oooooo02Woo`0300oooooo00Goo`009_oo00D03oooooooo`0?02Ooo`0308oooooo02Goo`0308oo
oooo02Koo`0307oooooo02Woo`0300oooooo00Goo`009_oo00D03oooooooo`0?02Ooo`0307oooooo
02Goo`0307oooooo02Koo`0308oooooo02Woo`0300oooooo00Goo`009_oo00D03oooooooo`0?02Oo
o`0308oooooo02Goo`0308oooooo02Koo`0307oooooo02Woo`0300oooooo00Goo`009_oo00D03ooo
ooooo`0?02Ooo`0307oooooo02Goo`0307oooooo02Koo`0308oooooo02Woo`0300oooooo00Goo`00
9_oo00D03oooooooo`0?02Ooo`0308oooooo02Goo`0308oooooo02Koo`0307oooooo02Woo`0300oo
oooo00Goo`009_oo00D03oooooooo`0?02Ooo`0307oooooo02Goo`0307oooooo02Koo`0308oooooo
02Woo`0300oooooo00Goo`009_oo00D03oooooooo`0?02Ooo`0308oooooo02Goo`0308oooooo02Ko
o`0307oooooo02Woo`0300oooooo00Goo`009_oo00D03oooooooo`0?02Ooo`0307oooooo02Goo`03
07oooooo02Koo`0308oooooo02Woo`0300oooooo00Goo`009_oo00D03oooooooo`0?02Ooo`0308oo
oooo02Goo`0308oooooo02Koo`0307oooooo02Woo`0300oooooo00Goo`009_oo00D03oooooooo`0?
02Ooo`0307oooooo02Goo`0307oooooo02Koo`0308oooooo02Woo`0300oooooo00Goo`009_oo00D0
3oooooooo`0?02Ooo`0308oooooo02Goo`0308oooooo02Koo`0307oooooo02Woo`0300oooooo00Go
o`009_oo00D03oooooooo`0?02Ooo`0307oooooo02Goo`0307oooooo02Koo`0308oooooo02Woo`03
00oooooo00Goo`005_oo0`0?0_oo00D03oooooooo`0?00Koo`0500ooooooool03`0Wool00`2?oooo
o`0Uool00`2?ooooo`0Vool00`1oooooo`0Yool00`0?ooooo`05ool001Ooo`0:00oooooo00ooo`0?
ool03ooo00l5ool01@0?oooooooo00l09ooo00<0Ooooool09Ooo00<0Ooooool09_oo00<0Soooool0
:Ooo00<03oooool01Ooo000Gool02P0?ooooo`0?ool03ooo00ooo`0?1Ooo0P0?0_oo00<03oooool0
9Ooo00<0Soooool09Ooo00<0Soooool09_oo00<0Ooooool0:?oo0P0?1ooo000Gool02P0?ooooo`0?
ool03ooo00ooo`0?1Ooo00D03oooooooo`0?02Ooo`0307oooooo02Goo`0307oooooo02Koo`0308oo
oooo02Woo`0300oooooo00Goo`005_oo0P0?0ooo00D03oooooooo`0?00Koo`0500ooooooool03`0W
ool00`2?ooooo`0Uool00`2?ooooo`0Vool00`1oooooo`0Yool00`0?ooooo`05ool002Koo`0300oo
oooo02Woo`0307oooooo02Goo`0307oooooo02Koo`0308oooooo02Woo`0300oooooo00Goo`009_oo
00@03oooool03`Ooo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Ko
o`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Go
o`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Koo`0300oooooo00Go
o`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Go
o`0500ooooooool03`07ool002KoojX03`Ooo`00eooo0000\
\>"],
  ImageRangeCache->{{{0, 214}, {131.5, 0}} -> {-0.51246, -22.755409, 0.015418,
   1.222677}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig14x3 = 
      Plot3D[atto\ Vs[d, L]\ rho[d, e\ En] /. case, {d, 0, 3}, {En, 0.1, 2}, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        AxesLabel \[Rule] {"\<d\>", "\<E [eV]\>", "\<DOS\>"}]; \)\)], "Input",\

  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
5.55111e-17 1.049774 -0.067959 1.049774 [
[.02757 .24618 -8 -11.60368 ]
[.02757 .24618 0 .39632 ]
[.22808 .16727 -7.72692 -12 ]
[.22808 .16727 .27308 0 ]
[.44535 .08183 -7.17095 -12 ]
[.44535 .08183 .82905 0 ]
[.68156 -0.01098 -6.61497 -12 ]
[.68156 -0.01098 1.38503 0 ]
[.29165 .07573 -7.44894 -12 ]
[.29165 .07573 .55106 0 ]
[.77078 .10213 0 -8.20922 ]
[.77078 .10213 14 3.79078 ]
[.84915 .22213 0 -8.05587 ]
[.84915 .22213 8 3.94413 ]
[.9191 .32925 0 -7.92242 ]
[.9191 .32925 14 4.07758 ]
[.98191 .42546 0 -7.80525 ]
[.98191 .42546 8 4.19475 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 26 3.95831 ]
[.02411 .26511 -8 -3.65642 ]
[.02411 .26511 0 8.34358 ]
[.01059 .34988 -16 -3.75209 ]
[.01059 .34988 0 8.24791 ]
[-0.0037 .43946 -16 -3.85374 ]
[-0.0037 .43946 0 8.14626 ]
[-0.05457 .39542 -20 -3.77786 ]
[-0.05457 .39542 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -69 -15.60368 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.23703 .17687 m
.2415 .18167 L
s
gsave
.22808 .16727 -68.72692 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.4535 .09211 m
.45758 .09725 L
s
gsave
.44535 .08183 -68.17095 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -67.61497 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.0759 .23997 m
.07874 .24269 L
s
.11524 .22456 m
.11804 .22733 L
s
.1552 .20892 m
.15797 .21172 L
s
.19579 .19302 m
.19852 .19586 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.40878 .10962 m
.41128 .11266 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.64007 .01906 m
.64229 .02231 L
s
gsave
.29165 .07573 -68.44894 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75847 .10666 m
.75231 .10893 L
s
gsave
.77078 .10213 -61 -12.20922 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.83673 .22638 m
.83053 .22851 L
s
gsave
.84915 .22213 -61 -12.05587 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.9066 .33325 m
.90035 .33526 L
s
gsave
.9191 .32925 -61 -11.92242 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.80525 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.77486 .13175 m
.77116 .13309 L
s
.79088 .15624 m
.78717 .15756 L
s
.80652 .18016 m
.8028 .18147 L
s
.8218 .20354 m
.81808 .20483 L
s
.85133 .24872 m
.8476 .24998 L
s
.86561 .27055 m
.86188 .2718 L
s
.87957 .29191 m
.87583 .29314 L
s
.89323 .31281 m
.88949 .31402 L
s
.91968 .35327 m
.91593 .35445 L
s
.93249 .37286 m
.92873 .37403 L
s
.94503 .39204 m
.94127 .3932 L
s
.95731 .41083 m
.95355 .41198 L
s
.74167 .08097 m
.73798 .08235 L
s
.72446 .05465 m
.72078 .05604 L
s
.70682 .02766 m
.70315 .02908 L
s
.68874 0 m
.68507 .00144 L
s
gsave
.91861 .21225 -61 -12.04169 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(E) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
69.875000 13.000000 moveto
(@) show
72.875000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(eV) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
82.125000 13.000000 moveto
(D) show
84.750000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
gsave
.02411 .26511 -69 -7.65642 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02288 .34528 m
.02902 .34298 L
s
gsave
.01059 .34988 -77 -7.75209 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.00865 .43504 m
.01483 .43283 L
s
gsave
-0.0037 .43946 -77 -7.85374 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.0337 .27696 m
.03737 .27553 L
s
.03104 .29376 m
.03471 .29235 L
s
.02835 .31075 m
.03203 .30934 L
s
.02563 .32792 m
.02931 .32653 L
s
.02009 .36283 m
.02378 .36146 L
s
.01728 .38058 m
.02098 .37922 L
s
.01444 .39853 m
.01813 .39718 L
s
.01156 .41668 m
.01526 .41534 L
s
.00571 .4536 m
.00942 .45229 L
s
.00273 .47238 m
.00645 .47108 L
s
gsave
-0.05457 .39542 -81 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(DOS) show
78.937500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.655 .739 .911 r
.38313 .58323 .40512 .60371 .44187 .59343 .42018 .57272 Metetra
.649 .738 .915 r
.42018 .57272 .44187 .59343 .47913 .58362 .45776 .5627 Metetra
.639 .736 .919 r
.45776 .5627 .47913 .58362 .51694 .57456 .4959 .55346 Metetra
.625 .732 .924 r
.4959 .55346 .51694 .57456 .55534 .56658 .53463 .54531 Metetra
.606 .727 .931 r
.53463 .54531 .55534 .56658 .59439 .56005 .57402 .53862 Metetra
.581 .719 .937 r
.57402 .53862 .59439 .56005 .63418 .55542 .61416 .5338 Metetra
.548 .706 .944 r
.61416 .5338 .63418 .55542 .67482 .55315 .65515 .53129 Metetra
.507 .688 .949 r
.65515 .53129 .67482 .55315 .71645 .55375 .69713 .53156 Metetra
.458 .664 .951 r
.69713 .53156 .71645 .55375 .75925 .55777 .74026 .53506 Metetra
.402 .631 .947 r
.74026 .53506 .75925 .55777 .80342 .56574 .78475 .54227 Metetra
.342 .592 .938 r
.78475 .54227 .80342 .56574 .8492 .57821 .83081 .55362 Metetra
.284 .548 .923 r
.83081 .55362 .8492 .57821 .89688 .59571 .87869 .56953 Metetra
.235 .503 .903 r
.87869 .56953 .89688 .59571 .94677 .61876 .92869 .59035 Metetra
.201 .462 .882 r
.92869 .59035 .94677 .61876 .99922 .6478 .98111 .61639 Metetra
.655 .739 .912 r
.36056 .56222 .38313 .58323 .42018 .57272 .39794 .55148 Metetra
.648 .738 .915 r
.39794 .55148 .42018 .57272 .45776 .5627 .43584 .54126 Metetra
.638 .736 .919 r
.43584 .54126 .45776 .5627 .4959 .55346 .4743 .53183 Metetra
.623 .732 .925 r
.4743 .53183 .4959 .55346 .53463 .54531 .51337 .52352 Metetra
.604 .727 .931 r
.51337 .52352 .53463 .54531 .57402 .53862 .55311 .51666 Metetra
.579 .719 .938 r
.55311 .51666 .57402 .53862 .61416 .5338 .59359 .51165 Metetra
.548 .707 .945 r
.59359 .51165 .61416 .5338 .65515 .53129 .63494 .50889 Metetra
.509 .689 .949 r
.63494 .50889 .65515 .53129 .69713 .53156 .67727 .50878 Metetra
.463 .666 .951 r
.67727 .50878 .69713 .53156 .74026 .53506 .72075 .51173 Metetra
.412 .637 .948 r
.72075 .51173 .74026 .53506 .78475 .54227 .76555 .51811 Metetra
.359 .602 .94 r
.76555 .51811 .78475 .54227 .83081 .55362 .81189 .52826 Metetra
.311 .563 .927 r
.81189 .52826 .83081 .55362 .87869 .56953 .86 .54247 Metetra
.271 .525 .91 r
.86 .54247 .87869 .56953 .92869 .59035 .91011 .56097 Metetra
.246 .49 .892 r
.91011 .56097 .92869 .59035 .98111 .61639 .9625 .58388 Metetra
.654 .739 .912 r
.33741 .54067 .36056 .56222 .39794 .55148 .3751 .52969 Metetra
.647 .738 .915 r
.3751 .52969 .39794 .55148 .43584 .54126 .41333 .51926 Metetra
.636 .735 .92 r
.41333 .51926 .43584 .54126 .4743 .53183 .45213 .50966 Metetra
.622 .732 .926 r
.45213 .50966 .4743 .53183 .51337 .52352 .49153 .50118 Metetra
.603 .727 .932 r
.49153 .50118 .51337 .52352 .55311 .51666 .53162 .49416 Metetra
.578 .719 .939 r
.53162 .49416 .55311 .51666 .59359 .51165 .57246 .48895 Metetra
.547 .707 .945 r
.57246 .48895 .59359 .51165 .63494 .50889 .61416 .48592 Metetra
.51 .691 .95 r
.61416 .48592 .63494 .50889 .67727 .50878 .65685 .48541 Metetra
.468 .669 .951 r
.65685 .48541 .67727 .50878 .72075 .51173 .70068 .48775 Metetra
.422 .643 .948 r
.70068 .48775 .72075 .51173 .76555 .51811 .74581 .49323 Metetra
.377 .611 .941 r
.74581 .49323 .76555 .51811 .81189 .52826 .79244 .50209 Metetra
.338 .578 .93 r
.79244 .50209 .81189 .52826 .86 .54247 .84076 .51449 Metetra
.307 .545 .916 r
.84076 .51449 .86 .54247 .91011 .56097 .891 .53053 Metetra
.29 .516 .9 r
.891 .53053 .91011 .56097 .9625 .58388 .94337 .5502 Metetra
.653 .739 .912 r
.31365 .51855 .33741 .54067 .3751 .52969 .35166 .50733 Metetra
.646 .737 .916 r
.35166 .50733 .3751 .52969 .41333 .51926 .39022 .4967 Metetra
.635 .735 .921 r
.39022 .4967 .41333 .51926 .45213 .50966 .42935 .48692 Metetra
.62 .732 .926 r
.42935 .48692 .45213 .50966 .49153 .50118 .4691 .47829 Metetra
.601 .726 .933 r
.4691 .47829 .49153 .50118 .53162 .49416 .50953 .4711 Metetra
.576 .719 .94 r
.50953 .4711 .53162 .49416 .57246 .48895 .55073 .4657 Metetra
.547 .708 .946 r
.55073 .4657 .57246 .48895 .61416 .48592 .5928 .46237 Metetra
.512 .692 .95 r
.5928 .46237 .61416 .48592 .65685 .48541 .63585 .46142 Metetra
.474 .673 .951 r
.63585 .46142 .65685 .48541 .70068 .48775 .68003 .4631 Metetra
.434 .649 .949 r
.68003 .4631 .70068 .48775 .74581 .49323 .7255 .4676 Metetra
.396 .622 .943 r
.7255 .4676 .74581 .49323 .79244 .50209 .77242 .47505 Metetra
.365 .593 .933 r
.77242 .47505 .79244 .50209 .84076 .51449 .82097 .48553 Metetra
.344 .566 .92 r
.82097 .48553 .84076 .51449 .891 .53053 .87134 .49898 Metetra
.334 .541 .905 r
.87134 .49898 .891 .53053 .94337 .5502 .92369 .51528 Metetra
.652 .739 .913 r
.28926 .49583 .31365 .51855 .35166 .50733 .32759 .48439 Metetra
.644 .737 .917 r
.32759 .48439 .35166 .50733 .39022 .4967 .36647 .47356 Metetra
.633 .735 .922 r
.36647 .47356 .39022 .4967 .42935 .48692 .40594 .46362 Metetra
.618 .731 .927 r
.40594 .46362 .42935 .48692 .4691 .47829 .44603 .45483 Metetra
.598 .726 .934 r
.44603 .45483 .4691 .47829 .50953 .4711 .48682 .44749 Metetra
.575 .719 .941 r
.48682 .44749 .50953 .4711 .55073 .4657 .52838 .44187 Metetra
.546 .708 .946 r
.52838 .44187 .55073 .4657 .5928 .46237 .57082 .43823 Metetra
.514 .694 .95 r
.57082 .43823 .5928 .46237 .63585 .46142 .61424 .4368 Metetra
.48 .676 .951 r
.61424 .4368 .63585 .46142 .68003 .4631 .65878 .43774 Metetra
.446 .655 .949 r
.65878 .43774 .68003 .4631 .7255 .4676 .70459 .44117 Metetra
.416 .632 .944 r
.70459 .44117 .7255 .4676 .77242 .47505 .75181 .4471 Metetra
.393 .608 .935 r
.75181 .4471 .77242 .47505 .82097 .48553 .8006 .4555 Metetra
.38 .585 .923 r
.8006 .4555 .82097 .48553 .87134 .49898 .8511 .46622 Metetra
.378 .564 .909 r
.8511 .46622 .87134 .49898 .92369 .51528 .90346 .47902 Metetra
.651 .738 .913 r
.2642 .4725 .28926 .49583 .32759 .48439 .30285 .46083 Metetra
.643 .737 .917 r
.30285 .46083 .32759 .48439 .36647 .47356 .34206 .44983 Metetra
.631 .735 .923 r
.34206 .44983 .36647 .47356 .40594 .46362 .38187 .43973 Metetra
.615 .731 .929 r
.38187 .43973 .40594 .46362 .44603 .45483 .42231 .43081 Metetra
.596 .726 .935 r
.42231 .43081 .44603 .45483 .48682 .44749 .46345 .42332 Metetra
.573 .719 .942 r
.46345 .42332 .48682 .44749 .52838 .44187 .50538 .41748 Metetra
.546 .71 .947 r
.50538 .41748 .52838 .44187 .57082 .43823 .54819 .4135 Metetra
.517 .697 .951 r
.54819 .4135 .57082 .43823 .61424 .4368 .59199 .41153 Metetra
.487 .681 .952 r
.59199 .41153 .61424 .4368 .65878 .43774 .6369 .41166 Metetra
.459 .662 .949 r
.6369 .41166 .65878 .43774 .70459 .44117 .68306 .41389 Metetra
.437 .642 .944 r
.68306 .41389 .70459 .44117 .75181 .4471 .73059 .41817 Metetra
.422 .622 .935 r
.73059 .41817 .75181 .4471 .8006 .4555 .77962 .42434 Metetra
.416 .603 .924 r
.77962 .42434 .8006 .4555 .8511 .46622 .83027 .43217 Metetra
.42 .586 .91 r
.83027 .43217 .8511 .46622 .90346 .47902 .88265 .44131 Metetra
.65 .738 .914 r
.23846 .44853 .2642 .4725 .30285 .46083 .27743 .43665 Metetra
.64 .736 .918 r
.27743 .43665 .30285 .46083 .34206 .44983 .31697 .42549 Metetra
.628 .734 .924 r
.31697 .42549 .34206 .44983 .38187 .43973 .35711 .41527 Metetra
.612 .731 .93 r
.35711 .41527 .38187 .43973 .42231 .43081 .3979 .40623 Metetra
.593 .727 .937 r
.3979 .40623 .42231 .43081 .46345 .42332 .4394 .3986 Metetra
.571 .72 .943 r
.4394 .3986 .46345 .42332 .50538 .41748 .4817 .39253 Metetra
.546 .711 .948 r
.4817 .39253 .50538 .41748 .54819 .4135 .52489 .38818 Metetra
.52 .699 .951 r
.52489 .38818 .54819 .4135 .59199 .41153 .56907 .38561 Metetra
.495 .685 .952 r
.56907 .38561 .59199 .41153 .6369 .41166 .61436 .38482 Metetra
.474 .67 .949 r
.61436 .38482 .6369 .41166 .68306 .41389 .66087 .38573 Metetra
.459 .653 .944 r
.66087 .38573 .68306 .41389 .73059 .41817 .70872 .38819 Metetra
.451 .636 .935 r
.70872 .38819 .73059 .41817 .77962 .42434 .75801 .39195 Metetra
.452 .62 .923 r
.75801 .39195 .77962 .42434 .83027 .43217 .80882 .3967 Metetra
.46 .605 .908 r
.80882 .3967 .83027 .43217 .88265 .44131 .86123 .40204 Metetra
.648 .737 .914 r
.212 .42389 .23846 .44853 .27743 .43665 .25129 .41183 Metetra
.638 .736 .919 r
.25129 .41183 .27743 .43665 .31697 .42549 .29115 .40054 Metetra
.625 .734 .925 r
.29115 .40054 .31697 .42549 .35711 .41527 .33162 .39024 Metetra
.609 .731 .932 r
.33162 .39024 .35711 .41527 .3979 .40623 .37276 .38112 Metetra
.59 .727 .939 r
.37276 .38112 .3979 .40623 .4394 .3986 .41462 .37335 Metetra
.569 .721 .945 r
.41462 .37335 .4394 .3986 .4817 .39253 .4573 .36706 Metetra
.546 .713 .949 r
.4573 .36706 .4817 .39253 .52489 .38818 .50087 .36229 Metetra
.524 .703 .952 r
.50087 .36229 .52489 .38818 .56907 .38561 .54545 .35903 Metetra
.504 .691 .952 r
.54545 .35903 .56907 .38561 .61436 .38482 .59113 .3572 Metetra
.49 .678 .949 r
.59113 .3572 .61436 .38482 .66087 .38573 .63801 .35662 Metetra
.482 .664 .943 r
.63801 .35662 .66087 .38573 .70872 .38819 .68619 .35705 Metetra
.481 .65 .933 r
.68619 .35705 .70872 .38819 .75801 .39195 .73575 .35819 Metetra
.487 .636 .92 r
.73575 .35819 .75801 .39195 .80882 .3967 .78673 .35966 Metetra
.499 .622 .904 r
.78673 .35966 .80882 .3967 .86123 .40204 .83918 .36104 Metetra
.645 .737 .915 r
.18479 .39856 .212 .42389 .25129 .41183 .22439 .38637 Metetra
.634 .736 .921 r
.22439 .38637 .25129 .41183 .29115 .40054 .26457 .37501 Metetra
.621 .734 .928 r
.26457 .37501 .29115 .40054 .33162 .39024 .30538 .36467 Metetra
.604 .732 .935 r
.30538 .36467 .33162 .39024 .37276 .38112 .34685 .35552 Metetra
.586 .728 .941 r
.34685 .35552 .37276 .38112 .41462 .37335 .38908 .34765 Metetra
.566 .723 .947 r
.38908 .34765 .41462 .37335 .4573 .36706 .43213 .34111 Metetra
.546 .716 .951 r
.43213 .34111 .4573 .36706 .50087 .36229 .47611 .33586 Metetra
.529 .707 .953 r
.47611 .33586 .50087 .36229 .54545 .35903 .52109 .33181 Metetra
.515 .698 .952 r
.52109 .33181 .54545 .35903 .59113 .3572 .56718 .32877 Metetra
.507 .687 .948 r
.56718 .32877 .59113 .3572 .63801 .35662 .61445 .32649 Metetra
.507 .675 .941 r
.61445 .32649 .63801 .35662 .68619 .35705 .66297 .32466 Metetra
.512 .663 .93 r
.66297 .32466 .68619 .35705 .73575 .35819 .7128 .32292 Metetra
.523 .651 .915 r
.7128 .32292 .73575 .35819 .78673 .35966 .76397 .32087 Metetra
.536 .637 .898 r
.76397 .32087 .78673 .35966 .83918 .36104 .81647 .31811 Metetra
.642 .736 .917 r
.1568 .3725 .18479 .39856 .22439 .38637 .1967 .36025 Metetra
.63 .735 .923 r
.1967 .36025 .22439 .38637 .26457 .37501 .23719 .34892 Metetra
.615 .734 .931 r
.23719 .34892 .26457 .37501 .30538 .36467 .27832 .33866 Metetra
.599 .732 .938 r
.27832 .33866 .30538 .36467 .34685 .35552 .32013 .32954 Metetra
.581 .73 .945 r
.32013 .32954 .34685 .35552 .38908 .34765 .36272 .32161 Metetra
.563 .726 .95 r
.36272 .32161 .38908 .34765 .43213 .34111 .40616 .3148 Metetra
.547 .72 .954 r
.40616 .3148 .43213 .34111 .47611 .33586 .45055 .30899 Metetra
.535 .714 .954 r
.45055 .30899 .47611 .33586 .52109 .33181 .49595 .30398 Metetra
.528 .706 .952 r
.49595 .30398 .52109 .33181 .56718 .32877 .54246 .29951 Metetra
.528 .697 .947 r
.54246 .29951 .56718 .32877 .61445 .32649 .59014 .29525 Metetra
.533 .687 .937 r
.59014 .29525 .61445 .32649 .66297 .32466 .63902 .29084 Metetra
.544 .676 .924 r
.63902 .29084 .66297 .32466 .7128 .32292 .68915 .28591 Metetra
.557 .663 .908 r
.68915 .28591 .7128 .32292 .76397 .32087 .74051 .28007 Metetra
.571 .649 .888 r
.74051 .28007 .76397 .32087 .81647 .31811 .79309 .27297 Metetra
.636 .734 .919 r
.128 .34568 .1568 .3725 .1967 .36025 .16818 .33354 Metetra
.623 .734 .927 r
.16818 .33354 .1967 .36025 .23719 .34892 .20895 .32242 Metetra
.607 .734 .935 r
.20895 .32242 .23719 .34892 .27832 .33866 .25038 .31238 Metetra
.59 .734 .943 r
.25038 .31238 .27832 .33866 .32013 .32954 .29253 .30343 Metetra
.574 .733 .95 r
.29253 .30343 .32013 .32954 .36272 .32161 .33548 .29548 Metetra
.559 .731 .955 r
.33548 .29548 .36272 .32161 .40616 .3148 .37932 .28838 Metetra
.548 .727 .957 r
.37932 .28838 .40616 .3148 .45055 .30899 .42413 .28187 Metetra
.543 .722 .957 r
.42413 .28187 .45055 .30899 .49595 .30398 .46999 .27567 Metetra
.544 .716 .952 r
.46999 .27567 .49595 .30398 .54246 .29951 .51695 .26943 Metetra
.551 .709 .944 r
.51695 .26943 .54246 .29951 .59014 .29525 .56505 .26278 Metetra
.563 .699 .932 r
.56505 .26278 .59014 .29525 .63902 .29084 .61432 .25536 Metetra
.577 .687 .916 r
.61432 .25536 .63902 .29084 .68915 .28591 .66476 .24683 Metetra
.591 .673 .897 r
.66476 .24683 .68915 .28591 .74051 .28007 .71633 .23686 Metetra
.603 .658 .876 r
.71633 .23686 .74051 .28007 .79309 .27297 .769 .22521 Metetra
.627 .732 .922 r
.09834 .31807 .128 .34568 .16818 .33354 .13875 .30639 Metetra
.611 .734 .933 r
.13875 .30639 .16818 .33354 .20895 .32242 .17977 .29582 Metetra
.594 .736 .943 r
.17977 .29582 .20895 .32242 .25038 .31238 .22146 .28633 Metetra
.577 .738 .952 r
.22146 .28633 .25038 .31238 .29253 .30343 .26392 .27776 Metetra
.563 .74 .959 r
.26392 .27776 .29253 .30343 .33548 .29548 .30724 .26989 Metetra
.554 .741 .963 r
.30724 .26989 .33548 .29548 .37932 .28838 .35151 .2624 Metetra
.551 .74 .964 r
.35151 .2624 .37932 .28838 .42413 .28187 .39679 .25493 Metetra
.555 .737 .96 r
.39679 .25493 .42413 .28187 .46999 .27567 .44314 .2471 Metetra
.566 .731 .953 r
.44314 .2471 .46999 .27567 .51695 .26943 .4906 .23854 Metetra
.58 .723 .94 r
.4906 .23854 .51695 .26943 .56505 .26278 .53917 .22888 Metetra
.596 .711 .924 r
.53917 .22888 .56505 .26278 .61432 .25536 .58885 .21782 Metetra
.611 .696 .904 r
.58885 .21782 .61432 .25536 .66476 .24683 .6396 .20511 Metetra
.623 .679 .882 r
.6396 .20511 .66476 .24683 .71633 .23686 .69139 .19059 Metetra
.633 .662 .86 r
.69139 .19059 .71633 .23686 .769 .22521 .74416 .17417 Metetra
.606 .725 .929 r
.0678 .28963 .09834 .31807 .13875 .30639 .10829 .27933 Metetra
.586 .733 .945 r
.10829 .27933 .13875 .30639 .17977 .29582 .14943 .27022 Metetra
.567 .742 .959 r
.14943 .27022 .17977 .29582 .22146 .28633 .19131 .26201 Metetra
.551 .751 .97 r
.19131 .26201 .22146 .28633 .26392 .27776 .23407 .25428 Metetra
.543 .759 .977 r
.23407 .25428 .26392 .27776 .30724 .26989 .27779 .24657 Metetra
.545 .765 .979 r
.27779 .24657 .30724 .26989 .35151 .2624 .32254 .23842 Metetra
.557 .767 .976 r
.32254 .23842 .35151 .2624 .39679 .25493 .36838 .22935 Metetra
.576 .764 .968 r
.36838 .22935 .39679 .25493 .44314 .2471 .41532 .21898 Metetra
.598 .756 .954 r
.41532 .21898 .44314 .2471 .4906 .23854 .46335 .20699 Metetra
.618 .741 .934 r
.46335 .20699 .4906 .23854 .53917 .22888 .51245 .19315 Metetra
.635 .722 .91 r
.51245 .19315 .53917 .22888 .58885 .21782 .56257 .17736 Metetra
.647 .7 .885 r
.56257 .17736 .58885 .21782 .6396 .20511 .61365 .1596 Metetra
.654 .678 .861 r
.61365 .1596 .6396 .20511 .69139 .19059 .66565 .13994 Metetra
.657 .658 .839 r
.66565 .13994 .69139 .19059 .74416 .17417 .71851 .11852 Metetra
.517 .694 .949 r
.03634 .26033 .0678 .28963 .10829 .27933 .0762 .25592 Metetra
.476 .731 .982 r
.0762 .25592 .10829 .27933 .14943 .27022 .11697 .25207 Metetra
.44 .765 .996 r
.11697 .25207 .14943 .27022 .19131 .26201 .15881 .24775 Metetra
.426 .793 .995 r
.15881 .24775 .19131 .26201 .23407 .25428 .20186 .24203 Metetra
.446 .819 .993 r
.20186 .24203 .23407 .25428 .27779 .24657 .24616 .23418 Metetra
.498 .843 .996 r
.24616 .23418 .27779 .24657 .32254 .23842 .29171 .22371 Metetra
.563 .854 .997 r
.29171 .22371 .32254 .23842 .36838 .22935 .33845 .21039 Metetra
.621 .843 .984 r
.33845 .21039 .36838 .22935 .41532 .21898 .38629 .19423 Metetra
.66 .812 .956 r
.38629 .19423 .41532 .21898 .46335 .20699 .43514 .17542 Metetra
.68 .771 .92 r
.43514 .17542 .46335 .20699 .51245 .19315 .4849 .15427 Metetra
.685 .728 .883 r
.4849 .15427 .51245 .19315 .56257 .17736 .53549 .13119 Metetra
.683 .69 .85 r
.53549 .13119 .56257 .17736 .61365 .1596 .58687 .10661 Metetra
.678 .659 .824 r
.58687 .10661 .61365 .1596 .66565 .13994 .63901 .08092 Metetra
.671 .634 .804 r
.63901 .08092 .66565 .13994 .71851 .11852 .6919 .0545 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -69 -15.60368 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.23703 .17687 m
.2415 .18167 L
s
gsave
.22808 .16727 -68.72692 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.4535 .09211 m
.45758 .09725 L
s
gsave
.44535 .08183 -68.17095 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -67.61497 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.0759 .23997 m
.07874 .24269 L
s
.11524 .22456 m
.11804 .22733 L
s
.1552 .20892 m
.15797 .21172 L
s
.19579 .19302 m
.19852 .19586 L
s
.27893 .16047 m
.28157 .16339 L
s
.32151 .14379 m
.32411 .14675 L
s
.36479 .12685 m
.36734 .12985 L
s
.40878 .10962 m
.41128 .11266 L
s
.49897 .07431 m
.50137 .07743 L
s
.54521 .0562 m
.54755 .05937 L
s
.59224 .03779 m
.59452 .041 L
s
.64007 .01906 m
.64229 .02231 L
s
gsave
.29165 .07573 -68.44894 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{149, 122},
  ImageMargins->{{113, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002k0000VA000`40l00?003`^ooo002kool00;_o
o`00^ooo002kool00;_oo`00^ooo002kool00;_oo`00^ooo002kool00;_oo`00^ooo002kool00;_o
o`00NOoo0P0?@?oo001kool00`0?ooooo`0mool007[oo`0300oooooo03koo`00Nooo00<03oooool0
?Ooo001iool200m0ool00;_oo`00^ooo002kool00;_oo`00^ooo001mool300lkool007[oo`<03`;o
o`803c[oo`00@Ooo0P0?=Ooo0P0?1Ooo0P0?>_oo0010ool00`0?ool03`0Dool300lKool400l6ool0
0`0?ool03`0iool0043oo`0300ooo`0?01Coo`0300oooooo01Woo`803`[oo`0400ooo`0?00lhool0
047oo`803aGoo`0300oooooo01Goo`<03`coo`0400oooooo00lhool004;oo`0300oooooo01;oo`03
00ooo`0?01?oo`<03`03ool03ooo00coo`0500ooooooool03`0gool005Soo`803a7oo`803a;oo`04
00ooooooool200lfool006Soo`<03a;oo`<03`03Z/oooooo00803cKoo`00I_oo0P0?4ooo0P0?00BZ
cjW?00l03`Coo`0300oooooo03?oo`00Hooo0`0?4ooo0P0?00BYgj[?ZLnZc`803`Coo`0300oooooo
00Koo`0500oooooo00ooo`0200lVool0067oo`803`03ool03ooo017oo`803`09Z/nYcj[?^LnZcjW?
00nic`0?00Coo`0300oooooo00Coo`0300ooo`0?00Goo`0300oooooo02?oo`00G_oo0`0?5?oo0P0?
00^Zg`0?ZLnZcjW?Z/nYcj[?00nZc`0?00Goo`0300oooooo00?oo`0300ooo`0?00?oo`803bKoo`00
G?oo0P0?5Ooo0P0?00jZckW?Z/l03j[?ZLnZcjW?Z/nYc`0?ZLl03jW?1?oo00<03oooool00ooo00<0
3ooo00l00ooo00<03oooool09Ooo001Iool300l00ooo00ooo`0Bool200l04:[OZ/nZgj[?Z]nZc`0?
Z/nYgj[?ZLnZc`0?Z/nYc`0?1Ooo00<03oooool00ooo00<03oooool00_oo0`0?9Ooo000gool300lL
ool300lFool200l04Z[?^/nZckW?Z/njcj[?^Ll03jW?Z/nicj[?ZLnZc`0?Z/l03`Goo`803c7oo`00
>?oo00<03oooool06Ooo0P0?00?oo`0?ool05?oo0P0?01FZg`0?Z]nZcj[OZ/nZgj[?Z]nZcjW?00nY
cj[?ZLnZcjW?00nYcj[?00l01Ooo00<03oooool0;ooo000hool00`0?ooooo`0Fool300lGool200l0
4j[?^]nZck[O00nicj[?Z]nZckW?Z/nZgj[?00nZcjW?Z/nYcj[?00@03`Koo`0300oooooo02koo`00
>?oo00<03oooool05?oo0P0?6?oo0P0?01BZgj_OZ]n[gj[OZml03j[?Z]nZcj[OZ/nZgj[?Z]l03jWO
Z/nYcj[?0P0?00BYci[?Z]l03`Koo`0300oooooo02goo`00=ooo0P0?4ooo0`0?5ooo01Fkg`0?00l0
3k[OZlnjgj[?^]n[ck[OZ/l03j[?^LnZck[?Z/nicj[?^/l0100?00JZc`0?Z/nZgj[?00l5ool200l_
ool004[oo`803aSoo`03Zml03`0?00:[g`0A00n[gj[OZmnZgj_OZ]n[gj[O00nZgj[?Z]nZcj[OZ/nZ
g`0200l02Z[?Z]nZcj[O00nZgj[?Z]l03j[O1_oo00<03oooool0;?oo0017ool400lGool300l04Z_O
^]n[gk_OZml03j[?^]nZck[OZ/njgj[?^]l03j[OZ/nic`<03`:Zg`0:00nZcjWOZ/l03j[?ZMnZcj[O
00l7ool00`0?ooooo`0[ool004Goo`803aWoo`803`0BZmn[kj_O^nn[gj__Zmnkkj_O00n[gj[OZmnZ
gj_OZ]n[gj[O0`0?00bZgj_OZ]nJgj[O00nZgi[?Z]l03j[OV/l2Z]l00`0?V/ooo`05ool00`0?oooo
o`0[ool004;oo`<03aSoo`0E[=l03`0?^nn/g`0?Zmnkgj_O^mn[gk_OZmnkg`0?^]nZck[OZlnjgj[?
00<03`:Zg`0@Z/nZgj[OZ]nZcj[O00nZgj[?00nZcj[OZ/nYgj[?00l7ool00`0?ooooo`0Zool0043o
o`803aWoo`<03`>/k`05Znn[g`0?Zmn[k`03Zml01Z__ZmnZg`0?Z]n[g`<03`0FVmnZki_O00nKgj[O
VmnZgi_OZ]nKg`0?Z/nZg`0?Z]nZcj[OV/nZg`0?Z]l7ool00`0?ooooo`0Yool003goo`<03aSoo`0D
[?l03`0?[>n[kjcO^nn/kj__[=nkk`0?^mn[gk[OZmnkgj_O^]n[g`<03`:Zg`05VmnZgj[OZ]l03`08
Z]l01`0?Z/l03j[?ZMnZcj[O00<03`Ooo`0300oooooo02Woo`00>_oo0`0?00?oo`0?ool05_oo0`0?
012/oic_00n/kj__[>n[kjc_Znn/kj__00nkkj_OZnn[g`<03`0DVnl03i_OZ^nKgj[_VmnZki_OZ]l0
3j[OZmnZgi[OZ]n[gj[O00nZg`D03`03Z]nJg`0?00Ooo`803a7oo`@03`Coo`803`03ool03`0?00;o
o`803`;oo`@03`;oo`006ooo00<03oooool06_oo0P0?6Ooo00>/k`0?00l01Zc_00T03jcO^nn/gk__
[=nkkjcO^nl0100?00nKgj__VmnZkj_O00n[gj[OZmnZgj_OZ]n[g`0?Z/l00j[O00>Zcj[OZ]l00`0?
00RZcj[OV/nZgi[OZ]nJc`0?2?oo00<03oooool01?oo0`0?2?oo00<03oooool00ooo00@03ooo00l0
3`Coo`803`?oo`0400oooooo00l1ool001[oo`0300ooo`0?01Soo`@03aOoo`03WOl03`0?00803`09
[?n]kjcoWNn/ojg_[?n/k`0?00>/k`0IZnl03`0?00n[k`0?ZnnKgj__Vnn[ki_OZnl03j[_VmnZki_O
Z^nKgj[_Vml03i_OZ]l0100?00>Kgj[O00l00Y[O00JZgi[OV]nJgj[O00l8ool00`0?ooooo`05ool0
0`0?ooooo`07ool200l4ool0200?ool03`0?ool03ooo00l2ool0100?ooooo`0?0_oo0@0?0Ooo000J
ool00`0?ool03`0Fool200lHool02Ig_00l03`0?WNn/oig_[?l03`02[>l01Zco[>n/kjc_[?n/g`@0
3`0@ZnnKkj__Vnl03i_OZ^nKgj[_VmnZki_OZ^l03j[OVml3Z]l00i_OZ]nZg`0200l04:[OV]nZgi[O
Z]nJg`0?V/nYgi[OZ]nJcjWOV]nZg`0?1ooo0P0?1_oo00<03oooool01ooo00<03oooool00ooo00<0
3oooool00`0?00Goo`0?ooooo`0?00;oo`0400oooooo00l1ool001[oo`0300ooo`0?01?oo`<03aOo
o`0@SOl03`0?00nMoicoWOn]oigoW?nMojco00n/ojg_[?l400l019c_00nLkj__0Y__00nLkj__Vnl0
3i__ZnnKgj__Vnn[ki_OZ^l03j[_Vml0100?00VJk`0?Z^nJgi[_VmnZki[OV^l00P0?00RJgj[OV]nZ
gi[OZ]nJg`0?2Ooo00<03oooool00ooo00<03oooool01_oo100?1?oo0P0?1?oo00D03oooool03ooo
00@03`;oo`006ooo00<03oooool04?oo0P0?5ooo100?00b=kicoWNl03ig_[?nMkjcoWNn/oig_[>l3
00l00jc_W>nKk`03Vnl03P0?Vnn[ki__ZnnKkj__Vnl03i_OZnnKgj[_Vml500l03I_OZ^nJgj[_VmnZ
g`0?Z]nJgj[OV]nZgi[O00803`09Z]nJcj[OV]nZgi[?Z]nJg`0?00Soo`0300oooooo00;oo`803b7o
o`00:ooo0`0?5Ooo100?00FMohgoSOn=oigo00>=o`803`03W?l03`0?00803`0=WOnKo`0?VonLki_o
S>nKoic_Vol03i__W>l00i__00>Lki__Vml01@0?0Y__016;k`0?VmnJki_OV^nKgi[_Vml03i_OZ]nK
gi[_VmnZgi_O00803`06Z]nJgi[OV]nZgi[O0P0?2Ooo00<03oooool09?oo000Yool200lCool500l0
17goS?mmohco0P0?00B=oicoSOnLo`D03`08VonKki_oS>nKoi__Vol03`NKk`0400n[ki__Znl500l0
5i[_VnnJki_OV^nKki[_Vml03i[OV^nKgj[_V]nJki_O00nJgj[OV]nZgi[OZ]l00P0?00>Jg`0?00l0
0`0?00>JgiWO00l01ooo0P0?9_oo000Vool300l?ool600l02FgoS?l03`0?OOn<oggoSOmmo`0600l0
4i_oS>n;ohcoVol03i_oS>nKohc_Von<ki_o00nKoic_VonLki_o00D03`07Vnn;ki_oRnnKk`0?V^l0
0i__012Jki__Vnl03i[_VnnJki_OV^nKki[_00nJki_OZ^nJg`<03`03V]l03i[O00:Jg`05V^nJgi[O
V]l03`09ool00`0?ooooo`0Sool002?oo`<03`03ool03ooo00Ooo`03Nol03`0?00T03`=lo`03O>ml
ogco00D03`0CONnKohc_Vol03i_oS>nKohc_Von<ki_o00nKoic_Von<ki_oW>l01P0?00FKkh__Vnl0
3i[_00>Kk`0BV^nKki__00nJki__V^nKgi[_VnnJk`0?Z^nJgj[_VmnZki[O1@0?00JJg`0?00nJk`0?
ZMl3V]l01JWOV]nJgi[O00l02Ooo00<03oooool08_oo000Qool200l3ool;00l017_oK?l03`0?0Vco
00ElofcoK?m/ogco00H03`0BS?n;o`0?00n<oh_oS>n;ohcoRol03h_oS?nKohc_Ron<oi_o1P0?01B<
ki_o00n;oh__Von;kh_oRnnKk`0?Vnn;ki__RnnKkh__Vnl03i[_0Y__00B;ki[_VnnJk`H03`03RnnJ
k`0?00<03`06R]l03i_OV^l03i[_0i[O00BJki[OV]l03`Woo`0300oooooo02;oo`008Ooo1@0?00R:
o`0?Nomkkh[oNnmkofco0P0?00EkofcoNom[og_o00L03`0AO?n<k`0?Rnn;ohc_Von;kh_oS>l03h__
Ron<ki_oRnn;o`0700l06I_o00nKkh__Von;ki__RnnKk`0?V^n;ki__RnnJkh__V^l03i[_VnnJkh__
V^nKki[_00P03`05R]nJki[OV^n:g`0300l02Y[OV^nJgi[_V]l03i[O00nJgiWO0i[O00BIgi[OV]l0
3`Woo`0300oooooo027oo`006_oo00<03oooool00ooo00P03h[o00n:og__R_mkkh[o0P0?1W_o00<0
3g_o00l0100?012;o`0?Von<kh_oS>nKohc_00n<oh_oS>n;ohcoRon<o`L03`0HRnl03hc_Von;kh_o
S>nKo`0?Ron;ki_oRnn;oh__Vol03i_oRnnKoh__Von;ki__1`0?00ZKkh__V^n;ki[_RnnJkh__00n;
k`<03`0>RnnJkh__00n:gi[_VmnJkh[O00nKg`0?V]nJk`>Jg`03V^nJg`0?00[oo`0300oooooo023o
o`006Ooo00<03ooo00l01?oo0P0?00>:k`0?R^l00X[_00J;kh[_Nnl03g__Rol600l03H__Vnn;ki_o
RnnKo`0?Von;ki_oRnnKoh__00803`03Rol03`0?00<03`0GVon;ki_oRnnKkh__Von;k`0?RnnKoh__
Vnn;ki_o00nKkh__Von;ki__RnnKk`0800l03H__V^n;ki[_RnnJkh__00n;ki[_RnnJkh__00<03`08
RmnJki[OV^n;gi[_V]l03`>Jg`08V^nJg`0?V]l03i[OZMnJg`D03`Woo`0300oooooo023oo`006Ooo
00<03ooo00l01?oo00/03ooooon:k`0?R_mkkh[_Nnl03g_o00803`0ANon;ki__RnnKohc_00n;ki_o
S>nKoh__Vol03h_oS>n;o`0500l059_oRnn;ohc_Von;k`0?S>n;oh__Ron<kh_oRnl03hc_Ron;kh_o
S>l700l038c_Rol03h_oRnn;oh__Ron;k`0?Rnn:o`>;k`04R_n;k`0?Rnl300l03X__R^l03i[_RnnJ
kh__V^n;ki[_00nJkh[OV^l800l01H[OV^n:gi[_00l02_oo00<03oooool07ooo000Iool00`0?ool0
3`04ool01@0?ooooooooR^l0100?00BKkj[_Vnl03`JKk`06Rnl03h__Vnn;ki_o1@0?0i__016;ki__
00nKoh__Vnn;ki_oRnl03h__Von;ki_oRnl03h__00D03`0GRnnKo`0?V^n;kh[oRnnJkh__R^l03i[_
Rnn:kh__V^n;k`0?RnnJkh__V^n;k`0300l01X__V^n:ki[_RnnJk`L03`0BV^l03`0?00nIkh[OV^l0
3iWO00nIgh[OVMn:giWOR]nIg`0?2_oo00<03oooool07_oo000Jool00`0?ooooo`03ool00`0?oooo
o`02ool00i__00nKk`05Vnl0200?RnnKoh__Vnn;ki_oS>l400l00i__RnnKo`0200l038__Von;ki_o
RnnKo`0?Von;ki_oS>nKo`H03`0KS>nKoh__00n;kh_oRnn;oh__Rol03h_oRnn;oh__Ron;kh_o00n;
oh__Ron;kh_oRnl03h__00d03`05Rnn:kh[_R^n;k`02R^l0100?R^nJkh[O0X[_00bJk`0?00n:gi[_
R]nIkh[OV^n:g`0?R]l9ool00`0?ooooo`0Nool0023oo`0300oooooo00?oo`03Vnl03j[_00:Kk`03
VmnZki__00803`03Vnl03`0?00803`03Vnl03i__00JKk`0300n;ki__00:Kk`03RnnKk`0?00@03`0C
Von;ki__00nKkh__Vnn;ki__Rnl03h__Vnn;ki[_RnnKk`0?V^l00h__00>Jkh__V^l02P0?00N;kh[_
Rnn:k`0?R^n;k`03R^l048__V^l03i[_R]nJkh[_V^n:g`0?R]nJkh[OV^n:gi[_0P0?00RJgiWOR]nI
gi[OVMn:g`0?2_oo00<03oooool01?oo0`0?00?oo`0?ool00P0?4Ooo000Oool200l6ool00i__00nK
k`03Vnl400l6Vnl0200?RnnKkic_Vnn;ki__S>l600l05I_o00nKkh__Von;ki__Rnn;o`0?Von;kh_o
RnnKoh__00n;kh_oRnn;o`0800l018__00mkkh[o0`0?01::oh__00mkkh[oRnn:kg__R^l03h[_Rnn:
kh__R^n;k`0?Rnl3R^l01h__R^n:g`0?R^nJkh[O00::k`803`09V^n:gi[_R]nJkh[OV^l03i[_00[o
o`0300oooooo00Coo`0300oooooo00Coo`0300oooooo00koo`007ooo00<03oooool01ooo100?00JK
kj__VnnKk`0?Znl3Vnl00j__Vnl03`03Vnl400l7Vnl0300?Vnn;ki__RnnKkh__V^l03i_oRnnJk`80
3`03Rnl03`0?00803`09V^n;kh[_00n:kh__R^n;kh[_00<03`08R^n;kh[_Rnn:k`0?R^n;k`>:k`03
Rnn:k`0?00J:k`0500n:kh[_R]nJk`02R^l01`0?VNn:gi[_R]nIkh[O00803`06VMn:giWOR]nIgh[O
0P0?2_oo00<03oooool01?oo00<03oooool00_oo0P0?4Ooo000Oool00`0?ooooo`08ool0100?VnnK
kj__19__00<03i__Vnl00i__100?1I__00<03h__Vol00Y__00N;ki_o00nKoh__Von;k`0200l04I_o
00l03`0?Von;ki_oRnl03h__Ron;kh_oRnn;o`0?R_l00`0?01F:oh__00n;kh[oRnn:oh__R_l03h[_
Rnn:oh__R^n;k`0?Rnn:kh__R_l00P0?00>:k`0?00l04`0?00>:g`0?R]l02_oo00<03oooool00ooo
00<03oooool00_oo00<03oooool04?oo000Oool200l:ool02P0?ZnnKgj__Vmn[ki_OZnl03j__0`0?
00F[ki__00l03j__00>Kk`03ZnnKk`0?00FKk`D03`>Kk`0=V^l03i__RnnJkh__Vnn;k`0?RnnKkh__
V^l00`0?00J:kh__R^n;kh[_RnlB00l3R^l01@0?R^n:kh[_R]l00X[_00N9k`0?RNn:ghW_R]n9k`02
00l028[OVMn:ghW_R]nIgh[O00l;ool0100?oooooooo0P0?1?oo0`0?4?oo000Oool00`0?ooooo`0:
ool01@0?VnnKkj__Vnl00P0?00FKk`0?VnnKkj__00BKk`0300nKki__00BKk`D03`0ARnnKk`0?Vnn;
ki_oRnnKkh__Rol03i__Rnn;oh__Vnn;k`0=00l098__00mkkh[oNnn:og__R_l03h[_Nnn:og__R^mk
k`0?Nnn:kg[_R^mkkh[_00n:kg[_R^mjkh[_N^l03g[OR^mjkh[_N]n:k`803`08R]n9kh[ORNn:ghW_
00n9k`Woo`803acoo`007ooo0P0?3?oo100?00ZKgj__Vmn[k`0?ZnnKkj__Vmn[k`:Kk`0300n[ki__
00D03`JKk`0400nKkh__V^l2Vnl018__V^l03i__1`0?00Z:kh__V^n;kh[_00n:kh__R^n;k`::k`03
00mkkh[_00::k`0BNnn:k`0?R^mjkh[_N^n:kg[_00mjkh[_N^n:kg[_R^l03hW_0X[_01=jkhW_R^l0
3h[ORNn:ghW_R]n9k`0?RNn:ghW_R]n9kh[ORNl03`0;ool00`0?ooooo`0Iool000ooo`<03`;oo`05
00ooooooool03`06ool00`0?ooooo`0<ool02@0?ZnnKkj__Vnn[ki__Znl03`02Vnl01J__VnnKk`0?
Vnl00P0?1I__00<03i__Vol00i__00FKo`0?00n;ki_o00L03`0/Von;ki__Rnl03h__Ron;kh_oRnn:
o`0?R_n;kh[oRnn:og__00mkkh[oNnn:og__R_l03h[oNnn:og__R_mjk`0?Nnn:kg[_R_mkkh[_00n:
kg[_R^mjk`::k`0300mjkh[_00::k`0;N^n:k`0?RNn:ghW_R]n9kh[O00n:g`0;ool00`0?ooooo`0H
ool0013oo`0:00oooooo00ooo`0?ool03ooo00l4ool00`0?ooooo`0>ool200l01Y_OZnnKgj__Vmn[
k`D03`0;ZnnKgj__00n[ki__ZnnKgj__Vnl03`04Vnl500l2Vnl200l05Y[_00nKkh__V^n;ki__Rnl0
3h__V^n;ki[_Rnn:k`0?R^n;kh[_Rnl03h__1P0?00>:k`0?00l07@0?00FIgh[ORNn:g`0?00[oo`80
3a[oo`004?oo00X03oooool03ooo00ooo`0?ool03`Coo`803a3oo`05Vnl03i__ZnnKk`0400l2Vnl0
0j__VnnKk`02Vnl00`0?VnnKk`03Vnl500l3Vnl03h__00l03`0?RnnKkh__Rol03i__Rnn;oh__Vnn;
k`0600l00h_o00l03`0200l04G__R_mkk`0?Nnn:og__R_mkk`0?Nnn:kg__N_mkkh[_00l01W[_00<0
3g[_N^l017[_00X03gW_N^mikg[_NNmjk`0?N]n9k`H03`_oo`0300oooooo01Ooo`004?oo00X03ooo
ool03ooo00ooo`0?ool03`Coo`0300oooooo013oo`0BVml03`0?00nKgj__Zmn[k`0?ZnnKkj__Vmn[
ki__Znl03j__0`0?00>[ki__00l00i__0`0?00BKk`0?VnnJk`>Kk`03V^l03`0?00H03`0gRnn:kh__
V^n;kh[_00n:kh__R^n;kh[_00n:kg[_R^mjkh[_N^l03g[_R^mjkh[_N^n:k`0?RNmjkh[_N^n9kg[_
00mjkhW_N^n9kg[_RNl03hW_N]n9kg[_RNmjg`0?NMn9kg[ORNmighW_00l02ooo0P0?6?oo000?ool2
00l3ool01@0?oooooooo00l01Ooo00<03oooool04Ooo00fKk`0?Vnn[ki__ZnnKkj__00n[ki__ZnnK
k`0400l2Vnl01:__VnnKki__0`0?19__00>;k`0?00l0100?02FKo`0?Vnn;ki_oRnnKkh__00n;kh_o
Rnn:oh__R_l03h[oRnn:og__R_l03h[oNnn:og__R_mkk`0?Nnn:og[_N_mkkg[_00mjo`03N^l00g[o
00mjk`05N^l01`0?N^n9kg[_NNmjkhW_00803`07N^n9kg[ORNmjkhW_00l02ooo00<03oooool05_oo
000Nool00`0?ooooo`0Bool029_O00n[gj__Vmn[kj_OZnl400l01i_OZnnKgj__00n[ki__00<03`04
Vnl03i__Znl600l00i__V^nKk`02Vnl03i[_00nKkh__V^n;ki__Rnl03h__V^n;ki[_Rnn:k`0<00l0
0g[_00l03`0400l00h[_00l03`0500l05HW_N^n9kg[_RNmjk`0?N]n9kg[ORNmjghW_00n9kgWORNmj
ghW_NMl03`0<ool00`0?ooooo`0Eool000;oo`<03`Coo`803`?oo`803`koo`0300oooooo01?oo`04
Vnl03ic_Znl300l02:__00n[kic_ZnnKkj__W>l300l3Vnl400l5Vnl03h__00n;ki__RnnKkh__Vol0
3i__RnnKoh__00n;k`0700l03g__R_mkkh[oNnn:o`0?R_mkkg[oNnn:og[_00mkk`02N^l01G[oNnl0
3f[_N_l00W[_00=Zkg[_00l01@0?00=jk`0?00l00`0?00Yjk`0?00n9kg[ORNmjghW_N]l03`_oo`80
3aKoo`000_oo00@03oooool03`;oo`0400oooooo00l4ool00`0?ooooo`0:ool200lFool029_O00l0
3j__Vmn[kj_OZnl200l01Y__00l03`0?Vnn[k`@03`06Vnn[ki__00nKkj[_0i__00FZki__00nKki[_
00:Kk`0300nJk`0?00<03`0;RnnJkh__00n;kh[_RnnJkh__00n;k`03R^l02X__R^l03h[_N^n:kg[_
R^mjk`0?0g[_012:kg[_00mjkgW_N^mikg[_NNl03gW_N^mikg[_NNl03`=ik`03N]l03`0?00P03`co
o`0300oooooo00Coo`<03`goo`000_oo00@03oooool03`;oo`0400oooooo00l2ool300l<ool00`0?
ooooo`0Fool01i__00nKkj__Vnn[ki__00<03`03Vnn[k`0?00803`05Znl03i__Vnn[k`03Vnl00`0?
VnnKk`05Vnl400l09i__RnnKo`0?Vnn;ki_oRnnKkh__00n;kh_oRnn:oh__00mkkh[oRnn:og__R_l0
3h[oNnn:og__R_l03g[oN^mjog[_N_mjk`0?J^mjo`02N^l03F[_00mZkgW_J^mikf[_NNl03gW_J^mi
kf[_009ik`0300mYggW_009ik`03JMl03`0?00coo`0300oooooo00?oo`0300oooooo00goo`000_oo
00@03oooool03`;oo`0400oooooo00l2ool00`0?ooooo`0<ool200lIool00`0?Zmn[k`0200l00j_O
00nKg`0200l03:__Vmn[kj_OZnl03j__Vnn[ki_OZnnKk`H03`05ZnnKk`0?VnnJk`03Vnl01I[_00nK
kh__V^l00Y__00@03i[_RnnJk`T03`03R^l03`0?00X03`04N^l03`0?00l3N^l03@0?N^mikg[_NNmj
kgW_00mikgWONNmjggW_00803`07NMmikgWONNmig`0?NMl02ooo00<03oooool01?oo00<03oooool0
3?oo0002ool300l4ool200l4ool200l<ool00`0?ooooo`0Hool600l02ic_ZnnKk`0?W>n[ki__ZnnL
kj__00l00Y__100?00>[ki__Vnl01I__00<03h__Vnl00Y__00>;ki__00l0200?0X__016:oh__00mk
kh[oNnn:og__N_l03g[oNnmjog__N_l03g[o009jk`05J^mjo`0?N^mZk`0300l00f[_00l03`0300l0
26[_00mZkgW_J^mikf[_NNl200l01VWONNmjkgW_JMl03`coo`0300oooooo00;oo`0300ooo`0?00go
o`007Ooo00<03oooool05Ooo0`0?0_oo00d03j_OZnnKgj__Zmn[ki_O00nKgj__Vmn[k`0400l029__
ZnnKgj__Vnl03i__Z^l3Vnl01:[_Vnl03i__1@0?00n;ki[_RnnJkh__V^l03i[_Rnn:kh__V^n;k`0?
Rnl00h[_00J;kh[_00n:kg[_R^l2N^l00`0?NNmjk`02N^l037W_00mikf[_NNmZkgW_00mikfW_NNmZ
k`L03`0:NMl03gWO00miggW_NMmik`0?NNl<ool00`0?ooooo`02ool200l=ool001goo`803a?oo`<0
3`Koo`0800nKkj__Vnn[ki__ZnnKk`@03`04ZnnKkj__00l2Vnl01J__VnnKki__00l00i__1@0?1I__
00VKo`0?Vnn;ki_oRnnKk`0?R_l00h__022:og__00mkkh[oNnn:og__00mkkh[oNnmjog__N_l03g[o
N^mjof[_N_l03g[_J^miof[_N^l03fW_J^mikf[_0VW_00@03fW_JNmYk`H03`=ik`0300oooooo00Oo
o`@03a?oo`003Ooo0`0?0_oo00D03oooooooo`0?00Goo`0300oooooo013oo`<03`[oo`0500n[gj__
Zmn[k`0400l03:_OZnnKgj__Zmn[k`0?ZnnKkj__Vmn[k`@03`08Vnn[ki_OZnnKk`0?VnnJk`>Kk`06
00nKki[_RnnJki__1`0?00>;k`0?00l0400?01Aik`0?00l03gW_N^mik`0?NNmYkgW_J^mik`0?NNmY
ggW_JNmikfWO0P0?00=hk`0?00l00`0?1Ooo0`0?0ooo00<03oooool04Ooo000=ool02`0?oooooooo
00ooo`0?ool03ooo00l01?oo00<03oooool03Ooo0`0?3_oo100?00^[kic_ZnnKk`0?W>n[ki__ZnnL
kj__00D03`:Kk`0300nKki__00FKk`0300n;ki__00:Kk`H03`04RnnKk`0?R_l3Rnl05h[oNnl03g__
R_mkkh[_Nnl03g__N_mjkg[oNnl03f[_N_mZkg[_J^mYo`0?JNl00`0?00Qik`0?00l03gW_J^mYk`0?
0fW_00MZkfW_00mYk`0?JNmYg`02JNl00`0?ool03`0300l6ool00`0?ooooo`0Aool000koo`0:00oo
oooo00ooo`0?ool03ooo00l4ool200l;ool300lBool02j__00n[kj_OZnn[gj__Vml03i_OZnl01@0?
00j[ki__ZnnKgj__Vnl03i__Z^nKkj__VnnZki__100?0Y__01003i__V^n;ki[_VnnJk`0?V^n;kh[_
RnnJkh[_00mkk`>:k`03Nnl03g[_009jk`0AR^mjk`0?J^mikg[_NNmZk`0?JNmikf[_NNmYk`0?JNmi
k`0300l03gW_00mikfWONNmYkgW_00mhk`0?N>mYggS_JMl03`0;ool00`0?ooooo`0@ool000goo`0;
00ooo`0?ool03ooo00ooo`0?ool03`04ool00`0?ooooo`07ool300lFool02:__00n[ki__ZnnKkj__
Vnl200l03:__Vnn[ki__Znl03j__Vnn[ki__ZnnKk`H03`03Vnl03i__00FKk`0900n;ki__RnnKoh__
Vnl03h[o00:;k`803`03Nnl03`0?00<03`03N^l03`0?00L03`0?J^mjof[_00mZkfW_J^mYof[_00mI
kfW_J^mYkeW_00H03`08NNl03`0?JNmikfWOJNl03`_oo`0300oooooo013oo`003_oo0P0?0_oo00D0
3oooooooo`0?00Goo`0300oooooo00Goo`803a[oo`03Znl03j__00<03`0<Znn[g`0?Zmn[ki_OZnn[
gj__00n[ki_O1@0?00NKgj__Vnn[ki_OZnl03`02Vnl019[_VnnKki__2P0?00JJkh__V^l03h[_Rnl3
R^l00g[_00mjk`02N^l018[_N^l03g[_200?00=ikf[_00l01FW_00D03fWOJ>mYgfS_00@03`05JMmh
kfWON>l03`0:ool00`0?ooooo`0@ool001coo`0300oooooo00;oo`<03agoo`803`0;ZnnKgj__W>n[
ki_O00nLkj__Vnn[k`0400l00i__ZnnKk`02Vnl00`0?VnnKk`04Vnl00`0?Vnl03`0400l01I__RnnK
kh__Vnl00X__00<03h[oRnl00X__01N:o`0?R^mkkh[oNnn:kg[_00mkkg[oN^mjof[_00mZkg[oJ^mj
ke[_00mZkfW_00803`0?J^l03`0?JNmZkfW_FNl03eW_JNmIkfW_FNl03eWO00D03`[oo`0300oooooo
013oo`007?oo00<03ooo00l00P0?8Ooo00R[k`0?Znn[gj__Zmn[kj_O100?00f[kj_OZnl03j__Vnn[
ki_OZnnKk`0?VmnZk`0500l2Vnl059[_VnnKki__00nKki[_RnnJki__R^l03i[_Rnn:kh__V^l03h[_
N^l3R^l00g[_00mjk`02N^l02H[_J^l03f[_NNmZkgW_J^l03`02JNl016[_JNl03fW_1@0?00eXkfW_
J>mIgfS_00mXk`0?J>mXgfS_JMl03`09ool00`0?ooooo`0@ool001_oo`<03bGoo`04Znl03j__Vnl5
00l02i__ZnnKkj__Vnn[k`0?ZnnKkj__Vnl0100?0Y__00B[ki__Vnl03`JKk`0400n;ki__Rnl200l0
0h__00l03`0G00l02fWoJ^mYkf[_JOl03fW_FNmYkeW_JNl0100?00YIkfW_00mXk`0?J>mIkfS_00mX
k`Soo`0300oooooo013oo`007?oo0P0?9_oo00n[k`0?00n[gj__Zmn[kj_O00n[gj__Vmn[kj_OZnl0
100?00^Kgj__Vml03i_OZnnKkj__Vmn[k`0?00:Kk`03V^l03`0?00@03`0=RnnJki__V^l03i[_RnnJ
kh__V^l03h[_Nnl00h[_00<03g[_N^l00g[_00D03gW_J^mikg[_00H03`0:J>l03fW_FNmXkeW_J>l0
3fS_JMl200l026S_00mXk`0?J>mYgfS_00l8ool00`0?ooooo`0@ool001koo`0300oooooo02Goo`09
00n[ki_OZnnLkj__Vml03ic_00@03`09Znl03j__Vnn[ki__ZnnKk`0?00BKk`D03`BKk`0500n;ki__
RnnKk`02Rnl00`0?R_n;k`02Rnl06H[o00n:kg__R_mkkh[_00mjog__N_mjkg[o00mjkf[_JOmZkg[_
00mYke[_JNl03fW_00803`09FNmYkeW_00mIkeS_FNmHkeW_00@03`04J>mIk`0?FMl8ool00`0?oooo
o`0?ool001ooo`0300oooooo02Goo`0500n[kj_OZnn[g`0300l03:_OZnnKgj__Zmn[k`0?ZnnKkj__
Vmn[k`D03`04ZnnKgj__00l2Vnl02i[_VnnKki__00nKki[_RnnJki__R^l01@0?00>:k`0?00l0300?
00EZkgW_J^mYk`0?00=Yk`03FNl03eW_00D03`07FMmXkeS_F>mIg`0?F=l01@0?2?oo00<03oooool0
3ooo000Pool00`0?ooooo`0Uool400l2Znl029__00nKkj__Vnn[ki__Znl500l00j__Vnl03`03Vnl0
1:__VnnKk`0?19__1`0?01F;kh[_00n:oh__R^n;kh[o00n:og__R_mkkg[o00mjog[_N_mjkfWoJ^l0
100?00MYk`0?JOmJkfW_FNl03`03FNl03ES_FNl03`0?F>mIkeS_00mHkeW_00mHgfS_00803`Ooo`03
00oooooo00ooo`008Ooo00<03oooool09Ooo00X03j__Zmn[kj_OZnn[g`0?Zmn[k`@03`0=Zml03i_O
ZnnKgj__Vml03i_OZnnKkj__Vml01@0?0Y__016Kg`0?VnnJki__V^nKk`0?RnnJkh__V^n;kh[_00n:
kg__00::k`03N^l03g[_00=jk`06NNl03gW_J^mikf[_1@0?00QIg`0?FNmHkeWOJ>l03eS_1@0?00IH
keSO00mHgeS_00l7ool00`0?ooooo`0?ool002;oo`803bKoo`0600n[ki_OZnnLkj__0`0?00b[ki_O
ZnnLkj__Vnl03i__ZnnKkj__Vnl500l2Vnl00`0?VnnKk`03Vnl02H__00n;ki__RnnKkh__00n;k`04
00l00h[o00l03`0300l00g[o00l03`0200l026[_00mZkfW_J^mYof[_00l2FNl00e[_JNl03`0300l0
3eW_F>l03eS_BNmHkeW_F>l03eS_FMl03eSOF>l03`06ool00`0?ooooo`0?ool002Coo`0300oooooo
02Coo`0300n[k`0?00803`0:Znn[gj__00n[ki_OZnn[gj__Vml500l02I__00nKgj__Vnn[ki_OZnl0
3`02Vnl019[_VnnKkh__1`0?00Z;ki[_RnnJkh__R^l03h[_N^n:k`9jk`0300mikg[_00L03`09FNl0
3eW_JNmIkfW_00mHkeW_00803`06F>l03eS_B=mHkeSO100?00AHkeSO00mHg`Goo`0300oooooo00oo
o`009Ooo00<03oooool09?oo0P0?00VKkj__Znn[ki__Znl03j__Vnl0100?00N[ki__ZnnKkj__Vnl0
3`03Vnl00j__Vnl03`0500l07Y__Rnl03h__Vnn;ki_oRnl03h__R_n;kh[_Rnl03g__R_mkkh[oNnl0
3f[_N_mjkg[oJ^l03f[_JNmZk`D03`07FNmYk`0?F>m9keS_FNl00`0?00I8keS_BNl03dSOB>l400l5
ool00`0?ooooo`0?ool002Koo`0300oooooo02Coo`08Zml03j_OZnn[gj__Zmn[k`803`0;Zmn[kj_O
ZnnKg`0?Zmn[ki_OZnn[g`0500l01Y_OZnl03i__VmnZk`>Kk`0:00nKki[_VnnJki__00n;ki[_Rnl:
00l4N^l01P0?J^mYkf[_NNl03`9Ik`803`08F>l03eS_FNmHkeWO00mHg`803`09F>m8g`0?B=mGg`0?
F>l03eOO00Coo`0300oooooo00ooo`009ooo0P0?9Ooo00>Lk`0?00l00`0?00^Kgj__00n[ki_OZnnL
kj__Vnl03ic_00D03`>Kk`04ZnnKki__00l5Vnl00h__00l03`0700l:ool400l01f[_00l03`0?J^mY
o`0?00AIk`07F>l03`0?00mHkdSO00l00TS_0P0?00M8g`0?B=l03dSOF>l03`05ool00`0?ooooo`0>
ool002Woo`0300oooooo02?oo`0<00n[kj_OZnn[gj__Zmn[k`0?ZnnKgj__100?00bKgj__Vmn[ki_O
00nKgj__Vnn[ki_OZnl500l00i__ooooo`0Iool500l01UW_J>mIk`0?B=mHk`803`06B=l03dSOB>m8
gdO_0P0?00E8g`0?B=mGk`0?00Coo`0300oooooo00koo`00:_oo00<03oooool08ooo00>[k`0?Vnl0
0j__00>Kkj__00l00P0?00Z[ki__ZnnKk`0?Vnn[ki__ZnnKk`H03bKoo`D03`04BNm8kdW_F>l200l2
B>l00dSOAnl03`0300l00dSO00ooo`03ool00`0?ooooo`0>ool002_oo`0300oooooo02?oo`03Zml0
3j_O00<03`0;Zmn[k`0?Znn[gj__Zmn[ki_O00n[g`0400l^ool01fS_B=l03`0?F>m8geS_00@03`05
B=l03dOOAmm8g`0300l3ool00`0?ooooo`0>ool002coo`803bCoo`0<W>l03i_OZnnLkj__Vmn[k`0?
ZnnKgj__100?=Ooo0158k`0?00l03dO_00m7kdS_00lhg`0?>=m7k`0?Anl03dO_00;oo`0300oooooo
00koo`00;_oo00<03oooool08_oo00R[g`0?Zmn[kj_OZnn[gj__0`0???oo00MHk`0?Anl03dO_>=m7
k`0200l01DOOAnl03dOO00l00_oo00<03oooool03_oo000_ool00`0?ooooo`0Sool00`0?Vml03`02
00l00i_Oooooo`10ool200l00dO_>=m7k`0300l01TO_00l03cSOool03a3oo`00<?oo00<03oooool0
8ooo00<03oooool0A_oo0`0?00<gg`0?=ml0100?0_oo00<03oooool03Ooo000aool200lSool00`0?
ooooo`18ool01TO_00l03cOO=nlgg`<03`03ool03ooo00koo`00<ooo00<03oooool08?oo00<03ooo
ool0B_oo00Dhg`0?00lfgcOO00803`03ool03ooo00koo`00=?oo00<03oooool07ooo00<03oooool0
C?oo00@gk`0?=nlgg`<03`ooo`00=Ooo00<03oooool07_oo00<03oooool0C_oo1@0?3ooo000fool2
00lNool00`0?ooooo`1@ool300l?ool003Soo`0300oooooo01_oo`0300oooooo05;oo`0300oooooo
00goo`00>Ooo00<03oooool06Ooo00<03oooool0DOoo0`0?3ooo000jool00`0?ooooo`0Hool00`0?
ooooo`1=ool400lBool003_oo`0300oooooo01Ooo`0300oooooo04[oo`<03aKoo`00??oo0P0?5ooo
00<03oooool0A_oo100?6Ooo000nool00`0?ooooo`0Dool00`0?ooooo`12ool400lMool003ooo`03
00oooooo01?oo`0300oooooo03koo`@03b7oo`00@?oo00<03oooool04_oo00<03oooool0>_oo100?
9Ooo0011ool200lBool00`0?ooooo`0fool400lYool004?oo`0300oooooo00ooo`0300oooooo03?o
o`<03bgoo`00A?oo00<03oooool03_oo00<03oooool0;ooo100?<?oo0015ool00`0?ooooo`0=ool0
0`0?ooooo`0[ool400ldool004Koo`803`goo`0300oooooo02Ooo`@03cSoo`00B?oo00<03oooool0
2_oo00<03oooool08ooo100???oo0019ool00`0?ooooo`09ool00`0?ooooo`0Pool300m0ool004[o
o`0300oooooo00Soo`0300oooooo01coo`@03d?oo`00Booo0P0?2?oo00<03oooool06?oo100?Aooo
001=ool00`0?ooooo`05ool00`0?ooooo`0Dool400m;ool004koo`0300oooooo00Coo`0300oooooo
013oo`@03dooo`00Cooo00<03oooool00ooo00<03oooool03?oo100?Dooo001@ool200l3ool00`0?
ooooo`09ool300mGool005;oo`0400oooooo00l7ool400mJool005?oo`0300ooo`0?00?oo`@03eko
o`00E?oo1@0?H_oo002kool00;_oo`00^ooo002kool00;_oo`00^ooo002kool00;_oo`00^ooo002k
ool00;_oo`00\
\>"],
  ImageRangeCache->{{{0, 185.25}, {151.5, 0}} -> {-0.184186, -0.091212, 
  0.008262, 0.008262}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Density of States in Confined Structures"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Quantum Well"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[rho10, rho11]; \)\), 
    \(rho10[En_, s_] := \(L\ rho[2, En]\)\/s\), 
    \(rho11[En_, s_] := 
      rho10[En, s]\ Floor[\(L\ rho[3, En]\)\/rho10[En, s]]\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig14x4 = 
      Plot[Evaluate[{atto\ L\^3\ rho[3, e\ En] //. case, 
            atto\ L\^2\ rho11[e\ En, 2\ nano] //. case}], {En, 0.01, 2}, 
        FrameLabel \[Rule] {"\<E in eV\>", "\<DOS\>"}, Evaluate[opt]]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.019024 0.478583 0.014715 0.009789 [
[.01902 -0.0125 -4 -12 ]
[.01902 -0.0125 4 0 ]
[.25832 -0.0125 -7 -12 ]
[.25832 -0.0125 7 0 ]
[.49761 -0.0125 -4 -12 ]
[.49761 -0.0125 4 0 ]
[.7369 -0.0125 -7 -12 ]
[.7369 -0.0125 7 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14.5 -24 ]
[.5 -0.0125 14.5 -12 ]
[-0.0125 .01472 -8 -6 ]
[-0.0125 .01472 0 6 ]
[-0.0125 .1126 -12 -6 ]
[-0.0125 .1126 0 6 ]
[-0.0125 .21049 -12 -6 ]
[-0.0125 .21049 0 6 ]
[-0.0125 .30838 -12 -6 ]
[-0.0125 .30838 0 6 ]
[-0.0125 .40627 -12 -6 ]
[-0.0125 .40627 0 6 ]
[-0.0125 .50416 -12 -6 ]
[-0.0125 .50416 0 6 ]
[-0.0125 .60204 -12 -6 ]
[-0.0125 .60204 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24 -10 ]
[-0.01875 .30902 -12 10 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.25832 0 m
.25832 .61803 L
s
.49761 0 m
.49761 .61803 L
s
.7369 0 m
.7369 .61803 L
s
0 .1126 m
1 .1126 L
s
0 .21049 m
1 .21049 L
s
0 .30838 m
1 .30838 L
s
0 .40627 m
1 .40627 L
s
0 .50416 m
1 .50416 L
s
0 g
.01902 0 m
.01902 .00625 L
s
gsave
.01902 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25832 0 m
.25832 .00625 L
s
gsave
.25832 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.49761 0 m
.49761 .00625 L
s
gsave
.49761 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7369 0 m
.7369 .00625 L
s
gsave
.7369 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06688 0 m
.06688 .00375 L
s
.11474 0 m
.11474 .00375 L
s
.1626 0 m
.1626 .00375 L
s
.21046 0 m
.21046 .00375 L
s
.30617 0 m
.30617 .00375 L
s
.35403 0 m
.35403 .00375 L
s
.40189 0 m
.40189 .00375 L
s
.44975 0 m
.44975 .00375 L
s
.54547 0 m
.54547 .00375 L
s
.59332 0 m
.59332 .00375 L
s
.64118 0 m
.64118 .00375 L
s
.68904 0 m
.68904 .00375 L
s
.78476 0 m
.78476 .00375 L
s
.83262 0 m
.83262 .00375 L
s
.88047 0 m
.88047 .00375 L
s
.92833 0 m
.92833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(E) show
69.875000 13.000000 moveto
(in) show
78.062500 13.000000 moveto
(eV) show
87.312500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .1126 m
.00625 .1126 L
s
gsave
-0.0125 .1126 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .21049 m
.00625 .21049 L
s
gsave
-0.0125 .21049 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .30838 m
.00625 .30838 L
s
gsave
-0.0125 .30838 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(30) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .40627 m
.00625 .40627 L
s
gsave
-0.0125 .40627 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .50416 m
.00625 .50416 L
s
gsave
-0.0125 .50416 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60204 m
.00625 .60204 L
s
gsave
-0.0125 .60204 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .03429 m
.00375 .03429 L
s
0 .05387 m
.00375 .05387 L
s
0 .07345 m
.00375 .07345 L
s
0 .09303 m
.00375 .09303 L
s
0 .13218 m
.00375 .13218 L
s
0 .15176 m
.00375 .15176 L
s
0 .17134 m
.00375 .17134 L
s
0 .19091 m
.00375 .19091 L
s
0 .23007 m
.00375 .23007 L
s
0 .24965 m
.00375 .24965 L
s
0 .26922 m
.00375 .26922 L
s
0 .2888 m
.00375 .2888 L
s
0 .32796 m
.00375 .32796 L
s
0 .34753 m
.00375 .34753 L
s
0 .36711 m
.00375 .36711 L
s
0 .38669 m
.00375 .38669 L
s
0 .42585 m
.00375 .42585 L
s
0 .44542 m
.00375 .44542 L
s
0 .465 m
.00375 .465 L
s
0 .48458 m
.00375 .48458 L
s
0 .52373 m
.00375 .52373 L
s
0 .54331 m
.00375 .54331 L
s
0 .56289 m
.00375 .56289 L
s
0 .58247 m
.00375 .58247 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
71 10 translate
90 rotate
-71 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(DOS) show
78.937500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.01902 .61178 m
.01902 .61803 L
s
.25832 .61178 m
.25832 .61803 L
s
.49761 .61178 m
.49761 .61803 L
s
.7369 .61178 m
.7369 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06688 .61428 m
.06688 .61803 L
s
.11474 .61428 m
.11474 .61803 L
s
.1626 .61428 m
.1626 .61803 L
s
.21046 .61428 m
.21046 .61803 L
s
.30617 .61428 m
.30617 .61803 L
s
.35403 .61428 m
.35403 .61803 L
s
.40189 .61428 m
.40189 .61803 L
s
.44975 .61428 m
.44975 .61803 L
s
.54547 .61428 m
.54547 .61803 L
s
.59332 .61428 m
.59332 .61803 L
s
.64118 .61428 m
.64118 .61803 L
s
.68904 .61428 m
.68904 .61803 L
s
.78476 .61428 m
.78476 .61803 L
s
.83262 .61428 m
.83262 .61803 L
s
.88047 .61428 m
.88047 .61803 L
s
.92833 .61428 m
.92833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1126 m
1 .1126 L
s
.99375 .21049 m
1 .21049 L
s
.99375 .30838 m
1 .30838 L
s
.99375 .40627 m
1 .40627 L
s
.99375 .50416 m
1 .50416 L
s
.99375 .60204 m
1 .60204 L
s
.125 Mabswid
.99625 .03429 m
1 .03429 L
s
.99625 .05387 m
1 .05387 L
s
.99625 .07345 m
1 .07345 L
s
.99625 .09303 m
1 .09303 L
s
.99625 .13218 m
1 .13218 L
s
.99625 .15176 m
1 .15176 L
s
.99625 .17134 m
1 .17134 L
s
.99625 .19091 m
1 .19091 L
s
.99625 .23007 m
1 .23007 L
s
.99625 .24965 m
1 .24965 L
s
.99625 .26922 m
1 .26922 L
s
.99625 .2888 m
1 .2888 L
s
.99625 .32796 m
1 .32796 L
s
.99625 .34753 m
1 .34753 L
s
.99625 .36711 m
1 .36711 L
s
.99625 .38669 m
1 .38669 L
s
.99625 .42585 m
1 .42585 L
s
.99625 .44542 m
1 .44542 L
s
.99625 .465 m
1 .465 L
s
.99625 .48458 m
1 .48458 L
s
.99625 .52373 m
1 .52373 L
s
.99625 .54331 m
1 .54331 L
s
.99625 .56289 m
1 .56289 L
s
.99625 .58247 m
1 .58247 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .05634 m
.02846 .07315 L
.03279 .08529 L
.04262 .10713 L
.06244 .14008 L
.10458 .19069 L
.14357 .22704 L
.18502 .25983 L
.22495 .28773 L
.26336 .3121 L
.30423 .33601 L
.34358 .35746 L
.38141 .37689 L
.4217 .39649 L
.46047 .41445 L
.5017 .4327 L
.54141 .44955 L
.5796 .46517 L
.62025 .48121 L
.65938 .49615 L
.70096 .51154 L
.74102 .52592 L
.77957 .53939 L
.82058 .55335 L
.86007 .56646 L
.89804 .57878 L
.93846 .5916 L
.97619 .60332 L
s
[ .02 ] 0 setdash
.02381 .01472 m
.04262 .01472 L
.0522 .01472 L
.05746 .01472 L
.06005 .01472 L
.06244 .01472 L
.06371 .01472 L
.06435 .14233 L
.06506 .14233 L
.0679 .14233 L
.07286 .14233 L
.08255 .14233 L
.10458 .14233 L
.14487 .14233 L
.1634 .14233 L
.18364 .14233 L
.18894 .14233 L
.19186 .14233 L
.1946 .14233 L
.19716 .14233 L
.19786 .14233 L
.19861 .14233 L
.19924 .26994 L
.19994 .26994 L
.20477 .26994 L
.22486 .26994 L
.26529 .26994 L
.3042 .26994 L
.34556 .26994 L
.3854 .26994 L
.40362 .26994 L
.41399 .26994 L
.41907 .26994 L
.4213 .26994 L
.42248 .26994 L
.42373 .26994 L
.42499 .39755 L
.42613 .39755 L
.42837 .39755 L
.43325 .39755 L
.44351 .39755 L
.46451 .39755 L
.5045 .39755 L
.54296 .39755 L
.58388 .39755 L
.62328 .39755 L
.66117 .39755 L
.68225 .39755 L
.70151 .39755 L
.71104 .39755 L
Mistroke
.72143 .39755 L
.72618 .39755 L
.73124 .39755 L
.7337 .39755 L
.73601 .39755 L
.73702 .39755 L
.73809 .39755 L
.73926 .52516 L
.74034 .52516 L
.77836 .52516 L
.81884 .52516 L
.8578 .52516 L
.89921 .52516 L
.93911 .52516 L
.97619 .52516 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{189, 116},
  ImageMargins->{{86, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003]0000TA000`40l00?003`kOoo003]ool00>go
o`00Mooo100?0ooo00D03ooo00ooo`0?00Coo`803`;oo`803f3oo`00N?oo00<03oooool00ooo00D0
3ooo00ooo`0?00?oo`0300oooooo00;oo`803f3oo`00N?oo0P0?1?oo00D03ooo00ooo`0?00?oo`05
00ooo`0?ool03`02ool00`0?ooooo`1Mool007Soo`0300oooooo00?oo`0400ooo`0?00l5ool200l0
1Ooo00oooooo00l0Gooo001gool400l?ool0100?ooooo`0?Gooo001nool00`0?ooooo`1/ool00>go
o`00kOoo003]ool00>goo`00kOoo003]ool002Woo`0300oooooo02Ooo`0500oooooo00ooo`0200lW
ool300lWool300l00ooo00ooo`0200lXool300l?ool002Soo`0300ooo`0?02Ooo`0300ooo`0?00Go
o`0300oooooo02Goo`0300oooooo02Ooo`0300oooooo00Coo`0300oooooo02Goo`0300oooooo00oo
o`00:?oo00<03ooo00l09ooo00<03ooo00l00ooo0P0?:?oo00<03oooool09ooo00<03oooool00_oo
0P0?:Ooo00<03oooool03_oo000Xool00`0?ool03`0Wool00`0?ool03`03ool00`0?ooooo`0Wool0
0`0?ooooo`0Wool00`0?ooooo`02ool00`0?ooooo`0Wool00`0?ool03`0?ool002Woo`0300oooooo
02Ooo`0300oooooo00;oo`<03bKoo`803bSoo`803`Coo`<03bSoo`803`ooo`00kOoo003]ool00>go
o`00kOoo003]ool00>goo`007ooo00<03oooool01?oo_00?2ooo000Nool00`0?ool03`05ool0100?
ooooo`0?2?oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<0
3oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<0
3oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<0
3oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01Ooo00<03oooool01_oo00<0
3oooool00_oo00<03oooool02Ooo000Nool00`0?ool03`05ool00`0?ooooo`0]ool00`2?ooooo`0Z
ool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?ooooo`09ool001koo`0300ooo`0?00Goo`803`;o
o`D03`?oo`0300oooooo027oo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02goo`803`_o
o`007ooo00<03oooool01?oo00<03oooool02Ooo00<03oooool08Ooo00<0Soooool0:_oo00<0Oooo
ool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`09ool00`0?ooooo`0Qool0
0`1oooooo`0Zool00`2?ooooo`0Zool00`1oooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo
00Woo`0300oooooo027oo`0308oooooo02[oo`0307oooooo02[oo`0308oooooo02goo`803`_oo`00
9_oo00<03oooool0;Ooo00<0Ooooool0:_oo00<0Soooool0:_oo00<0Ooooool0;_oo00<03oooool0
2Ooo000Vool00`0?ooooo`0]ool00`2?ooooo`0Zool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?
ooooo`09ool002Koo`0300oooooo02goo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02ko
o`0300oooooo00Woo`009_oo00D03oooooooo`0?00Ooo`0300oooooo027oo`0308oooooo02[oo`03
07oooooo02[oo`0308oooooo02goo`803`_oo`009_oo00@03oooooooo`803`Koo`0300oooooo027o
o`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`009_oo00<03ooo
ool00_oo00<03oooool01?oo00<03oooool08Ooo00<0Soooool0:_oo00<0Ooooool0:_oo00<0Sooo
ool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`02ool00`0?ooooo`04ool00`0?ooooo`0Qool0
0`1oooooo`0Zool00`2?ooooo`0Zool00`1oooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo
00;oo`0300oooooo00Coo`0300oooooo027oo`0308oooooo02[oo`0307oooooo02[oo`0308oooooo
02goo`803`_oo`009_oo00<03oooool00_oo0P0?:Ooo00<0Ooooool0:_oo00<0Soooool0:_oo00<0
Ooooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`03ool00`0?ooooo`0Wool00`2?ooooo`0Z
ool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo00?oo`803bSo
o`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02goo`803`_oo`006_oo0`0?0_oo00<03ooo
ool01?oo00<03oooool01?oo00<03oooool00_oo00<03oooool08Ooo00<0Soooool0:_oo00<0Oooo
ool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000Kool01P0?ooooo`0?ool03`Goo`0300oooooo
00Coo`803`?oo`0300oooooo027oo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02koo`03
00oooooo00Woo`006ooo00H03oooool03ooo00l5ool00`0?ooooo`05ool01@0?oooooooo00l08ooo
00<0Soooool0:_oo00<0Ooooool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000Kool01P0?oooo
o`0?ool03`Goo`803`0607l0S`1o08l0O`2?0P0?0;00O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?0P0?2ooo000Jool200l3ool00`0?ooooo`04ool00`0?oooo
o`06ool00`0?ooooo`0Tool00`2?ooooo`0Zool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?oooo
o`09ool002Koo`0300oooooo00Koo`803bGoo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo
02koo`0300oooooo00Woo`009_oo00<03oooool01ooo00<03oooool08ooo00<0Soooool0:_oo00<0
Ooooool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`08ool200lSool00`1o
ooooo`0Zool00`2?ooooo`0Zool00`1oooooo`0]ool200l;ool002Koo`0300oooooo00Soo`@03`?o
o`D03`;oo`D03`?oo`D03`[oo`0308oooooo02[oo`0307oooooo02[oo`0308oooooo02koo`0300oo
oooo00Woo`009_oo00<03oooool02Ooo0P0?8_oo00<0Ooooool0:_oo00<0Soooool0:_oo00<0Oooo
ool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`0:ool00`0?ooooo`0Pool00`2?ooooo`0Zool0
0`1oooooo`0Zool00`2?ooooo`0]ool200l;ool002Koo`0300oooooo00[oo`803b7oo`0307oooooo
02[oo`0308oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`009_oo00<03oooool02ooo0P0?
5Ooo00<03oooool02?oo00<0Soooool0:_oo00<0Ooooool0:_oo00<0Soooool0;_oo00<03oooool0
2Ooo000Vool00`0?ooooo`0<ool200lDool00`0?ooooo`08ool00`1oooooo`0Zool00`2?ooooo`0Z
ool00`1oooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo00goo`803a?oo`0300oooooo00So
o`0308oooooo02[oo`0307oooooo02[oo`0308oooooo02goo`803`_oo`009_oo00<03oooool03_oo
0P0?4_oo00<03oooool02?oo00<0Ooooool0:_oo00<0Soooool0:_oo00<0Ooooool0;_oo00<03ooo
ool02Ooo000Vool00`0?ooooo`0?ool00`0?ooooo`0@ool00`0?ooooo`08ool00`2?ooooo`0Zool0
0`1oooooo`0Zool00`2?ooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo00ooo`803acoo`03
07oooooo02[oo`0308oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`009_oo00<03oooool0
4?oo0P0?6ooo00<0Soooool0:_oo00<0Ooooool0:_oo00<0Soooool0;Ooo0P0?2ooo000Jool300l2
ool00`0?ooooo`04ool00`0?ooooo`0Aool200l?ool00`0?ooooo`08ool00`1oooooo`0Zool00`2?
ooooo`0Zool00`1oooooo`0^ool00`0?ooooo`09ool001[oo`0700ooooooool03ooo00l01Ooo00<0
3oooool04_oo0`0?3Ooo00<03oooool02?oo00<0Soooool0:_oo00<0Ooooool0:_oo00<0Soooool0
;_oo00<03oooool02Ooo000Kool01P0?ooooo`0?ool03`Goo`803`0E07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o00803`2Q08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0200l;ool0
01[oo`0700ooo`0?ool03ooo00l01Ooo00<03oooool05Ooo0P0?2ooo00<03oooool02?oo00<0Sooo
ool0:_oo00<0Ooooool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000Kool200l2ool00`0?oooo
o`04ool00`0?ooooo`0Fool200l:ool00`0?ooooo`08ool00`1oooooo`0Zool00`2?ooooo`0Zool0
0`1oooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo01Ooo`803aCoo`0308oooooo02[oo`03
07oooooo02[oo`0308oooooo02koo`0300oooooo00Woo`009_oo00<03oooool06?oo0P0?4ooo00<0
Ooooool0:_oo00<0Soooool0:_oo00<0Ooooool0;Ooo0P0?2ooo000Vool00`0?ooooo`0Iool200lB
ool00`2?ooooo`0Zool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?ooooo`09ool002Koo`0300oo
oooo01[oo`<03`Goo`0300oooooo00Soo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02ko
o`0300oooooo00Woo`009_oo00<03oooool07?oo0P0?1?oo00<03oooool02?oo00<0Soooool0:_oo
00<0Ooooool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`0Mool200l3ool0
0`0?ooooo`08ool00`1oooooo`0Zool00`2?ooooo`0Zool00`1oooooo`0]ool200l;ool002Koo`03
00oooooo01koo`803`;oo`0300oooooo00Soo`0308oooooo02[oo`0307oooooo02[oo`0308oooooo
02koo`0300oooooo00Woo`009_oo00<03oooool07ooo100?2_oo00<0Ooooool0:_oo00<0Soooool0
:_oo00<0Ooooool0;_oo00<03oooool02Ooo000>ool00`0?ooooo`02ool00`0?ooooo`0@ool00`0?
ooooo`0Qool200l00ooo00l03`0300l3ool400l3ool500l2ool500l3ool500l2ool400l=ool00`1o
ooooo`0Zool00`2?ooooo`0]ool200l;ool000koo`H03a;oo`0300oooooo02;oo`<03`Soo`0307oo
oooo01coo`0300oooooo00_oo`0308oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`003_oo
00<03oooool00_oo00<03oooool04?oo00<03oooool09?oo0P0?1ooo00<0Soooool07?oo00<03ooo
ool02ooo00<0Ooooool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000>ool00`0?ooooo`02ool0
0`0?ooooo`0@ool00`0?ooooo`0Uool300l5ool00`1oooooo`0Zool00`2?ooooo`0Zool00`1ooooo
o`0^ool00`0?ooooo`09ool000ooo`0400oooooo00lCool00`0?ooooo`0Wool200l4ool00`2?oooo
o`0Zool00`1oooooo`0Zool00`2?ooooo`0]ool200l;ool0013oo`803`Soo`803`?oo`0300oooooo
00Coo`0300oooooo02Soo`<03`;oo`0307oooooo01coo`0300oooooo00_oo`0308oooooo02[oo`03
07oooooo02koo`0300oooooo00Woo`004?oo0P0?2_oo00D03ooo00ooo`0?00Goo`0300oooooo02[o
o`803`03ool0Sooo01goo`0300oooooo00_oo`0307oooooo02[oo`0308oooooo02koo`0300oooooo
00Woo`003ooo00<03oooool00P0?1ooo00H03oooool03ooo00l5ool00`0?ooooo`0[ool300lNool0
0`0?ooooo`0;ool00`2?ooooo`0Zool00`1oooooo`0^ool00`0?ooooo`09ool000koo`0300oooooo
00;oo`0300oooooo00Koo`0500ooo`0?ool03`05ool200l0;P2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o0P0?08P0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`803`_oo`003_oo00<0
3oooool00_oo00<03oooool01?oo0P0?0ooo00<03oooool01?oo00<03oooool0;Ooo00@0O`0?00l0
3a_oo`0300oooooo00_oo`0308oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`003ooo00<0
3oooool00P0?4_oo00<03oooool0;Ooo00<0Soooool00`0?9ooo00<0Ooooool0:_oo00<0Soooool0
;_oo00<03oooool02Ooo000@ool200lDool00`0?ooooo`0]ool00`1oooooo`02ool300lUool00`2?
ooooo`0Zool00`1oooooo`0]ool200l;ool000ooo`0300oooooo00803a;oo`0300oooooo02goo`03
08oooooo00Coo`803bCoo`0307oooooo02[oo`0308oooooo02koo`0300oooooo00Woo`003_oo00<0
3ooo00l00_oo00<03oooool04?oo00<03oooool0;Ooo00<0Ooooool01Ooo0`0?5?oo00<03oooool0
2ooo00<0Soooool0:_oo00<0Ooooool0;_oo00<03oooool02Ooo000>ool01P0?ooooo`0?ool03a;o
o`0300oooooo02goo`0308oooooo00Ooo`<03a;oo`0300oooooo00_oo`0307oooooo02[oo`0308oo
oooo02koo`0300oooooo00Woo`003_oo0P0?0_oo00<03oooool04Ooo00<03oooool0;Ooo00<0Oooo
ool02Ooo0`0?4?oo00<03oooool02ooo00<0Soooool0:_oo00<0Ooooool0;Ooo0P0?2ooo000Vool0
0`0?ooooo`0]ool00`2?ooooo`0;ool300l>ool00`0?ooooo`0;ool00`1oooooo`0Zool00`2?oooo
o`0^ool00`0?ooooo`09ool002Koo`0300oooooo02goo`0307oooooo00goo`<03a[oo`0308oooooo
02[oo`0307oooooo02koo`0300oooooo00Woo`009_oo00<03oooool0;Ooo00<0Soooool03ooo0P0?
6Ooo00<0Ooooool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`0]ool00`1o
ooooo`0Aool200lGool00`2?ooooo`0Zool00`1oooooo`0]ool200l;ool002Koo`0300oooooo02go
o`0308oooooo01;oo`<03`Ooo`0300oooooo00_oo`0307oooooo02[oo`0308oooooo02koo`0300oo
oooo00Woo`009_oo00<03oooool0;Ooo00<0Ooooool05?oo0`0?1Ooo00<03oooool02ooo00<0Sooo
ool0:_oo00<0Ooooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`0]ool00`2?ooooo`0Fool3
00l3ool00`0?ooooo`0;ool00`1oooooo`0Zool00`2?ooooo`0]ool200l;ool001coo`0400oooooo
00l6ool00`0?ooooo`0]ool00`1oooooo`0Iool400l=ool00`2?ooooo`0Zool00`1oooooo`0^ool0
0`0?ooooo`09ool001[oo`<03`04ool03ooo00l5ool00`0?ooooo`0]ool00`2?ooooo`0Kool300l2
ool400l3ool500l3ool400l3ool500l3ool400l3ool500l3ool400l3ool400l`ool00`0?ooooo`09
ool001[oo`0700ooo`0?ool03ooo00l01Ooo00<03oooool0;Ooo00<0Ooooool07Ooo0`0?2_oo00<0
Soooool0:_oo00<03oooool0;_oo00<03oooool02Ooo000Kool200l01?oo00ooo`0?1Ooo0P0?0500
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o0`0?06D0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o00803`_oo`007?oo00@03oooool03`Koo`0300oooooo02goo`0307oooooo027oo`<03`Ko
o`0308oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`009_oo00<03oooool0;Ooo00<0Sooo
ool08ooo0`0?1?oo00<0Ooooool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000Vool00`0?oooo
o`0]ool00`1oooooo`0Uool400l00ooo08ooo`0[ool00`0?ooooo`0^ool00`0?ooooo`09ool002Ko
o`0300oooooo02goo`0308oooooo02Soo`<03bcoo`0300oooooo02goo`803`_oo`009_oo00<03ooo
ool0;Ooo00<0Ooooool0:_oo0`0?:_oo00<03oooool0;_oo00<03oooool02Ooo000Vool00`0?oooo
o`0]ool00`2?ooooo`0Zool00`1oool03`0300lWool00`0?ooooo`0^ool00`0?ooooo`09ool002Ko
o`0300oooooo02goo`0307oooooo02[oo`0308oooooo00;oo`<03bGoo`0300oooooo02goo`803`_o
o`009_oo00<03oooool0;Ooo00<0Soooool0:_oo00<0Ooooool01?oo0`0?8ooo00<0Soooool0;_oo
00<03oooool02Ooo000Vool00`0?ooooo`0]ool00`1oooooo`0Zool00`2?ooooo`06ool400lPool0
0`1oooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo02goo`0308oooooo02[oo`0307oooooo
00Woo`<03akoo`0300oooooo02koo`0300oooooo00Woo`009_oo00<03oooool0;Ooo00<0Ooooool0
:_oo00<0Soooool02ooo100?6ooo00<03oooool0;Ooo0P0?2ooo000Vool00`0?ooooo`0]ool00`2?
ooooo`0Zool00`1oooooo`0>ool300lIool00`0?ooooo`0^ool00`0?ooooo`09ool002Koo`0300oo
oooo02goo`0307oooooo02[oo`0308oooooo013oo`@03aKoo`0300oooooo02koo`0300oooooo00Wo
o`009_oo00<03oooool0;Ooo00<0Soooool0:_oo00<0Ooooool04ooo0`0?5?oo00<03oooool0;_oo
00<03oooool02Ooo000Vool00`0?ooooo`0]ool00`1oooooo`0Zool00`2?ooooo`0Eool400lAool0
0`1oooooo`0]ool200l;ool001[oo`803`?oo`0300oooooo00Coo`0300oooooo02goo`0308oooooo
02[oo`0307oooooo01Soo`@03`koo`0308oooooo02koo`0300oooooo00Woo`007?oo00D03ooo00oo
o`0?00Goo`0300oooooo02goo`0307oooooo02[oo`0308oooooo01_oo`<03`coo`0307oooooo02ko
o`0300oooooo00Woo`006_oo0P0?0_oo00<03ooo00l01Ooo0P0?07/0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0100?03T0O`2?07l0
S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l00P0?2ooo000Jool0
1`0?oooooooo00ooo`0?00Goo`0300oooooo02goo`0307oooooo02[oo`0308oooooo023oo`@03`Ko
o`0300oooooo02koo`0300oooooo00Woo`006_oo0`0?0_oo00<03oooool01?oo00<03oooool0;Ooo
00<0Soooool0:_oo00<0Ooooool08ooo100?0ooo00<03oooool0;_oo00<03oooool02Ooo000Vool0
0`0?ooooo`0]ool00`1oooooo`0Zool00`2?ooooo`0Vool300l00ooo00ooo`0_ool00`0?ooooo`09
ool002Koo`0300oooooo02goo`0308oooooo02[oo`0307oooooo02Soo`@03`03ool03`0?00<03`?o
o`D03`;oo`D03`?oo`D03`;oo`D03`?oo`@03`?oo`803`_oo`009_oo00<03oooool0;Ooo00<0Oooo
ool0:_oo00<0Soooool0:_oo00<0O`0?00l00P0?;?oo00<03oooool02Ooo000Vool00`0?ooooo`0]
ool00`2?ooooo`0Zool00`1oooooo`0Zool0102?oooooooo100?:Ooo00<03oooool02Ooo000Vool0
0`0?ooooo`0]ool00`1oooooo`0Zool00`2?ooooo`0Zool00`1oooooo`04ool400lVool00`0?oooo
o`09ool002Koo`0300oooooo02goo`0308oooooo02[oo`0307oooooo02[oo`0308oooooo00Ooo`@0
3b;oo`803`_oo`009_oo00<03oooool0;Ooo00<0Ooooool0:_oo00<0Soooool0:_oo00<0Ooooool0
2_oo100?8?oo00<03oooool02Ooo000Vool00`0?ooooo`0]ool00`2?ooooo`0Zool00`1oooooo`0Z
ool00`2?ooooo`0=ool400lMool00`0?ooooo`09ool002Koo`0300oooooo02goo`0307oooooo02[o
o`0308oooooo02[oo`0307oooooo013oo`@03aWoo`803`_oo`009_oo00<03oooool0;Ooo00<0Sooo
ool0:_oo00<0Ooooool0:_oo00<0Soooool04ooo100?5ooo00<03oooool02Ooo000Vool00`0?oooo
o`0]ool00`1oooooo`0Zool00`2?ooooo`0Zool00`1oooooo`0Fool400lDool00`0?ooooo`09ool0
02Koo`0300oooooo02goo`0308oooooo02[oo`0307oooooo02[oo`0308oooooo01Woo`@03a7oo`03
00oooooo00Woo`009_oo00<03oooool0;Ooo00<0Ooooool0:_oo00<0Soooool0:_oo00<0Ooooool0
7?oo100?3Ooo0P0?2ooo000Kool01@0?oooooooo00l01_oo00<03oooool0;Ooo00<0Soooool0:_oo
00<0Ooooool0:_oo00<0Soooool07ooo100?2ooo00<03oooool02Ooo000Jool01`0?ool03ooo00oo
o`0?00Goo`0300oooooo02goo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02;oo`@03`So
o`0300oooooo00Woo`006_oo0P0?0_oo00<03ooo00l01Ooo0P0?;_oo00<0Soooool0:_oo00<0Oooo
ool0:_oo00<0Soooool09Ooo1@0?0ooo0P0?2ooo000Jool01`0?oooooooo00ooo`0?00Goo`0300oo
oooo02goo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02Woo`0300oooooo00;oo`0300oo
oooo00Woo`006ooo0P0?0_oo00<03oooool01?oo00@03oooool03bcoo`0300oooooo02[oo`0300oo
oooo02[oo`0300oooooo02Woo`0300oooooo00;oo`0300oooooo00Woo`009_oo_00?2ooo003]ool0
0>goo`00kOoo0000\
\>"],
  ImageRangeCache->{{{0, 235.25}, {144, 0}} -> {-0.466873, -15.336326, 
  0.013958, 0.682383}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Quantum Wire"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[rho20, rho22]; \)\), 
    \(rho20[En_, s_] := \((L\/s)\)\^2\ rho[1, En]\), 
    \(rho22[En_, s_] := 
      rho20[En, s]\ Floor[\(L\^2\ rho[3, En]\)\/rho20[En, s]]\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig14x5 = 
      Plot[Evaluate[{atto\ L\^3\ rho[3, e\ En] //. case, 
            atto\ L\ rho22[e\ En, 1\ nano] //. case}], {En, 0.01, 2}, 
        FrameLabel \[Rule] {"\<E in eV\>", "\<DOS\>"}, Evaluate[opt]]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.019024 0.478583 0.014715 0.009789 [
[.01902 -0.0125 -4 -12 ]
[.01902 -0.0125 4 0 ]
[.25832 -0.0125 -7 -12 ]
[.25832 -0.0125 7 0 ]
[.49761 -0.0125 -4 -12 ]
[.49761 -0.0125 4 0 ]
[.7369 -0.0125 -7 -12 ]
[.7369 -0.0125 7 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14.5 -24 ]
[.5 -0.0125 14.5 -12 ]
[-0.0125 .01472 -8 -6 ]
[-0.0125 .01472 0 6 ]
[-0.0125 .1126 -12 -6 ]
[-0.0125 .1126 0 6 ]
[-0.0125 .21049 -12 -6 ]
[-0.0125 .21049 0 6 ]
[-0.0125 .30838 -12 -6 ]
[-0.0125 .30838 0 6 ]
[-0.0125 .40627 -12 -6 ]
[-0.0125 .40627 0 6 ]
[-0.0125 .50416 -12 -6 ]
[-0.0125 .50416 0 6 ]
[-0.0125 .60204 -12 -6 ]
[-0.0125 .60204 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24 -10 ]
[-0.01875 .30902 -12 10 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.25832 0 m
.25832 .61803 L
s
.49761 0 m
.49761 .61803 L
s
.7369 0 m
.7369 .61803 L
s
0 .1126 m
1 .1126 L
s
0 .21049 m
1 .21049 L
s
0 .30838 m
1 .30838 L
s
0 .40627 m
1 .40627 L
s
0 .50416 m
1 .50416 L
s
0 g
.01902 0 m
.01902 .00625 L
s
gsave
.01902 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25832 0 m
.25832 .00625 L
s
gsave
.25832 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.49761 0 m
.49761 .00625 L
s
gsave
.49761 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7369 0 m
.7369 .00625 L
s
gsave
.7369 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06688 0 m
.06688 .00375 L
s
.11474 0 m
.11474 .00375 L
s
.1626 0 m
.1626 .00375 L
s
.21046 0 m
.21046 .00375 L
s
.30617 0 m
.30617 .00375 L
s
.35403 0 m
.35403 .00375 L
s
.40189 0 m
.40189 .00375 L
s
.44975 0 m
.44975 .00375 L
s
.54547 0 m
.54547 .00375 L
s
.59332 0 m
.59332 .00375 L
s
.64118 0 m
.64118 .00375 L
s
.68904 0 m
.68904 .00375 L
s
.78476 0 m
.78476 .00375 L
s
.83262 0 m
.83262 .00375 L
s
.88047 0 m
.88047 .00375 L
s
.92833 0 m
.92833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(E) show
69.875000 13.000000 moveto
(in) show
78.062500 13.000000 moveto
(eV) show
87.312500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .1126 m
.00625 .1126 L
s
gsave
-0.0125 .1126 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .21049 m
.00625 .21049 L
s
gsave
-0.0125 .21049 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .30838 m
.00625 .30838 L
s
gsave
-0.0125 .30838 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(30) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .40627 m
.00625 .40627 L
s
gsave
-0.0125 .40627 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .50416 m
.00625 .50416 L
s
gsave
-0.0125 .50416 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60204 m
.00625 .60204 L
s
gsave
-0.0125 .60204 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .03429 m
.00375 .03429 L
s
0 .05387 m
.00375 .05387 L
s
0 .07345 m
.00375 .07345 L
s
0 .09303 m
.00375 .09303 L
s
0 .13218 m
.00375 .13218 L
s
0 .15176 m
.00375 .15176 L
s
0 .17134 m
.00375 .17134 L
s
0 .19091 m
.00375 .19091 L
s
0 .23007 m
.00375 .23007 L
s
0 .24965 m
.00375 .24965 L
s
0 .26922 m
.00375 .26922 L
s
0 .2888 m
.00375 .2888 L
s
0 .32796 m
.00375 .32796 L
s
0 .34753 m
.00375 .34753 L
s
0 .36711 m
.00375 .36711 L
s
0 .38669 m
.00375 .38669 L
s
0 .42585 m
.00375 .42585 L
s
0 .44542 m
.00375 .44542 L
s
0 .465 m
.00375 .465 L
s
0 .48458 m
.00375 .48458 L
s
0 .52373 m
.00375 .52373 L
s
0 .54331 m
.00375 .54331 L
s
0 .56289 m
.00375 .56289 L
s
0 .58247 m
.00375 .58247 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
71 10 translate
90 rotate
-71 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(DOS) show
78.937500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.01902 .61178 m
.01902 .61803 L
s
.25832 .61178 m
.25832 .61803 L
s
.49761 .61178 m
.49761 .61803 L
s
.7369 .61178 m
.7369 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06688 .61428 m
.06688 .61803 L
s
.11474 .61428 m
.11474 .61803 L
s
.1626 .61428 m
.1626 .61803 L
s
.21046 .61428 m
.21046 .61803 L
s
.30617 .61428 m
.30617 .61803 L
s
.35403 .61428 m
.35403 .61803 L
s
.40189 .61428 m
.40189 .61803 L
s
.44975 .61428 m
.44975 .61803 L
s
.54547 .61428 m
.54547 .61803 L
s
.59332 .61428 m
.59332 .61803 L
s
.64118 .61428 m
.64118 .61803 L
s
.68904 .61428 m
.68904 .61803 L
s
.78476 .61428 m
.78476 .61803 L
s
.83262 .61428 m
.83262 .61803 L
s
.88047 .61428 m
.88047 .61803 L
s
.92833 .61428 m
.92833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1126 m
1 .1126 L
s
.99375 .21049 m
1 .21049 L
s
.99375 .30838 m
1 .30838 L
s
.99375 .40627 m
1 .40627 L
s
.99375 .50416 m
1 .50416 L
s
.99375 .60204 m
1 .60204 L
s
.125 Mabswid
.99625 .03429 m
1 .03429 L
s
.99625 .05387 m
1 .05387 L
s
.99625 .07345 m
1 .07345 L
s
.99625 .09303 m
1 .09303 L
s
.99625 .13218 m
1 .13218 L
s
.99625 .15176 m
1 .15176 L
s
.99625 .17134 m
1 .17134 L
s
.99625 .19091 m
1 .19091 L
s
.99625 .23007 m
1 .23007 L
s
.99625 .24965 m
1 .24965 L
s
.99625 .26922 m
1 .26922 L
s
.99625 .2888 m
1 .2888 L
s
.99625 .32796 m
1 .32796 L
s
.99625 .34753 m
1 .34753 L
s
.99625 .36711 m
1 .36711 L
s
.99625 .38669 m
1 .38669 L
s
.99625 .42585 m
1 .42585 L
s
.99625 .44542 m
1 .44542 L
s
.99625 .465 m
1 .465 L
s
.99625 .48458 m
1 .48458 L
s
.99625 .52373 m
1 .52373 L
s
.99625 .54331 m
1 .54331 L
s
.99625 .56289 m
1 .56289 L
s
.99625 .58247 m
1 .58247 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .05634 m
.02846 .07315 L
.03279 .08529 L
.04262 .10713 L
.06244 .14008 L
.10458 .19069 L
.14357 .22704 L
.18502 .25983 L
.22495 .28773 L
.26336 .3121 L
.30423 .33601 L
.34358 .35746 L
.38141 .37689 L
.4217 .39649 L
.46047 .41445 L
.5017 .4327 L
.54141 .44955 L
.5796 .46517 L
.62025 .48121 L
.65938 .49615 L
.70096 .51154 L
.74102 .52592 L
.77957 .53939 L
.82058 .55335 L
.86007 .56646 L
.89804 .57878 L
.93846 .5916 L
.97619 .60332 L
s
[ .02 ] 0 setdash
.02381 .01472 m
.06244 .01472 L
.08255 .01472 L
.10458 .01472 L
.11448 .01472 L
.11992 .01472 L
.12507 .01472 L
.12986 .01472 L
.13117 .01472 L
.13189 .01472 L
.13256 .01472 L
.13375 .21821 L
.13506 .21706 L
.14415 .20957 L
.18292 .18497 L
.20406 .17495 L
.22415 .1669 L
.23373 .16347 L
.239 .16168 L
.24158 .16082 L
.24395 .16005 L
.24621 .15933 L
.24734 .15897 L
.24859 .30243 L
.24984 .30165 L
.25118 .30082 L
.2536 .29934 L
.26234 .29418 L
.3037 .27308 L
.3244 .26418 L
.34355 .2567 L
.35313 .25321 L
.35783 .25155 L
.35988 .25083 L
.36105 .25043 L
.36213 .25006 L
.3632 .36718 L
.36433 .3666 L
.36665 .36543 L
.37152 .363 L
.38188 .35799 L
.42337 .3399 L
.44418 .33184 L
.45331 .32849 L
.46336 .32492 L
.46801 .32331 L
.47058 .32243 L
.47301 .32161 L
.47527 .32085 L
.47654 .32042 L
Mistroke
.47773 .4218 L
.47883 .42131 L
.47982 .42087 L
.48204 .4199 L
.50182 .41151 L
.54194 .39598 L
.56036 .38944 L
.5708 .38588 L
.58054 .38264 L
.5855 .38103 L
.58794 .38025 L
.59019 .37952 L
.59145 .37912 L
.59208 .46997 L
.59278 .4697 L
.5956 .46858 L
.60052 .46666 L
.6216 .45868 L
.66186 .44456 L
.68037 .4385 L
.69085 .43518 L
.69596 .43359 L
.70059 .43216 L
.703 .43143 L
.70426 .43105 L
.70495 .43084 L
.7056 .43064 L
.70676 .5134 L
.70805 .51294 L
.71031 .51212 L
.72067 .50843 L
.74179 .50117 L
.78066 .48859 L
.79082 .48546 L
.80188 .48213 L
.80694 .48062 L
.81232 .47904 L
.81692 .4777 L
.81818 .47734 L
.81953 .47694 L
.82082 .47657 L
.82199 .55315 L
.82327 .55273 L
.82447 .55233 L
.82672 .55158 L
.83178 .5499 L
.84089 .54693 L
.86158 .54035 L
.90002 .52876 L
.91987 .52306 L
Mistroke
.92469 .52171 L
.92988 .52026 L
.93141 .51984 L
.93286 .51944 L
.93416 .51908 L
.93489 .51888 L
.93557 .59068 L
.93627 .59047 L
.93693 .59026 L
.93815 .58988 L
.9409 .58902 L
.97619 .57833 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{189, 116},
  ImageMargins->{{86, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003]0000TA000`40l00?003`kOoo003]ool00>go
o`00Mooo100?0ooo00D03ooo00ooo`0?00Coo`803`;oo`803f3oo`00N?oo00<03oooool00ooo00D0
3ooo00ooo`0?00?oo`0300oooooo00;oo`803f3oo`00N?oo0P0?1?oo00D03ooo00ooo`0?00?oo`05
00ooo`0?ool03`02ool00`0?ooooo`1Mool007Soo`0300oooooo00?oo`0400ooo`0?00l5ool200l0
1Ooo00oooooo00l0Gooo001gool400l?ool0100?ooooo`0?Gooo001nool00`0?ooooo`1/ool00>go
o`00kOoo003]ool00>goo`00kOoo003]ool002Woo`0300oooooo02Ooo`0500oooooo00ooo`0200lW
ool300lWool300l00ooo00ooo`0200lXool300l?ool002Soo`0300ooo`0?02Ooo`0300ooo`0?00Go
o`0300oooooo02Goo`0300oooooo02Ooo`0300oooooo00Coo`0300oooooo02Goo`0300oooooo00oo
o`00:?oo00<03ooo00l09ooo00<03ooo00l00ooo0P0?:?oo00<03oooool09ooo00<03oooool00_oo
0P0?:Ooo00<03oooool03_oo000Xool00`0?ool03`0Wool00`0?ool03`03ool00`0?ooooo`0Wool0
0`0?ooooo`0Wool00`0?ooooo`02ool00`0?ooooo`0Wool00`0?ool03`0?ool002Woo`0300oooooo
02Ooo`0300oooooo00;oo`<03bKoo`803bSoo`803`Coo`<03bSoo`803`ooo`00kOoo003]ool00>go
o`00kOoo003]ool00>goo`007ooo00<03oooool01?oo_00?2ooo000Nool00`0?ool03`05ool0100?
ooooo`0?2?oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<0
3oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<0
3oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01_oo00<0
3oooool01_oo00<03oooool01_oo00<03oooool01_oo00<03oooool01Ooo00<03oooool01_oo00<0
3oooool00_oo00<03oooool02Ooo000Nool00`0?ool03`05ool00`0?ooooo`0]ool00`2?ooooo`0Z
ool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?ooooo`09ool001koo`0300ooo`0?00Goo`803`;o
o`D03`?oo`@03`?oo`D03aSoo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02goo`803`_o
o`007ooo00<03oooool01?oo00<03oooool0;Ooo00<0Soooool0:_oo00<0Ooooool0:_oo00<0Sooo
ool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`0Fool00`0?ooooo`0Dool00`1oooooo`0Zool0
0`2?ooooo`0Zool00`1oooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo01Koo`0300oooooo
01Coo`0308oooooo02[oo`0307oooooo02[oo`0308oooooo02goo`803`_oo`009_oo00<03oooool0
5_oo00<03oooool05?oo00<0Ooooool0:_oo00<0Soooool0:_oo00<0Ooooool0;_oo00<03oooool0
2Ooo000Vool00`0?ooooo`0Fool00`0?ooooo`0Dool00`2?ooooo`0Zool00`1oooooo`0Zool00`2?
ooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo02goo`0307oooooo02[oo`0308oooooo02[o
o`0307oooooo02koo`0300oooooo00Woo`009_oo00D03oooooooo`0?02_oo`0308oooooo02[oo`03
07oooooo02[oo`0308oooooo02goo`803`_oo`009_oo00@03oooooooo`803b[oo`0307oooooo02[o
o`0308oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`009_oo00<03oooool00_oo00<03ooo
ool04Ooo00<03oooool05?oo00<0Soooool0:_oo00<0Ooooool0:_oo00<0Soooool0;_oo00<03ooo
ool02Ooo000Vool00`0?ooooo`02ool00`0?ooooo`0Aool00`0?ooooo`0Dool00`1oooooo`0Zool0
0`2?ooooo`0Zool00`1oooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo00;oo`0300oooooo
017oo`0300oooooo01Coo`0308oooooo02[oo`0307oooooo02[oo`0308oooooo02goo`803`_oo`00
9_oo00<03oooool00_oo0P0?4_oo00<03oooool05?oo00<0Ooooool0:_oo00<0Soooool0:_oo00<0
Ooooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`03ool00`0?ooooo`0@ool00`0?ooooo`0D
ool00`2?ooooo`0Zool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?ooooo`09ool002Koo`0300oo
oooo00?oo`803bSoo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02goo`803`_oo`006_oo
0`0?0_oo00<03oooool01?oo00<03oooool01?oo00<03oooool09_oo00<0Soooool0:_oo00<0Oooo
ool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000Kool01P0?ooooo`0?ool03`Goo`0300oooooo
00Coo`803bOoo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`00
6ooo00H03oooool03ooo00l5ool00`0?ooooo`05ool00`0?ooooo`0>ool00`0?ooooo`0Dool00`2?
ooooo`0Zool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?ooooo`09ool001_oo`0600oooooo00oo
o`0?1Ooo0P0?00H0O`2?07l0S`1o08l200l0/01o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l200l;ool001[oo`803`?oo`0300oooooo00Coo`0300oooooo00Ko
o`0300oooooo00goo`0300oooooo01Coo`0308oooooo02[oo`0307oooooo02[oo`0308oooooo02ko
o`0300oooooo00Woo`009_oo00<03oooool01_oo0P0?3_oo00<03oooool05?oo00<0Ooooool0:_oo
00<0Soooool0:_oo00<0Ooooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`07ool00`0?oooo
o`0Sool00`2?ooooo`0Zool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?ooooo`09ool002Koo`03
00oooooo00Soo`0300oooooo02;oo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo02goo`80
3`_oo`009_oo00<03oooool02?oo0P0?8ooo00<0Soooool0:_oo00<0Ooooool0:_oo00<0Soooool0
;_oo00<03oooool02Ooo000Vool00`0?ooooo`09ool200l;ool00`0?ooooo`0Dool00`1oooooo`0Z
ool00`2?ooooo`0Zool00`1oooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo00[oo`0300oo
oooo00Woo`0300oooooo01Coo`0308oooooo02[oo`0307oooooo02[oo`0308oooooo02goo`803`_o
o`009_oo00<03oooool02_oo0P0?2_oo00<03oooool05?oo00<0Ooooool0:_oo00<0Soooool0:_oo
00<0Ooooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`0;ool200l9ool00`0?ooooo`0Bool0
0`0?ool0S`0/ool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo
00coo`803`Soo`0300oooooo00goo`803`?oo`0300ooo`1o02coo`0308oooooo02[oo`0307oooooo
02koo`0300oooooo00Woo`009_oo00<03oooool03Ooo0P0?5Ooo0P0?1Ooo00<03ooo08l0;?oo00<0
Ooooool0:_oo00<0Soooool0;Ooo0P0?2ooo000Vool00`0?ooooo`0>ool200lKool00`0?ool0O`0/
ool00`2?ooooo`0Zool00`1oooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo00ooo`0300oo
oooo00goo`803`coo`0308oooooo02[oo`0307oooooo02[oo`0308oooooo02koo`0300oooooo00Wo
o`009_oo00<03oooool03ooo0P0?1Ooo00<03oooool01Ooo00<03oooool03?oo00<0Ooooool0:_oo
00<0Soooool0:_oo00<0Ooooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`0@ool200l4ool0
0`0?ooooo`04ool00`0?ooooo`0=ool00`2?ooooo`0Zool00`1oooooo`0Zool00`2?ooooo`0]ool2
00l;ool001[oo`<03`;oo`0300oooooo00Coo`0300oooooo017oo`803`?oo`0300oooooo01;oo`03
00ooo`1o02coo`0308oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`006_oo00L03ooooooo
o`0?ool03`05ool00`0?ooooo`0Bool300l01?oo00oooooo0P0?4?oo00<03ooo08l0;?oo00<0Oooo
ool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000Kool01P0?ooooo`0?ool03`Goo`803`0E07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00803`2Q08l0O`0?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`0200l;ool001[oo`0700ooo`0?ool03ooo00l01Ooo00<03oooool05Ooo0`0?4ooo00<0
3ooo08l0;?oo00<0Ooooool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000Kool200l2ool00`0?
ooooo`04ool00`0?ooooo`0Fool200lCool00`0?ool0O`0/ool00`2?ooooo`0Zool00`1oooooo`0^
ool00`0?ooooo`09ool002Koo`0300oooooo01Ooo`803aCoo`0308oooooo02[oo`0307oooooo02[o
o`0308oooooo02koo`0300oooooo00Woo`009_oo00<03oooool06?oo0P0?4ooo00<0Ooooool0:_oo
00<0Soooool0:_oo00<0Ooooool0;Ooo0P0?2ooo000Vool00`0?ooooo`0Iool200l@ool00`0?ool0
S`0/ool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo01[oo`<0
3`koo`0300ooo`1o02coo`0308oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`009_oo00<0
3oooool07?oo0P0?3Ooo00<03ooo08l0;?oo00<0Ooooool0:_oo00<0Soooool0;_oo00<03oooool0
2Ooo000Vool00`0?ooooo`0Mool200l<ool00`0?ool0O`0Aool00`0?ooooo`0Hool00`2?ooooo`0Z
ool00`1oooooo`0]ool200l;ool002Koo`0300oooooo01koo`803`_oo`0300ooo`2?00koo`<03a_o
o`0307oooooo02[oo`0308oooooo02koo`0300oooooo00Woo`009_oo00<03oooool07ooo0`0?2ooo
00<0Ooooool02ooo00<03oooool00ooo00<03oooool05_oo00<0Soooool0:_oo00<0Ooooool0;_oo
00<03oooool02Ooo000>ool00`0?ooooo`02ool00`0?ooooo`0@ool00`0?ooooo`0Qool200l:ool0
0`2?ooooo`07ool200l8ool00`0?ooooo`0Fool00`1oooooo`0Zool00`2?ooooo`0]ool200l;ool0
00koo`H03a;oo`0300oooooo02;oo`<03`Soo`0307oooooo00Goo`803`[oo`0300oooooo01Koo`03
08oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`003_oo00<03oooool00_oo00<03oooool0
4?oo00<03oooool09?oo0P0?1Ooo00<03ooo08l01_oo00<03oooool02_oo00<03oooool05_oo00<0
Ooooool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000>ool00`0?ooooo`02ool00`0?ooooo`0@
ool00`0?ooooo`0Uool300l3ool00`0?ool0O`03ool00`0?ooooo`0Vool00`2?ooooo`0Zool00`1o
ooooo`0^ool00`0?ooooo`09ool000ooo`0400oooooo00lCool00`0?ooooo`0Wool200l2ool0100?
ool0Sooo0P0?:Ooo00<0Ooooool0:_oo00<0Soooool0;Ooo0P0?2ooo000@ool200l8ool200l3ool0
0`0?ooooo`04ool00`0?ooooo`0Xool400l00ooo07l03`0[ool00`2?ooooo`0Zool00`1oooooo`0^
ool00`0?ooooo`09ool0013oo`803`[oo`0500ooo`0?ool03`05ool00`0?ooooo`0Zool200l00ooo
08ooo`0Bool00`0?ooooo`0Fool00`1oooooo`0Zool00`2?ooooo`0^ool00`0?ooooo`09ool000oo
o`0300oooooo00803`Ooo`0600oooooo00ooo`0?1Ooo00<03oooool0:ooo0`0?4ooo00<03oooool0
5_oo00<0Soooool0:_oo00<0Ooooool0;_oo00<03oooool02Ooo000>ool00`0?ooooo`02ool00`0?
ooooo`06ool01@0?ool03ooo00l01Ooo0P0?02h0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`803`2808l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l200l;ool000koo`0300oooooo00;o
o`0300oooooo00Coo`803`?oo`0300oooooo00Coo`0300oooooo02goo`0407l03`0?00l@ool00`0?
ooooo`0Fool00`2?ooooo`0Zool00`1oooooo`0^ool00`0?ooooo`09ool000ooo`0300oooooo0080
3a;oo`0300oooooo02goo`0308oooooo00<03`koo`0300oooooo013oo`0300oooooo00?oo`0307oo
oooo02[oo`0308oooooo02koo`0300oooooo00Woo`004?oo0P0?5?oo00<03oooool0;Ooo00<0Oooo
ool00_oo0`0?7Ooo0P0?1_oo00<0Soooool0:_oo00<0Ooooool0;Ooo0P0?2ooo000?ool00`0?oooo
o`0200lBool00`0?ooooo`0]ool00`2?ooooo`04ool200lKool00`0?ooooo`02ool01@0?oooooooo
07l0;?oo00<0Soooool0;_oo00<03oooool02Ooo000>ool00`0?ool03`02ool00`0?ooooo`0@ool0
0`0?ooooo`0]ool00`1oooooo`05ool300l9ool00`0?ooooo`08ool200l8ool01@0?oooooooo08l0
;?oo00<0Ooooool0;_oo00<03oooool02Ooo000>ool01P0?ooooo`0?ool03a;oo`0300oooooo02go
o`0308oooooo00Ooo`<03`Ooo`0300oooooo00Koo`803`[oo`0500ooooooool0O`0/ool00`2?oooo
o`0^ool00`0?ooooo`09ool000koo`803`;oo`0300oooooo017oo`0300oooooo02goo`0307oooooo
00Woo`<03`Goo`0300oooooo01;oo`0500ooooooool0S`0/ool00`1oooooo`0]ool200l;ool002Ko
o`0300oooooo02goo`0308oooooo00_oo`<03`?oo`0400ooooooool200lCool00`1oooooo`0Zool0
0`2?ooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo02goo`0307oooooo00goo`<03`03ool0
3ooo00803aGoo`0308oooooo02[oo`0307oooooo02koo`0300oooooo00Woo`009_oo00<03oooool0
;Ooo00<0Soooool03ooo0P0?6Ooo00<0Ooooool0:_oo00<0Soooool0;_oo00<03oooool02Ooo000V
ool00`0?ooooo`0]ool00`1oooooo`0Aool200lCool01@0?oooooooo08l0;?oo00<0Ooooool0;Ooo
0P0?2ooo000Vool00`0?ooooo`0]ool00`2?ooooo`0Bool300lAool01@0?oooooooo07l0;?oo00<0
Soooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`0]ool00`1oooooo`0Dool300l?ool01@0?
oooooooo08l03_oo0`0?6ooo00<0Ooooool0;_oo00<03oooool02Ooo000Vool00`0?ooooo`0]ool0
0`2?ooooo`0Fool300l=ool01@0?oooooooo07l03_oo00<03ooo00l06ooo00<0Soooool0;Ooo0P0?
2ooo000Lool0100?ooooo`0?1_oo00<03oooool0;Ooo00<0Ooooool06Ooo0`0?2_oo00D03ooooooo
o`2?00Woo`<03b3oo`0307oooooo02koo`0300oooooo00Woo`006_oo0`0?00Coo`0?ool03`Goo`03
00oooooo02goo`0308oooooo01_oo`<03`coo`0307oooooo00Goo`803b?oo`0308oooooo02koo`03
00oooooo00Woo`006_oo00L03ooo00ooo`0?ool03`05ool00`0?ooooo`0]ool00`1oooooo`0Mool3
00l:ool00`2?ooooo`02ool00`0?ooooo`0Uool00`1oooooo`0^ool00`0?ooooo`09ool001_oo`80
3`04ool03ooo00l5ool200l0D02?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l3
00l02P1o08l0O`2?07l0S`1o08l0O`2?0`0?05P0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`803`_oo`007?oo00@03oooool03`Koo`0300oooooo02go
o`0307oooooo027oo`<03`;oo`0600ooooooool0S`0?3ooo00<03oooool06Ooo00<0Ooooool0;_oo
00<03oooool02Ooo000Vool00`0?ooooo`0]ool00`2?ooooo`0Sool600l00ooo07ooo`0?ool00`0?
ooooo`0Iool00`2?ooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo02goo`0307oooooo02Go
o`@03`03ool0Sooo00ooo`0300oooooo01Woo`0307oooooo02koo`0300oooooo00Woo`009_oo00<0
3oooool0;Ooo00<0Soooool0:?oo0`0?4?oo00<03oooool06Ooo00<0Soooool0;Ooo0P0?2ooo000V
ool00`0?ooooo`0]ool00`1oooooo`0Zool300lQool300l6ool00`1oooooo`0^ool00`0?ooooo`09
ool002Koo`0300oooooo02goo`0308oooooo02[oo`0307ooo`0?00<03agoo`0300oooooo00Ooo`03
08oooooo02koo`0300oooooo00Woo`009_oo00<03oooool0;Ooo00<0Ooooool0:_oo00<0Soooool0
0_oo0`0?2_oo00<03oooool02Ooo0P0?1ooo00<03oooool00ooo00<0Ooooool0;Ooo0P0?2ooo000V
ool00`0?ooooo`0]ool00`2?ooooo`0Zool00`1oooooo`04ool300l8ool00`0?ooooo`06ool300l9
ool00`0?ooooo`03ool00`2?ooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo02goo`0307oo
oooo02[oo`0308oooooo00Koo`@03`Goo`0300oooooo00?oo`0300oooooo00coo`0300oooooo00?o
o`0307oooooo02koo`0300oooooo00Woo`009_oo00<03oooool0;Ooo00<0Soooool0:_oo00<0Oooo
ool02Ooo0`0?0ooo00<03oooool00`0?3ooo00<03oooool00ooo00<0Soooool0;_oo00<03oooool0
2Ooo000Vool00`0?ooooo`0]ool00`1oooooo`0Zool00`2?ooooo`0;ool500l00ooo00ooo`0Aool0
0`0?ooooo`03ool00`1oooooo`0]ool200l;ool002Koo`0300oooooo02goo`0308oooooo02[oo`03
07oooooo00koo`<03aWoo`0308oooooo02koo`0300oooooo00Woo`009_oo00<03oooool0;Ooo00<0
Ooooool0:_oo00<0Soooool04?oo100?5_oo00<0Ooooool02ooo00<03oooool08?oo00<03oooool0
2Ooo000Vool00`0?ooooo`0]ool00`2?ooooo`0Zool00`1oooooo`0Cool300lDool00`2?ooooo`08
ool300lSool00`0?ooooo`09ool002Koo`0300oooooo02goo`0307oooooo02[oo`0308oooooo01Go
o`@03`_oo`0300oooooo00?oo`0307oooooo02goo`803`_oo`006_oo0P0?0ooo00<03oooool01?oo
00<03oooool0;Ooo00<0Soooool0:_oo00<0Ooooool06?oo100?2?oo00<03oooool00ooo00<0Sooo
ool00_oo0`0?1ooo00<03oooool07ooo00<03oooool02Ooo000Lool01@0?ool03ooo00l01Ooo00<0
3oooool0;Ooo00<0Ooooool0:_oo00<0Soooool06ooo0`0?1_oo00<03oooool00ooo00<0Ooooool0
0P0?2_oo00<03oooool07ooo00<03oooool02Ooo000Jool200l2ool00`0?ool03`05ool200l0N`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`0400l0201o08l0O`0?07l0S`1o08l200l0;`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
3`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l00P0?2ooo000Jool01`0?oooooooo00ooo`0?00Goo`0300oooooo02goo`0307oooooo02[o
o`0308oooooo023oo`D03`06ool03`0?00ooo`1o3_oo00<03oooool07ooo00<03oooool02Ooo000J
ool300l2ool00`0?ooooo`04ool00`0?ooooo`0]ool00`2?ooooo`0Zool00`1oooooo`0Sool400l3
ool00`2?ooooo`0^ool00`0?ooooo`09ool002Koo`0300oooooo02goo`0307oooooo02[oo`0308oo
oooo02Koo`<03`03ool0Oooo027oo`<03`_oo`0300oooooo00Woo`009_oo00<03oooool0;Ooo00<0
Soooool0:_oo00<0Ooooool0:?oo100?7ooo0P0?3Ooo0P0?2ooo000Vool00`0?ooooo`0]ool00`1o
ooooo`0Zool00`2?ooooo`0Zool00`1o00l03`0200l;ool00`0?ooooo`09ool200lCool00`0?oooo
o`09ool002Koo`0300oooooo02goo`0308oooooo02[oo`0307oooooo02[oo`0408ooooooool400l8
ool00`0?ooooo`07ool200l9ool00`0?ooooo`09ool00`0?ooooo`09ool002Koo`0300oooooo02go
o`0307oooooo02[oo`0308oooooo02[oo`0307oooooo00Coo`@03`Goo`0300oooooo00?oo`0300oo
oooo00coo`0300oooooo00Woo`0300oooooo00Woo`009_oo00<03oooool0;Ooo00<0Soooool0:_oo
00<0Ooooool0:_oo00<0Soooool01ooo100?0_oo00<03oooool00`0?3ooo00<03oooool02?oo0P0?
2ooo000Vool00`0?ooooo`0]ool00`1oooooo`0Zool00`2?ooooo`0Zool00`1oooooo`0:ool400lD
ool00`0?ooooo`09ool00`0?ooooo`09ool002Koo`0300oooooo02goo`0308oooooo02[oo`0307oo
oooo02[oo`0308oooooo00goo`@03a7oo`0300oooooo00Woo`0300oooooo00Woo`009_oo00<03ooo
ool0;Ooo00<0Ooooool0:_oo00<0Soooool0:_oo00<0Ooooool04?oo100?6Ooo0P0?2ooo000Vool0
0`0?ooooo`0]ool00`2?ooooo`0Zool00`1oooooo`0Zool00`2?ooooo`0Cool400lGool00`0?oooo
o`09ool002Koo`0300oooooo02goo`0307oooooo02[oo`0308oooooo02[oo`0307oooooo01Koo`@0
3aCoo`0300oooooo00Woo`009_oo00<03oooool0;Ooo00<0Soooool0:_oo00<0Ooooool0:_oo00<0
Soooool06Ooo100?1Ooo00<03oooool00ooo0P0?1?oo00<03oooool02Ooo000Vool00`0?ooooo`0]
ool00`1oooooo`0Zool00`2?ooooo`0Zool00`1oooooo`0Lool400l2ool00`0?ooooo`02ool00`0?
ooooo`03ool200l;ool001_oo`0500ooooooool03`06ool00`0?ooooo`0]ool00`2?ooooo`0Zool0
0`1oooooo`0Zool00`2?ooooo`0Oool500l:ool00`0?ooooo`09ool001[oo`0700ooo`0?ool03ooo
00l01Ooo00<03oooool0;Ooo00<0Ooooool0:_oo00<0Soooool0:_oo00<0Ooooool08_oo100?2?oo
00<03oooool02Ooo000Jool200l2ool00`0?ool03`05ool200l^ool00`2?ooooo`0Zool00`1ooooo
o`0Zool00`2?ooooo`0Uool500l3ool200l;ool001[oo`0700ooooooool03ooo00l01Ooo00<03ooo
ool0;Ooo00<0Ooooool0:_oo00<0Soooool0:_oo00<0Ooooool0:Ooo00<03oooool00_oo00<03ooo
ool02Ooo000Kool200l2ool00`0?ooooo`04ool0100?ooooo`0?;?oo00<03oooool0:_oo00<03ooo
ool0:_oo00<03oooool0:Ooo00<03oooool00_oo00<03oooool02Ooo000Voonl00l;ool00>goo`00
kOoo003]ool00001\
\>"],
  ImageRangeCache->{{{0, 235.25}, {144, 0}} -> {-0.466873, -15.336326, 
  0.013958, 0.682383}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Cubical Quantum Dot"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Ec]; \)\), 
    \(\(Ec[Lc_, n_] := 3\ En[k] /. k \[Rule] \(n\ \[Pi]\)\/Lc; \)\)}], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \(\(tbl5 = Table[Ec[Lc\ nano, n]\/e, {n, 1, 6, 1}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig14x6 = 
      Plot[Evaluate[tbl5 /. case], {Lc, 1, 5}, 
        FrameLabel \[Rule] {"\<L in nm\>", "\<Ec in eV\>"}, Evaluate[opt]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.01406 0.01451 [
[.02381 -0.0125 -4 -12 ]
[.02381 -0.0125 4 0 ]
[.2619 -0.0125 -4 -12 ]
[.2619 -0.0125 4 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.7381 -0.0125 -4 -12 ]
[.7381 -0.0125 4 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -15 -24 ]
[.5 -0.0125 15 -12 ]
[-0.0125 .01406 -8 -6 ]
[-0.0125 .01406 0 6 ]
[-0.0125 .15916 -12 -6 ]
[-0.0125 .15916 0 6 ]
[-0.0125 .30426 -12 -6 ]
[-0.0125 .30426 0 6 ]
[-0.0125 .44935 -12 -6 ]
[-0.0125 .44935 0 6 ]
[-0.0125 .59445 -12 -6 ]
[-0.0125 .59445 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24 -16 ]
[-0.01875 .30902 -12 16 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .15916 m
1 .15916 L
s
0 .30426 m
1 .30426 L
s
0 .44935 m
1 .44935 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -76 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(L) show
69.875000 13.000000 moveto
(in) show
78.062500 13.000000 moveto
(nm) show
88.250000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01406 m
.00625 .01406 L
s
gsave
-0.0125 .01406 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .15916 m
.00625 .15916 L
s
gsave
-0.0125 .15916 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .30426 m
.00625 .30426 L
s
gsave
-0.0125 .30426 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .44935 m
.00625 .44935 L
s
gsave
-0.0125 .44935 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(30) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .59445 m
.00625 .59445 L
s
gsave
-0.0125 .59445 -73 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .04308 m
.00375 .04308 L
s
0 .0721 m
.00375 .0721 L
s
0 .10112 m
.00375 .10112 L
s
0 .13014 m
.00375 .13014 L
s
0 .18818 m
.00375 .18818 L
s
0 .2172 m
.00375 .2172 L
s
0 .24622 m
.00375 .24622 L
s
0 .27524 m
.00375 .27524 L
s
0 .33328 m
.00375 .33328 L
s
0 .3623 m
.00375 .3623 L
s
0 .39132 m
.00375 .39132 L
s
0 .42033 m
.00375 .42033 L
s
0 .47837 m
.00375 .47837 L
s
0 .50739 m
.00375 .50739 L
s
0 .53641 m
.00375 .53641 L
s
0 .56543 m
.00375 .56543 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -95 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
77 10 translate
90 rotate
-77 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Ec) show
73.375000 13.000000 moveto
(in) show
81.562500 13.000000 moveto
(eV) show
90.812500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01406 m
1 .01406 L
s
.99375 .15916 m
1 .15916 L
s
.99375 .30426 m
1 .30426 L
s
.99375 .44935 m
1 .44935 L
s
.99375 .59445 m
1 .59445 L
s
.125 Mabswid
.99625 .04308 m
1 .04308 L
s
.99625 .0721 m
1 .0721 L
s
.99625 .10112 m
1 .10112 L
s
.99625 .13014 m
1 .13014 L
s
.99625 .18818 m
1 .18818 L
s
.99625 .2172 m
1 .2172 L
s
.99625 .24622 m
1 .24622 L
s
.99625 .27524 m
1 .27524 L
s
.99625 .33328 m
1 .33328 L
s
.99625 .3623 m
1 .3623 L
s
.99625 .39132 m
1 .39132 L
s
.99625 .42033 m
1 .42033 L
s
.99625 .47837 m
1 .47837 L
s
.99625 .50739 m
1 .50739 L
s
.99625 .53641 m
1 .53641 L
s
.99625 .56543 m
1 .56543 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .03043 m
.04262 .02812 L
.06244 .02618 L
.08426 .02447 L
.10458 .02319 L
.14264 .02134 L
.18163 .01998 L
.22307 .01891 L
.263 .01813 L
.30142 .01755 L
.34228 .01706 L
.38164 .01667 L
.41947 .01637 L
.45976 .0161 L
.49853 .01589 L
.53975 .01569 L
.57946 .01553 L
.61766 .0154 L
.6583 .01528 L
.69743 .01518 L
.73901 .01508 L
.77908 .015 L
.81763 .01493 L
.85863 .01487 L
.89812 .01481 L
.93609 .01476 L
.97619 .01472 L
s
[ .02 ] 0 setdash
.02381 .07953 m
.04262 .0703 L
.06244 .06253 L
.08426 .0557 L
.10458 .05057 L
.14264 .0432 L
.18163 .03774 L
.22307 .03346 L
.263 .03035 L
.30142 .02802 L
.34228 .02604 L
.38164 .02451 L
.41947 .0233 L
.45976 .02223 L
.49853 .02137 L
.53975 .02059 L
.57946 .01995 L
.61766 .01942 L
.6583 .01894 L
.69743 .01853 L
.73901 .01814 L
.77908 .01782 L
.81763 .01755 L
.85863 .01728 L
.89812 .01706 L
.93609 .01687 L
.97619 .01668 L
s
.02381 .16137 m
.04262 .14059 L
.06244 .12311 L
.08426 .10776 L
.10458 .0962 L
.14264 .07961 L
.18163 .06734 L
.22307 .05772 L
.263 .05072 L
.30142 .04546 L
.34228 .04102 L
.38164 .03758 L
.41947 .03485 L
.45976 .03244 L
.49853 .0305 L
.53975 .02875 L
.57946 .02732 L
.61766 .02613 L
.6583 .02503 L
.69743 .02411 L
.73901 .02325 L
.77908 .02252 L
.81763 .0219 L
.85863 .02131 L
.89812 .02081 L
.93609 .02037 L
.97619 .01995 L
s
.02381 .27595 m
.04262 .23901 L
.06244 .20793 L
.08426 .18063 L
.10458 .16008 L
.14264 .1306 L
.18163 .10878 L
.22307 .09168 L
.263 .07923 L
.30142 .06988 L
.34228 .06199 L
.38164 .05587 L
.41947 .05102 L
.45976 .04674 L
.49853 .04328 L
.53975 .04017 L
.57946 .03762 L
.61766 .03551 L
.6583 .03356 L
.69743 .03192 L
.73901 .0304 L
.77908 .02911 L
.81763 .028 L
.85863 .02696 L
.89812 .02606 L
.93609 .02528 L
.97619 .02454 L
s
.02381 .42327 m
.04262 .36555 L
.06244 .31698 L
.08426 .27433 L
.10458 .24222 L
.14264 .19616 L
.18163 .16205 L
.22307 .13533 L
.263 .11589 L
.30142 .10129 L
.34228 .08895 L
.38164 .07938 L
.41947 .07182 L
.45976 .06512 L
.49853 .05972 L
.53975 .05486 L
.57946 .05088 L
.61766 .04758 L
.6583 .04453 L
.69743 .04197 L
.73901 .03959 L
.77908 .03757 L
.81763 .03585 L
.85863 .03421 L
.89812 .03281 L
.93609 .03159 L
.97619 .03043 L
s
[ .0001 ] 0 setdash
.02381 .60332 m
.04262 .5202 L
.06244 .45027 L
.08426 .38885 L
.10458 .3426 L
.14264 .27628 L
.18163 .22717 L
.22307 .18869 L
.263 .1607 L
.30142 .13967 L
.34228 .1219 L
.38164 .10813 L
.41947 .09723 L
.45976 .08758 L
.49853 .0798 L
.53975 .07281 L
.57946 .06708 L
.61766 .06232 L
.6583 .05793 L
.69743 .05425 L
.73901 .05082 L
.77908 .04791 L
.81763 .04543 L
.85863 .04308 L
.89812 .04106 L
.93609 .0393 L
.97619 .03763 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{172, 106},
  ImageMargins->{{109, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003G0000QA000`40l00?003`eooo003Gool00=Oo
o`00eooo001/ool300l4ool01@0?ool03ooo00l00ooo00T03ooo00ooo`0?ool03ooo00l0Dooo001/
ool00`0?ooooo`04ool01@0?ool03ooo00l00ooo00T03ooo00ooo`0?ool03ooo00l0Dooo001/ool0
0`0?ooooo`04ool01@0?ool03ooo00l00ooo00T03ooo00ooo`0?ool03ooo00l0Dooo001/ool00`0?
ooooo`04ool0100?ool03`0?1?oo0P0?0_oo0P0?00?oo`0?ool0Dooo001/ool00`0?ooooo`1Xool0
07?oo`0300oooooo067oo`00eooo003Gool00=Ooo`00eooo003Gool00=Ooo`009ooo0`0?9Ooo0`0?
9Ooo0P0?:?oo00<03oooool08ooo0P0?3_oo000Xool00`0?ooooo`0Tool00`0?ooooo`0Wool00`0?
ooooo`0Sool300lWool00`0?ooooo`0;ool002Soo`0300oooooo02Goo`0300oooooo02Goo`0300oo
oooo02Coo`0300ooo`0?02Goo`803`koo`00:?oo00<03oooool09?oo00<03ooo00l09ooo00<03ooo
ool09?oo0P0?9Ooo00<03oooool03Ooo000Wool200lWool200lUool200lXool00`0?ooooo`0Sool3
00l=ool00=Ooo`00eooo003Gool00=Ooo`00eooo000Mool00`0?ooooo`04oonZ00l9ool001coo`03
00ooo`0?00Goo`0500ooooooool03`07ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05
ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05
ool00`0?ooooo`06ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05
ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`05
ool00`0?ooooo`05ool01@0?oooooooo00l02Ooo000Lool00`0?ool03`05ool200lZool00`2?oooo
o`0Vool00`1oooooo`0Uool00`1oooooo`0Xool200l9ool001coo`0300ooo`0?00Goo`0300oooooo
01_oohP03`?oo`0300oooooo00Ooo`007Ooo00<03oooool01?oo00<03oooool02?oo500?3Ooo00<0
Soooool03?oo0P0?0ooo100?0_oo1@0?0_oo1@0?0_oo100?0ooo100?3?oo100?0ooo100?0_oo1@0?
00<0Oooo00l00`0?0ooo100?0ooo100?0_oo1@0?00?oo`0?00l02@0?1Ooo00<03oooool01ooo000T
ool0100?oooooooo200?8?oo100?0_oo1@0?0_oo0P0?5Ooo100?00?oo`2?ool0100?0_oo1@0?0_oo
100?3_oo100?0ooo100?0_oo1@0?0_oo1@0?0_oo100?0ooo00<03oooool00_oo1@0?0_oo0P0?0ooo
00<03oooool01ooo000Tool00`0?ooooo`0Lool300l3ool400l3ool00`2?ooooo`0Cool500l2ool4
00l8ool00`1oooooo`0:ool400l2ool500l2ool500l9ool00`1oooooo`03ool400l2ool400l3ool4
00l2ool500l9ool200l3ool00`0?ooooo`07ool002Coo`803aKoo`@03`;oo`0300oooooo00_oo`03
07oooooo00Ooo`<03`?oo`@03aCoo`D03`;oo`@03a;oo`0400ooooooool400l2ool500l2ool00`0?
ooooo`0:oolF00l3ool200l9ool002Coo`0300oooooo013oo`803`;oo`0300oooooo01;oo`0308oo
o`0?00@03`;oo`0300oooooo01;oo`0400ooooooool400l3ool00`1oooooo`0?ool500l2ool400l;
ool00`1oooooo`0@00lIool00`0?ooooo`07ool002Coo`0300oooooo00koo`803aGoo`@03`0307oo
oooo01;oo`<03`?oo`<03`_oo`0308oooooo00?oo`<03`;oo`D03`koo`h03bSoo`0300oooooo00Oo
o`009?oo00<03oooool02Ooo0P0?5Ooo0P0?0ooo00D03oooooooo`2?00koo`<03`;oo`803a7oo`@0
3`?oo`0300oooooo00goo`X03`Woo`0307oooooo02Woo`0300oooooo00Ooo`009?oo00<03oooool0
1ooo0P0?5Ooo0P0?2Ooo00<0Ooooool01ooo00<03oooool00P0?4Ooo1@0?1?oo00<0Soooool02_oo
2@0?4_oo00<0Soooool0:Ooo00<03oooool01ooo000Tool200l5ool00`0?ooooo`0Bool300l=ool0
0`2?ooooo`04ool300l@ool400l;ool00`1oooooo`03ool800lJool00`1oooooo`0Xool200l9ool0
02Coo`0300oooooo00;oo`803a?oo`803a3oo`D03a3oo`803a;oo`L03b7oo`0308oooooo02Woo`03
00oooooo00Ooo`009?oo00D03oooooooo`0?01;oo`0300oooooo01;oo`0300oooooo013oo`<03`ko
o`H03bOoo`0307oooooo02Woo`0300oooooo00Ooo`009?oo00<03oooool04Ooo0`0?4?oo0`0?0_oo
00<0Ooooool02_oo100?3_oo1P0?1?oo00<0Soooool09Ooo00<0Soooool0:Ooo00<03oooool01ooo
000Tool00`0?ooooo`0Sool00`0?ooooo`03ool00`2?ooooo`0:ool00`0?ooooo`0;ool500l9ool0
0`1oooooo`0Uool00`1oooooo`0Yool00`0?ooooo`07ool002Coo`803`koo`803a3oo`803`Soo`03
07oooooo00Coo`<03`koo`@03`goo`0308oooooo02Goo`0308oooooo02Soo`803`Woo`009?oo00<0
3oooool02ooo0P0?4?oo0P0?2_oo00<0Soooool00ooo00<03oooool02ooo1@0?4?oo00<0Ooooool0
9Ooo00<0Ooooool0:Ooo00<03oooool01ooo000Tool00`0?ooooo`0Yool0101o00l03`0?3Ooo100?
5?oo00<0Soooool09Ooo00<0Soooool0:Ooo00<03oooool01ooo000Tool00`0?ooooo`08ool00`0?
ooooo`0>ool200l>ool00`0?ooooo`0;ool400lGool00`1oooooo`0Uool00`1oooooo`0Yool00`0?
ooooo`07ool002Coo`0300oooooo00Ooo`803`koo`803`goo`0400oooooo07l;ool300lJool00`2?
ooooo`0Uool00`2?ooooo`0Yool00`0?ooooo`07ool002Coo`803`Ooo`0300oooooo01_oo`803`?o
o`0308oooooo00Ooo`<03acoo`0307oooooo02Goo`0307oooooo02Soo`803`Woo`009?oo00<03ooo
ool01_oo00<03oooool02ooo00<03oooool03?oo00<03oooool00ooo00<0Ooooool01?oo100?7_oo
00<0Soooool09Ooo00<0Soooool0:Ooo00<03oooool01ooo000Hool300l2ool00`0?ooooo`04ool0
0`0?ooooo`0Cool00`0?ooooo`0Cool00`2?ooooo`03ool200lQool00`1oooooo`0Uool00`1ooooo
o`0Yool00`0?ooooo`07ool001Woo`0600oooooo00ooo`0?1Ooo00<03oooool00ooo00<03oooool0
2ooo0P0?3?oo0P0?2?oo00@0Ooooooooo`<03b;oo`0308oooooo02Goo`0308oooooo02Woo`0300oo
oooo00Ooo`006Ooo00H03oooool03ooo00l5ool00`0?ooooo`02ool00`0?ooooo`0Iool00`0?oooo
o`08ool00`2?ool03`0200lTool00`1oooooo`0Uool00`1oooooo`0Yool00`0?ooooo`07ool001Wo
o`0600oooooo00ooo`0?1Ooo0P0?02X0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l300l0N@2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00803`Wo
o`006?oo0P0?0ooo00<03oooool01?oo00<03oooool03_oo00<03oooool05ooo0P0?:?oo00<0Oooo
ool09Ooo00<0Ooooool0:Ooo00<03oooool01ooo000Tool00`0?ooooo`0=ool00`0?ooooo`0:ool0
0`0?ooooo`09ool300l00`1oooooo`0Vool00`2?ooooo`0Uool00`2?ooooo`0Yool00`0?ooooo`07
ool002Coo`0300oooooo00coo`0300oooooo00[oo`0300oooooo00Woo`803`;oo`0308oooooo02Ko
o`0307oooooo02Goo`0307oooooo02Woo`0300oooooo00Ooo`009?oo00<03oooool06?oo00<03ooo
ool02?oo0`0?0ooo00<0Ooooool09_oo00<0Soooool09Ooo00<0Soooool0:Ooo00<03oooool01ooo
000Tool200l;ool00`0?ooooo`0Eool200l5ool00`2?ooooo`0Vool00`1oooooo`0Uool00`1ooooo
o`0Xool200l9ool002Coo`0300oooooo00Woo`0300oooooo00Woo`0300oooooo00Woo`803`Koo`03
07oooooo02Koo`0308oooooo02Goo`0308oooooo02Woo`0300oooooo00Ooo`009?oo00<03oooool0
2Ooo00<03oooool02Ooo00<03oooool02?oo0P0?1ooo00<0Soooool09_oo00<0Ooooool09Ooo00<0
Ooooool0:Ooo00<03oooool01ooo000Tool00`0?ooooo`08ool00`0?ooooo`09ool00`0?ooooo`08
ool200l8ool00`1oooooo`0Vool00`2?ooooo`0Uool00`2?ooooo`0Yool00`0?ooooo`07ool002Co
o`0300oooooo01?oo`0300oooooo00Soo`803`Woo`0308oooooo02Koo`0307oooooo02Goo`0307oo
oooo02Woo`0300oooooo00Ooo`009?oo0P0?7_oo0P0?2_oo00<0Ooooool09_oo00<0Soooool09Ooo
00<0Soooool0:?oo0P0?2Ooo000Tool00`0?ooooo`06ool00`0?ooooo`08ool00`0?ooooo`08ool2
00l;ool00`2?ooooo`0Vool00`1oooooo`0Uool00`1oooooo`0Yool00`0?ooooo`07ool000coo`03
00oooooo00;oo`0300oooooo013oo`0300oooooo00Goo`0300oooooo00Soo`0300oooooo00Soo`80
3`coo`0307oooooo02Koo`0308oooooo02Goo`0308oooooo02Woo`0300oooooo00Ooo`003?oo1P0?
4_oo00<03oooool01?oo00<03oooool02Ooo00<03oooool01ooo0P0?3Ooo00<0Soooool09_oo00<0
Ooooool09Ooo00<0Ooooool0:Ooo00<03oooool01ooo000<ool01P0?ooooo`0?ool03a;oo`0300oo
oooo00Coo`0300oooooo00Soo`0300oooooo00Ooo`803`koo`0307oooooo02Koo`0308oooooo02Go
o`0308oooooo02Woo`0300oooooo00Ooo`003?oo00H03oooool03ooo00lBool200lJool00`0?oooo
o`0=ool00`2?ooooo`0Vool00`1oooooo`0Uool00`1oooooo`0Xool200l9ool000coo`803`?oo`03
00oooooo013oo`0300oooooo01Soo`803`ooo`0307oooooo02Koo`0308oooooo02Goo`0308oooooo
02Woo`0300oooooo00Ooo`003ooo0P0?4ooo00<03oooool00_oo0P0?2Ooo00<03oooool01ooo0P0?
4?oo00<0Soooool09_oo00<0Ooooool09Ooo00<0Ooooool0:Ooo00<03oooool01ooo000>ool0100?
ooooo`0?4_oo00<03oooool00_oo00<03oooool01ooo00<03oooool01ooo0P0?4Ooo00<0Ooooool0
9_oo00<0Soooool09Ooo00<0Soooool0:Ooo00<03oooool01ooo000>ool200l00ooo00ooo`0Aool0
1@0?oooooooo00l02Ooo00<03oooool01ooo0P0?4_oo00<0Soooool09_oo00<0Ooooool09Ooo00<0
Ooooool0:Ooo00<03oooool01ooo000Tool200l2ool00`0?ooooo`07ool00`0?ooooo`07ool00`0?
ooooo`0Aool00`1oooooo`0Vool00`2?ooooo`0Uool00`2?ooooo`0Xool200l9ool002Coo`0300oo
oooo01Coo`803a?oo`0308oooooo02Koo`0307oooooo02Goo`0307oooooo02Woo`0300oooooo00Oo
o`003ooo00<03ooo00l01_oo0`0?0_oo00<03oooool01?oo00<03oooool05?oo00<03oooool04_oo
00<0Ooooool09_oo00<0Soooool09Ooo00<0Soooool0:Ooo00<03oooool01ooo000<ool00`0?ool0
3`0300l6ool01`0?oooooooo00ooo`0?00Goo`0300oooooo00Woo`803`Soo`803aCoo`0308oooooo
02Koo`0307oooooo02Goo`0307oooooo02Woo`0300oooooo00Ooo`003_oo100?1ooo00H03oooool0
3ooo00l5ool200l04`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o00803`2A08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l00P0?2Ooo000>ool0
100?ooooo`0?1_oo00L03ooo00ooo`0?ool03`05ool00`0?ooooo`08ool00`0?ooooo`07ool00`0?
ooooo`0Dool00`2?ooooo`0Vool00`1oooooo`0Uool00`1oooooo`0Yool00`0?ooooo`07ool000ko
o`0300oooooo00Soo`803`;oo`0300oooooo00Coo`0300oooooo00Soo`0300oooooo00Koo`803aKo
o`0307oooooo02Koo`0308oooooo02Goo`0308oooooo02Woo`0300oooooo00Ooo`003ooo0`0?4_oo
00<03oooool04Ooo00<03oooool05Ooo00<0Soooool09_oo00<0Ooooool09Ooo00<0Ooooool0:Ooo
00<03oooool01ooo000Tool00`0?ooooo`0@ool200lGool00`1oooooo`0Vool00`2?ooooo`0Uool0
0`2?ooooo`0Yool00`0?ooooo`07ool002Coo`803`Soo`0300oooooo00Koo`0300oooooo01Koo`03
08oooooo02Koo`0307oooooo02Goo`0307oooooo02Soo`803`Woo`003ooo0P0?4ooo00<03oooool0
1_oo00<03oooool01_oo0P0?6?oo00<0Ooooool09_oo00<0Soooool09Ooo00<0Soooool0:Ooo00<0
3oooool01ooo000>ool200l00ooo00ooo`0Aool00`0?ooooo`06ool00`0?ooooo`06ool00`0?oooo
o`0Gool00`2?ooooo`0Vool00`1oooooo`0Uool00`1oooooo`0Yool00`0?ooooo`07ool000koo`80
3`03ool03ooo017oo`0300oooooo00Koo`0300oooooo00Goo`803aWoo`0307oooooo02Koo`0308oo
oooo02Goo`0308oooooo02Woo`0300oooooo00Ooo`004?oo00<03oooool04Ooo00<03oooool03_oo
00<03oooool06?oo00<0Soooool09_oo00<0Ooooool09Ooo00<0Ooooool0:Ooo00<03oooool01ooo
000<ool00`0?ooooo`0Eool200l>ool200lJool00`1oooooo`0Vool00`2?ooooo`0Uool00`2?oooo
o`0Xool200l9ool000coo`<03aGoo`0300oooooo00Coo`0300oooooo00Koo`0300oooooo01Woo`03
08oooooo02Koo`0307oooooo02Goo`0307oooooo02Woo`0300oooooo00Ooo`003ooo0`0?4_oo00<0
3oooool01?oo00<03oooool01Ooo0P0?6ooo00<0Ooooool09_oo00<0Soooool09Ooo00<0Soooool0
:Ooo00<03oooool01ooo000<ool0100?ool03`0?5?oo00<03oooool01?oo00<03oooool01Ooo00<0
3oooool06_oo00<0Soooool09_oo00<0Ooooool09Ooo00<0Ooooool0:Ooo00<03oooool01ooo000<
ool200lFool00`0?ooooo`03ool00`0?ooooo`05ool200lLool00`1oooooo`0Vool00`2?ooooo`0U
ool00`2?ooooo`0Yool00`0?ooooo`07ool002Coo`803`coo`0300oooooo01_oo`0308oooooo02Ko
o`0307oooooo02Goo`0307oooooo02Soo`803`Woo`009?oo00<03oooool02ooo00<03oooool06ooo
00<0Ooooool09_oo00<0Soooool09Ooo00<0Soooool0:Ooo00<03oooool01ooo000Tool00`0?oooo
o`02ool00`0?ooooo`05ool200lMool00`2?ooooo`0Vool00`1oooooo`0Uool00`1oooooo`0Yool0
0`0?ooooo`07ool002Coo`0300oooooo00;oo`0300oooooo00Goo`0300oooooo01coo`0307oooooo
02Koo`0308oooooo02Goo`0308oooooo02Woo`0300oooooo00Ooo`009?oo00<03oooool00_oo00<0
3oooool01Ooo00<03oooool07?oo00<0Soooool09_oo00<0Ooooool09Ooo00<0Ooooool0:Ooo00<0
3oooool01ooo000Tool200l2ool00`0?ooooo`05ool200lNool00`1oooooo`0Vool00`2?ooooo`0U
ool00`2?ooooo`0Xool200l9ool002Coo`0500ooooooool03`07ool00`0?ooooo`0Mool00`2?oooo
o`0Vool00`1oooooo`0Uool00`1oooooo`0Yool00`0?ooooo`07ool001Soo`803`?oo`0300oooooo
00Coo`0300oooooo00Woo`0300oooooo01goo`0307oooooo02Koo`0308oooooo02Goo`0308oooooo
02Woo`0300oooooo00Ooo`006_oo00D03ooo00ooo`0?00Goo`0300oooooo00Soo`803aooo`0308oo
oooo02Koo`0307oooooo02Goo`0307oooooo02Woo`0300oooooo00Ooo`006Ooo00H03oooool03ooo
00l5ool00`0?ooooo`08ool00`0?ooooo`0Nool00`1oooooo`0Vool00`2?ooooo`0Uool00`2?oooo
o`0Yool00`0?ooooo`07ool001[oo`0500ooo`0?ool03`05ool200l0YP2?07l0S`1o08l0O`2?07l0
S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o0P0?2Ooo000Hool200l3ool00`0?ooooo`04ool00`0?ooooo`07ool200lP
ool00`1oooooo`0Vool00`2?ooooo`0Uool00`2?ooooo`0Yool00`0?ooooo`07ool002Coo`0300oo
oooo00Ooo`0300oooooo01ooo`0308oooooo02Koo`0307oooooo02Goo`0307oooooo02Woo`0300oo
oooo00Ooo`009?oo00<03oooool01ooo00<03oooool07ooo00<0Ooooool09_oo00<0Soooool09Ooo
00<0Soooool0:Ooo00<03oooool01ooo000Tool00`0?ooooo`06ool200lQool00`2?ooooo`0Vool0
0`1oooooo`0Uool00`1oooooo`0Yool00`0?ooooo`07ool002Coo`803`Ooo`0300oooooo023oo`03
07oooooo02Koo`0308oooooo02Goo`0308oooooo02Soo`803`Woo`009?oo00<03oooool01_oo00<0
3oooool08?oo00<0Soooool09_oo00<0Ooooool09Ooo00<0Ooooool0:Ooo00<03oooool01ooo000T
ool00`0?ooooo`06ool00`0?ooooo`0Pool00`1oooooo`0Vool00`2?ooooo`0Uool00`2?ooooo`0Y
ool00`0?ooooo`07ool002Coo`0300oooooo00Goo`803b;oo`0308oooooo02Koo`0307oooooo02Go
o`0307oooooo02Woo`0300oooooo00Ooo`009?oo00<03oooool01Ooo00<03oooool08Ooo00<0Oooo
ool09_oo00<0Soooool09Ooo00<0Soooool0:Ooo00<03oooool01ooo000Tool200l6ool00`0?oooo
o`0Qool00`2?ooooo`0Vool00`1oooooo`0Uool00`1oooooo`0Xool200l9ool002Coo`0300oooooo
00Coo`803b?oo`0307oooooo02Koo`0308oooooo02Goo`0308oooooo02Woo`0300oooooo00Ooo`00
9?oo00<03oooool01?oo00<03oooool08_oo00<0Soooool09_oo00<0Ooooool09Ooo00<0Ooooool0
:Ooo00<03oooool01ooo000Tool00`0?ooooo`04ool00`0?ooooo`0Rool00`1oooooo`0Vool00`2?
ooooo`0Uool00`2?ooooo`0Yool00`0?ooooo`07ool002Coo`0300oooooo00Coo`0300oooooo02;o
o`0308oooooo02Koo`0307oooooo02Goo`0307oooooo02Woo`0300oooooo00Ooo`009?oo0P0?1?oo
0P0?9?oo00<0Ooooool09_oo00<0Soooool09Ooo00<0Soooool0:?oo0P0?2Ooo000Tool00`0?oooo
o`03ool00`0?ooooo`0Sool00`2?ooooo`0Vool00`1oooooo`0Uool00`1oooooo`0Yool00`0?oooo
o`07ool002Coo`0300oooooo00?oo`0300oooooo02?oo`0307oooooo02Koo`0308oooooo02Goo`03
08oooooo02Woo`0300oooooo00Ooo`009?oo00<03oooool00ooo00<03oooool08ooo00<0Soooool0
9_oo00<0Ooooool09Ooo00<0Ooooool0:Ooo00<03oooool01ooo000Tool00`0?ooooo`03ool00`0?
ooooo`0Sool00`1oooooo`0Vool00`2?ooooo`0Uool00`2?ooooo`0Yool00`0?ooooo`07ool002Co
o`803`?oo`803bGoo`0308oooooo02Koo`0307oooooo02Goo`0307oooooo02Soo`803`Woo`009?oo
00<03oooool00_oo00<03oooool09?oo00<0Ooooool09_oo00<0Soooool09Ooo00<0Soooool0:Ooo
00<03oooool01ooo000Jool0100?ooooo`0?1_oo00<03oooool00_oo00<03oooool09?oo00<0Sooo
ool09_oo00<0Ooooool09Ooo00<0Ooooool0:Ooo00<03oooool01ooo000Hool300l01?oo00ooo`0?
1Ooo00<03oooool00_oo00<03oooool09?oo00<0Ooooool09_oo00<0Soooool09Ooo00<0Soooool0
:Ooo00<03oooool01ooo000Hool01`0?ool03ooo00ooo`0?00Goo`803`;oo`803bKoo`0308oooooo
02Koo`0307oooooo02Goo`0307oooooo02Soo`803`Woo`006Ooo0P0?00Coo`0?ool03`Goo`0500oo
ooooool03`0Wool00`1oooooo`0Vool00`2?ooooo`0Uool00`2?ooooo`0Yool00`0?ooooo`07ool0
01[oo`0400oooooo00l6ool01@0?oooooooo00l09ooo00<0Soooool09_oo00<0Ooooool09Ooo00<0
Ooooool0:Ooo00<03oooool01ooo000Tool01@0?oooooooo00l09ooo00<03oooool09_oo00<03ooo
ool09Ooo00<03oooool09Ooo00D03oooooooo`0?00Woo`009?ooZP0?2Ooo003Gool00=Ooo`00\
\>"],
  ImageRangeCache->{{{0, 214}, {131.5, 0}} -> {-0.009832, -11.216955, 
  0.031088, 0.510124}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Spherical Quantum Dot"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(tbl6 = {\[Pi], 4.4934, 5.7635, 2\ \[Pi], 7.7253, 9.0950}; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Es]; \)\), 
    \(\(Es[R_] := \(hbar\^2\ tbl6\^2\)\/\(\((2\ me)\)\ R\^2\); \)\)}], "Input",\

  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig14x7 = 
      Plot[Evaluate[Es[R\ nano]\/e /. case], {R, 1, 5}, 
        FrameLabel \[Rule] {"\<R in nm\>", "\<Es in eV\>"}, Evaluate[opt]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.011892 0.187661 [
[.02381 -0.0125 -4 -12 ]
[.02381 -0.0125 4 0 ]
[.2619 -0.0125 -4 -12 ]
[.2619 -0.0125 4 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.7381 -0.0125 -4 -12 ]
[.7381 -0.0125 4 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -15 -24 ]
[.5 -0.0125 15 -12 ]
[-0.0125 .01189 -8 -6 ]
[-0.0125 .01189 0 6 ]
[-0.0125 .10572 -14 -6 ]
[-0.0125 .10572 0 6 ]
[-0.0125 .19955 -8 -6 ]
[-0.0125 .19955 0 6 ]
[-0.0125 .29338 -14 -6 ]
[-0.0125 .29338 0 6 ]
[-0.0125 .38721 -8 -6 ]
[-0.0125 .38721 0 6 ]
[-0.0125 .48105 -14 -6 ]
[-0.0125 .48105 0 6 ]
[-0.0125 .57488 -8 -6 ]
[-0.0125 .57488 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26 -16 ]
[-0.01875 .30902 -14 16 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .10572 m
1 .10572 L
s
0 .19955 m
1 .19955 L
s
0 .29338 m
1 .29338 L
s
0 .38721 m
1 .38721 L
s
0 .48105 m
1 .48105 L
s
0 .57488 m
1 .57488 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -76 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(R) show
70.312500 13.000000 moveto
(in) show
78.500000 13.000000 moveto
(nm) show
88.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01189 m
.00625 .01189 L
s
gsave
-0.0125 .01189 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .10572 m
.00625 .10572 L
s
gsave
-0.0125 .10572 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .19955 m
.00625 .19955 L
s
gsave
-0.0125 .19955 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .29338 m
.00625 .29338 L
s
gsave
-0.0125 .29338 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .38721 m
.00625 .38721 L
s
gsave
-0.0125 .38721 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .48105 m
.00625 .48105 L
s
gsave
-0.0125 .48105 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .57488 m
.00625 .57488 L
s
gsave
-0.0125 .57488 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .03066 m
.00375 .03066 L
s
0 .04942 m
.00375 .04942 L
s
0 .06819 m
.00375 .06819 L
s
0 .08696 m
.00375 .08696 L
s
0 .12449 m
.00375 .12449 L
s
0 .14326 m
.00375 .14326 L
s
0 .16202 m
.00375 .16202 L
s
0 .18079 m
.00375 .18079 L
s
0 .21832 m
.00375 .21832 L
s
0 .23709 m
.00375 .23709 L
s
0 .25585 m
.00375 .25585 L
s
0 .27462 m
.00375 .27462 L
s
0 .31215 m
.00375 .31215 L
s
0 .33092 m
.00375 .33092 L
s
0 .34968 m
.00375 .34968 L
s
0 .36845 m
.00375 .36845 L
s
0 .40598 m
.00375 .40598 L
s
0 .42475 m
.00375 .42475 L
s
0 .44351 m
.00375 .44351 L
s
0 .46228 m
.00375 .46228 L
s
0 .49981 m
.00375 .49981 L
s
0 .51858 m
.00375 .51858 L
s
0 .53734 m
.00375 .53734 L
s
0 .55611 m
.00375 .55611 L
s
0 .59364 m
.00375 .59364 L
s
0 .61241 m
.00375 .61241 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -97 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
77 10 translate
90 rotate
-77 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Es) show
72.937500 13.000000 moveto
(in) show
81.125000 13.000000 moveto
(eV) show
90.375000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01189 m
1 .01189 L
s
.99375 .10572 m
1 .10572 L
s
.99375 .19955 m
1 .19955 L
s
.99375 .29338 m
1 .29338 L
s
.99375 .38721 m
1 .38721 L
s
.99375 .48105 m
1 .48105 L
s
.99375 .57488 m
1 .57488 L
s
.125 Mabswid
.99625 .03066 m
1 .03066 L
s
.99625 .04942 m
1 .04942 L
s
.99625 .06819 m
1 .06819 L
s
.99625 .08696 m
1 .08696 L
s
.99625 .12449 m
1 .12449 L
s
.99625 .14326 m
1 .14326 L
s
.99625 .16202 m
1 .16202 L
s
.99625 .18079 m
1 .18079 L
s
.99625 .21832 m
1 .21832 L
s
.99625 .23709 m
1 .23709 L
s
.99625 .25585 m
1 .25585 L
s
.99625 .27462 m
1 .27462 L
s
.99625 .31215 m
1 .31215 L
s
.99625 .33092 m
1 .33092 L
s
.99625 .34968 m
1 .34968 L
s
.99625 .36845 m
1 .36845 L
s
.99625 .40598 m
1 .40598 L
s
.99625 .42475 m
1 .42475 L
s
.99625 .44351 m
1 .44351 L
s
.99625 .46228 m
1 .46228 L
s
.99625 .49981 m
1 .49981 L
s
.99625 .51858 m
1 .51858 L
s
.99625 .53734 m
1 .53734 L
s
.99625 .55611 m
1 .55611 L
s
.99625 .59364 m
1 .59364 L
s
.99625 .61241 m
1 .61241 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .08246 m
.04262 .0725 L
.06244 .06413 L
.08426 .05678 L
.10458 .05124 L
.14264 .04329 L
.18163 .03741 L
.22307 .03281 L
.263 .02945 L
.30142 .02693 L
.34228 .02481 L
.38164 .02316 L
.41947 .02185 L
.45976 .0207 L
.49853 .01977 L
.53975 .01893 L
.57946 .01824 L
.61766 .01767 L
.6583 .01715 L
.69743 .01671 L
.73901 .01629 L
.77908 .01595 L
.81763 .01565 L
.85863 .01537 L
.89812 .01513 L
.93609 .01492 L
.97619 .01472 L
s
[ .02 ] 0 setdash
.02381 .15625 m
.04262 .13589 L
.06244 .11876 L
.08426 .10371 L
.10458 .09238 L
.14264 .07613 L
.18163 .0641 L
.22307 .05468 L
.263 .04782 L
.30142 .04266 L
.34228 .03831 L
.38164 .03494 L
.41947 .03227 L
.45976 .0299 L
.49853 .028 L
.53975 .02629 L
.57946 .02488 L
.61766 .02372 L
.6583 .02264 L
.69743 .02174 L
.73901 .0209 L
.77908 .02019 L
.81763 .01958 L
.85863 .019 L
.89812 .01851 L
.93609 .01808 L
.97619 .01767 L
s
.02381 .24939 m
.04262 .21589 L
.06244 .18771 L
.08426 .16295 L
.10458 .14431 L
.14264 .11758 L
.18163 .09779 L
.22307 .08228 L
.263 .07099 L
.30142 .06252 L
.34228 .05536 L
.38164 .04981 L
.41947 .04541 L
.45976 .04153 L
.49853 .03839 L
.53975 .03557 L
.57946 .03326 L
.61766 .03135 L
.6583 .02958 L
.69743 .02809 L
.73901 .02671 L
.77908 .02554 L
.81763 .02454 L
.85863 .02359 L
.89812 .02277 L
.93609 .02207 L
.97619 .02139 L
s
.02381 .29416 m
.04262 .25434 L
.06244 .22084 L
.08426 .19142 L
.10458 .16927 L
.14264 .1375 L
.18163 .11398 L
.22307 .09554 L
.263 .08213 L
.30142 .07206 L
.34228 .06355 L
.38164 .05695 L
.41947 .05173 L
.45976 .04711 L
.49853 .04338 L
.53975 .04004 L
.57946 .03729 L
.61766 .03501 L
.6583 .03291 L
.69743 .03114 L
.73901 .0295 L
.77908 .02811 L
.81763 .02692 L
.85863 .02579 L
.89812 .02482 L
.93609 .02398 L
.97619 .02318 L
s
.02381 .4386 m
.04262 .37841 L
.06244 .32777 L
.08426 .28329 L
.10458 .2498 L
.14264 .20177 L
.18163 .16621 L
.22307 .13835 L
.263 .11808 L
.30142 .10285 L
.34228 .08998 L
.38164 .08001 L
.41947 .07212 L
.45976 .06513 L
.49853 .0595 L
.53975 .05444 L
.57946 .05029 L
.61766 .04684 L
.6583 .04366 L
.69743 .04099 L
.73901 .03851 L
.77908 .03641 L
.81763 .03461 L
.85863 .03291 L
.89812 .03144 L
.93609 .03017 L
.97619 .02896 L
s
[ .0001 ] 0 setdash
.02381 .60332 m
.04262 .51989 L
.06244 .44971 L
.08426 .38806 L
.10458 .34164 L
.14264 .27507 L
.18163 .22579 L
.22307 .18717 L
.263 .15907 L
.30142 .13796 L
.34228 .12013 L
.38164 .1063 L
.41947 .09537 L
.45976 .08569 L
.49853 .07788 L
.53975 .07086 L
.57946 .06511 L
.61766 .06033 L
.6583 .05593 L
.69743 .05223 L
.73901 .04879 L
.77908 .04587 L
.81763 .04338 L
.85863 .04102 L
.89812 .03899 L
.93609 .03723 L
.97619 .03555 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{172, 106},
  ImageMargins->{{109, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003G0000QA000`40l00?003`eooo003Gool00=Oo
o`00eooo001]ool0100?ool03`0?0ooo00H03oooool03ooo00l3ool02@0?ool03ooo00ooo`0?ool0
3`1Aool006goo`0300ooo`0?00Coo`0600oooooo00ooo`0?0ooo00T03ooo00ooo`0?ool03ooo00l0
DOoo001]ool300l4ool01P0?ooooo`0?ool03`?oo`0900ooo`0?ool03ooo00ooo`0?057oo`00KOoo
00@03oooool03`?oo`0300oooooo00803`Coo`803`;oo`803`03ool03ooo057oo`00KOoo0`0?Iooo
001dool00`0?ooooo`1Pool00=Ooo`00eooo003Gool00=Ooo`00eooo003Gool002Koo`<03bKoo`<0
3bKoo`803bWoo`0300oooooo02Coo`803`_oo`009ooo00<03oooool09Ooo00<03oooool0:?oo00<0
3oooool09?oo0`0?:?oo00<03oooool02?oo000Wool00`0?ooooo`0Vool00`0?ooooo`0Vool00`0?
ooooo`0Uool00`0?ool03`0Vool200l;ool002Ooo`0300oooooo02Goo`0300ooo`0?02Soo`0300oo
oooo02Goo`803bKoo`0300oooooo00[oo`009_oo0P0?:?oo0P0?9_oo0P0?:Ooo00<03oooool09?oo
0`0?2_oo003Gool00=Ooo`00eooo003Gool00=Ooo`007Ooo00<03oooool01?oo[@0?1_oo000Lool0
0`0?ool03`05ool01@0?oooooooo00l01ooo00<03oooool01Ooo00<03oooool01Ooo00<03oooool0
1Ooo00<03oooool01_oo00<03oooool01Ooo00<03oooool01Ooo00<03oooool01Ooo00<03oooool0
1Ooo00<03oooool01_oo00<03oooool01Ooo00<03oooool01Ooo00<03oooool01Ooo00<03oooool0
1Ooo00<03oooool01_oo00<03oooool01Ooo00<03oooool01Ooo00<03oooool01Ooo00<03oooool0
1Ooo00<03oooool01Ooo00<03oooool00_oo00<03oooool01?oo000Lool00`0?ool03`05ool200l[
ool00`1oooooo`0Vool00`2?ooooo`0Vool00`1oooooo`0Yool200l6ool001coo`0300ooo`0?00Go
o`0300oooooo02[oo`0308oooooo02Koo`0307ooo`0?04l03`Coo`0300oooooo00Coo`007Ooo00<0
3oooool01?oo00<03oooool0:_oo00<0Ooooool02Ooo800?2Ooo00@03oooooooo`@03`;oo`D03`;o
o`D03`;oo`D03`0307ooo`0?00@03`;oo`@03`;oo`D03`;ooa<03`Coo`0300oooooo00Coo`009?oo
00<03oooool09_oo4@0?4_oo0`0?0_oo100?00?oo`1oool0100?0ooo0`0?2_oo1@0?0_oo100?00?o
o`0?00l03P0?0_oo1@0?0_oo1@0?2?oo100?0ooo0`0?0ooo0P0?1_oo000Tool00`0?ooooo`0Mool:
00l3ool00`1oooooo`0>ool300l2ool500l2ool200l:ool0102?oooooooo0P0?0_oo1@0?0_oo1`0?
0ooo100?0ooo0`0?1_oo00<0Ooooool00_oo0`0?0_oo100?0ooo100?0ooo100?1ooo1P0?1?oo00<0
3oooool01?oo000Tool00`0?ooooo`0Fool800l<ool00`2?ooooo`05ool500l2ool200l?ool0100?
oooooooo100?00?oo`1o00l01`0?0_oo100?3ooo1@0?0_oo1@0?0_oo0P0?2_oo5@0?2Ooo00<03ooo
ool01?oo000Tool00`0?ooooo`0Aool600lCool00`1oool03`0300lAool300l3ool700l2ool400l@
ool400l3ool400l=ool@00lMool00`0?ooooo`04ool002Coo`0300oooooo00goo`D03a?oo`@03`03
ool0Sooo00goo`@03`?oo`0300oooooo00@03`?oo`0300oooooo00Koo`0307oooooo00Ooo`@03a3o
o``03b_oo`803`Koo`009?oo00<03oooool02Ooo1@0?4Ooo0`0?2?oo00<0Ooooool01_oo100?1Ooo
100?4_oo0P0?0_oo100?3Ooo2`0?2_oo00<0Ooooool0:_oo00<03oooool01?oo000Tool00`0?oooo
o`07ool300lAool0100?ooooo`0?2ooo00@0Soooooooo`803`;oo`0400ooooooool300lBool200l2
ool300l00ooo07ooo`0:ool900lDool00`2?ooooo`0Zool00`0?ooooo`04ool002Coo`0300oooooo
00Coo`@03a3oo`<03`ooo`0407ooo`0?00l3ool200l2ool00`0?ooooo`0@ool300l8ool00`2?oooo
o`02ool800lLool00`1oooooo`0Yool200l6ool002Coo`0300oooooo00;oo`<03b7oo`<03`03ool0
Sooo00;oo`<03a7oo`@03`goo`H03b?oo`0308oooooo02[oo`0300oooooo00Coo`009?oo00@03ooo
ooooo`803a3oo`803a3oo`0300oooooo00;oo`803a3oo`<03`ooo`H03bSoo`0307oooooo02[oo`03
00oooooo00Coo`009?oo00<03oooool04Ooo0P0?3Ooo0`0?1Ooo0P0?00<0Soooool03_oo00<03ooo
ool02ooo1P0?1?oo00<0Ooooool09_oo00<0Soooool0:Ooo0P0?1_oo000Gool01@0?ooooo`0?ool0
0P0?1_oo00<03oooool03_oo00<03oooool03Ooo0P0?1?oo0P0?1?oo00<0Ooooool02?oo100?3?oo
1@0?2Ooo00<0Soooool09_oo00<0Ooooool0:_oo00<03oooool01?oo000Fool00`0?ool03`05ool0
0`0?ooooo`03ool00`0?ooooo`0<ool200l=ool00`0?ooooo`03ool300l6ool00`2?ooooo`07ool0
0`0?ooooo`0:ool500l=ool00`1oooooo`0Vool00`2?ooooo`0Zool00`0?ooooo`04ool001Koo`03
00ooo`0?00?oo`803`Koo`803`0J08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`803`0D08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`<0
3`0<07l0S`1o08l0O`2?07l0S`1o08l0O`2?100?06H0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l200l6
ool001Koo`0300ooo`0?00?oo`0300oooooo00Goo`0300oooooo01Soo`0300oooooo00;oo`803`_o
o`0508ooooooool03`0<ool400lDool00`1oooooo`0Vool00`2?ooooo`0Zool00`0?ooooo`04ool0
01Ooo`0300oooooo00;oo`<03`Goo`0300oooooo00Soo`0300oooooo00[oo`0300oooooo00?oo`80
3`goo`803`coo`@03aOoo`0308oooooo02Koo`0307oooooo02[oo`0300oooooo00Coo`009?oo00<0
3oooool01ooo00<03oooool02_oo00<03oooool04Ooo0P0?00<0Soooool02Ooo0`0?6_oo00<0Oooo
ool09_oo00<0Soooool0:_oo00<03oooool01?oo000Tool00`0?ooooo`05ool200l;ool200l4ool0
0`0?ooooo`0<ool0100?ooooo`1o2Ooo0`0?7?oo00<0Soooool09_oo00<0Ooooool0:Ooo0P0?1_oo
000Tool00`0?ooooo`0Fool200l<ool00`0?ooooo`03ool00`2?ooooo`04ool400lNool00`1ooooo
o`0Vool00`2?ooooo`0Zool00`0?ooooo`04ool002Coo`0300oooooo00ooo`0300oooooo00?oo`03
00oooooo00_oo`0300oooooo00Coo`0307oooooo00;oo`<03b7oo`0308oooooo02Koo`0307oooooo
02[oo`0300oooooo00Coo`009?oo00<03oooool00_oo0P0?2_oo0P0?4Ooo0P0?1ooo00<0Soooool0
0`0?8ooo00<0Ooooool09_oo00<0Soooool0:Ooo0P0?1_oo000Tool00`0?ooooo`02ool00`0?oooo
o`08ool00`0?ooooo`02ool200lFool0101oool03`0?9Ooo00<0Soooool09_oo00<0Ooooool0:_oo
00<03oooool01?oo000Tool01@0?oooooooo00l02ooo00D03oooooooo`0?00coo`803`[oo`<03bKo
o`0307oooooo02Koo`0308oooooo02[oo`0300oooooo00Coo`009?oo00<03oooool04?oo00<03ooo
ool02_oo00<03oooool02?oo0`0?:?oo00<0Soooool09_oo00<0Ooooool0:Ooo0P0?1_oo000Tool0
0`0?ooooo`0:ool00`0?ooooo`0?ool00`0?ooooo`08ool200l00ooo08ooo`0Wool00`1oooooo`0V
ool00`2?ooooo`0Zool00`0?ooooo`04ool002Coo`0300oooooo00Woo`0300oooooo01[oo`803`;o
o`0307oooooo02Koo`0308oooooo02Koo`0307oooooo02[oo`0300oooooo00Coo`009?oo00<03ooo
ool02Ooo00D03oooooooo`0?00_oo`0300oooooo00Soo`<03`?oo`0308oooooo02Koo`0307oooooo
02Koo`0308oooooo02Woo`803`Koo`007?oo0`0?1Ooo00<03oooool02?oo00D03oooooooo`0?00_o
o`0300oooooo00Soo`803`Goo`0307oooooo02Koo`0308oooooo02Koo`0307oooooo02[oo`0300oo
oooo00Coo`007Ooo00<03oooool01?oo00<03oooool02ooo00<03oooool02Ooo00<03oooool02?oo
0P0?1_oo00<0Soooool09_oo00<0Ooooool09_oo00<0Soooool0:_oo00<03oooool01?oo000Mool0
0`0?ooooo`04ool200l08P2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o0P0?08D0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0200l6
ool001goo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo01Soo`803`Soo`0308oooooo02Ko
o`0307oooooo02Koo`0308oooooo02[oo`0300oooooo00Coo`007?oo0P0?1_oo00<03oooool01Ooo
00D03oooooooo`0?00[oo`0300oooooo00Ooo`<03`Woo`0307oooooo02Koo`0308oooooo02Koo`03
07oooooo02[oo`0300oooooo00Coo`009?oo00<03oooool01?oo00D03oooooooo`0?00[oo`0300oo
oooo00Ooo`803`_oo`0308oooooo02Koo`0307oooooo02Koo`0308oooooo02[oo`0300oooooo00Co
o`009?oo00<03oooool01ooo00<03oooool02Ooo00<03oooool01_oo0P0?3?oo00<0Ooooool09_oo
00<0Soooool09_oo00<0Ooooool0:Ooo0P0?1_oo000Tool00`0?ooooo`07ool00`0?ooooo`08ool0
0`0?ooooo`06ool200l=ool00`2?ooooo`0Vool00`1oooooo`0Vool00`2?ooooo`0Zool00`0?oooo
o`04ool000[oo`0300oooooo00;oo`0300oooooo01;oo`0300oooooo00;oo`0300oooooo01Koo`03
00oooooo00coo`0307oooooo02Koo`0308oooooo02Koo`0307oooooo02[oo`0300oooooo00Coo`00
2_oo1P0?5?oo00<03oooool00_oo00<03oooool02ooo00<03oooool01ooo0P0?3_oo00<0Soooool0
9_oo00<0Ooooool09_oo00<0Soooool0:Ooo0P0?1_oo000:ool01P0?ooooo`0?ool03aCoo`0500oo
ooooool03`03ool00`0?ooooo`07ool00`0?ooooo`07ool200l?ool00`1oooooo`0Vool00`2?oooo
o`0Vool00`1oooooo`0Zool00`0?ooooo`04ool000[oo`0600oooooo00ooo`0?5?oo00D03ooooooo
o`0?00;oo`0300oooooo00Soo`0300oooooo00Koo`803a3oo`0308oooooo02Koo`0307oooooo02Ko
o`0308oooooo02[oo`0300oooooo00Coo`002_oo0P0?0ooo00<03oooool04_oo00<03oooool01?oo
00<03oooool01ooo00<03oooool01_oo0P0?4Ooo00<0Ooooool09_oo00<0Soooool09_oo00<0Oooo
ool0:Ooo0P0?1_oo000=ool00`0?ool03`0Dool00`0?ooooo`04ool00`0?ooooo`0@ool00`0?oooo
o`0@ool00`2?ooooo`0Vool00`1oooooo`0Vool00`2?ooooo`0Zool00`0?ooooo`04ool000coo`80
3`03ool03ooo01?oo`0300oooooo01Koo`803a;oo`0307oooooo02Koo`0308oooooo02Koo`0307oo
oooo02[oo`0300oooooo00Coo`003?oo00<03ooo00l05Ooo00<03oooool03?oo00<03oooool01_oo
0P0?4ooo00<0Soooool09_oo00<0Ooooool09_oo00<0Soooool0:Ooo0P0?1_oo000Fool300l00ooo
00ooo`0200l6ool00`0?ooooo`02ool00`0?ooooo`07ool00`0?ooooo`05ool200lDool00`1ooooo
o`0Vool00`2?ooooo`0Vool00`1oooooo`0Zool00`0?ooooo`04ool001Ooo`0300oooooo00Coo`03
00oooooo00?oo`0500ooooooool03`09ool00`0?ooooo`06ool00`0?ooooo`0Cool00`2?ooooo`0V
ool00`1oooooo`0Vool00`2?ooooo`0Zool00`0?ooooo`04ool000goo`0300ooo`0?00Ooo`0300oo
oooo00;oo`803`Koo`0500ooooooool03`08ool00`0?ooooo`06ool200lEool00`1oooooo`0Vool0
0`2?ooooo`0Vool00`1oooooo`0Zool00`0?ooooo`04ool000[oo`0300ooo`0?00<03`Ooo`0300oo
oooo00;oo`0300oooooo00Goo`803`2Y07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l00P0?1_oo000<ool400l6ool200l4ool300l5ool00`0?ooooo`0Bool200lFool00`1oooooo`0V
ool00`2?ooooo`0Vool00`1oooooo`0Zool00`0?ooooo`04ool000coo`0400oooooo00lDool00`0?
ooooo`09ool00`0?ooooo`06ool00`0?ooooo`0Eool00`2?ooooo`0Vool00`1oooooo`0Vool00`2?
ooooo`0Zool00`0?ooooo`04ool000coo`0300oooooo01Goo`0300oooooo00Woo`0300oooooo00Go
o`803aOoo`0307oooooo02Koo`0308oooooo02Koo`0307oooooo02Woo`803`Koo`003Ooo0`0?5?oo
00<03oooool02?oo00<03oooool01Ooo0P0?6?oo00<0Soooool09_oo00<0Ooooool09_oo00<0Sooo
ool0:_oo00<03oooool01?oo000Tool00`0?ooooo`07ool00`0?ooooo`06ool00`0?ooooo`0Gool0
0`1oooooo`0Vool00`2?ooooo`0Vool00`1oooooo`0Zool00`0?ooooo`04ool002Coo`0300oooooo
00ooo`803aWoo`0308oooooo02Koo`0307oooooo02Koo`0308oooooo02Woo`803`Koo`003Ooo0P0?
5Ooo00<03oooool03ooo00<03oooool06?oo00<0Ooooool09_oo00<0Soooool09_oo00<0Ooooool0
:_oo00<03oooool01?oo000<ool200l00ooo00ooo`0Cool00`0?ooooo`06ool00`0?ooooo`05ool2
00lJool00`2?ooooo`0Vool00`1oooooo`0Vool00`2?ooooo`0Zool00`0?ooooo`04ool000coo`80
3`03ool03ooo01?oo`0300oooooo00Koo`0300oooooo00Goo`0300oooooo01Woo`0307oooooo02Ko
o`0308oooooo02Koo`0307oooooo02Woo`803`Koo`003_oo00<03oooool04ooo00<03oooool01_oo
00<03oooool01?oo0P0?6ooo00<0Soooool09_oo00<0Ooooool09_oo00<0Soooool0:_oo00<03ooo
ool01?oo000:ool00`0?ooooo`0Gool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`0Jool0
0`1oooooo`0Vool00`2?ooooo`0Vool00`1oooooo`0Zool00`0?ooooo`04ool000[oo`<03aOoo`03
00oooooo00Goo`0300oooooo00Goo`0300oooooo01[oo`0308oooooo02Koo`0307oooooo02Koo`03
08oooooo02[oo`0300oooooo00Coo`003Ooo0`0?3?oo0`0?1Ooo00<03oooool03?oo0P0?7?oo00<0
Ooooool09_oo00<0Soooool09_oo00<0Ooooool0:Ooo0P0?1_oo000:ool0100?ool03`0?3_oo00<0
3oooool01Ooo00<03oooool03?oo00<03oooool06ooo00<0Soooool09_oo00<0Ooooool09_oo00<0
Soooool0:_oo00<03oooool01?oo000:ool200lAool00`0?ooooo`04ool00`0?ooooo`04ool00`0?
ooooo`04ool200lMool00`1oooooo`0Vool00`2?ooooo`0Vool00`1oooooo`0Zool00`0?ooooo`04
ool001coo`0300ooo`0?00Goo`803`2Y07l0S`1o08l03`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l00P0?1_oo000Mool200l5ool00`0?ooooo`03ool00`0?ooooo`04ool200lNool00`1oooooo`0V
ool00`2?ooooo`0Vool00`1oooooo`0Zool00`0?ooooo`04ool002Coo`0300oooooo00?oo`0300oo
oooo00Coo`0300oooooo01goo`0308oooooo02Koo`0307oooooo02Koo`0308oooooo02[oo`0300oo
oooo00Coo`009?oo00<03oooool02_oo00<03oooool07Ooo00<0Ooooool09_oo00<0Soooool09_oo
00<0Ooooool0:Ooo0P0?1_oo000Tool00`0?ooooo`09ool200lOool00`2?ooooo`0Vool00`1ooooo
o`0Vool00`2?ooooo`0Zool00`0?ooooo`04ool002Coo`0300oooooo00;oo`0300oooooo00Coo`03
00oooooo01koo`0307oooooo02Koo`0308oooooo02Koo`0307oooooo02[oo`0300oooooo00Coo`00
9?oo00D03oooooooo`0?00Ooo`0300oooooo01koo`0308oooooo02Koo`0307oooooo02Koo`0308oo
oooo02Woo`803`Koo`009?oo00D03oooooooo`0?00Koo`803b3oo`0307oooooo02Koo`0308oooooo
02Koo`0307oooooo02[oo`0300oooooo00Coo`009?oo00D03oooooooo`0?00Koo`0300oooooo01oo
o`0308oooooo02Koo`0307oooooo02Koo`0308oooooo02[oo`0300oooooo00Coo`009?oo00D03ooo
ooooo`0?00Koo`0300oooooo01ooo`0307oooooo02Koo`0308oooooo02Koo`0307oooooo02Woo`80
3`Koo`009?oo00<03oooool01ooo0P0?8Ooo00<0Soooool09_oo00<0Ooooool09_oo00<0Soooool0
:_oo00<03oooool01?oo000Tool00`0?ooooo`07ool00`0?ooooo`0Pool00`1oooooo`0Vool00`2?
ooooo`0Vool00`1oooooo`0Zool00`0?ooooo`04ool002Coo`0300oooooo00Ooo`0300oooooo023o
o`0308oooooo02Koo`0307oooooo02Koo`0308oooooo02[oo`0300oooooo00Coo`005_oo0`0?00?o
o`0?ool00P0?1_oo00<03oooool01_oo0P0?8_oo00<0Ooooool09_oo00<0Soooool09_oo00<0Oooo
ool0:Ooo0P0?1_oo000Fool00`0?ooooo`05ool00`0?ooooo`03ool00`0?ooooo`06ool00`0?oooo
o`0Qool00`2?ooooo`0Vool00`1oooooo`0Vool00`2?ooooo`0Zool00`0?ooooo`04ool001Ooo`03
00oooooo00;oo`803`Koo`0300oooooo00Koo`0300oooooo027oo`0307oooooo02Koo`0308oooooo
02Koo`0307oooooo02[oo`0300oooooo00Coo`005_oo00<03ooo00l00ooo00<03oooool01Ooo0P0?
0:T0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0200l6ool001Ooo`803`?oo`<0
3`Goo`0300oooooo00Goo`803b?oo`0307oooooo02Koo`0308oooooo02Koo`0307oooooo02[oo`03
00oooooo00Coo`009?oo00<03oooool01Ooo00<03oooool08_oo00<0Soooool09_oo00<0Ooooool0
9_oo00<0Soooool0:_oo00<03oooool01?oo000Tool00`0?ooooo`05ool00`0?ooooo`0Rool00`1o
ooooo`0Vool00`2?ooooo`0Vool00`1oooooo`0Yool200l6ool002Coo`0300oooooo00Coo`803bCo
o`0308oooooo02Koo`0307oooooo02Koo`0308oooooo02[oo`0300oooooo00Coo`009?oo00<03ooo
ool01?oo00<03oooool08ooo00<0Ooooool09_oo00<0Soooool09_oo00<0Ooooool0:_oo00<03ooo
ool01?oo000Tool00`0?ooooo`04ool00`0?ooooo`0Sool00`2?ooooo`0Vool00`1oooooo`0Vool0
0`2?ooooo`0Yool200l6ool002Coo`0300oooooo00Coo`0300oooooo02?oo`0307oooooo02Koo`03
08oooooo02Koo`0307oooooo02[oo`0300oooooo00Coo`009?oo00<03oooool00ooo0P0?9Ooo00<0
Soooool09_oo00<0Ooooool09_oo00<0Soooool0:_oo00<03oooool01?oo000Tool00`0?ooooo`03
ool00`0?ooooo`0Tool00`1oooooo`0Vool00`2?ooooo`0Vool00`1oooooo`0Zool00`0?ooooo`04
ool002Coo`0300oooooo00?oo`0300oooooo02Coo`0308oooooo02Koo`0307oooooo02Koo`0308oo
oooo02Woo`803`Koo`009?oo00<03oooool00ooo00<03oooool09?oo00<0Ooooool09_oo00<0Sooo
ool09_oo00<0Ooooool0:_oo00<03oooool01?oo000Tool00`0?ooooo`03ool00`0?ooooo`0Tool0
0`2?ooooo`0Vool00`1oooooo`0Vool00`2?ooooo`0Zool00`0?ooooo`04ool002Coo`0300oooooo
00;oo`803bKoo`0307oooooo02Koo`0308oooooo02Koo`0307oooooo02Woo`803`Koo`007?oo0P0?
1_oo00<03oooool00_oo00<03oooool09Ooo00<0Soooool09_oo00<0Ooooool09_oo00<0Soooool0
:_oo00<03oooool01?oo000Nool00`0?ooooo`03ool00`0?ooooo`02ool00`0?ooooo`0Uool00`1o
ooooo`0Vool00`2?ooooo`0Vool00`1oooooo`0Zool00`0?ooooo`04ool001goo`0300oooooo00Co
o`803`2Y07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l00P0?1_oo000Nool00`0?
ooooo`03ool0100?oooooooo0P0?9ooo00<0Ooooool09_oo00<0Soooool09_oo00<0Ooooool0:_oo
00<03oooool01?oo000Lool200l6ool01@0?oooooooo00l0:?oo00<0Soooool09_oo00<0Ooooool0
9_oo00<0Soooool0:_oo00<03oooool01?oo000Tool01@0?oooooooo00l0:?oo00<0Ooooool09_oo
00<0Soooool09_oo00<0Ooooool0:Ooo0P0?1_oo000Tool01@0?oooooooo00l0:?oo00<0Soooool0
9_oo00<0Ooooool09_oo00<0Soooool0:_oo00<03oooool01?oo000Tool01@0?oooooooo00l0:?oo
00<0Ooooool09_oo00<0Soooool09_oo00<0Ooooool0:_oo00<03oooool01?oo000Tool01@0?oooo
oooo00l0:?oo00<03oooool09_oo00<03oooool09_oo00<03oooool09Ooo00<03oooool00_oo00<0
3oooool01?oo000Toon]00l6ool00001\
\>"],
  ImageRangeCache->{{{0, 214}, {131.5, 0}} -> {0.021005, -0.842249, 0.03051, 
  0.038709}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig14x8 = 
      Plot[Evaluate[{
            \(Es[Lc\ nano]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\/e /. 
              case, Ec[Lc\ nano\ \((\(4\ \[Pi]\)\/3)\)\^\(1/3\), 1]\/e /. 
              case}], {Lc, 1, 3}, 
        FrameLabel \[Rule] {"\<L in nm\>", "\<En in eV\>"}, Evaluate[opt]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
-0.452381 0.476191 -0.047965 1.500218 [
[.02381 -0.0125 -4 -12 ]
[.02381 -0.0125 4 0 ]
[.2619 -0.0125 -7 -12 ]
[.2619 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.7381 -0.0125 -7 -12 ]
[.7381 -0.0125 7 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -15 -24 ]
[.5 -0.0125 15 -12 ]
[-0.0125 .10206 -14 -6 ]
[-0.0125 .10206 0 6 ]
[-0.0125 .25208 -14 -6 ]
[-0.0125 .25208 0 6 ]
[-0.0125 .4021 -14 -6 ]
[-0.0125 .4021 0 6 ]
[-0.0125 .55212 -14 -6 ]
[-0.0125 .55212 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26 -16.5 ]
[-0.01875 .30902 -14 16.5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .10206 m
1 .10206 L
s
0 .25208 m
1 .25208 L
s
0 .4021 m
1 .4021 L
s
0 .55212 m
1 .55212 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -76 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(L) show
69.875000 13.000000 moveto
(in) show
78.062500 13.000000 moveto
(nm) show
88.250000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .10206 m
.00625 .10206 L
s
gsave
-0.0125 .10206 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .25208 m
.00625 .25208 L
s
gsave
-0.0125 .25208 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .4021 m
.00625 .4021 L
s
gsave
-0.0125 .4021 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .55212 m
.00625 .55212 L
s
gsave
-0.0125 .55212 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .13206 m
.00375 .13206 L
s
0 .16207 m
.00375 .16207 L
s
0 .19207 m
.00375 .19207 L
s
0 .22207 m
.00375 .22207 L
s
0 .28208 m
.00375 .28208 L
s
0 .31209 m
.00375 .31209 L
s
0 .34209 m
.00375 .34209 L
s
0 .3721 m
.00375 .3721 L
s
0 .4321 m
.00375 .4321 L
s
0 .46211 m
.00375 .46211 L
s
0 .49211 m
.00375 .49211 L
s
0 .52212 m
.00375 .52212 L
s
0 .07205 m
.00375 .07205 L
s
0 .04205 m
.00375 .04205 L
s
0 .01204 m
.00375 .01204 L
s
0 .58213 m
.00375 .58213 L
s
0 .61213 m
.00375 .61213 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -97.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
77.5 10 translate
90 rotate
-77.5 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(En) show
73.875000 13.000000 moveto
(in) show
82.062500 13.000000 moveto
(eV) show
91.312500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .10206 m
1 .10206 L
s
.99375 .25208 m
1 .25208 L
s
.99375 .4021 m
1 .4021 L
s
.99375 .55212 m
1 .55212 L
s
.125 Mabswid
.99625 .13206 m
1 .13206 L
s
.99625 .16207 m
1 .16207 L
s
.99625 .19207 m
1 .19207 L
s
.99625 .22207 m
1 .22207 L
s
.99625 .28208 m
1 .28208 L
s
.99625 .31209 m
1 .31209 L
s
.99625 .34209 m
1 .34209 L
s
.99625 .3721 m
1 .3721 L
s
.99625 .4321 m
1 .4321 L
s
.99625 .46211 m
1 .46211 L
s
.99625 .49211 m
1 .49211 L
s
.99625 .52212 m
1 .52212 L
s
.99625 .07205 m
1 .07205 L
s
.99625 .04205 m
1 .04205 L
s
.99625 .01204 m
1 .01204 L
s
.99625 .58213 m
1 .58213 L
s
.99625 .61213 m
1 .61213 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .51616 m
.06244 .43467 L
.10458 .3644 L
.14415 .31151 L
.18221 .26969 L
.22272 .23271 L
.26171 .20289 L
.30316 .17613 L
.34309 .15419 L
.3815 .136 L
.42237 .11921 L
.46172 .10513 L
.49955 .0932 L
.53984 .08197 L
.57861 .07238 L
.61984 .0633 L
.65954 .0555 L
.69774 .04874 L
.73838 .04225 L
.77751 .0366 L
.81909 .03116 L
.85916 .0264 L
.89771 .02221 L
.93871 .01814 L
.97619 .01472 L
s
[ .02 ] 0 setdash
.02381 .60332 m
.06244 .50924 L
.10458 .42812 L
.14415 .36705 L
.18221 .31877 L
.22272 .27607 L
.26171 .24165 L
.30316 .21075 L
.34309 .18543 L
.3815 .16442 L
.42237 .14504 L
.46172 .12878 L
.49955 .11501 L
.53984 .10204 L
.57861 .09097 L
.61984 .08049 L
.65954 .07148 L
.69774 .06368 L
.73838 .05619 L
.77751 .04967 L
.81909 .04339 L
.85916 .03789 L
.89771 .03306 L
.93871 .02835 L
.97619 .0244 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.9375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000ga000`40l00?003`ooooJOoo003ooomY
ool00?ooofWoo`00ooooJOoo002gool300l4ool01@0?ool03ooo00l00ooo00T03ooo00ooo`0?ool0
3ooo00l0VOoo002gool00`0?ooooo`04ool01@0?ool03ooo00l00ooo00T03ooo00ooo`0?ool03ooo
00l0VOoo002gool00`0?ooooo`04ool01@0?ool03ooo00l00ooo00T03ooo00ooo`0?ool03ooo00l0
VOoo002gool00`0?ooooo`04ool0100?ool03`0?1?oo0P0?0_oo0P0?00?oo`0?ool0VOoo002gool0
0`0?ooooo`2^ool00;koo`0300oooooo0:Ooo`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo
003ooomYool00?ooofWoo`00;?oo0`0?AOoo0`0?00?oo`0?ool00P0?A_oo0`0?AOoo0`0?00?oo`0?
ool00P0?A_oo0P0?3_oo000]ool00`0?ooooo`15ool00`0?ooooo`04ool00`0?ooooo`13ool00`0?
ooooo`15ool00`0?ooooo`05ool00`0?ooooo`15ool00`0?ooooo`0;ool002goo`0300oooooo04Go
o`0300oooooo00;oo`803dOoo`0300oooooo04Goo`0300oooooo00;oo`803dOoo`0300oooooo00co
o`00;Ooo00<03oooool0AOoo00<03oooool00_oo00<03oooool0AOoo00<03ooo00l0AOoo00<03ooo
00l00ooo00<03oooool0Aooo00<03oooool02ooo000/ool200m6ool200l4ool300m6ool200m6ool2
00l3ool300m5ool200l>ool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo003o
oomYool00?ooofWoo`009_ooo`0??@0?1_oo000Vool00`0?ooooo`05ool00`0?ooooo`0<ool00`0?
ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0;ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?
ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?
ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?
ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`0<ool00`0?ooooo`05ool00`0?
ooooo`04ool002Koo`0300oooooo00Goo`0300oooooo04Ooo`0300oooooo04Soo`0300oooooo04So
o`0300oooooo04Soo`0300oooooo00Goo`0300oooooo00Coo`009_oo00<03oooool0Cooo00<0Oooo
ool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000Vool200m@ool00`2?oooo
o`18ool00`1oooooo`18ool00`2?ooooo`1?ool200l6ool002Koo`0300oooooo04ooo`0307oooooo
04Soo`0308oooooo04Soo`0307oooooo03ooo`X03`Ooo`0300oooooo00Coo`009_oo00<03oooool0
Cooo00<0Soooool0B?oo00<0Ooooool0B?oo00<0Soooool0=Ooo2`0?4?oo00<03oooool01?oo000V
ool00`0?ooooo`1?ool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`0[ool;00lJool00`0?
ooooo`04ool002Koo`0300oooooo04ooo`0308oooooo04Soo`0307oooooo04Soo`0308oooooo02;o
o`X03aGoo`<03`coo`0300oooooo00Coo`009_oo00<03oooool0Cooo00<0Ooooool0B?oo00<0Sooo
ool0B?oo00<0Ooooool06_oo2@0?6_oo100?3ooo00<03oooool01?oo000Vool00`0?ooooo`1?ool0
0`2?ooooo`18ool00`1oooooo`18ool00`2?ooooo`0Bool900lFool700lHool00`0?ooooo`04ool0
02Koo`0300oooooo04ooo`0307oooooo04Soo`0308oooooo04Soo`0307oooooo00[oo`T03aGoo`<0
3bGoo`0300oooooo00Coo`009_oo00<03oooool0Cooo00<0Soooool0B?oo00<0Ooooool0B?oo00<0
Soooool00ooo200?6Ooo100?:?oo00<03oooool01?oo000Vool200m@ool00`1oooooo`18ool00`2?
ooooo`17ool800lEool600l`ool200l6ool002Koo`0300oooooo04ooo`0308oooooo04Soo`0307oo
oooo047oo`L03`0308oooooo01Soo`0300oooooo03Goo`0300oooooo00Coo`009_oo00<03oooool0
Cooo00<0Ooooool0B?oo00<0Soooool0>ooo1`0?1_oo00<0Ooooool02ooo1`0??_oo00<03oooool0
1?oo000Vool00`0?ooooo`1?ool00`2?ooooo`18ool00`1oooooo`0eool700l<ool00`2?ooooo`05
ool00`0?ooooo`18ool00`0?ooooo`04ool002Koo`0300oooooo04ooo`0307oooooo04Soo`0308oo
oooo033oo`H03a;oo`0307ooo`0?00D03d_oo`0300oooooo00Coo`009_oo00<03oooool0Cooo00<0
Soooool0B?oo00<0Ooooool0:ooo1P0?5ooo00<0Soooool0D?oo00<03oooool01?oo000Vool00`0?
ooooo`1?ool00`1oooooo`18ool00`2?ooooo`0Vool600lCool600l3ool00`1oooooo`1@ool00`0?
ooooo`04ool002Koo`0300oooooo04ooo`0308oooooo04Soo`0307oooooo027oo`D03aOoo`803`Wo
o`0308oooooo053oo`0300oooooo00Coo`009_oo00<03oooool0Cooo00<0Ooooool0B?oo00<0Sooo
ool07?oo1P0?4ooo0`0?4?oo00<0Ooooool0D?oo00<03oooool01?oo000Vool00`0?ooooo`1?ool0
0`2?ooooo`18ool00`1oooooo`0Hool500lDool400lCool00`2?ooooo`1@ool00`0?ooooo`04ool0
02Koo`803e3oo`0307oooooo04Soo`0308oooooo01?oo`H03booo`0307oooooo04ooo`803`Koo`00
9_oo00<03oooool0Cooo00<0Soooool0B?oo00<0Ooooool03ooo1@0?4ooo1@0?7?oo00<0Soooool0
D?oo00<03oooool01?oo000Vool00`0?ooooo`1?ool00`1oooooo`18ool00`2?ooooo`0;ool500lE
ool200lQool00`1oooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo04ooo`0308oooooo04So
o`0307oooooo00Soo`@03a?oo`0300oooooo02Koo`0308oooooo053oo`0300oooooo00Coo`009_oo
00<03oooool0Cooo00<0Ooooool0B?oo00<0Soooool01?oo1@0?4_oo100?:Ooo00<0Ooooool0D?oo
00<03oooool01?oo000Vool00`0?ooooo`1?ool00`2?ooooo`18ool00`1oooooo`0500lDool200l]
ool00`2?ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo04ooo`0307oooooo04Soo`@03dOo
o`0307oooooo053oo`0300oooooo00Coo`006?oo00D03oooool03ooo00<03`Koo`0300oooooo04oo
o`0308oooooo04Goo`@03a;oo`@03cCoo`0308oooooo053oo`0300oooooo00Coo`005ooo00<03ooo
00l01?oo00<03oooool01Ooo00<03oooool0Cooo00<0Ooooool0@_oo100?0_oo00<0Soooool03Ooo
0`0?>?oo00<0Ooooool0D?oo00<03oooool01?oo000Gool00`0?ool03`04ool00`0?ooooo`05ool3
00l0T01o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`@03`2R07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?0`0?1_oo000Gool00`0?ool03`04ool00`0?ooooo`05ool00`0?
ooooo`1?ool00`1oooooo`0kool400l9ool00`2?ooooo`06ool200m0ool00`1oooooo`1@ool00`0?
ooooo`04ool001Soo`0300oooooo00;oo`803`Ooo`0300oooooo04ooo`0308oooooo03Woo`<03`co
o`0307oooooo00?oo`<03d;oo`0308oooooo053oo`0300oooooo00Coo`009_oo00<03oooool0Cooo
00<0Ooooool0=_oo100?3_oo00@0Soooooooo`803dGoo`0307oooooo053oo`0300oooooo00Coo`00
9_oo00<03oooool0Cooo00<0Soooool0<ooo100?4Ooo00<0Ooooool0B?oo00<0Soooool0D?oo00<0
3oooool01?oo000Vool00`0?ooooo`1?ool00`1oooooo`0`ool400lAool200l00ooo08ooo`19ool0
0`1oooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo04ooo`0308oooooo02koo`<03a;oo`80
3`?oo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`009_oo00<03oooool0Cooo00<0
Ooooool0:ooo100?4Ooo0`0?1Ooo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000V
ool00`0?ooooo`1?ool00`2?ooooo`0Yool300lLool00`1oooooo`18ool00`2?ooooo`1@ool00`0?
ooooo`04ool002Koo`0300oooooo04ooo`0307oooooo02Koo`@03akoo`0308oooooo04Soo`0307oo
oooo053oo`0300oooooo00Coo`009_oo0P0?D?oo00<0Soooool09?oo0`0?4Ooo0`0?3Ooo00<0Oooo
ool0B?oo00<0Soooool0Cooo0P0?1_oo000Vool00`0?ooooo`1?ool00`1oooooo`0Rool300lAool2
00l@ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo04ooo`03
08oooooo023oo`<03a7oo`803a;oo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`00
9_oo00<03oooool0Cooo00<0Ooooool07_oo0`0?9ooo00<0Soooool0B?oo00<0Ooooool0D?oo00<0
3oooool01?oo000Vool00`0?ooooo`1?ool00`2?ooooo`0Kool300lZool00`1oooooo`18ool00`2?
ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo04ooo`0307oooooo01Woo`<03a7oo`803aWo
o`0308oooooo04Soo`0307oooooo053oo`0300oooooo00Coo`009_oo00<03oooool0Cooo00<0Sooo
ool05ooo0`0?4Ooo0P0?6ooo00<0Ooooool0B?oo00<0Soooool0D?oo00<03oooool01?oo000Vool0
0`0?ooooo`1?ool00`1oooooo`0Eool300lAool200lMool00`2?ooooo`18ool00`1oooooo`1@ool0
0`0?ooooo`04ool002Koo`0300oooooo04ooo`0308oooooo01Coo`803c;oo`0307oooooo04Soo`03
08oooooo053oo`0300oooooo00Coo`009_oo0P0?D?oo00<0Ooooool04_oo0`0?<ooo00<0Soooool0
B?oo00<0Ooooool0Cooo0P0?1_oo000Vool00`0?ooooo`1?ool00`2?ooooo`0@ool300l?ool200lT
ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo04ooo`0307oo
oooo00koo`<03`ooo`803bKoo`0308oooooo04Soo`0307oooooo053oo`0300oooooo00Coo`009_oo
00<03oooool0Cooo00<0Soooool03?oo0`0?4?oo00<03oooool09_oo00<0Ooooool0B?oo00<0Sooo
ool0D?oo00<03oooool01?oo000Vool00`0?ooooo`1?ool00`1oooooo`0:ool300l@ool200lYool0
0`2?ooooo`18ool00`1oooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo04ooo`0308oooooo
00Woo`803cgoo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`009_oo00<03oooool0
Cooo00<0Ooooool01ooo0`0??_oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000V
ool00`0?ooooo`1?ool00`2?ooooo`06ool200l?ool200l_ool00`1oooooo`18ool00`2?ooooo`1@
ool00`0?ooooo`04ool002Koo`0300oooooo04ooo`0307oooooo00Coo`<03`ooo`0300oooooo02oo
o`0308oooooo04Soo`0307oooooo053oo`0300oooooo00Coo`009_oo0P0?D?oo00<0Soooool00ooo
0P0?3ooo0P0?<_oo00<0Ooooool0B?oo00<0Soooool0Cooo0P0?1_oo000Vool00`0?ooooo`1?ool0
101ooooooooo0`0?3_oo0P0?=?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000V
ool00`0?ooooo`1?ool00`2?ooooo`0200m6ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?oooo
o`04ool002Koo`0300oooooo04ooo`0407l03`0?00m7ool00`2?ooooo`18ool00`1oooooo`1@ool0
0`0?ooooo`04ool002Koo`0300oooooo04ooo`803dWoo`0307oooooo04Soo`0308oooooo053oo`03
00oooooo00Coo`009_oo00<03oooool0COoo0`0?3_oo0P0?>_oo00<0Soooool0B?oo00<0Ooooool0
D?oo00<03oooool01?oo000Vool00`0?ooooo`1<ool200l00ooo08ooo`0;ool200llool00`1ooooo
o`18ool00`2?ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo04_oo`803`;oo`0307oooooo
00Woo`803cgoo`0308oooooo04Soo`0307oooooo053oo`0300oooooo00Coo`009_oo00<03oooool0
BOoo0`0?0ooo00<0Soooool02?oo00<03oooool0?Ooo00<0Ooooool0B?oo00<0Soooool0D?oo00<0
3oooool01?oo000Vool00`0?ooooo`18ool200l5ool00`1oooooo`18ool00`2?ooooo`18ool00`1o
ooooo`1@ool00`0?ooooo`04ool002Koo`803dSoo`803`Koo`0308oooooo04Soo`0307oooooo04So
o`0308oooooo04ooo`803`Koo`009_oo00<03oooool0AOoo0`0?1ooo00<0Ooooool0B?oo00<0Sooo
ool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000Vool00`0?ooooo`14ool200l9ool00`2?oooo
o`03ool00`0?ooooo`12ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool002Koo`03
00oooooo04?oo`803`[oo`0407ooooooool200m5ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?
ooooo`04ool002Koo`0300oooooo04;oo`803`_oo`0408oooooo00m7ool00`1oooooo`18ool00`2?
ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo047oo`803`coo`0307ooo`0?04Soo`0308oo
oooo04Soo`0307oooooo053oo`0300oooooo00Coo`009_oo00<03oooool0@?oo0P0?3Ooo00<0S`0?
ool0B?oo00<0Ooooool0B?oo00<0Soooool0D?oo00<03oooool01?oo000Hool01@0?ooooo`0?ool0
0`0?1_oo00<03oooool0?ooo0P0?3_oo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo
00<03oooool01?oo000Gool00`0?ool03`03ool00`0?ooooo`06ool00`0?ooooo`0mool300l?ool0
0`2?ooooo`18ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool001Ooo`0300ooo`0?
00Coo`0300oooooo00Goo`<03`0l08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o0P0?0?P0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o0`0?1_oo000Gool00`0?ool0
3`03ool00`0?ool03`06ool00`0?ooooo`0kool200l>ool01@0?oooooooo08l0B_oo00<0Ooooool0
B?oo00<0Soooool0D?oo00<03oooool01?oo000Hool00`0?ooooo`03ool200l6ool00`0?ooooo`0j
ool200l>ool00`0?ooooo`02ool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?
ooooo`04ool002Koo`0300oooooo03Woo`803`koo`0300oooooo00?oo`0308oooooo04Soo`0307oo
oooo04Soo`0308oooooo053oo`0300oooooo00Coo`002_oo00<03oooool00_oo00<03oooool05?oo
00<03oooool0>?oo0P0?3_oo00<03oooool01?oo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Oooo
ool0D?oo00<03oooool01?oo000:ool600lFool00`0?ooooo`0gool200l=ool200l7ool00`2?oooo
o`18ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool000[oo`0600oooooo00ooo`0?
5_oo00<03oooool0=_oo0P0?5ooo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<0
3oooool01?oo000:ool01P0?ooooo`0?ool03aKoo`0300oooooo03Goo`803aSoo`0308oooooo04So
o`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`002_oo0P0?0ooo00<03oooool05?oo
00<03oooool0=?oo0P0?6Ooo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03ooo
ool01?oo000<ool400lFool00`0?ooooo`0cool200l=ool00`0?ooooo`0:ool00`2?ooooo`18ool0
0`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool000coo`0400oooooo00lFool200lcool2
00l=ool00`0?ooooo`0;ool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1?ool200l6ool0
00coo`0300oooooo01Ooo`0300oooooo037oo`803`goo`0300oooooo00coo`0308oooooo04Soo`03
07oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`003Ooo0`0?5_oo00<03oooool0<?oo0P0?
3Ooo00<03oooool03Ooo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool0
1?oo000Vool00`0?ooooo`0_ool200l=ool00`0?ooooo`0>ool00`2?ooooo`18ool00`1oooooo`18
ool00`2?ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo02ooo`0300oooooo00_oo`0300oo
oooo00ooo`0307oooooo04Soo`0308oooooo04Soo`0307oooooo053oo`0300oooooo00Coo`003Ooo
00<03ooo00l05_oo00<03oooool0;_oo0P0?7ooo00<0Soooool0B?oo00<0Ooooool0B?oo00<0Sooo
ool0D?oo00<03oooool01?oo000:ool00`0?ool03`0300lFool00`0?ooooo`0]ool200lPool00`1o
ooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?ooooo`04ool000coo`@03aKoo`0300oo
oooo02coo`803b7oo`0308oooooo04Soo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Co
o`003?oo00@03oooool03aKoo`0300oooooo02_oo`803`coo`0300oooooo01?oo`0307oooooo04So
o`0308oooooo04Soo`0307oooooo053oo`0300oooooo00Coo`003?oo00<03oooool05ooo0P0?:ooo
0P0?3Ooo00<03oooool04ooo00<0Soooool0B?oo00<0Ooooool0B?oo00<0Soooool0Cooo0P0?1_oo
000=ool300lFool00`0?ooooo`0Yool200l=ool00`0?ooooo`0Dool00`1oooooo`18ool00`2?oooo
o`18ool00`1oooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo02Woo`0300oooooo00[oo`80
3aOoo`0308oooooo04Soo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`009_oo00<0
3oooool0:?oo0P0?3?oo00<03oooool05_oo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0
D?oo00<03oooool01?oo000=ool200lGool00`0?ooooo`0Wool200l<ool00`0?ooooo`0Gool00`2?
ooooo`18ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool000coo`803`03ool03ooo
01Goo`0300oooooo02Koo`803bOoo`0307oooooo04Soo`0308oooooo04Soo`0307oooooo053oo`03
00oooooo00Coo`003?oo0P0?00?oo`0?ool05Ooo00<03oooool09_oo00<03oooool09_oo00<0Sooo
ool0B?oo00<0Ooooool0B?oo00<0Soooool0D?oo00<03oooool01?oo000>ool00`0?ooooo`0Eool0
0`0?ooooo`0Uool200lXool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?oooo
o`04ool000[oo`0300oooooo01Woo`0300oooooo02Coo`803bWoo`0308oooooo04Soo`0307oooooo
04Soo`0308oooooo053oo`0300oooooo00Coo`002_oo0`0?6Ooo00<03oooool08ooo0P0?3?oo00<0
3oooool06ooo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000=
ool300lFool200lTool00`0?ooooo`0:ool00`0?ooooo`0Lool00`2?ooooo`18ool00`1oooooo`18
ool00`2?ooooo`1?ool200l6ool000[oo`0400ooo`0?00lHool00`0?ooooo`0Rool200l<ool00`0?
ooooo`0Lool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?ooooo`04ool000[o
o`803a[oo`0300oooooo027oo`803`coo`0300oooooo01goo`0308oooooo04Soo`0307oooooo04So
o`0308oooooo053oo`0300oooooo00Coo`009_oo00<03oooool08?oo0P0?3?oo00<03oooool07_oo
00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000Vool00`0?oooo
o`0Pool00`0?ooooo`0:ool00`0?ooooo`0Oool00`2?ooooo`18ool00`1oooooo`18ool00`2?oooo
o`1@ool00`0?ooooo`04ool002Koo`0300oooooo01ooo`803bkoo`0307oooooo04Soo`0308oooooo
04Soo`0307oooooo053oo`0300oooooo00Coo`009_oo00<03oooool07_oo0P0?;ooo00<0Soooool0
B?oo00<0Ooooool0B?oo00<0Soooool0D?oo00<03oooool01?oo000Vool00`0?ooooo`0Nool00`0?
ooooo`0^ool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?ooooo`04ool002Ko
o`0300oooooo01goo`0300oooooo02ooo`0308oooooo04Soo`0307oooooo04Soo`0308oooooo053o
o`0300oooooo00Coo`009_oo0P0?7Ooo0P0?2ooo00<03oooool08ooo00<0Ooooool0B?oo00<0Sooo
ool0B?oo00<0Ooooool0Cooo0P0?1_oo000Vool00`0?ooooo`0Lool00`0?ooooo`0:ool00`0?oooo
o`0Sool00`2?ooooo`18ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool002Koo`03
00oooooo01_oo`803`_oo`0300oooooo02Coo`0307oooooo04Soo`0308oooooo04Soo`0307oooooo
053oo`0300oooooo00Coo`009_oo00<03oooool06ooo00<03oooool02_oo00<03oooool09?oo00<0
Soooool0B?oo00<0Ooooool0B?oo00<0Soooool0D?oo00<03oooool01?oo000Vool00`0?ooooo`0J
ool200l;ool00`0?ooooo`0Uool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?
ooooo`04ool002Koo`0300oooooo01Woo`803`_oo`0300oooooo02Koo`0308oooooo04Soo`0307oo
oooo04Soo`0308oooooo053oo`0300oooooo00Coo`009_oo00<03oooool06Ooo00<03oooool0<ooo
00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000Hool01@0?oooo
o`0?ool00P0?1ooo00<03oooool06?oo0P0?=Ooo00<0Soooool0B?oo00<0Ooooool0B?oo00<0Sooo
ool0D?oo00<03oooool01?oo000Gool00`0?ool03`05ool00`0?ooooo`04ool00`0?ooooo`0Hool0
0`0?ooooo`0dool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?ooooo`04ool0
01Ooo`0300ooo`0?00Coo`0300oooooo00Goo`0300oooooo01Ooo`803cKoo`0308oooooo04Soo`03
07oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`005ooo00<03ooo00l01Ooo00<03oooool0
1?oo0`0?01H0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`803`3o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?000O08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l00`0?1_oo000Hool00`0?ooooo`02ool200l7
ool00`0?ooooo`0Fool00`0?ooooo`09ool200l[ool00`2?ooooo`18ool00`1oooooo`18ool00`2?
ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo01Goo`803`_oo`0300oooooo02[oo`0307oo
oooo04Soo`0308oooooo04Soo`0307oooooo053oo`0300oooooo00Coo`009_oo00<03oooool05Ooo
00<03oooool02Ooo00<03oooool0:ooo00<0Soooool0B?oo00<0Ooooool0B?oo00<0Soooool0D?oo
00<03oooool01?oo000Vool00`0?ooooo`0Dool00`0?ooooo`09ool00`0?ooooo`0/ool00`1ooooo
o`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo01?oo`80
3`_oo`0300oooooo02coo`0308oooooo04Soo`0307oooooo04Soo`0308oooooo053oo`0300oooooo
00Coo`009_oo00<03oooool04ooo00<03oooool02Ooo00<03oooool0;Ooo00<0Ooooool0B?oo00<0
Soooool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000Vool00`0?ooooo`0Bool200lkool00`2?
ooooo`18ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo01;o
o`0300oooooo03[oo`0307oooooo04Soo`0308oooooo04Soo`0307oooooo053oo`0300oooooo00Co
o`009_oo0P0?4_oo0P0???oo00<0Soooool0B?oo00<0Ooooool0B?oo00<0Soooool0Cooo0P0?1_oo
000Vool00`0?ooooo`0@ool200lmool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool0
0`0?ooooo`04ool002Koo`0300oooooo013oo`0300oooooo00Woo`0300oooooo033oo`0308oooooo
04Soo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`009_oo00<03oooool03ooo0P0?
2ooo00<03oooool0<?oo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool0
1?oo000Vool00`0?ooooo`0?ool00`0?ooooo`09ool00`0?ooooo`0aool00`2?ooooo`18ool00`1o
ooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo00ooo`0300oooooo00Wo
o`0300oooooo037oo`0307oooooo04Soo`0308oooooo04Soo`0307oooooo053oo`0300oooooo00Co
o`009_oo00<03oooool03_oo00<03oooool02Ooo00<03oooool0<_oo00<0Soooool0B?oo00<0Oooo
ool0B?oo00<0Soooool0D?oo00<03oooool01?oo000Vool00`0?ooooo`0>ool00`0?ooooo`09ool0
0`0?ooooo`0bool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?ooooo`04ool0
02Koo`0300oooooo00goo`803`[oo`0300oooooo03?oo`0308oooooo04Soo`0307oooooo04Soo`03
08oooooo053oo`0300oooooo00Coo`009_oo0P0?3_oo00<03oooool0?ooo00<0Ooooool0B?oo00<0
Soooool0B?oo00<0Ooooool0Cooo0P0?1_oo000Vool00`0?ooooo`0<ool200m1ool00`2?ooooo`18
ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo00coo`0300oo
oooo043oo`0307oooooo04Soo`0308oooooo04Soo`0307oooooo053oo`0300oooooo00Coo`009_oo
00<03oooool02ooo0P0?@_oo00<0Soooool0B?oo00<0Ooooool0B?oo00<0Soooool0D?oo00<03ooo
ool01?oo000Vool00`0?ooooo`0;ool00`0?ooooo`11ool00`1oooooo`18ool00`2?ooooo`18ool0
0`1oooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo00[oo`803`[oo`0300oooooo03Koo`03
08oooooo04Soo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`009_oo00<03oooool0
2_oo00<03oooool02Ooo00<03oooool0=_oo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0
D?oo00<03oooool01?oo000Vool00`0?ooooo`09ool200l:ool00`0?ooooo`0gool00`2?ooooo`18
ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo00Woo`0300oo
oooo00Woo`0300oooooo03Ooo`0307oooooo04Soo`0308oooooo04Soo`0307oooooo053oo`0300oo
oooo00Coo`009_oo00<03oooool02?oo0P0?2_oo00<03oooool0>?oo00<0Soooool0B?oo00<0Oooo
ool0B?oo00<0Soooool0D?oo00<03oooool01?oo000Vool200l9ool00`0?ooooo`08ool00`0?oooo
o`0iool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1?ool200l6ool002Koo`0300oooooo
00Ooo`803dKoo`0308oooooo04Soo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`00
9_oo00<03oooool01ooo00<03oooool0AOoo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0
D?oo00<03oooool01?oo000Vool00`0?ooooo`06ool200m7ool00`2?ooooo`18ool00`1oooooo`18
ool00`2?ooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo00Koo`0300oooooo04Koo`0307oo
oooo04Soo`0308oooooo04Soo`0307oooooo053oo`0300oooooo00Coo`009_oo00<03oooool01_oo
00<03oooool0A_oo00<0Soooool0B?oo00<0Ooooool0B?oo00<0Soooool0D?oo00<03oooool01?oo
000Vool00`0?ooooo`05ool00`0?ooooo`08ool200lmool00`1oooooo`18ool00`2?ooooo`18ool0
0`1oooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo00Goo`0300oooooo00Soo`0300oooooo
03coo`0308oooooo04Soo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`009_oo00<0
3oooool04?oo00<03oooool0??oo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<0
3oooool01?oo000Vool200l@ool00`0?ooooo`0mool00`2?ooooo`18ool00`1oooooo`18ool00`2?
ooooo`1?ool200l6ool002Koo`0300oooooo00ooo`0300oooooo03goo`0307oooooo04Soo`0308oo
oooo04Soo`0307oooooo053oo`0300oooooo00Coo`009_oo00<03oooool03_oo00<03oooool0?_oo
00<0Soooool0B?oo00<0Ooooool0B?oo00<0Soooool0D?oo00<03oooool01?oo000Vool00`0?oooo
o`0>ool00`0?ooooo`0nool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?oooo
o`04ool002Koo`0300oooooo04ooo`0308oooooo04Soo`0307oooooo04Soo`0308oooooo053oo`03
00oooooo00Coo`009_oo00<03oooool0Cooo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0
D?oo00<03oooool01?oo000Vool00`0?ooooo`1?ool00`2?ooooo`18ool00`1oooooo`18ool00`2?
ooooo`1@ool00`0?ooooo`04ool001Soo`0400oooooo00l3ool00`0?ooooo`04ool00`0?ooooo`1?
ool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?ooooo`04ool001Ooo`0300oo
o`0?00?oo`<03`Koo`0300oooooo00coo`0300oooooo043oo`0308oooooo04Soo`0307oooooo04So
o`0308oooooo053oo`0300oooooo00Coo`005ooo00<03ooo00l00ooo00<03ooo00l01_oo00<03ooo
ool02ooo00<03oooool0@Ooo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03ooo
ool01?oo000Gool00`0?ool03`04ool200l6ool300l0o`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`00=`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00<0
3`Koo`006?oo00<03oooool01?oo00<03oooool01?oo00<03oooool02ooo00<03oooool0@Ooo00<0
Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000Vool00`0?ooooo`0:
ool00`0?ooooo`12ool00`2?ooooo`18ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04
ool002Koo`0300oooooo00[oo`0300oooooo04;oo`0307oooooo04Soo`0308oooooo04Soo`0307oo
oooo053oo`0300oooooo00Coo`009_oo00<03oooool02Ooo00<03oooool0@ooo00<0Soooool0B?oo
00<0Ooooool0B?oo00<0Soooool0D?oo00<03oooool01?oo000Vool00`0?ooooo`1?ool00`1ooooo
o`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo04ooo`03
08oooooo04Soo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`009_oo00<03oooool0
Cooo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000Vool00`0?
ooooo`1?ool00`2?ooooo`18ool00`1oooooo`18ool00`2?ooooo`1@ool00`0?ooooo`04ool002Ko
o`803e3oo`0307oooooo04Soo`0308oooooo04Soo`0307oooooo04ooo`803`Koo`009_oo00<03ooo
ool01ooo00<03oooool0AOoo00<0Soooool0B?oo00<0Ooooool0B?oo00<0Soooool0D?oo00<03ooo
ool01?oo000Vool00`0?ooooo`07ool00`0?ooooo`15ool00`1oooooo`18ool00`2?ooooo`18ool0
0`1oooooo`1@ool00`0?ooooo`04ool002Koo`0300oooooo00Koo`0300oooooo04Koo`0308oooooo
04Soo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`009_oo00<03oooool01_oo00<0
3oooool0A_oo00<0Ooooool0B?oo00<0Soooool0B?oo00<0Ooooool0D?oo00<03oooool01?oo000V
ool00`0?ooooo`05ool00`0?ooooo`17ool00`2?ooooo`18ool00`1oooooo`18ool00`2?ooooo`1@
ool00`0?ooooo`04ool002Koo`0300oooooo00Goo`0300oooooo04Ooo`0307oooooo04Soo`0308oo
oooo04Soo`0307oooooo053oo`0300oooooo00Coo`009_oo00<03oooool01Ooo00<03oooool0Aooo
00<0Soooool0B?oo00<0Ooooool0B?oo00<0Soooool0D?oo00<03oooool01?oo000Vool00`0?oooo
o`1?ool00`1oooooo`18ool00`2?ooooo`18ool00`1oooooo`1@ool00`0?ooooo`04ool002Koo`03
00oooooo04ooo`0308oooooo04Soo`0307oooooo04Soo`0308oooooo053oo`0300oooooo00Coo`00
9_oo0P0?1_oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool02ooo00<0
3oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<0
3oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<0
3oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<03oooool03?oo00<0
3oooool03?oo00<03oooool01?oo0P0?1_oo000Voooo00lm00l6ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0.69248, -0.025092, 0.008344,
   0.002648}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"NeXT 3.0",
ScreenRectangle->{{0, 957}, {0, 768}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{627, 484},
WindowMargins->{{Automatic, 161}, {Automatic, 11}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"NeXTAutomaticEncoding",
Magnification->1.25
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 92, 2, 122, "Title"],
Cell[1826, 55, 55, 1, 31, "Input"],
Cell[1884, 58, 87, 2, 64, "Section"],
Cell[1974, 62, 85, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[2084, 68, 89, 2, 64, "Section"],
Cell[2176, 72, 1790, 36, 739, "Input"],
Cell[3969, 110, 135, 3, 48, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4141, 118, 107, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[4273, 124, 86, 2, 54, "Subsection"],
Cell[4362, 128, 151, 4, 92, "Input"],

Cell[CellGroupData[{
Cell[4538, 136, 95, 2, 31, "Input"],
Cell[4636, 140, 79, 1, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4752, 146, 189, 5, 48, "Input"],
Cell[4944, 153, 44917, 1281, 233, 16575, 927, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49898, 1439, 320, 8, 100, "Input"],
Cell[50221, 1449, 173, 3, 27, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[50443, 1458, 84, 2, 54, "Subsection"],
Cell[50530, 1462, 130, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[50685, 1469, 95, 2, 31, "Input"],
Cell[50783, 1473, 69, 1, 34, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[50901, 1480, 91, 2, 54, "Subsection"],
Cell[50995, 1484, 150, 3, 76, "Input"],

Cell[CellGroupData[{
Cell[51170, 1491, 96, 2, 31, "Input"],
Cell[51269, 1495, 60, 1, 32, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[51390, 1503, 118, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[51533, 1509, 97, 2, 54, "Subsection"],
Cell[51633, 1513, 127, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[51785, 1520, 95, 2, 31, "Input"],
Cell[51883, 1524, 76, 1, 50, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[52008, 1531, 117, 2, 54, "Subsection"],
Cell[52128, 1535, 134, 3, 77, "Input"],

Cell[CellGroupData[{
Cell[52287, 1542, 197, 5, 48, "Input"],
Cell[52487, 1549, 360, 11, 48, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[52896, 1566, 97, 2, 54, "Subsection"],
Cell[52996, 1570, 135, 3, 78, "Input"],
Cell[53134, 1575, 137, 3, 48, "Input"],
Cell[53274, 1580, 136, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[53435, 1587, 197, 4, 65, "Input"],
Cell[53635, 1593, 433, 14, 55, "Print"],
Cell[54071, 1609, 251, 7, 40, "Print"],
Cell[54325, 1618, 445, 14, 48, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54807, 1637, 337, 8, 104, "Input"],
Cell[55147, 1647, 27870, 909, 143, 12794, 717, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83054, 2561, 270, 6, 82, "Input"],
Cell[83327, 2569, 53564, 1454, 163, 32446, 1187, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[136952, 4030, 117, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[137094, 4036, 92, 2, 54, "Subsection"],
Cell[137189, 4040, 223, 5, 125, "Input"],

Cell[CellGroupData[{
Cell[137437, 4049, 280, 6, 88, "Input"],
Cell[137720, 4057, 30813, 1033, 155, 14553, 826, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[168582, 5096, 92, 2, 54, "Subsection"],
Cell[168677, 5100, 231, 5, 127, "Input"],

Cell[CellGroupData[{
Cell[168933, 5109, 277, 6, 85, "Input"],
Cell[169213, 5117, 32367, 1091, 155, 15297, 874, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[201629, 6214, 99, 2, 54, "Subsection"],
Cell[201731, 6218, 148, 4, 72, "Input"],
Cell[201882, 6224, 111, 2, 55, "Input"],

Cell[CellGroupData[{
Cell[202018, 6230, 203, 5, 48, "Input"],
Cell[202224, 6237, 28788, 984, 143, 13926, 795, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[231061, 7227, 101, 2, 54, "Subsection"],
Cell[231165, 7231, 124, 3, 31, "Input"],
Cell[231292, 7236, 148, 4, 81, "Input"],

Cell[CellGroupData[{
Cell[231465, 7244, 212, 5, 81, "Input"],
Cell[231680, 7251, 32430, 1129, 143, 15833, 918, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[264147, 8385, 365, 8, 159, "Input"],
Cell[264515, 8395, 37189, 980, 233, 11615, 660, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

