(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    353383,      14223]*)
(*NotebookOutlinePosition[    354303,      14255]*)
(*  CellTagsIndexPosition[    354259,      14251]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["ELECTROSTATICS"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Remove["\<Global`*\>"]\)], "Input"],

Cell[TextData["Highlights"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Abstract"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Introduction"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Needs["\<Graphics`PlotField`\>"]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Off[General::"\<spell\>", General::"\<spell1\>"]; \)\), 
    \(\(Needs["\<Graphics`Arrow`\>"]; \)\), 
    \(tera = 10\^12; micro = 1\/10\^6; \), 
    \(giga = 10\^9; nano = 1\/10\^9; \), 
    \(mega = 10\^6; pico = 1\/10\^12; \), 
    \(kilo = 10\^3; femto = 1\/10\^15; \), 
    \(milli = 1\/10.\^3; atto = 1\/10\^18; \), 
    \(\(NSub
       = {c \[Rule] 2.99792458\ 10\^8, e \[Rule] 1.6021773\/10\^19, 
        h \[Rule] 6.6260755\/10.\^34, hbar \[Rule] 1.05457\/10.\^34, 
        K \[Rule] 1.380658\/10\^23, me \[Rule] 9.109389\/10\^31, 
        mu0 \[Rule] \(4.\ \[Pi]\)\/10\^7, eps0 \[Rule] 8.85419\/10\^12}; \)\),
   
    \(ESi = 0.179\ tera; rhoSi = 2330; nuSi = 0.28; \), 
    \(ESiO2 = 0.06\ tera; rhoSiO2 = 2200; nuSiO2 = 0.3; \), 
    \(ESi3N4 = 0.15\ tera; rhoSi3N4 = 3100; nuSi3N4 = 0.24; \), 
    \(EAu = 0.08\ tera; rhoAu = 19300; nuAu = 0.42; \), 
    \(ENi = 0.207\ tera; rhoNi = 8900; nuNi = 0.41; \), 
    \(EW = 0.345\ tera; rhoW = 19300; nuW = 0.28; \), 
    \(EPt = 0.17\ tera; rhoPt = 21400; nuPt = 0.39; \), 
    \(EIr = 0.52\ tera; rhoIr = 22500; nuIr = 0.3; \), 
    \(EHOPG = 0.2\ tera; rhoHOPG = 2250; nuHOPG = 0.3; \), 
    \(EPol = 0.001\ tera; rhoPol = 1000; nuPol = 0.3; \), 
    \(\(xx = 0.8; \)\), 
    \(\(EPtIr = xx\ 0.8\ EPt + \((1 - xx)\)\ EIr; \)\), 
    \(\(rhoPtIr = xx\ rhoPt + \((1 - xx)\)\ rhoIr; \)\), 
    \(\(nuPtIr = 0.3; \)\), 
    \(opt = {PlotRange \[Rule] All, AxesOrigin \[Rule] {0, 0}, 
        Frame \[Rule] True, GridLines \[Rule] Automatic, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        PlotStyle 
          \[Rule] {Dashing[{.0001}], Dashing[{.0500}], Dashing[{.0200}], 
            Dashing[{.0001}]}}; \n
    \(opt1 = {DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>"}, Frame \[Rule] True}; \)\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Isolated Point Charge"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[vpoint]; \)\), 
    \(\(vpoint[x_, y_] := 1\/\@\(x\^2 + y\^2\); \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(discGraphics = 
      Graphics[Disk[{0, 0}, .1], AxesOrigin \[Rule] {0, 0}, 
        AspectRatio \[Rule] Automatic, PlotLabel \[Rule] "\<a\>", opt1]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(fieldGraphics = 
      PlotGradientField[
        \(-vpoint[x, y]\), {x, \(-1.5\), 1.5}, {y, \(-1.5\), 1.5}, 
        ScaleFunction \[Rule] \((2 + Log[1 + #1]&)\), 
        ScaleFactor \[Rule] 0.5, PlotPoints \[Rule] 8, 
        DisplayFunction \[Rule] Identity]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(discfieldGraphics = 
      Show[{discGraphics, fieldGraphics}, DisplayFunction \[Rule] Identity]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(potentialGraphics = 
      ContourPlot[vpoint[x, y], {x, \(-2.5\), 2.5}, {y, \(-2.5\), 2.5}, 
        PlotPoints \[Rule] 20, Contours \[Rule] 7, PlotLabel \[Rule] "\<b\>", 
        ContourShading \[Rule] False, DisplayFunction \[Rule] Identity, 
        Evaluate[opt1]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig1 = Show[GraphicsArray[{discfieldGraphics, potentialGraphics}]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.47619 0.011338 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.02381 0.011338 0.477324 0.464853 MathSubStart
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.270383 0.5 0.270383 [
[.09443 -0.0125 -10 -12 ]
[.09443 -0.0125 10 0 ]
[.22962 -0.0125 -7 -12 ]
[.22962 -0.0125 7 0 ]
[.36481 -0.0125 -10 -12 ]
[.36481 -0.0125 10 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.63519 -0.0125 -7 -12 ]
[.63519 -0.0125 7 0 ]
[.77038 -0.0125 -4 -12 ]
[.77038 -0.0125 4 0 ]
[.90557 -0.0125 -7 -12 ]
[.90557 -0.0125 7 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4 -24 ]
[.5 -0.0125 4 -12 ]
[-0.0125 .09443 -20 -6 ]
[-0.0125 .09443 0 6 ]
[-0.0125 .22962 -14 -6 ]
[-0.0125 .22962 0 6 ]
[-0.0125 .36481 -20 -6 ]
[-0.0125 .36481 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .63519 -14 -6 ]
[-0.0125 .63519 0 6 ]
[-0.0125 .77038 -8 -6 ]
[-0.0125 .77038 0 6 ]
[-0.0125 .90557 -14 -6 ]
[-0.0125 .90557 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -32 -4 ]
[-0.01875 .5 -20 4 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09443 0 m
.09443 .00625 L
s
gsave
.09443 -0.0125 -71 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.22962 0 m
.22962 .00625 L
s
gsave
.22962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.36481 0 m
.36481 .00625 L
s
gsave
.36481 -0.0125 -71 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.63519 0 m
.63519 .00625 L
s
gsave
.63519 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77038 0 m
.77038 .00625 L
s
gsave
.77038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.90557 0 m
.90557 .00625 L
s
gsave
.90557 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.12146 0 m
.12146 .00375 L
s
.1485 0 m
.1485 .00375 L
s
.17554 0 m
.17554 .00375 L
s
.20258 0 m
.20258 .00375 L
s
.25666 0 m
.25666 .00375 L
s
.28369 0 m
.28369 .00375 L
s
.31073 0 m
.31073 .00375 L
s
.33777 0 m
.33777 .00375 L
s
.39185 0 m
.39185 .00375 L
s
.41889 0 m
.41889 .00375 L
s
.44592 0 m
.44592 .00375 L
s
.47296 0 m
.47296 .00375 L
s
.52704 0 m
.52704 .00375 L
s
.55408 0 m
.55408 .00375 L
s
.58111 0 m
.58111 .00375 L
s
.60815 0 m
.60815 .00375 L
s
.66223 0 m
.66223 .00375 L
s
.68927 0 m
.68927 .00375 L
s
.71631 0 m
.71631 .00375 L
s
.74334 0 m
.74334 .00375 L
s
.79742 0 m
.79742 .00375 L
s
.82446 0 m
.82446 .00375 L
s
.8515 0 m
.8515 .00375 L
s
.87854 0 m
.87854 .00375 L
s
.06739 0 m
.06739 .00375 L
s
.04035 0 m
.04035 .00375 L
s
.01331 0 m
.01331 .00375 L
s
.93261 0 m
.93261 .00375 L
s
.95965 0 m
.95965 .00375 L
s
.98669 0 m
.98669 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .09443 m
.00625 .09443 L
s
gsave
-0.0125 .09443 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .22962 m
.00625 .22962 L
s
gsave
-0.0125 .22962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .36481 m
.00625 .36481 L
s
gsave
-0.0125 .36481 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .63519 m
.00625 .63519 L
s
gsave
-0.0125 .63519 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .77038 m
.00625 .77038 L
s
gsave
-0.0125 .77038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .90557 m
.00625 .90557 L
s
gsave
-0.0125 .90557 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .12146 m
.00375 .12146 L
s
0 .1485 m
.00375 .1485 L
s
0 .17554 m
.00375 .17554 L
s
0 .20258 m
.00375 .20258 L
s
0 .25666 m
.00375 .25666 L
s
0 .28369 m
.00375 .28369 L
s
0 .31073 m
.00375 .31073 L
s
0 .33777 m
.00375 .33777 L
s
0 .39185 m
.00375 .39185 L
s
0 .41889 m
.00375 .41889 L
s
0 .44592 m
.00375 .44592 L
s
0 .47296 m
.00375 .47296 L
s
0 .52704 m
.00375 .52704 L
s
0 .55408 m
.00375 .55408 L
s
0 .58111 m
.00375 .58111 L
s
0 .60815 m
.00375 .60815 L
s
0 .66223 m
.00375 .66223 L
s
0 .68927 m
.00375 .68927 L
s
0 .71631 m
.00375 .71631 L
s
0 .74334 m
.00375 .74334 L
s
0 .79742 m
.00375 .79742 L
s
0 .82446 m
.00375 .82446 L
s
0 .8515 m
.00375 .8515 L
s
0 .87854 m
.00375 .87854 L
s
0 .06739 m
.00375 .06739 L
s
0 .04035 m
.00375 .04035 L
s
0 .01331 m
.00375 .01331 L
s
0 .93261 m
.00375 .93261 L
s
0 .95965 m
.00375 .95965 L
s
0 .98669 m
.00375 .98669 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -91 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
65 10 translate
90 rotate
-65 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.09443 .99375 m
.09443 1 L
s
.22962 .99375 m
.22962 1 L
s
.36481 .99375 m
.36481 1 L
s
.5 .99375 m
.5 1 L
s
.63519 .99375 m
.63519 1 L
s
.77038 .99375 m
.77038 1 L
s
.90557 .99375 m
.90557 1 L
s
.125 Mabswid
.12146 .99625 m
.12146 1 L
s
.1485 .99625 m
.1485 1 L
s
.17554 .99625 m
.17554 1 L
s
.20258 .99625 m
.20258 1 L
s
.25666 .99625 m
.25666 1 L
s
.28369 .99625 m
.28369 1 L
s
.31073 .99625 m
.31073 1 L
s
.33777 .99625 m
.33777 1 L
s
.39185 .99625 m
.39185 1 L
s
.41889 .99625 m
.41889 1 L
s
.44592 .99625 m
.44592 1 L
s
.47296 .99625 m
.47296 1 L
s
.52704 .99625 m
.52704 1 L
s
.55408 .99625 m
.55408 1 L
s
.58111 .99625 m
.58111 1 L
s
.60815 .99625 m
.60815 1 L
s
.66223 .99625 m
.66223 1 L
s
.68927 .99625 m
.68927 1 L
s
.71631 .99625 m
.71631 1 L
s
.74334 .99625 m
.74334 1 L
s
.79742 .99625 m
.79742 1 L
s
.82446 .99625 m
.82446 1 L
s
.8515 .99625 m
.8515 1 L
s
.87854 .99625 m
.87854 1 L
s
.06739 .99625 m
.06739 1 L
s
.04035 .99625 m
.04035 1 L
s
.01331 .99625 m
.01331 1 L
s
.93261 .99625 m
.93261 1 L
s
.95965 .99625 m
.95965 1 L
s
.98669 .99625 m
.98669 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .09443 m
1 .09443 L
s
.99375 .22962 m
1 .22962 L
s
.99375 .36481 m
1 .36481 L
s
.99375 .5 m
1 .5 L
s
.99375 .63519 m
1 .63519 L
s
.99375 .77038 m
1 .77038 L
s
.99375 .90557 m
1 .90557 L
s
.125 Mabswid
.99625 .12146 m
1 .12146 L
s
.99625 .1485 m
1 .1485 L
s
.99625 .17554 m
1 .17554 L
s
.99625 .20258 m
1 .20258 L
s
.99625 .25666 m
1 .25666 L
s
.99625 .28369 m
1 .28369 L
s
.99625 .31073 m
1 .31073 L
s
.99625 .33777 m
1 .33777 L
s
.99625 .39185 m
1 .39185 L
s
.99625 .41889 m
1 .41889 L
s
.99625 .44592 m
1 .44592 L
s
.99625 .47296 m
1 .47296 L
s
.99625 .52704 m
1 .52704 L
s
.99625 .55408 m
1 .55408 L
s
.99625 .58111 m
1 .58111 L
s
.99625 .60815 m
1 .60815 L
s
.99625 .66223 m
1 .66223 L
s
.99625 .68927 m
1 .68927 L
s
.99625 .71631 m
1 .71631 L
s
.99625 .74334 m
1 .74334 L
s
.99625 .79742 m
1 .79742 L
s
.99625 .82446 m
1 .82446 L
s
.99625 .8515 m
1 .8515 L
s
.99625 .87854 m
1 .87854 L
s
.99625 .06739 m
1 .06739 L
s
.99625 .04035 m
1 .04035 L
s
.99625 .01331 m
1 .01331 L
s
.99625 .93261 m
1 .93261 L
s
.99625 .95965 m
1 .95965 L
s
.99625 .98669 m
1 .98669 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
66.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 .5 m
.5 .5 .02704 0 365.72958 arc
F
.0001 w
.09443 .09443 m
.04742 .04742 L
s
% Start of user PostScript
-1.5 -1.5 -1.67384 -1.67384 MAarrowhead1
% End of user PostScript
.09443 .2103 m
.03893 .17066 L
s
% Start of user PostScript
-1.5 -1.07143 -1.70527 -1.21805 MAarrowhead1
% End of user PostScript
.09443 .32618 m
.03005 .29859 L
s
% Start of user PostScript
-1.5 -0.642857 -1.7381 -0.744902 MAarrowhead1
% End of user PostScript
.09443 .44206 m
.02381 .43197 L
s
% Start of user PostScript
-1.5 -0.214286 -1.76117 -0.251596 MAarrowhead1
% End of user PostScript
.09443 .55794 m
.02381 .56803 L
s
% Start of user PostScript
-1.5 0.214286 -1.76117 0.251596 MAarrowhead1
% End of user PostScript
.09443 .67382 m
.03005 .70141 L
s
% Start of user PostScript
-1.5 0.642857 -1.7381 0.744902 MAarrowhead1
% End of user PostScript
.09443 .7897 m
.03893 .82934 L
s
% Start of user PostScript
-1.5 1.07143 -1.70527 1.21805 MAarrowhead1
% End of user PostScript
.09443 .90557 m
.04742 .95258 L
s
% Start of user PostScript
-1.5 1.5 -1.67384 1.67384 MAarrowhead1
% End of user PostScript
.2103 .09443 m
.17066 .03893 L
s
% Start of user PostScript
-1.07143 -1.5 -1.21805 -1.70527 MAarrowhead1
% End of user PostScript
.2103 .2103 m
.15986 .15986 L
s
% Start of user PostScript
-1.07143 -1.07143 -1.25798 -1.25798 MAarrowhead1
% End of user PostScript
.2103 .32618 m
.14568 .28741 L
s
% Start of user PostScript
-1.07143 -0.642857 -1.31044 -0.786265 MAarrowhead1
% End of user PostScript
.2103 .44206 m
.13304 .42661 L
s
% Start of user PostScript
-1.07143 -0.214286 -1.35718 -0.271436 MAarrowhead1
% End of user PostScript
.2103 .55794 m
.13304 .57339 L
s
% Start of user PostScript
-1.07143 0.214286 -1.35718 0.271436 MAarrowhead1
% End of user PostScript
.2103 .67382 m
.14568 .71259 L
s
% Start of user PostScript
-1.07143 0.642857 -1.31044 0.786265 MAarrowhead1
% End of user PostScript
.2103 .7897 m
.15986 .84014 L
s
% Start of user PostScript
-1.07143 1.07143 -1.25798 1.25798 MAarrowhead1
% End of user PostScript
.2103 .90557 m
.17066 .96107 L
s
% Start of user PostScript
-1.07143 1.5 -1.21805 1.70527 MAarrowhead1
% End of user PostScript
.32618 .09443 m
.29859 .03005 L
s
% Start of user PostScript
-0.642857 -1.5 -0.744902 -1.7381 MAarrowhead1
% End of user PostScript
.32618 .2103 m
.28741 .14568 L
s
% Start of user PostScript
-0.642857 -1.07143 -0.786265 -1.31044 MAarrowhead1
% End of user PostScript
.32618 .32618 m
.26653 .26653 L
s
% Start of user PostScript
-0.642857 -0.642857 -0.863487 -0.863487 MAarrowhead1
% End of user PostScript
.32618 .44206 m
.23574 .41191 L
s
% Start of user PostScript
-0.642857 -0.214286 -0.977361 -0.325787 MAarrowhead1
% End of user PostScript
.32618 .55794 m
.23574 .58809 L
s
% Start of user PostScript
-0.642857 0.214286 -0.977361 0.325787 MAarrowhead1
% End of user PostScript
.32618 .67382 m
.26653 .73347 L
s
% Start of user PostScript
-0.642857 0.642857 -0.863487 0.863487 MAarrowhead1
% End of user PostScript
.32618 .7897 m
.28741 .85432 L
s
% Start of user PostScript
-0.642857 1.07143 -0.786265 1.31044 MAarrowhead1
% End of user PostScript
.32618 .90557 m
.29859 .96995 L
s
% Start of user PostScript
-0.642857 1.5 -0.744902 1.7381 MAarrowhead1
% End of user PostScript
.44206 .09443 m
.43197 .02381 L
s
% Start of user PostScript
-0.214286 -1.5 -0.251596 -1.76117 MAarrowhead1
% End of user PostScript
.44206 .2103 m
.42661 .13304 L
s
% Start of user PostScript
-0.214286 -1.07143 -0.271436 -1.35718 MAarrowhead1
% End of user PostScript
.44206 .32618 m
.41191 .23574 L
s
% Start of user PostScript
-0.214286 -0.642857 -0.325787 -0.977361 MAarrowhead1
% End of user PostScript
.44206 .44206 m
.34647 .34647 L
s
% Start of user PostScript
-0.214286 -0.214286 -0.567839 -0.567839 MAarrowhead1
% End of user PostScript
.44206 .55794 m
.34647 .65353 L
s
% Start of user PostScript
-0.214286 0.214286 -0.567839 0.567839 MAarrowhead1
% End of user PostScript
.44206 .67382 m
.41191 .76426 L
s
% Start of user PostScript
-0.214286 0.642857 -0.325787 0.977361 MAarrowhead1
% End of user PostScript
.44206 .7897 m
.42661 .86696 L
s
% Start of user PostScript
-0.214286 1.07143 -0.271436 1.35718 MAarrowhead1
% End of user PostScript
.44206 .90557 m
.43197 .97619 L
s
% Start of user PostScript
-0.214286 1.5 -0.251596 1.76117 MAarrowhead1
% End of user PostScript
.55794 .09443 m
.56803 .02381 L
s
% Start of user PostScript
0.214286 -1.5 0.251596 -1.76117 MAarrowhead1
% End of user PostScript
.55794 .2103 m
.57339 .13304 L
s
% Start of user PostScript
0.214286 -1.07143 0.271436 -1.35718 MAarrowhead1
% End of user PostScript
.55794 .32618 m
.58809 .23574 L
s
% Start of user PostScript
0.214286 -0.642857 0.325787 -0.977361 MAarrowhead1
% End of user PostScript
.55794 .44206 m
.65353 .34647 L
s
% Start of user PostScript
0.214286 -0.214286 0.567839 -0.567839 MAarrowhead1
% End of user PostScript
.55794 .55794 m
.65353 .65353 L
s
% Start of user PostScript
0.214286 0.214286 0.567839 0.567839 MAarrowhead1
% End of user PostScript
.55794 .67382 m
.58809 .76426 L
s
% Start of user PostScript
0.214286 0.642857 0.325787 0.977361 MAarrowhead1
% End of user PostScript
.55794 .7897 m
.57339 .86696 L
s
% Start of user PostScript
0.214286 1.07143 0.271436 1.35718 MAarrowhead1
% End of user PostScript
.55794 .90557 m
.56803 .97619 L
s
% Start of user PostScript
0.214286 1.5 0.251596 1.76117 MAarrowhead1
% End of user PostScript
.67382 .09443 m
.70141 .03005 L
s
% Start of user PostScript
0.642857 -1.5 0.744902 -1.7381 MAarrowhead1
% End of user PostScript
.67382 .2103 m
.71259 .14568 L
s
% Start of user PostScript
0.642857 -1.07143 0.786265 -1.31044 MAarrowhead1
% End of user PostScript
.67382 .32618 m
.73347 .26653 L
s
% Start of user PostScript
0.642857 -0.642857 0.863487 -0.863487 MAarrowhead1
% End of user PostScript
.67382 .44206 m
.76426 .41191 L
s
% Start of user PostScript
0.642857 -0.214286 0.977361 -0.325787 MAarrowhead1
% End of user PostScript
.67382 .55794 m
.76426 .58809 L
s
% Start of user PostScript
0.642857 0.214286 0.977361 0.325787 MAarrowhead1
% End of user PostScript
.67382 .67382 m
.73347 .73347 L
s
% Start of user PostScript
0.642857 0.642857 0.863487 0.863487 MAarrowhead1
% End of user PostScript
.67382 .7897 m
.71259 .85432 L
s
% Start of user PostScript
0.642857 1.07143 0.786265 1.31044 MAarrowhead1
% End of user PostScript
.67382 .90557 m
.70141 .96995 L
s
% Start of user PostScript
0.642857 1.5 0.744902 1.7381 MAarrowhead1
% End of user PostScript
.7897 .09443 m
.82934 .03893 L
s
% Start of user PostScript
1.07143 -1.5 1.21805 -1.70527 MAarrowhead1
% End of user PostScript
.7897 .2103 m
.84014 .15986 L
s
% Start of user PostScript
1.07143 -1.07143 1.25798 -1.25798 MAarrowhead1
% End of user PostScript
.7897 .32618 m
.85432 .28741 L
s
% Start of user PostScript
1.07143 -0.642857 1.31044 -0.786265 MAarrowhead1
% End of user PostScript
.7897 .44206 m
.86696 .42661 L
s
% Start of user PostScript
1.07143 -0.214286 1.35718 -0.271436 MAarrowhead1
% End of user PostScript
.7897 .55794 m
.86696 .57339 L
s
% Start of user PostScript
1.07143 0.214286 1.35718 0.271436 MAarrowhead1
% End of user PostScript
.7897 .67382 m
.85432 .71259 L
s
% Start of user PostScript
1.07143 0.642857 1.31044 0.786265 MAarrowhead1
% End of user PostScript
.7897 .7897 m
.84014 .84014 L
s
% Start of user PostScript
1.07143 1.07143 1.25798 1.25798 MAarrowhead1
% End of user PostScript
.7897 .90557 m
.82934 .96107 L
s
% Start of user PostScript
1.07143 1.5 1.21805 1.70527 MAarrowhead1
% End of user PostScript
.90557 .09443 m
.95258 .04742 L
s
% Start of user PostScript
1.5 -1.5 1.67384 -1.67384 MAarrowhead1
% End of user PostScript
.90557 .2103 m
.96107 .17066 L
s
% Start of user PostScript
1.5 -1.07143 1.70527 -1.21805 MAarrowhead1
% End of user PostScript
.90557 .32618 m
.96995 .29859 L
s
% Start of user PostScript
1.5 -0.642857 1.7381 -0.744902 MAarrowhead1
% End of user PostScript
.90557 .44206 m
.97619 .43197 L
s
% Start of user PostScript
1.5 -0.214286 1.76117 -0.251596 MAarrowhead1
% End of user PostScript
.90557 .55794 m
.97619 .56803 L
s
% Start of user PostScript
1.5 0.214286 1.76117 0.251596 MAarrowhead1
% End of user PostScript
.90557 .67382 m
.96995 .70141 L
s
% Start of user PostScript
1.5 0.642857 1.7381 0.744902 MAarrowhead1
% End of user PostScript
.90557 .7897 m
.96107 .82934 L
s
% Start of user PostScript
1.5 1.07143 1.70527 1.21805 MAarrowhead1
% End of user PostScript
.90557 .90557 m
.95258 .95258 L
s
% Start of user PostScript
1.5 1.5 1.67384 1.67384 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.011338 0.97619 0.464853 MathSubStart
%% ContourGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.192308 0.5 0.192308 [
[.11538 -0.0125 -7 -12 ]
[.11538 -0.0125 7 0 ]
[.30769 -0.0125 -7 -12 ]
[.30769 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.69231 -0.0125 -4 -12 ]
[.69231 -0.0125 4 0 ]
[.88462 -0.0125 -4 -12 ]
[.88462 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4 -24 ]
[.5 -0.0125 4 -12 ]
[-0.0125 .11538 -14 -6 ]
[-0.0125 .11538 0 6 ]
[-0.0125 .30769 -14 -6 ]
[-0.0125 .30769 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .69231 -8 -6 ]
[-0.0125 .69231 0 6 ]
[-0.0125 .88462 -8 -6 ]
[-0.0125 .88462 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -26 -4 ]
[-0.01875 .5 -14 4 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.30769 0 m
.30769 .00625 L
s
gsave
.30769 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.69231 0 m
.69231 .00625 L
s
gsave
.69231 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .11538 m
.00625 .11538 L
s
gsave
-0.0125 .11538 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .30769 m
.00625 .30769 L
s
gsave
-0.0125 .30769 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .69231 m
.00625 .69231 L
s
gsave
-0.0125 .69231 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .88462 m
.00625 .88462 L
s
gsave
-0.0125 .88462 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .15385 m
.00375 .15385 L
s
0 .19231 m
.00375 .19231 L
s
0 .23077 m
.00375 .23077 L
s
0 .26923 m
.00375 .26923 L
s
0 .34615 m
.00375 .34615 L
s
0 .38462 m
.00375 .38462 L
s
0 .42308 m
.00375 .42308 L
s
0 .46154 m
.00375 .46154 L
s
0 .53846 m
.00375 .53846 L
s
0 .57692 m
.00375 .57692 L
s
0 .61538 m
.00375 .61538 L
s
0 .65385 m
.00375 .65385 L
s
0 .73077 m
.00375 .73077 L
s
0 .76923 m
.00375 .76923 L
s
0 .80769 m
.00375 .80769 L
s
0 .84615 m
.00375 .84615 L
s
0 .07692 m
.00375 .07692 L
s
0 .03846 m
.00375 .03846 L
s
0 .92308 m
.00375 .92308 L
s
0 .96154 m
.00375 .96154 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -85 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
65 10 translate
90 rotate
-65 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .15385 m
1 .15385 L
s
.99625 .19231 m
1 .19231 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .26923 m
1 .26923 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .38462 m
1 .38462 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .46154 m
1 .46154 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .57692 m
1 .57692 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .65385 m
1 .65385 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .76923 m
1 .76923 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .84615 m
1 .84615 L
s
.99625 .07692 m
1 .07692 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .92308 m
1 .92308 L
s
.99625 .96154 m
1 .96154 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.4747 .35716 m
.5253 .35716 L
.57296 .37348 L
.57591 .37529 L
.62471 .42409 L
.62652 .42704 L
.64284 .4747 L
.64284 .5253 L
.62652 .57296 L
.62471 .57591 L
.57591 .62471 L
.57296 .62652 L
.5253 .64284 L
.4747 .64284 L
.42704 .62652 L
.42409 .62471 L
.37529 .57591 L
.37348 .57296 L
.35716 .5253 L
.35716 .4747 L
.37348 .42704 L
.37529 .42409 L
.42409 .37529 L
.42704 .37348 L
.4747 .35716 L
s
.42409 .35388 m
.4747 .33748 L
.5253 .33748 L
.57591 .35388 L
.60655 .37348 L
.62652 .39345 L
.64612 .42409 L
.66252 .4747 L
.66252 .5253 L
.64612 .57591 L
.62652 .60655 L
.60655 .62652 L
.57591 .64612 L
.5253 .66252 L
.4747 .66252 L
.42409 .64612 L
.39345 .62652 L
.37348 .60655 L
.35388 .57591 L
.33748 .5253 L
.33748 .4747 L
.35388 .42409 L
.37348 .39345 L
.39345 .37348 L
.42409 .35388 L
s
.4747 .31222 m
.5253 .31222 L
.56814 .32287 L
.57591 .3261 L
.62652 .3586 L
.6414 .37348 L
.6739 .42409 L
.67713 .43186 L
.68778 .4747 L
.68778 .5253 L
.67713 .56814 L
.6739 .57591 L
.6414 .62652 L
.62652 .6414 L
.57591 .6739 L
.56814 .67713 L
.5253 .68778 L
.4747 .68778 L
.43186 .67713 L
.42409 .6739 L
.37348 .6414 L
.3586 .62652 L
.3261 .57591 L
.32287 .56814 L
.31222 .5253 L
.31222 .4747 L
.32287 .43186 L
.3261 .42409 L
.3586 .37348 L
.37348 .3586 L
.42409 .3261 L
.43186 .32287 L
.4747 .31222 L
s
.37348 .3161 m
.42409 .29025 L
.4747 .27829 L
.5253 .27829 L
.57591 .29025 L
.62652 .3161 L
.63599 .32287 L
.67713 .36401 L
.6839 .37348 L
.70975 .42409 L
.72171 .4747 L
.72171 .5253 L
.70975 .57591 L
.6839 .62652 L
.67713 .63599 L
.63599 .67713 L
.62652 .6839 L
.57591 .70975 L
.5253 .72171 L
.4747 .72171 L
.42409 .70975 L
.37348 .6839 L
.36401 .67713 L
.32287 .63599 L
.3161 .62652 L
.29025 .57591 L
.27829 .5253 L
.27829 .4747 L
.29025 .42409 L
.3161 .37348 L
.32287 .36401 L
.36401 .32287 L
.37348 .3161 L
s
.37348 .26035 m
.42409 .23993 L
.4747 .23022 L
.5253 .23022 L
.57591 .23993 L
.62652 .26035 L
.64722 .27227 L
.67713 .29485 L
.70515 .32287 L
.72773 .35278 L
.73965 .37348 L
.76007 .42409 L
.76978 .4747 L
.76978 .5253 L
.76007 .57591 L
.73965 .62652 L
.72773 .64722 L
.70515 .67713 L
.67713 .70515 L
.64722 .72773 L
.62652 .73965 L
.57591 .76007 L
.5253 .76978 L
.4747 .76978 L
.42409 .76007 L
.37348 .73965 L
.35278 .72773 L
.32287 .70515 L
.29485 .67713 L
.27227 .64722 L
.26035 .62652 L
.23993 .57591 L
.23022 .5253 L
.23022 .4747 L
.23993 .42409 L
.26035 .37348 L
.27227 .35278 L
.29485 .32287 L
.32287 .29485 L
.35278 .27227 L
.37348 .26035 L
s
.42409 .16362 m
.4747 .15613 L
.5253 .15613 L
.57591 .16362 L
.6059 .17105 L
.62652 .1792 L
.67713 .20413 L
.70369 .22166 L
.72773 .24102 L
.75898 .27227 L
.77834 .29631 L
.79587 .32287 L
.8208 .37348 L
.82895 .3941 L
.83638 .42409 L
.84387 .4747 L
.84387 .5253 L
.83638 .57591 L
.82895 .6059 L
.8208 .62652 L
.79587 .67713 L
.77834 .70369 L
.75898 .72773 L
.72773 .75898 L
.70369 .77834 L
.67713 .79587 L
.62652 .8208 L
.6059 .82895 L
.57591 .83638 L
.5253 .84387 L
.4747 .84387 L
.42409 .83638 L
.3941 .82895 L
.37348 .8208 L
.32287 .79587 L
.29631 .77834 L
.27227 .75898 L
.24102 .72773 L
.22166 .70369 L
.20413 .67713 L
.1792 .62652 L
.17105 .6059 L
.16362 .57591 L
.15613 .5253 L
.15613 .4747 L
.16362 .42409 L
.17105 .3941 L
.1792 .37348 L
.20413 .32287 L
.22166 .29631 L
Mistroke
.24102 .27227 L
.27227 .24102 L
.29631 .22166 L
.32287 .20413 L
.37348 .1792 L
.3941 .17105 L
.42409 .16362 L
Mfstroke
.32287 .06039 m
.37348 .04321 L
.42409 .03213 L
.4747 .0267 L
.5253 .0267 L
.57591 .03213 L
.62652 .04321 L
.67713 .06039 L
.69909 .06984 L
.72773 .08438 L
.77834 .11641 L
.78383 .12045 L
.82895 .15881 L
.84119 .17105 L
.87955 .21617 L
.88359 .22166 L
.91562 .27227 L
.93016 .30091 L
.93961 .32287 L
.95679 .37348 L
.96787 .42409 L
.9733 .4747 L
.9733 .5253 L
.96787 .57591 L
.95679 .62652 L
.93961 .67713 L
.93016 .69909 L
.91562 .72773 L
.88359 .77834 L
.87955 .78383 L
.84119 .82895 L
.82895 .84119 L
.78383 .87955 L
.77834 .88359 L
.72773 .91562 L
.69909 .93016 L
.67713 .93961 L
.62652 .95679 L
.57591 .96787 L
.5253 .9733 L
.4747 .9733 L
.42409 .96787 L
.37348 .95679 L
.32287 .93961 L
.30091 .93016 L
.27227 .91562 L
.22166 .88359 L
.21617 .87955 L
.17105 .84119 L
.15881 .82895 L
Mistroke
.12045 .78383 L
.11641 .77834 L
.08438 .72773 L
.06984 .69909 L
.06039 .67713 L
.04321 .62652 L
.03213 .57591 L
.0267 .5253 L
.0267 .4747 L
.03213 .42409 L
.04321 .37348 L
.06039 .32287 L
.06984 .30091 L
.08438 .27227 L
.11641 .22166 L
.12045 .21617 L
.15881 .17105 L
.17105 .15881 L
.21617 .12045 L
.22166 .11641 L
.27227 .08438 L
.30091 .06984 L
.32287 .06039 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{271, 129},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005C0000XP800@400oooE?l00?ooE?l00?ooE?l0
0?ooE?l00?ooE?l00?ooE?l00?ooE?l00?ooE?l006Co00<`0:?o00<`04Ko001Uo`03?02So`03?015
o`00IOl00c`0Xol00c`0AOl006Co00<`0:?o00<`04Ko003ooeCo003ooeCo003ooeCo003ooeCo003o
oeCo003ooeCo003ooeCo003ooeCo000eo`D31L<8o`03000;o`04?005``Oo00<l00Wo00@l00G32Ol0
0`002Ol50`G3Aol00`004ol00`004_l00c`04_l00`004ol00`006_l003Ko00@o00Ol1ol00c`02Ol0
0c001Ol00c`01Ol00c002Ol00c001Ol00c`02Ol00c`02Ol013l01oa5o`03?00Do`03?00@o`03<00D
o`03?00Bo`03?00Jo`00<?l00`001o`5``03o005`0G?00Cl00D?1/l00c`01_l00c002Ol013<01_0:
o`03?009o`03?006l4?o00<000Kc3Ol00`001_<?o`03<00Do`03?00Co`03?00Io`00=_l00c`01_<9
o`03?009o`03<007o0Ko00<`00Wo00<`00Ol2_l00c`02Ol00c`01_=7o`03<00Do`03?00@o`03<00D
o`03?00Bo`03<00Jo`00=Ol01@o01L08o`03300;o`04?`05`0Oo00<l00Wo00@o00G02Ol00``02Ol0
1@o01L18o`03300Bo`03300Bo`03?00Bo`03300Do`03300Io`00oomDo`00oomDo`00oomDo`00oomD
o`00oomDo`00;?md03;oM00=o`00;?l00``0Kol00``0<Ol00c`0L?l00c`02ol002co00<l02oo00<l
00co00<l02oo00<l033o00<l073o00<l00_o000/o`03?00Oo`03300<o`03300=o`03?00<o`03300P
o`03?00`o`03?00]oa@0;ol00c`02ol002co00<<017o00<l00_o00<<00co00<000co00<<00co00<<
00go00<l013o00<<037o00<l02So1@0Do`D0:Ol00``03?l002co00<l00Ol2_l00``03?l00``02ol0
0``03Ol00c`02ol00``02ol00`003?l010l01o`_o`03?00Uo`03000Mo`03000Xo`03?00;o`00;?l0
1Co01L0:o`03300=o`03?00;o`03?00<o`03?00;o`03?00;o`03000;o`030005o`03?00`o`03?00R
o`03000So`04000To`03?00;o`00;?l01@o01L0<o`03?00;o`03?00;o`03?00<o`03?00;o`03?00;
o`03?00;o`053l06l33o00<l023o00<<02So00<002;o00<l00_o000Oo`D31L<7o0Go00<l00_o00<l
00[o00<l00_o00<l00_o00<l00_o00<l00_o00<l00_o00<l00Ko00<l033o00<l01ko00<002co00<0
01oo00<<00co000Po`04?`07o0G?1_l00c`02_l00c`02ol00c`02ol00c`02_l00c`02ol00c`02ol0
0c`02_l00c`01ol00c`0<?l00c`07?l00``0<Ol00c`07Ol00c`02ol001[o00<000Ol1L<01O`02Ol0
0c`02_l00c`02_l00c`02ol00c`02_l00c`02_l00c`02ol00c`02_l00c`01ol00``0:_l010<01o`J
o`03?00co`03300Lo`03?00;o`008?l00c`01_<7o6oo00<l02Wo00@o00Ol6?l00``0=ol00``06_l0
0c`02ol001oo00D?`0G01oa_o`03?00To`030007o0Kc5ol00c`0>_l00c`06?l00c`02ol002co00<<
06oo00<<02[o00Dc`0K`5Ol00``0?Ol00``05_l00``03?l002co00<l073o00<l02[o00<<00Ol5?l0
0c`0@?l00c`05Ol00c`02ol002co00<l02ko00<l00ko00<l02ko00<l033o00<l01Co00<l04;o00<l
01Co00<l00_o000/o`03?00No`03?00=o`03300=o`03300>o`03?00No`03?00`o`03?00Co`03?014
o`03?00Co`03?00;o`00;?l00``07_l00``03Ol00``03Ol00``03Ol00``07_l00``0<Ol00c`04Ol0
0``07ol7027o00<l017o00<<00co000/o`03?00?o`03300<o`03000>o`03?00<o`03?00<o`03300<
o`03300Ao`03?00`o`03?00@o`03300Jo`H01ol601co00<l017o00<l00_o000/o`03?006l0[o00<<
00go00<l00co00<l00co00<l00co00<l00_o00<000co00<<00Ol;ol00c`03ol00c`06?l00`004ol0
10006Ol00c`04?l00c`02ol002co00@?00G02_l00`003Ol00c`03?l00c`03?l00c`03?l00c`02ol0
0``02ol010<01_0`o`03?00>o`03?00Fo`03000Jo`03300Go`03?00?o`03?00;o`00;?l013l01_0<
o`03?00;o`03?00;o`03?00<o`03?00;o`03?00;o`03?00;o`030005o`03?00`o`03?00>o`03?00D
o`03300No`03300Fo`03?00>o`03?00;o`00;?l00c`01Ol00``03?l00c`02_l00c`02ol00c`02ol0
0c`02ol00c`02ol00c`02ol00c`01_l00c`0<?l00c`03Ol00c`04ol00``08_l00``05Ol00c`03?l0
0``03?l002Go00D3`0K`1_l00c`02ol00c`02_l00c`02ol00c`02_l00c`02ol00c`02_l00c`02ol0
0c`01_l00``0<Ol00c`03?l00c`04ol00c`09Ol00``05?l00c`03?l00c`02ol002Ko00<l00Ol1ol0
0c`02_l00c`02_l00c`02ol00c`02_l00c`02_l00c`02ol00c`02_l00c`02?l00c`0<?l00c`02ol0
0c`04_l00``0:Ol00``04ol00c`02ol00c`02ol0023o00<000Ol1_=_o`03?00`o`03?00:o`03?00B
o`03?00/o`03?00Ao`03?00;o`03?00;o`009_l013l01_1^o`03300ao`03?00:o`03?00Ao`03?00@
o``04_l00c`04Ol00c`02Ol00``03?l002Go00@?00Ol:ol00``04Ol00``0;Ol00c`0<?l00c`02Ol0
0c`04?l00``03_l010003?l010003ol00c`04Ol00c`02Ol00c`02ol002co00<l02co00<0013o00<<
02ko00<l033o00<l00So00<l013o00<l00go00<<01?o00<<00go00<l013o00<l00Wo00<l00_o000/
o`03300/o`03000@o`03300]o`03300ao`03?008o`03?00?o`03?00;o`03000Ho`03000<o`03?00@
o`03?008o`03?00;o`00;?l00c`07?l00c`03_l00c`03ol00c`03ol00c`07?l00c`0<?l00c`01ol0
0c`03ol00c`02_l00``07Ol00c`02_l00c`04?l00c`01_l00``03?l002co00<l01co00<000oo00<l
00ko00<l00go00<001ko00<l033o00<l00Oo00<l00ko00<<00[o00<l00_o1`0=o`03300:o`03?00?
o`03?007o`03?00;o`00;?l00``03_l00c`02ol00`003ol00c`03_l00c`03Ol00``03Ol00c`03Ol0
0``0:_l010<01o`5o`03?00?o`03?009o`03?008o`D01_l010002ol00c`02Ol00c`03ol00c`01_l0
0c`02ol002co00<l00ko00<000ko00<l00co00<l00go00<l00go00<l00co00<0013o00<l02[o00<l
00Ol1Ol00c`03_l00c`02?l00``02?l00``03_l00`002Ol00``02Ol00c`03_l00c`01_l00c`02ol0
02co1Cl00``02_l00`003_l00c`03?l00c`03?l00c`03?l00c`03?l00`002ol00`001o`So`030007
o0Kc00?l00G?3Ol00c`02?l00c`01ol00``04ol00``01ol00c`02?l00``03ol00c`01Ol00c`02ol0
02co1Pl00``03?l00c`03?l00c`02ol00c`03?l00c`02ol00c`03?l00c`02ol010<01_0Zo`04?`06
l003o005c`co00<l00So00<l00Ko00<<00Oo1`09o`033006o`03?008o`03?00>o`05?l06l0_o000/
o`03?005o`03300;o`03300<o`03?00:o`03?00;o`03?00;o`03?00;o`03300:o`030007o`03?00Y
o`043`07o0Ol3Ol00c`01ol00c`01Ol00``01Ol010001ol010001ol00c`01Ol00c`02?l00c`03_l0
13l01o`:o`00;?l00c`01ol00``02ol00c`02_l00c`02ol00c`02_l00c`02_l00c`02ol00c`02_l0
0c`02?l00c`0<?l013l01o`<o`03?007o`033005o`063o001L0=o`033005o`03?005o`03?007o`03
300>o`04?`07o0[o000/o`03301_o`03300ao`03?007o0go00<l00Oo00@o00Ol1o`00o`02005o`04
3`07o003o005c`Ko00<l00go00@o00Ol2_l0023o00@l00G31o`To`03?00Po`03?00Uo`03?00`o`03
?007o0co00<l00Oo00@o00Ol1_001O002?l01@?01_06l`03o005c`Go00<l00ko00<l00K`2ol001oo
00<`00Go00<l00Kc9?l00`007_l00`009ol00c`0<?l00c`01o`<o`03?006o`04?`07o0Kc1L<00l00
1@000o`01L<6l`G?1o`6o`03?00=o`03?007o0[o000Jo`040`05c0K`00Gl02Oo00<<01go00<<02Ko
00<<037o00<l00Kc3?l00c`01ol00c`01o`5``G31L05o`040`06l0G?1L<7o0Go00<l00go00<l00Ol
2_l001oo00<`00Ol1o`Wo`03?00Jo`03?00Xo`03?00`o`03?006l`co00<l00Ko00<l00Ol1/l5?003
?00:o`03000:l0G?1o`5o`03?00=o`03?006l`[o000Po`04?`05`0Ol:?l00c`06?l00c`0:Ol00c`0
<?l00c`01_<;o`03?007o`03?007o003c006c`03?00>o``o1Ll6l`Go00<l00go00<l00Kc2_l002co
00<<02[o00<l01Ko00<l02Wo00<<037o00<l00Kc2ol00c`01_l00c`01o`00l`02Ll@oa0o1o`5o`03
?00<o`Do00<l00_o000/o`03?00[o`03?00Do`03?00[o`03?00`o`Po3?l00c`01_l00c`03_`00c`0
4ol7?`03?006l`Kc1Ol00c`03?l00c`01_<:o`00;?l00c`0;?l00c`04_l00c`0;?l00c`0<?l8?`_o
00<l00Ko00<l00Ol00G?00Kc5?l7?`Po1_<5o`03?00=o`Po2_l002co00<l01So00<001;o00<l013o
00<l00oo00@001[o00<l033o23l;o`03?006o`03?00:o004?00Io`03?00<?`Kc1Ol00c`03?l8?`[o
000/o`03300<o`040009o`D04?l00c`03_l00c`03_l500Wo00@000go00<<037o23l;o`03?006o`03
?00<l`03?00Io`04300:l`Kc1Ol00c`03?l7?0_o000/o`Dl00<l00Oo1P0<o`03000>o`03?00<o`03
?00<o`03000<o`D02_l00`001_<_o`Po2ol00c`01Ol00c`02_`013`07?l00c002o`5c`Go00<l00co
23l:o`00;?l5?`L02Ol010002ol00``03?l00c`02_l00c`02_l00`002ol010002Ol800Ol;ol013`0
3_l00c`01_l00c`02_`00c007Ol013`02_<6l`03o005c`_o23l:o`00;?l00``0Kol00``0<Ol013`0
3_l00c`01_l00c`02_`00c007_l00c002_<6l`03o005c`_o23l:o`00;?l00c`0L?l00c`0<?l013`0
3_l00c`01_l00c`02O<013`07_l00c002_<6l`Go00<l00_o1c`;o`00;?l00c`0L?l00c`0<?l013`0
3_l00c`01_l00c`02O<00c007ol013`02_<5c`Go00<l00co00@l00go000Vo`04?`06l3Co00@003Ko
00<<02_o00<l00Kl00<l00co00<l00Go00<l00[l00<`023o00<`00[c1Ll5o`03?00<o`04?00=o`00
3ol00c`01_<=o`04<`07o3?o1P0fo`03?00Io`03?006l`Oo00@c00Kl00<l00co00<l00Go00<l00[l
00<`023o00<`00[c1Ll5o`03?00<o`04?00=o`003ol60a3o00@c00Ol<_l703Ko00<l01Wo1P<:o`04
<`06o003?00<o`03?005o`03?00:o003<00Po`03<00:l`G?1Ol00c`03?l013`03Ol0017o00<<017o
00Dc`0K`<_l803Co00<<01co00<<00_o00Dc`0G`00<l00co00<l00Go00<l00[l00<`023o00<`00[c
1Ll5o`03?00<o`04<00=o`003ol00``05?l00c`01o`co`H0=_l00c`06Ol00``03_l00c`01_`00c`0
3?l00c`01Ol00c`02_`00c008?l00c002_<5c`Go00<l00co00@l00go000/o`03?00do`H0=_l00c`0
<?l013`03_l00c`01Ol00c`02_`00c008?l00c002_<5c`Go00<l00co00@l00go000/o`03300eo`04
000fo`03300ao`04?00>o`03?005o`03?00:o003<00Po`03<00:l`G?1Ol00c`03?l013`03Ol002co
00<l073o00<l033o00@l00ko00<l00Ko00<l00Wc00<`01oo00@l00Gc00<l00Ol1Ol00c`03?l01300
3Ol002co00<l073o00<l033o00@l00ko00<l00Ko00<l00Wc00@l01ko00<`00[c1_<00o`01Ll;o`Po
2_l002co00<<06oo00<<037o00@l00ko00<l00Ko00<l00[l00<`01ko00<`00[c1_<00o`01Ll;o`Po
2_l002co1C`700Go1P`00``02Ol00`003?l00``02ol00``02_l010002_l500G300?l00T01_<_o`Po
2ol00c`01Ol00c`02_`00c007Ol013`02_<5c`Go00<l00co23l:o`00;?l5?003?007o`D03?l00`00
3_l00c`03_l00c`03?l00`003?l500Wo00<000Kc;ol8?`_o00<l00Go00<l00[l00@l01co00<`00_l
1Ll5o`03?00<o`Po2_l002co00<<01Wo00@0013o00<l013o00<l00ko00@001[o00<<037o23l;o`03
?006o`03?00;l0G?6?l010`02_<6l`Go00<l00co1c`;o`00;?l00c`06?l00`004Ol00c`04_l00c`0
3_l010006_l00c`0<?l8?`_o00<l00Ko00<l00[l00@l01Wo00@l00Kc1Ll6l`Go00<l00co23l:o`00
;?l00c`0:ol00c`05?l00c`0:ol00c`0<?l8?`_o00<l00Ko00@o00[l00@l01Oo1cl8?`Kc1Ol00c`0
3?l00c`01_<:o`00;?l00``0:_l00c`05_l00c`0:Ol00``0<Ol8?`co00<l00Ko00<l00Ol00G?00Kc
4_l7?`03?006l`Kc1Ol00c`03?l00c`01_<:o`008?l013`01L<7o2So00<l01So00<l02Wo00<l033o
00<l00Kc2ol00c`01_l013l03_`00c`04Ol7?`03?006l`Kc1_l00c`03?l5?`03?00;o`007ol00c00
1Ol00c`01_<Wo`03?00Jo`03?00Xo`03?00`o`03?006l`co00<l00Ko00<l00Ol2<l00``03ol@?`Ol
1Ol00c`03Ol00c`01_<:o`007ol013<01_001O`09ol00``07Ol00``09_l00``0<Ol00c`01_<<o`03
?006o`04?`07o0[?00<<00Wo00<000K`1Ll5c`Kc1_l00c`03Ol00c`01_<:o`007ol00c001o`7o2Co
00<001ko00<<02Oo00<l033o00<l00Ol2ol00c`01ol013l01o`6c`05?l0:0003o005c`G?1Ll7o0Go
00<l00go00<l00Ol2_l0023o00@o00G01o`To`03300No`03000Wo`03?00`o`03?007o0co00<l00Ko
00<l00Go00<l00K`1L0;o`040`06l0Kc1o`6o`03?00=o`03?007o0[o000/o`03301_o`03300ao`03
?007o0co00<l00Oo00<l00Go00<l00Ol00G`00Ko00<000Go00<l00Ol00?l00G?1Ol00c`03_l00c`0
1_0;o`00;?l00c`0L?l00c`0:Ol010<01o`7o0co00<l00Oo00<l00Go00@o00K`00?l00L01_l010l0
1o`00o`01Ll6o`03?00=o`04?`07o0[o000/o`03?007o`03300;o`03?00:o`03?00;o`03?00:o`03
?00:o`03300;o`03?00:o`033008o`03?00Zo`03?007o0Ol3?l00c`02?l00c`01Ol01Co01_0;o`03
0006o`03?005o`03?007o`03?00>o`04?`07o0[o000/o`06?o001L0;o`03300;o`03?00;o`03?00;
o`03?00<o`03?00:o`03300;o`033006o`03?00Zo`03?007o0Ol3Ol00c`02?l00c`01Ol00c`01Ol=
00Oo00<<00Ko00<l00So00<l00go00<l00Go00<l00_o000/o`H?00<l00_o00<<00co00<l00co00<l
00co00<l00co00<l00_o00<<00_o00<000Ll:_l013l01_000o`01Ll=o`03?008o`03?005o`03300F
o`033007o`03?008o`03?00>o`05?l06l0_o000/o`Do00<<00[o00<<00go00<l00go00<l00co00<l
00go00<l00co00<<00[o00<000Ol:?l010l01o`00o`01Ll=o`03?009o`03?006o`03300Bo`033008
o`03?008o`03?00?o`03?005o`03?00;o`00;?l00c`03_l00`003Ol00c`03Ol00c`03Ol00c`03_l0
0c`02ol00`004?l00c`0<?l00c`01_l00c`03_l00c`02Ol00c`01ol010003?l00`002_l00c`02Ol0
0c`03_l00c`01_l00c`02ol002co00<<01co00<000oo00<l00ko00<l00go00<001go00<<037o00<l
00Ko00<l00oo00<l00Wo00<l00[o300;o`03300:o`03?00?o`03?006o`03?00;o`00;?l00c`07?l0
0`003ol00c`03_l00c`03Ol00`007_l00c`0<?l00c`01ol00c`03ol00c`02Ol00``07ol00c`02_l0
0c`03ol00c`01_l00``03?l002co00<l01co00<l00ko00<l00oo00<l00oo00<l01co00<l033o00<l
00Oo00<l013o00<l00[o00<<01_o00<<00_o00<l00oo00<l00So00<l00_o000Uo`050l06l2_o00<0
013o00<<02go00<<037o00<l00So00<l013o00<l00_o00<<01Oo00<<00co00<l013o00<l00So00<l
00_o000Vo`03?007o2_o00<<013o00<<02ko00<l033o00<l00Wo00<l013o00<l00co00<001;o00<0
00ko00<l013o00<l00Wo00<l00_o000Vo`03?007o2_o00<<017o00<<02go00<l033o00<l00Wo00<l
013o00<<00oo00@000Wo1@0@o`03?00@o`03?00:o`03?00;o`009_l013l01_1^o`03300ao`03?00:
o`03?00Ao`03?00Ao`T05?l00c`04Ol00c`02Ol00``03?l002Go00@?00OlKol00c`0<?l00c`02_l0
0``04_l00``0:ol00``04_l00c`02ol00c`02ol002co00<l00So00<l00[o00<l00[o00<l00_o00<l
00[o00<l00[o00<l00_o00<l00[o00<l00So00<l033o00<l00_o00<l01?o00<l02So00<l01;o00<l
00co00<l00_o000/o`033006o`03300;o`03?00;o`03?00;o`03?00:o`03?00;o`03?00;o`03?00:
o`03?006o`03300ao`03?00<o`03?00Co`03300Uo`03300Do`03?00<o`03?00;o`00;?l00c`01Ol0
0c`02ol00c`02ol00c`02ol00c`02ol00c`02ol00c`03?l00c`02_l00``01_l00c`0<?l00c`03Ol0
0c`05?l00``08Ol00``05Ol00c`03?l00``03?l002co00@o00K`2ol00c`03?l00c`02ol00c`03?l0
0c`02ol00c`03?l00c`02ol010l01o`_o`03?00>o`03?00Eo`03300Mo`03300Fo`03?00>o`03?00;
o`00;?l010l01L0:o`03300=o`03?00<o`03?00<o`03?00<o`03?00<o`03300:o`040`06l33o00<l
00oo00<l01Ko00<<01So00<001So00<l00oo00<l00_o000/o`03?006l`[o00<<00co00<<00go00<l
00co00<l00co00<<00_o00<000go00<l00Kc;ol00c`03ol00``06?l5013o00@001[o00<l013o00<l
00_o000/o`03?00?o`03300<o`03000>o`03?00<o`03?00<o`03300=o`03?00@o`03?00`o`03?00A
o`03?00Joa407Ol00c`04Ol00c`02ol002co00<<01ko00<<00go00<<00go00<<00go00<<01ko00<<
037o00<l01;o00<l04Ko00<l017o00<<00co000/o`03?00No`03?00=o`03300=o`03300>o`03?00N
o`03?00Yo`040`07o1;o00<l04Co00<l01?o00<l00_o000/o`03?00^o`03?00>o`03?00^o`03?00Y
o`04?`07o1?o00<l047o00<<01Go00<l00_o000/o`03301_o`03300[o`03?007o1Co00<<03oo00<l
01Ko00<l00_o000Oo`D31L<7o6oo00<l02Wo00Dc`0K`5Ol00``0?Ol00c`05_l00``03?l0023o00@o
00Ol1Lm_o`03?00Zo`033007o1Oo00<l03Wo00<<01Wo00<l00_o000Po`03?006l005o009o`03?00:
o`03?00:o`03?00;o`03?00:o`03?00:o`03?00;o`03?00:o`03?007o`03300ao`03?00Io`03300g
o`03?00Jo`03?00;o`008?l00c`01_<7o0Ko00<l00_o00<l00[o00<l00_o00<l00[o00<l00_o00<l
00[o00<l00_o00<l00Oo00<l033o00<l01_o00<<03?o00<<01co00<l00_o000Oo`053l05`0Ol1Ol0
0c`02ol00c`02ol00c`02ol00c`02_l00c`02ol00c`02ol00c`02ol00c`01_l00c`0<?l00c`07?l0
0`00<?l00``07Ol00``03?l002co00<<00Go00<l00_o00<l00_o00<l00_o00<l00_o00<l00_o00<l
00co00<l00_o00Do`0K`<?l00c`07ol00``0:ol00``08?l00c`02ol002co00@o00K`3?l00c`02ol0
0c`02ol00c`03?l00c`02ol00c`02ol00c`02ol00`001Ol00c`0<?l00c`08Ol00``09ol00``08_l0
0c`02ol002co00Do`0G02_l00``03?l00``03?l00c`03?l00c`02ol00``02ol00`002ol00`001Ol0
0c`0<?l00c`08ol00`008_l00`009Ol00c`02ol002co00<l00Ol2_l00``03?l00``02ol00`003?l0
0``03?l00``03?l00``03?l00c`01o`_o`03?00Vo`03000Ko`04000Xo`03?00;o`00;?l00``04Ol0
0c`02ol00``03?l00``03?l00``03Ol00c`03?l00c`04?l00``0<Ol00c`0:Ol501;o00@002_o00<<
00co000/o`03?00Oo`03300=o`03?00<o`03?00<o`03300Po`03?00`o`03?00^oa80<?l00c`02ol0
02co00<l073o00<l033o00<l073o00<l00_o000/o`03301_o`03300ao`03?01`o`03?00;o`00;?md
03;oM00=o`00oomDo`00oomDo`00oomDo`00oomDo`00I?l00c00Xol00``0A_l006Co00<<0:?o00<`
04Ko001Uo`03?02Ro`03<016o`00I?l00``0Xol00``0A_l00?oo2ol00c`0A_l00?ooE?l00?ooE?l0
0?ooE?l00?ooE?l00?ooE?l00?ooE?l00?ooE?l00?ooE?l00001\
\>"],
  ImageRangeCache->{{{0, 337.75}, {160.25, 0}} -> {-2.600953, -2.58464, 
  0.019195, 0.019195}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Point Charge and Plane"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(case1 = {d \[Rule] 1}; \)\), 
    \(\(Qi = \(-1\); \)\), 
    \(\(si = \(-2\)\ d /. case1; \)\), 
    \(\(Clear[vreal, vimage]; \)\), 
    \(\(vreal[x_, y_] := 1\/\@\(x\^2 + y\^2\); \)\), 
    \(\(vimage[x_, y_] := \(-\(1\/\@\(x\^2 + \((y - si)\)\^2\)\)\); \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(discGraphics = 
      Graphics[{Disk[{0, 0}, .1], 
          Rectangle[{\(-2\), \(-1.1\)}, {2, \(-1\)}]}, 
        AspectRatio \[Rule] Automatic, PlotLabel \[Rule] "\<a\>", opt1]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(fieldGraphics = 
      PlotGradientField[
        \(-\((vreal[x, y] + vimage[x, y])\)\), {x, \(-1.5\), 1.5}, {y, 
          \(-1\), 1}, ScaleFunction \[Rule] \((2 + Log[1 + #1]&)\), 
        ScaleFactor \[Rule] 0.5, PlotPoints \[Rule] 8, 
        DisplayFunction \[Rule] Identity]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(discfieldGraphics = 
      Show[{discGraphics, fieldGraphics}, DisplayFunction \[Rule] Identity]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(potentialGraphics = 
      ContourPlot[
        vreal[x, y] + vimage[x, y], {x, \(-2.5\), 2.5}, {y, \(-3.5\), 1.5}, 
        PlotPoints \[Rule] 20, Contours \[Rule] 10, 
        PlotLabel \[Rule] "\<b\>", ContourShading \[Rule] False, 
        DisplayFunction \[Rule] Identity, Evaluate[opt1]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig2 = Show[GraphicsArray[{discfieldGraphics, potentialGraphics}]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .30774 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.47619 0.007327 0.47619 [
[ 0 0 0 0 ]
[ 1 .30774 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .30774 L
0 .30774 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.02381 0.007327 0.477324 0.300412 MathSubStart
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.32946 0.238095 [
[.02381 -0.0125 -7 -12 ]
[.02381 -0.0125 7 0 ]
[.2619 -0.0125 -7 -12 ]
[.2619 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.7381 -0.0125 -4 -12 ]
[.7381 -0.0125 4 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4 -24 ]
[.5 -0.0125 4 -12 ]
[-0.0125 .09136 -14 -6 ]
[-0.0125 .09136 0 6 ]
[-0.0125 .21041 -20 -6 ]
[-0.0125 .21041 0 6 ]
[-0.0125 .32946 -8 -6 ]
[-0.0125 .32946 0 6 ]
[-0.0125 .44851 -14 -6 ]
[-0.0125 .44851 0 6 ]
[-0.0125 .56756 -8 -6 ]
[-0.0125 .56756 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .32313 -32 -4 ]
[-0.01875 .32313 -20 4 ]
[ 0 .64625 .125 0 ]
[ 1 0 .125 0 ]
[.5 .65875 -4 0 ]
[.5 .65875 4 12 ]
[ 0 0 0 0 ]
[ 1 .64625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .09136 m
.00625 .09136 L
s
gsave
-0.0125 .09136 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .21041 m
.00625 .21041 L
s
gsave
-0.0125 .21041 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .32946 m
.00625 .32946 L
s
gsave
-0.0125 .32946 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .44851 m
.00625 .44851 L
s
gsave
-0.0125 .44851 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .56756 m
.00625 .56756 L
s
gsave
-0.0125 .56756 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .11517 m
.00375 .11517 L
s
0 .13898 m
.00375 .13898 L
s
0 .16279 m
.00375 .16279 L
s
0 .1866 m
.00375 .1866 L
s
0 .23422 m
.00375 .23422 L
s
0 .25803 m
.00375 .25803 L
s
0 .28184 m
.00375 .28184 L
s
0 .30565 m
.00375 .30565 L
s
0 .35327 m
.00375 .35327 L
s
0 .37708 m
.00375 .37708 L
s
0 .40089 m
.00375 .40089 L
s
0 .4247 m
.00375 .4247 L
s
0 .47232 m
.00375 .47232 L
s
0 .49613 m
.00375 .49613 L
s
0 .51994 m
.00375 .51994 L
s
0 .54375 m
.00375 .54375 L
s
0 .06756 m
.00375 .06756 L
s
0 .04375 m
.00375 .04375 L
s
0 .01994 m
.00375 .01994 L
s
0 .59136 m
.00375 .59136 L
s
0 .61517 m
.00375 .61517 L
s
0 .63898 m
.00375 .63898 L
s
.25 Mabswid
0 0 m
0 .64625 L
s
gsave
-0.01875 .32313 -91 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
65 10 translate
90 rotate
-65 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .64 m
.02381 .64625 L
s
.2619 .64 m
.2619 .64625 L
s
.5 .64 m
.5 .64625 L
s
.7381 .64 m
.7381 .64625 L
s
.97619 .64 m
.97619 .64625 L
s
.125 Mabswid
.07143 .6425 m
.07143 .64625 L
s
.11905 .6425 m
.11905 .64625 L
s
.16667 .6425 m
.16667 .64625 L
s
.21429 .6425 m
.21429 .64625 L
s
.30952 .6425 m
.30952 .64625 L
s
.35714 .6425 m
.35714 .64625 L
s
.40476 .6425 m
.40476 .64625 L
s
.45238 .6425 m
.45238 .64625 L
s
.54762 .6425 m
.54762 .64625 L
s
.59524 .6425 m
.59524 .64625 L
s
.64286 .6425 m
.64286 .64625 L
s
.69048 .6425 m
.69048 .64625 L
s
.78571 .6425 m
.78571 .64625 L
s
.83333 .6425 m
.83333 .64625 L
s
.88095 .6425 m
.88095 .64625 L
s
.92857 .6425 m
.92857 .64625 L
s
.25 Mabswid
0 .64625 m
1 .64625 L
s
.99375 .09136 m
1 .09136 L
s
.99375 .21041 m
1 .21041 L
s
.99375 .32946 m
1 .32946 L
s
.99375 .44851 m
1 .44851 L
s
.99375 .56756 m
1 .56756 L
s
.125 Mabswid
.99625 .11517 m
1 .11517 L
s
.99625 .13898 m
1 .13898 L
s
.99625 .16279 m
1 .16279 L
s
.99625 .1866 m
1 .1866 L
s
.99625 .23422 m
1 .23422 L
s
.99625 .25803 m
1 .25803 L
s
.99625 .28184 m
1 .28184 L
s
.99625 .30565 m
1 .30565 L
s
.99625 .35327 m
1 .35327 L
s
.99625 .37708 m
1 .37708 L
s
.99625 .40089 m
1 .40089 L
s
.99625 .4247 m
1 .4247 L
s
.99625 .47232 m
1 .47232 L
s
.99625 .49613 m
1 .49613 L
s
.99625 .51994 m
1 .51994 L
s
.99625 .54375 m
1 .54375 L
s
.99625 .06756 m
1 .06756 L
s
.99625 .04375 m
1 .04375 L
s
.99625 .01994 m
1 .01994 L
s
.99625 .59136 m
1 .59136 L
s
.99625 .61517 m
1 .61517 L
s
.99625 .63898 m
1 .63898 L
s
.25 Mabswid
1 0 m
1 .64625 L
s
gsave
.5 .65875 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
66.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 .64625 L
0 .64625 L
closepath
clip
newpath
.5 .32946 m
.5 .32946 .02381 0 365.72958 arc
F
.02381 .06756 m
.02381 .09136 L
.97619 .09136 L
.97619 .06756 L
F
.0001 w
.14286 .09136 m
.14286 .03431 L
s
% Start of user PostScript
-1.5 -1. -1.5 -1.23964 MAarrowhead1
% End of user PostScript
.14286 .15939 m
.12111 .10649 L
s
% Start of user PostScript
-1.5 -0.714286 -1.59133 -0.93646 MAarrowhead1
% End of user PostScript
.14286 .22742 m
.10361 .18543 L
s
% Start of user PostScript
-1.5 -0.428571 -1.66486 -0.604938 MAarrowhead1
% End of user PostScript
.14286 .29545 m
.0922 .26793 L
s
% Start of user PostScript
-1.5 -0.142857 -1.71276 -0.258416 MAarrowhead1
% End of user PostScript
.14286 .36347 m
.08674 .35113 L
s
% Start of user PostScript
-1.5 0.142857 -1.7357 0.0910325 MAarrowhead1
% End of user PostScript
.14286 .4315 m
.08602 .43296 L
s
% Start of user PostScript
-1.5 0.428571 -1.73873 0.434684 MAarrowhead1
% End of user PostScript
.14286 .49953 m
.08835 .51228 L
s
% Start of user PostScript
-1.5 0.714286 -1.72892 0.767839 MAarrowhead1
% End of user PostScript
.14286 .56756 m
.09218 .58892 L
s
% Start of user PostScript
-1.5 1. -1.71285 1.08973 MAarrowhead1
% End of user PostScript
.2449 .09136 m
.2449 .02938 L
s
% Start of user PostScript
-1.07143 -1. -1.07143 -1.26035 MAarrowhead1
% End of user PostScript
.2449 .15939 m
.21932 .1024 L
s
% Start of user PostScript
-1.07143 -0.714286 -1.17886 -0.953653 MAarrowhead1
% End of user PostScript
.2449 .22742 m
.19851 .18396 L
s
% Start of user PostScript
-1.07143 -0.428571 -1.26625 -0.611081 MAarrowhead1
% End of user PostScript
.2449 .29545 m
.1853 .27115 L
s
% Start of user PostScript
-1.07143 -0.142857 -1.32173 -0.244898 MAarrowhead1
% End of user PostScript
.2449 .36347 m
.18102 .35993 L
s
% Start of user PostScript
-1.07143 0.142857 -1.33973 0.127984 MAarrowhead1
% End of user PostScript
.2449 .4315 m
.18421 .44564 L
s
% Start of user PostScript
-1.07143 0.428571 -1.32634 0.48794 MAarrowhead1
% End of user PostScript
.2449 .49953 m
.19102 .52599 L
s
% Start of user PostScript
-1.07143 0.714286 -1.2977 0.825425 MAarrowhead1
% End of user PostScript
.2449 .56756 m
.19828 .60168 L
s
% Start of user PostScript
-1.07143 1. -1.26724 1.14333 MAarrowhead1
% End of user PostScript
.34694 .09136 m
.34694 .02211 L
s
% Start of user PostScript
-0.642857 -1. -0.642857 -1.29088 MAarrowhead1
% End of user PostScript
.34694 .15939 m
.32003 .09382 L
s
% Start of user PostScript
-0.642857 -0.714286 -0.755882 -0.989687 MAarrowhead1
% End of user PostScript
.34694 .22742 m
.29354 .17453 L
s
% Start of user PostScript
-0.642857 -0.428571 -0.867149 -0.650697 MAarrowhead1
% End of user PostScript
.34694 .29545 m
.27187 .26963 L
s
% Start of user PostScript
-0.642857 -0.142857 -0.958147 -0.251272 MAarrowhead1
% End of user PostScript
.34694 .36347 m
.2689 .37446 L
s
% Start of user PostScript
-0.642857 0.142857 -0.970606 0.189003 MAarrowhead1
% End of user PostScript
.34694 .4315 m
.28349 .46788 L
s
% Start of user PostScript
-0.642857 0.428571 -0.909326 0.58138 MAarrowhead1
% End of user PostScript
.34694 .49953 m
.2993 .54614 L
s
% Start of user PostScript
-0.642857 0.714286 -0.842925 0.910047 MAarrowhead1
% End of user PostScript
.34694 .56756 m
.31051 .61722 L
s
% Start of user PostScript
-0.642857 1. -0.795845 1.20858 MAarrowhead1
% End of user PostScript
.44898 .09136 m
.44898 .01539 L
s
% Start of user PostScript
-0.214286 -1. -0.214286 -1.31911 MAarrowhead1
% End of user PostScript
.44898 .15939 m
.43467 .08093 L
s
% Start of user PostScript
-0.214286 -0.714286 -0.27438 -1.04384 MAarrowhead1
% End of user PostScript
.44898 .22742 m
.41141 .14234 L
s
% Start of user PostScript
-0.214286 -0.428571 -0.372066 -0.785894 MAarrowhead1
% End of user PostScript
.44898 .29545 m
.35105 .22776 L
s
% Start of user PostScript
-0.214286 -0.142857 -0.625608 -0.427135 MAarrowhead1
% End of user PostScript
.44898 .36347 m
.34954 .42817 L
s
% Start of user PostScript
-0.214286 0.142857 -0.631915 0.414599 MAarrowhead1
% End of user PostScript
.44898 .4315 m
.4072 .51208 L
s
% Start of user PostScript
-0.214286 0.428571 -0.389758 0.766987 MAarrowhead1
% End of user PostScript
.44898 .49953 m
.42646 .57018 L
s
% Start of user PostScript
-0.214286 0.714286 -0.308859 1.01101 MAarrowhead1
% End of user PostScript
.44898 .56756 m
.4342 .63087 L
s
% Start of user PostScript
-0.214286 1. -0.276345 1.26591 MAarrowhead1
% End of user PostScript
.55102 .09136 m
.55102 .01539 L
s
% Start of user PostScript
0.214286 -1. 0.214286 -1.31911 MAarrowhead1
% End of user PostScript
.55102 .15939 m
.56533 .08093 L
s
% Start of user PostScript
0.214286 -0.714286 0.27438 -1.04384 MAarrowhead1
% End of user PostScript
.55102 .22742 m
.58859 .14234 L
s
% Start of user PostScript
0.214286 -0.428571 0.372066 -0.785894 MAarrowhead1
% End of user PostScript
.55102 .29545 m
.64895 .22776 L
s
% Start of user PostScript
0.214286 -0.142857 0.625608 -0.427135 MAarrowhead1
% End of user PostScript
.55102 .36347 m
.65046 .42817 L
s
% Start of user PostScript
0.214286 0.142857 0.631915 0.414599 MAarrowhead1
% End of user PostScript
.55102 .4315 m
.5928 .51208 L
s
% Start of user PostScript
0.214286 0.428571 0.389758 0.766987 MAarrowhead1
% End of user PostScript
.55102 .49953 m
.57354 .57018 L
s
% Start of user PostScript
0.214286 0.714286 0.308859 1.01101 MAarrowhead1
% End of user PostScript
.55102 .56756 m
.5658 .63087 L
s
% Start of user PostScript
0.214286 1. 0.276345 1.26591 MAarrowhead1
% End of user PostScript
.65306 .09136 m
.65306 .02211 L
s
% Start of user PostScript
0.642857 -1. 0.642857 -1.29088 MAarrowhead1
% End of user PostScript
.65306 .15939 m
.67997 .09382 L
s
% Start of user PostScript
0.642857 -0.714286 0.755882 -0.989687 MAarrowhead1
% End of user PostScript
.65306 .22742 m
.70646 .17453 L
s
% Start of user PostScript
0.642857 -0.428571 0.867149 -0.650697 MAarrowhead1
% End of user PostScript
.65306 .29545 m
.72813 .26963 L
s
% Start of user PostScript
0.642857 -0.142857 0.958147 -0.251272 MAarrowhead1
% End of user PostScript
.65306 .36347 m
.7311 .37446 L
s
% Start of user PostScript
0.642857 0.142857 0.970606 0.189003 MAarrowhead1
% End of user PostScript
.65306 .4315 m
.71651 .46788 L
s
% Start of user PostScript
0.642857 0.428571 0.909326 0.58138 MAarrowhead1
% End of user PostScript
.65306 .49953 m
.7007 .54614 L
s
% Start of user PostScript
0.642857 0.714286 0.842925 0.910047 MAarrowhead1
% End of user PostScript
.65306 .56756 m
.68949 .61722 L
s
% Start of user PostScript
0.642857 1. 0.795845 1.20858 MAarrowhead1
% End of user PostScript
.7551 .09136 m
.7551 .02938 L
s
% Start of user PostScript
1.07143 -1. 1.07143 -1.26035 MAarrowhead1
% End of user PostScript
.7551 .15939 m
.78068 .1024 L
s
% Start of user PostScript
1.07143 -0.714286 1.17886 -0.953653 MAarrowhead1
% End of user PostScript
.7551 .22742 m
.80149 .18396 L
s
% Start of user PostScript
1.07143 -0.428571 1.26625 -0.611081 MAarrowhead1
% End of user PostScript
.7551 .29545 m
.8147 .27115 L
s
% Start of user PostScript
1.07143 -0.142857 1.32173 -0.244898 MAarrowhead1
% End of user PostScript
.7551 .36347 m
.81898 .35993 L
s
% Start of user PostScript
1.07143 0.142857 1.33973 0.127984 MAarrowhead1
% End of user PostScript
.7551 .4315 m
.81579 .44564 L
s
% Start of user PostScript
1.07143 0.428571 1.32634 0.48794 MAarrowhead1
% End of user PostScript
.7551 .49953 m
.80898 .52599 L
s
% Start of user PostScript
1.07143 0.714286 1.2977 0.825425 MAarrowhead1
% End of user PostScript
.7551 .56756 m
.80172 .60168 L
s
% Start of user PostScript
1.07143 1. 1.26724 1.14333 MAarrowhead1
% End of user PostScript
.85714 .09136 m
.85714 .03431 L
s
% Start of user PostScript
1.5 -1. 1.5 -1.23964 MAarrowhead1
% End of user PostScript
.85714 .15939 m
.87889 .10649 L
s
% Start of user PostScript
1.5 -0.714286 1.59133 -0.93646 MAarrowhead1
% End of user PostScript
.85714 .22742 m
.89639 .18543 L
s
% Start of user PostScript
1.5 -0.428571 1.66486 -0.604938 MAarrowhead1
% End of user PostScript
.85714 .29545 m
.9078 .26793 L
s
% Start of user PostScript
1.5 -0.142857 1.71276 -0.258416 MAarrowhead1
% End of user PostScript
.85714 .36347 m
.91326 .35113 L
s
% Start of user PostScript
1.5 0.142857 1.7357 0.0910325 MAarrowhead1
% End of user PostScript
.85714 .4315 m
.91398 .43296 L
s
% Start of user PostScript
1.5 0.428571 1.73873 0.434684 MAarrowhead1
% End of user PostScript
.85714 .49953 m
.91165 .51228 L
s
% Start of user PostScript
1.5 0.714286 1.72892 0.767839 MAarrowhead1
% End of user PostScript
.85714 .56756 m
.90782 .58892 L
s
% Start of user PostScript
1.5 1. 1.71285 1.08973 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.007327 0.97619 0.300412 MathSubStart
%% ContourGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.192308 0.692308 0.192308 [
[.11538 -0.0125 -7 -12 ]
[.11538 -0.0125 7 0 ]
[.30769 -0.0125 -7 -12 ]
[.30769 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.69231 -0.0125 -4 -12 ]
[.69231 -0.0125 4 0 ]
[.88462 -0.0125 -4 -12 ]
[.88462 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4 -24 ]
[.5 -0.0125 4 -12 ]
[-0.0125 .11538 -14 -6 ]
[-0.0125 .11538 0 6 ]
[-0.0125 .30769 -14 -6 ]
[-0.0125 .30769 0 6 ]
[-0.0125 .5 -14 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .69231 -8 -6 ]
[-0.0125 .69231 0 6 ]
[-0.0125 .88462 -8 -6 ]
[-0.0125 .88462 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -26 -4 ]
[-0.01875 .5 -14 4 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.30769 0 m
.30769 .00625 L
s
gsave
.30769 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.69231 0 m
.69231 .00625 L
s
gsave
.69231 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .11538 m
.00625 .11538 L
s
gsave
-0.0125 .11538 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .30769 m
.00625 .30769 L
s
gsave
-0.0125 .30769 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .69231 m
.00625 .69231 L
s
gsave
-0.0125 .69231 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .88462 m
.00625 .88462 L
s
gsave
-0.0125 .88462 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .15385 m
.00375 .15385 L
s
0 .19231 m
.00375 .19231 L
s
0 .23077 m
.00375 .23077 L
s
0 .26923 m
.00375 .26923 L
s
0 .34615 m
.00375 .34615 L
s
0 .38462 m
.00375 .38462 L
s
0 .42308 m
.00375 .42308 L
s
0 .46154 m
.00375 .46154 L
s
0 .53846 m
.00375 .53846 L
s
0 .57692 m
.00375 .57692 L
s
0 .61538 m
.00375 .61538 L
s
0 .65385 m
.00375 .65385 L
s
0 .73077 m
.00375 .73077 L
s
0 .76923 m
.00375 .76923 L
s
0 .80769 m
.00375 .80769 L
s
0 .84615 m
.00375 .84615 L
s
0 .07692 m
.00375 .07692 L
s
0 .03846 m
.00375 .03846 L
s
0 .92308 m
.00375 .92308 L
s
0 .96154 m
.00375 .96154 L
s
0 1 m
.00375 1 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -85 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
65 10 translate
90 rotate
-65 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .15385 m
1 .15385 L
s
.99625 .19231 m
1 .19231 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .26923 m
1 .26923 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .38462 m
1 .38462 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .46154 m
1 .46154 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .57692 m
1 .57692 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .65385 m
1 .65385 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .76923 m
1 .76923 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .84615 m
1 .84615 L
s
.99625 .07692 m
1 .07692 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .92308 m
1 .92308 L
s
.99625 .96154 m
1 .96154 L
s
.99625 1 m
1 1 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.42409 .62 m
.4747 .59525 L
.5253 .59525 L
.57591 .62 L
.58177 .62652 L
.60303 .67713 L
.60673 .72773 L
.57933 .77834 L
.57591 .78144 L
.5253 .80501 L
.4747 .80501 L
.42409 .78144 L
.42067 .77834 L
.39327 .72773 L
.39697 .67713 L
.41823 .62652 L
.42409 .62 L
s
.42409 .59885 m
.4747 .5799 L
.5253 .5799 L
.57591 .59885 L
.6054 .62652 L
.62652 .66172 L
.63057 .67713 L
.63193 .72773 L
.62652 .75055 L
.61173 .77834 L
.57591 .81361 L
.54655 .82895 L
.5253 .83421 L
.4747 .83421 L
.45345 .82895 L
.42409 .81361 L
.38827 .77834 L
.37348 .75055 L
.36807 .72773 L
.36943 .67713 L
.37348 .66172 L
.3946 .62652 L
.42409 .59885 L
s
.42409 .57541 m
.4747 .56073 L
.5253 .56073 L
.57591 .57541 L
.57702 .57591 L
.62652 .60922 L
.63933 .62652 L
.66358 .67713 L
.66857 .72773 L
.65607 .77834 L
.62652 .82479 L
.62263 .82895 L
.57591 .86198 L
.5253 .87803 L
.4747 .87803 L
.42409 .86198 L
.37737 .82895 L
.37348 .82479 L
.34393 .77834 L
.33143 .72773 L
.33642 .67713 L
.36067 .62652 L
.37348 .60922 L
.42298 .57591 L
.42409 .57541 L
s
.37348 .56686 m
.42409 .54731 L
.4747 .53862 L
.5253 .53862 L
.57591 .54731 L
.62652 .56686 L
.64157 .57591 L
.67713 .60252 L
.69604 .62652 L
.72325 .67713 L
.72773 .69157 L
.73353 .72773 L
.73093 .77834 L
.72773 .79361 L
.71511 .82895 L
.68349 .87955 L
.67713 .8869 L
.62652 .92897 L
.6248 .93016 L
.57591 .95286 L
.5253 .96384 L
.4747 .96384 L
.42409 .95286 L
.3752 .93016 L
.37348 .92897 L
.32287 .8869 L
.31651 .87955 L
.28489 .82895 L
.27227 .79361 L
.26907 .77834 L
.26647 .72773 L
.27227 .69157 L
.27675 .67713 L
.30396 .62652 L
.32287 .60252 L
.35843 .57591 L
.37348 .56686 L
s
.91396 .98077 m
.9288 .93016 L
.93016 .92368 L
.9362 .87955 L
.93627 .82895 L
.93016 .78521 L
.92866 .77834 L
.91242 .72773 L
.88604 .67713 L
.87955 .66688 L
.84511 .62652 L
.82895 .61071 L
.78037 .57591 L
.77834 .57464 L
.72773 .5498 L
.67713 .53328 L
.64109 .5253 L
.62652 .52266 L
.57591 .51637 L
.5253 .51349 L
.4747 .51349 L
.42409 .51637 L
.37348 .52266 L
.35891 .5253 L
.32287 .53328 L
.27227 .5498 L
.22166 .57464 L
.21963 .57591 L
.17105 .61071 L
.15489 .62652 L
.12045 .66688 L
.11396 .67713 L
.08758 .72773 L
.07134 .77834 L
.06984 .78521 L
.06373 .82895 L
.0638 .87955 L
.06984 .92368 L
.0712 .93016 L
.08604 .98077 L
s
.91396 .01923 m
.9288 .06984 L
.93016 .07632 L
.9362 .12045 L
.93627 .17105 L
.93016 .21479 L
.92866 .22166 L
.91242 .27227 L
.88604 .32287 L
.87955 .33312 L
.84511 .37348 L
.82895 .38929 L
.78037 .42409 L
.77834 .42536 L
.72773 .4502 L
.67713 .46672 L
.64109 .4747 L
.62652 .47734 L
.57591 .48363 L
.5253 .48651 L
.4747 .48651 L
.42409 .48363 L
.37348 .47734 L
.35891 .4747 L
.32287 .46672 L
.27227 .4502 L
.22166 .42536 L
.21963 .42409 L
.17105 .38929 L
.15489 .37348 L
.12045 .33312 L
.11396 .32287 L
.08758 .27227 L
.07134 .22166 L
.06984 .21479 L
.06373 .17105 L
.0638 .12045 L
.06984 .07632 L
.0712 .06984 L
.08604 .01923 L
s
.42409 .04714 m
.4747 .03616 L
.5253 .03616 L
.57591 .04714 L
.6248 .06984 L
.62652 .07103 L
.67713 .1131 L
.68349 .12045 L
.71511 .17105 L
.72773 .20639 L
.73093 .22166 L
.73353 .27227 L
.72773 .30843 L
.72325 .32287 L
.69604 .37348 L
.67713 .39748 L
.64157 .42409 L
.62652 .43314 L
.57591 .45269 L
.5253 .46138 L
.4747 .46138 L
.42409 .45269 L
.37348 .43314 L
.35843 .42409 L
.32287 .39748 L
.30396 .37348 L
.27675 .32287 L
.27227 .30843 L
.26647 .27227 L
.26907 .22166 L
.27227 .20639 L
.28489 .17105 L
.31651 .12045 L
.32287 .1131 L
.37348 .07103 L
.3752 .06984 L
.42409 .04714 L
s
.42409 .13802 m
.4747 .12197 L
.5253 .12197 L
.57591 .13802 L
.62263 .17105 L
.62652 .17521 L
.65607 .22166 L
.66857 .27227 L
.66358 .32287 L
.63933 .37348 L
.62652 .39078 L
.57702 .42409 L
.57591 .42459 L
.5253 .43927 L
.4747 .43927 L
.42409 .42459 L
.42298 .42409 L
.37348 .39078 L
.36067 .37348 L
.33642 .32287 L
.33143 .27227 L
.34393 .22166 L
.37348 .17521 L
.37737 .17105 L
.42409 .13802 L
s
.4747 .16579 m
.5253 .16579 L
.54655 .17105 L
.57591 .18639 L
.61173 .22166 L
.62652 .24945 L
.63193 .27227 L
.63057 .32287 L
.62652 .33828 L
.6054 .37348 L
.57591 .40115 L
.5253 .4201 L
.4747 .4201 L
.42409 .40115 L
.3946 .37348 L
.37348 .33828 L
.36943 .32287 L
.36807 .27227 L
.37348 .24945 L
.38827 .22166 L
.42409 .18639 L
.45345 .17105 L
.4747 .16579 L
s
.42409 .21856 m
.4747 .19499 L
.5253 .19499 L
.57591 .21856 L
.57933 .22166 L
.60673 .27227 L
.60303 .32287 L
.58177 .37348 L
.57591 .38 L
.5253 .40475 L
.4747 .40475 L
.42409 .38 L
.41823 .37348 L
.39697 .32287 L
.39327 .27227 L
.42067 .22166 L
.42409 .21856 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{320.75, 98.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006A0000O0800@400oooT_l00?ooT_l00?ooT_l0
0?ooT_l00?ooT_l00?ooT_l00?ooT_l007?o00<`0<;o00<`05Ko001do`03?032o`03?01Eo`00M?l0
0c`0`_l00c`0EOl007?o00<`0<;o00<`05Ko003ooi;o003ooi;o003ooi;o003ooi;o003ooi;o003o
oi;o003ooi;o003ooi;o000lo`03000Jo`03000Ho`03?00Io`03000Jo`03001/o`03000<o`03000;
o`03?00;o`03000=o`03000go`00??l00c`06ol00c`05_l00c006ol00c`06Ol00c`0K?l00c`03Ol0
0c`02Ol00c003Ol00c`03?l00c`0=ol003Oo00<000Ol4ol00`001o`Eo`03<00Ko`03?00Jo`03?01W
o`030006l`Ko00<000Kc2?l00c003Ol00c`03Ol00c`0=_l003co00<`01_o00<l01Ko00<`01_o00<l
01Wo00<`06co00<`00go00<l00Wo00<`00go00<l00co00<`03Oo000mo`03300Io`03300Ho`03?00I
o`03300Ko`03301/o`03300;o`03300;o`03?00;o`03300>o`03300fo`00oonBo`00oonBo`00oonB
o`00oonBo`00oolCoe00;ol003SoNP1Po`03?006o`03?00<o`03?00=o`03?00<o`03?00<o`03?006
o`03?00]o`00>?l00c`0M_l00c`0G_l013l01o`mo`043`07o2co000ho`03?00Wo`03?009o`03300:
o`03?009o`03?00Wo`03?01No`03?007o1[o200Mo`03?007o2co000ho`03?00Ko`03?009o`03?009
o`033009o`03300:o`03?00:o`03?00Jo`03?01No`03?007o1Oo00<000So00<001[o00<l00Ol;?l0
03So00<l00ko00<<00Wo00<<00[o00<<00Wo00<<00Wo00<<00[o00<<00Wo00<<00[o00<l00ko00<l
05ko00<l00Ol5Ol00``03Ol00``05ol00c`01o`/o`00>?l00c`03_l00``02Ol00``02Ol00`002_l0
0c`02_l00c`02Ol00``02Ol00``02_l00c`03_l00c`0G_l00c`01_0Do`03300Ao`03300Fo`03?006
lbco000ho`03?00>o`033009o`03300:o`03?009o`03?00:o`03?009o`03?009o`033009o`03000?
o`03?01Go`043`07o0G?4ol00c`05?l00c`05?l00c`01_</o`00>?l00c`03_l00c`02_l00c`02Ol0
0c`02Ol00c`02_l00c`02Ol00c`02_l00c`02Ol00c`03_l00c`0FOl00c`01_<5ca;o00<l01Ko00<l
01?o00<l00Kc;?l0037o00@300KlM006le7o00<000Ol1_<5ca3o00<<01Wo00<<01;o00<l00Kc;?l0
03;o00<l00KlM006leSo00<l00Kc1Ll@o`03?008o`P02_l00c`04Ol00c`01_</o`00;?l00`001o`5
lg@01_=Fo`043`07o0G?3ol00c`01ol00``01ol00`002?l00c`04?l00c`01_</o`00<_l013l01O1d
00KcGOl00c`01_<?o`03?005o`03300<o`03?006o`03?00?o`03?006lbco000ao`043`07o1Oo00<l
00Wo00<<00_o00<<00co00<<00[o00<<00[o00<<01So00<l05ko00<l00Kc3_l00c`01Ol01So`00H0
1Ol00c`01Ol00c`03ol00c`01_</o`00>?l00c`03?l00c`02Ol00``02Ol00``02ol00c`03?l00c`0
2_l00``02_l00``02Ol00``03?l00c`0G_l00c`01_<=o`03?005o`03?006l003o005``K`00?l00G?
3Ol00c`01_</o`00>?l00c`03?l00``02Ol00``02Ol00``03?l00c`02ol00c`02_l00``02Ol00``0
2Ol00``03Ol00c`0G_l00c`01_<=o`04?`08o003?008o`033006l`Ol3Ol00c`01_</o`00>?l00c`0
3?l00``02Ol00``02_l00c`02ol00c`02ol00c`02_l00c`02Ol00``02Ol00``03Ol00c`0G_l00c`0
1_<=o`03?00<o0L02o`6l`go00<l00Kc;?l003So00<l00go00<l00Wo00<l00[o00<l00[o00<l00[o
00<l00[o00<l00[o00<l00Wo00<l00go00<l05ko00<l00Kc3?l013l01_`7?0Ko1@l6l`Ol3?l00c`0
1_</o`00>?l00c`03_l00c`02Ol00c`02Ol00c`01_l8?`Wo23l5o`03?009o`03?00:o`03?00=o`03
?01No`03?007o0_o00<l00Wl00<<00[o00@`00Kc1_<<o`03?006lbco000ho`03?00>o`03?009o`03
?00:o`03?005o`D?3?l7?0Ko00<l00Wo00<l00Wo00<l00ko00<l05ko00<l00Ol2ol00c`01_`013`0
3Ol00c001_<6l`_o00<l00Ol;?l003So00<l00ko00<l00[o00<l00Wo00<l00Go1@l<o`Ll1Ol00c`0
2_l00c`02Ol00c`03_l00c`0G_l00c`01o`;o`03?005o004300>o`04?005c`Kc2ol00c`01o`/o`00
>?l00c`0<?l00c`04?l00c`0<?l00c`0G_l013l01o`:o`03?005l`04?00?o`03<006l`G?2ol00c`0
1o`/o`00>?l00c`08Ol00``03Ol00c`03ol00c`03?l00``08Ol00c`0Eol010<01o`7o0[o00<l00Gc
00<`013o00<`00Kc1Ll:o`04?`07o2co000ho`03?00:o`03?008o`033009o`03000=o`03?00>o`03
?00<o`033009o`033009o`03300:o`03?01Go`04?`07o0Ol2_l00c`01O<00c004?l00c001_<5c`[o
00@o00Ol;?l002co00@l00G31o`9o`030008o`03000:o`03300=o`03?00=o`03?00<o`033008o`03
0009o`03000;o`03?01Bo`030007o0Kc00?l00G?2Ol00c`01O<00c004?l00c001_<5c`Wo00<l00Go
00<l02go000[o`03<005o`03?006l`Wo00<000Wo00<<00_o00<l00_o00<l00co00<l00co00<l00Wo
00<<00Wo00<<00_o00<l05Oo00@c00Ol00?l00G?2Ol00``01O<00c004?l00c001_<5c`Wo00<l00Go
00<l02go000Vo`040`05c0K`00Gl00go00<l00Wo00<l00[o00<l00[o00<l00co00<l00[o00<<00[o
00<l00Wo00<l00co00<l05So00<<00Ol1Ol00c`02_l013l01l`?o`Dc23l9o`03?006o`03?00]o`00
:ol00c001o`7o0co00<l00Wo00<l00[o00<l00[o00<l00[o00<l00[o00<l00[o00<l00Wo00<l00go
00<l05ko00<l00Ko00<<00[o00<l00Gc00<`00ko00@l00G?1Ll8o`033007o`03?00]o`00;?l013l0
1L07o0go00<l00Wo00<<00[o00<<00Wo00<l00[o00<l00So00<<00_o00<l00Wo00<l00ko00<l05ko
00<l00So00<l00Wo00@o00O<3Ol6<`Ol2Ol00c`01ol00c`0;Ol003So00<l02So00<001ko00@002Wo
00<l05ko00<l00So00<l00[o1cl00c003?l00c001_<5c`So00<l00So00<l02go000ho`03?00Yo`03
300Mo`03000Zo`03?01No`03?009o`03?009o`Do1C<00c`02Ol5<`Po2?l00c`02Ol00c`0;Ol003So
00<l02_o00<<01[o00<l02_o00<l05ko00<l00[o00<<00Wo00@o00K<00<l00Ko00@<00[c2?l00c`0
2_l00c`0;Ol003So00<l02go00<l01Ko00<<02go00<l05ko00<l00co00<l00Oo00<<00G`1P`50003
`005``G31ol00``03?l00c`0;Ol003So00<l00So00<<01?o00<<00go00<<01Co00<l00co00<<01?o
00<<00Wo00<l05ko00<l00go00<l00So00<l00Gc00H3l005`0G?1Ll7o`03?00=o`03?00]o`00>?l0
0c`02Ol00`001ol010001ol010003_l00c`04?l00``03Ol00`001ol010002?l00`002_l00c`0G_l0
0c`03_l00``02?l010l01L000l0020<6l0Oo00<<00oo00<l02go000ho`03?00:o`030008o`040007
o`H`2ol00c`03_l00c`02ol500Oo00@000Oo00@000_o00<l05ko00<l013o00<<00So00H?l0080003
o005`0Oo00<<017o00<l02go000ho`03?00=o`033009o`033009o`03000:o`03300;o`03300:o`03
0009o`030009o`03300>o`03?01No`03?00Bo`030008o`040008o`040008o`03000Do`03?00]o`00
>?l00c`03_l00c`02_l00c`02Ol00c`02Ol00c`02_l00c`02Ol00c`02_l00c`02Ol00c`03_l00c`0
Eol010<01o`Do`030009o`P02Ol00`005ol00c`0;Ol001_o00<l00Kc3_l00c`01o`go`04000jo`03
?018o`03?006l`Oo00<l00Ol5ol600ko1P0Jo`03?00]o`006ol60a3o00@c00Ol=_l603Wo00<l04So
1P<00o`01L06l`Kc7Ol>023o00<l02go000Mo`03300Ao`04<`07o3Ko1P0io`03?01:o`03300;o`03
?007o4_o00<l02go000Ko`03300Co`05<l06l3Ko1`0ho`03?018o`03300<o`043`07o1_o4P0No`03
?00]o`00<_l00c`01o`fo`H0>Ol00c`0G_l00c`05ol501;o1@0Io`03?00]o`00>?l00c`02?l00`00
;Ol502co00@000Wo00<l05ko00<l01Co00<000Wo2P09o`03000Fo`03?00]o`00>?l00c`02?l600Go
00<002Co00<l027o00<000Ko1@0:o`03?01No`03?00Bo`033008o`03000:o`030009o`03300Co`03
?00]o`00>?l00c`03_l01So`00P000?l00H<00<000_o00<l00[o00<l00Wo1P05``03l0070003o005
``go00<l05ko00<l013o00<<00Oo00H3l00:0006o0002?l00`004Ol00c`0;Ol003So00<l01ko00@0
00oo00<<00go00<<00ko1@0Oo`03?01No`03?00>o`033008o`03?008l0030007?0Kc1ol00c`03_l0
0c`0;Ol003So00<l033o00<l013o00<<033o00<l05ko00<l00go00<l00So00<l00Gc1P`00`001c`5
c`Oo00<<00go00<l02go000ho`03?00^o`03300Do`03?00^o`03?01No`03?00;o`033008o`033005
l0D<00Co00D<1o<00c`02?l00c`02ol00c`0;Ol003So00<l02go00<l01Ko00<<02go00<l05ko00<l
00[o00<l00Wo1Cl5<`03?006o`04000:l`So00<l00[o00<l02go000ho`03?00[o`03300Jo`03?00[
o`03?01No`03?009o`03?009o`Lo00<`00co00<`00[c2?l00c`02Ol00c`0;Ol003So00<l02So00<0
01ko00<002[o00<l05ko00<l00So00<l00Wo00<l00Gc00<`00co00@l00G?1Ll8o`03?008o`03?00]
o`00>?l00c`0:?l00`007ol00`00:Ol00c`0G_l00c`01ol00c`02_l7?`03<00>o`03<00:l`Wo00<l
00Oo00<l02go000/o`04?005``Ol1_l800[o00<000_o00<<00Wo00<l00[o00<l00Wo00<<00[o00<<
00Wo2009o`03?01Ho`03?007o0Go00<l00[o00Toc0001Ll;o`04?005c`G?2Ol00c`01_l00c`0;Ol0
02_o00<`00Go00<l00Kc2?l00``02?l500co00<<00_o00<l00[o00<l00_o00<l00[o1@09o`03300:
o`03?01Go`04<`07o0Go00<l00[o00@o00O<3ol00c002_<9o`03?006o`03?00]o`00:ol013<01_00
1O`05?l010003?l00``03?l00c`03?l00c`02ol00``02ol010005Ol00c`0Eol013<01o`00o`01Ll9
o`03?005l`03<00@o`03<006l`G?2Ol00c`01Ol00c`0;Ol002_o00<`00Ol1o`Oo`03000?o`03?00<
o`03?00=o`03000Ro`03?01Go`04<`07o003o005c`Wo00<l00Gc00<`013o00<`00Kc1Ll9o`03?005
o`03?00]o`00;?l013l01L07o1ko00@000ko00<l00ko00<l00co00@0027o00<l05So00<l00Ol1o`:
o`03?005l`03<00@o`03<006l`G?2_l013l01o`/o`00>?l00c`0<Ol00c`03_l00c`0<Ol00c`0G_l0
13l01o`:o`03?005l`03<00@o`03<006l`G?2_l013l01o`/o`00>?l00c`0<?l00c`04?l00c`0<?l0
0c`0G_l00c`01o`;o`03?005l`04?00>o`04?006l`G?2ol00c`01o`/o`00>?l00c`0;ol00``04Ol0
0``0<?l00c`0G_l00c`01o`;o`03?006o003<00>o`04<005c`Kc2ol00c`01o`/o`00>?l00c`03_l0
0c`02_l00c`02Ol00c`01Ol53`co1C`013l01o`9o`03?009o`03?00>o`03?01No`03?007o0_o00<l
00Kl00@l00co00@l00Kc1_<;o`03?007o2co000ho`03?008o`H02ol00``02_l00c`01Ol00`001_<9
o`Do00<l00Go00<l00[o00<<00Wo1P0:o`03?01No`03?007o0_o00<l00Wl00<<00Wo00<<00Po1_<<
o`03?006lbco000ho`03?008o`03000:o`04000<o`03?006o`033006l`Wo00<l00Kc1Ol00c`02ol0
0`002_l010002Ol00c`0G_l00c`01_<<o`04?`0:o0033005o`D?1o`7o0co00<l00Kc;?l003So00<l
01Co00@000co00<l00co00<l00_o00<l00_o00<l00_o00<001Ko00<l05ko00<l00Kc3Ol00c`01o`6
c`D01o`5c`Kc3Ol00c`01_</o`00>?l00c`08_l00``03Ol00c`03?l00c`03?l00``08ol00c`0G_l0
0c`01_<=o`04?`07o0G?1ol00``01_<7o0go00<l00Kc;?l003So00<l02;o00<<00go00<l00co00<l
00co00<002?o00<l05ko00<l00Kc3Ol00c`01Ol01Co02P000o`01L<00o`01Ll=o`03?006lbco000a
o`040`07o23o00<<00go00<<00ko00<l00co00<<02;o00<l05ko00<l00Kc3_l00c`01Ol00c`03_l0
0c`01Ol00c`03ol00c`01_</o`00<_l00c`01o``o`03300=o`03300bo`03?01Go`040`07o0G?3ol0
0c`01Ol00``02ol00``01_l00c`04?l00c`01_</o`00<_l00c`01o``o`03300>o`03300ao`03?01H
o`03?007o0G?3ol00c`01ol00`001_l010002?l00c`04?l00c`01_</o`00<_l013l01_0<o`03300:
o`03300:o`03?007o`03<00<o`04<008o`03300:o`03?009o`03000>o`03?01Ho`03?007o0G?4?l0
0c`02Ol600_o00<l017o00<l00Kc;?l0037o00@?00Ol2?l010003?l00c`02_l00c`02_l00c`02_l0
0c`02_l00c`02_l00``02ol00`002ol00c`0F?l00c`01o`5ca3o00<<01Wo00<<01;o00<l00Kc;?l0
03So00<l00So00@000[o00<000co00<l00_o00<l00[o00<l00_o00<l00_o00<<00[o00<000[o00<l
05Oo00@?00Ol1LlBo`03?00Fo`03?00Co`03?006lbco000ho`03?00Eo`03000<o`03300<o`03?00;
o`03?00;o`03300:o`03000Go`03?01No`03?006la?o00<l01Co00<l01Co00<l00Kc;?l003So00<l
01Go00<l00_o00<000co00<l00co00<l00_o00<<00co00<l01Go00<l05ko00<l00K`5?l00``04Ol0
0``05_l00c`01_</o`00>?l00c`08ol00``03?l00``02ol00`003?l00`009?l00c`0G_l00c`01o`E
o`03300=o`03300Go`03?007o2co000ho`03?00So`03?00<o`03300<o`03300=o`03?00Ro`03?01N
o`03?007o1Oo00@000Ko00@001[o00<l00Ol;?l003So00<l03;o00<l00co00<<03;o00<l05ko00<l
00Ol6ol601ko00<l00Ol;?l003So00@l01co00<l01[o00<l01[o00<l01Wo00@l063o00@o00Ol?Ol0
13l01o`/o`00>?mj063o00@l00Gc00@l00Gc00@l00Gc00@l00Gc1cl013`01O<013`01O<013`01O<0
13`01O<00c`0;Ol00?oo4om@02oo003ooi;o003ooi;o003ooi;o001co`03<032o`03301Fo`00Lol0
0``0`_l00c00E_l007Co00<l0<7o00<`05Ko001co`033032o`03301Fo`00oolio`03?01Fo`00oonB
o`00oonBo`00oonBo`00oonBo`00oonBo`00oonBo`00oonBo`00\
\>"],
  ImageRangeCache->{{{0, 399.9375}, {122.25, 0}} -> {-2.602833, -3.587012, 
  0.01623, 0.01623}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Point Charge and Sphere"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(case2 = {R \[Rule] 1., d \[Rule] 2.}; \)\), 
    \(\(Qi = \(-\(R\/d\)\) /. case2; \)\), 
    \(\(si = d - R\^2\/d /. case2; \)\), 
    \(\(Clear[vreal, vimage]; \)\), 
    \(\(vreal[x_, y_] := 1\/\@\(x\^2 + y\^2\); \)\), 
    \(\(vimage[x_, y_] := Qi\/\@\(x\^2 + \((y + si)\)\^2\); \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(discGraphics = 
      Graphics[{Disk[{0, 0}, .1], Disk[{0, \(-d\) /. case2}, 1]}, 
        AspectRatio \[Rule] Automatic, PlotLabel \[Rule] "\<a\>", opt1]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(fieldGraphics = 
      PlotGradientField[
        \(-\((vreal[x, y] + vimage[x, y])\)\), {x, \(-2\), 2}, {y, \(-3.5\), 
          1.5}, ScaleFunction \[Rule] \((2 + Log[1 + #1]&)\), 
        ScaleFactor \[Rule] 0.5, PlotPoints \[Rule] 8, 
        DisplayFunction \[Rule] Identity]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(discfieldGraphics = 
      Show[{discGraphics, fieldGraphics}, DisplayFunction \[Rule] Identity]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(potentialGraphics = 
      ContourPlot[
        vreal[x, y] + vimage[x, y], {x, \(-2.5\), 2.5}, {y, \(-3.5\), 1.5}, 
        PlotPoints \[Rule] 30, Contours \[Rule] 10, 
        PlotLabel \[Rule] "\<b\>", ContourShading \[Rule] False, 
        DisplayFunction \[Rule] Identity, Evaluate[opt1]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig3 = Show[GraphicsArray[{discfieldGraphics, potentialGraphics}]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57252 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.47619 0.013631 0.47619 [
[ 0 0 0 0 ]
[ 1 .57252 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .57252 L
0 .57252 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.02381 0.013631 0.477324 0.558891 MathSubStart
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.212994 0.800701 0.212994 [
[.07401 -0.0125 -7 -12 ]
[.07401 -0.0125 7 0 ]
[.28701 -0.0125 -7 -12 ]
[.28701 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.71299 -0.0125 -4 -12 ]
[.71299 -0.0125 4 0 ]
[.92599 -0.0125 -4 -12 ]
[.92599 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4 -24 ]
[.5 -0.0125 4 -12 ]
[-0.0125 .16172 -14 -6 ]
[-0.0125 .16172 0 6 ]
[-0.0125 .37471 -14 -6 ]
[-0.0125 .37471 0 6 ]
[-0.0125 .58771 -14 -6 ]
[-0.0125 .58771 0 6 ]
[-0.0125 .8007 -8 -6 ]
[-0.0125 .8007 0 6 ]
[-0.0125 1.01369 -8 -6 ]
[-0.0125 1.01369 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .60115 -26 -4 ]
[-0.01875 .60115 -14 4 ]
[ 0 1.2023 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.2148 -4 0 ]
[.5 1.2148 4 12 ]
[ 0 0 0 0 ]
[ 1 1.2023 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07401 0 m
.07401 .00625 L
s
gsave
.07401 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.28701 0 m
.28701 .00625 L
s
gsave
.28701 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.71299 0 m
.71299 .00625 L
s
gsave
.71299 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.92599 0 m
.92599 .00625 L
s
gsave
.92599 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.11661 0 m
.11661 .00375 L
s
.15921 0 m
.15921 .00375 L
s
.20181 0 m
.20181 .00375 L
s
.24441 0 m
.24441 .00375 L
s
.32961 0 m
.32961 .00375 L
s
.3722 0 m
.3722 .00375 L
s
.4148 0 m
.4148 .00375 L
s
.4574 0 m
.4574 .00375 L
s
.5426 0 m
.5426 .00375 L
s
.5852 0 m
.5852 .00375 L
s
.6278 0 m
.6278 .00375 L
s
.67039 0 m
.67039 .00375 L
s
.75559 0 m
.75559 .00375 L
s
.79819 0 m
.79819 .00375 L
s
.84079 0 m
.84079 .00375 L
s
.88339 0 m
.88339 .00375 L
s
.03141 0 m
.03141 .00375 L
s
.96859 0 m
.96859 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .16172 m
.00625 .16172 L
s
gsave
-0.0125 .16172 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .37471 m
.00625 .37471 L
s
gsave
-0.0125 .37471 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .58771 m
.00625 .58771 L
s
gsave
-0.0125 .58771 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .8007 m
.00625 .8007 L
s
gsave
-0.0125 .8007 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 1.01369 m
.00625 1.01369 L
s
gsave
-0.0125 1.01369 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .20432 m
.00375 .20432 L
s
0 .24692 m
.00375 .24692 L
s
0 .28952 m
.00375 .28952 L
s
0 .33211 m
.00375 .33211 L
s
0 .41731 m
.00375 .41731 L
s
0 .45991 m
.00375 .45991 L
s
0 .50251 m
.00375 .50251 L
s
0 .54511 m
.00375 .54511 L
s
0 .63031 m
.00375 .63031 L
s
0 .6729 m
.00375 .6729 L
s
0 .7155 m
.00375 .7155 L
s
0 .7581 m
.00375 .7581 L
s
0 .8433 m
.00375 .8433 L
s
0 .8859 m
.00375 .8859 L
s
0 .9285 m
.00375 .9285 L
s
0 .9711 m
.00375 .9711 L
s
0 .11912 m
.00375 .11912 L
s
0 .07652 m
.00375 .07652 L
s
0 .03392 m
.00375 .03392 L
s
0 1.05629 m
.00375 1.05629 L
s
0 1.09889 m
.00375 1.09889 L
s
0 1.14149 m
.00375 1.14149 L
s
0 1.18409 m
.00375 1.18409 L
s
.25 Mabswid
0 0 m
0 1.2023 L
s
gsave
-0.01875 .60115 -85 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
65 10 translate
90 rotate
-65 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.07401 1.19605 m
.07401 1.2023 L
s
.28701 1.19605 m
.28701 1.2023 L
s
.5 1.19605 m
.5 1.2023 L
s
.71299 1.19605 m
.71299 1.2023 L
s
.92599 1.19605 m
.92599 1.2023 L
s
.125 Mabswid
.11661 1.19855 m
.11661 1.2023 L
s
.15921 1.19855 m
.15921 1.2023 L
s
.20181 1.19855 m
.20181 1.2023 L
s
.24441 1.19855 m
.24441 1.2023 L
s
.32961 1.19855 m
.32961 1.2023 L
s
.3722 1.19855 m
.3722 1.2023 L
s
.4148 1.19855 m
.4148 1.2023 L
s
.4574 1.19855 m
.4574 1.2023 L
s
.5426 1.19855 m
.5426 1.2023 L
s
.5852 1.19855 m
.5852 1.2023 L
s
.6278 1.19855 m
.6278 1.2023 L
s
.67039 1.19855 m
.67039 1.2023 L
s
.75559 1.19855 m
.75559 1.2023 L
s
.79819 1.19855 m
.79819 1.2023 L
s
.84079 1.19855 m
.84079 1.2023 L
s
.88339 1.19855 m
.88339 1.2023 L
s
.03141 1.19855 m
.03141 1.2023 L
s
.96859 1.19855 m
.96859 1.2023 L
s
.25 Mabswid
0 1.2023 m
1 1.2023 L
s
.99375 .16172 m
1 .16172 L
s
.99375 .37471 m
1 .37471 L
s
.99375 .58771 m
1 .58771 L
s
.99375 .8007 m
1 .8007 L
s
.99375 1.01369 m
1 1.01369 L
s
.125 Mabswid
.99625 .20432 m
1 .20432 L
s
.99625 .24692 m
1 .24692 L
s
.99625 .28952 m
1 .28952 L
s
.99625 .33211 m
1 .33211 L
s
.99625 .41731 m
1 .41731 L
s
.99625 .45991 m
1 .45991 L
s
.99625 .50251 m
1 .50251 L
s
.99625 .54511 m
1 .54511 L
s
.99625 .63031 m
1 .63031 L
s
.99625 .6729 m
1 .6729 L
s
.99625 .7155 m
1 .7155 L
s
.99625 .7581 m
1 .7581 L
s
.99625 .8433 m
1 .8433 L
s
.99625 .8859 m
1 .8859 L
s
.99625 .9285 m
1 .9285 L
s
.99625 .9711 m
1 .9711 L
s
.99625 .11912 m
1 .11912 L
s
.99625 .07652 m
1 .07652 L
s
.99625 .03392 m
1 .03392 L
s
.99625 1.05629 m
1 1.05629 L
s
.99625 1.09889 m
1 1.09889 L
s
.99625 1.14149 m
1 1.14149 L
s
.99625 1.18409 m
1 1.18409 L
s
.25 Mabswid
1 0 m
1 1.2023 L
s
gsave
.5 1.2148 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
66.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1.2023 L
0 1.2023 L
closepath
clip
newpath
.5 .8007 m
.5 .8007 .0213 0 365.72958 arc
F
.5 .37471 m
.5 .37471 .21299 0 365.72958 arc
F
.0001 w
.07401 .05522 m
.11336 .02863 L
s
% Start of user PostScript
-2. -3.5 -1.81528 -3.62487 MAarrowhead1
% End of user PostScript
.07401 .20736 m
.11037 .17623 L
s
% Start of user PostScript
-2. -2.78571 -1.82932 -2.93188 MAarrowhead1
% End of user PostScript
.07401 .3595 m
.0956 .31606 L
s
% Start of user PostScript
-2. -2.07143 -1.89865 -2.27538 MAarrowhead1
% End of user PostScript
.07401 .51164 m
.06583 .46283 L
s
% Start of user PostScript
-2. -1.35714 -2.03841 -1.58629 MAarrowhead1
% End of user PostScript
.07401 .66378 m
.03702 .62918 L
s
% Start of user PostScript
-2. -0.642857 -2.1737 -0.805263 MAarrowhead1
% End of user PostScript
.07401 .81591 m
.02381 .80558 L
s
% Start of user PostScript
-2. 0.0714286 -2.2357 0.0229293 MAarrowhead1
% End of user PostScript
.07401 .96805 m
.02451 .97951 L
s
% Start of user PostScript
-2. 0.785714 -2.2324 0.839509 MAarrowhead1
% End of user PostScript
.07401 1.12019 m
.03125 1.14585 L
s
% Start of user PostScript
-2. 1.5 -2.20076 1.62045 MAarrowhead1
% End of user PostScript
.19572 .05522 m
.24301 .06082 L
s
% Start of user PostScript
-1.42857 -3.5 -1.20658 -3.4737 MAarrowhead1
% End of user PostScript
.19572 .20736 m
.24407 .20715 L
s
% Start of user PostScript
-1.42857 -2.78571 -1.2016 -2.78671 MAarrowhead1
% End of user PostScript
.19572 .3595 m
.24048 .33781 L
s
% Start of user PostScript
-1.42857 -2.07143 -1.21843 -2.17326 MAarrowhead1
% End of user PostScript
.19572 .51164 m
.20922 .46186 L
s
% Start of user PostScript
-1.42857 -1.35714 -1.36521 -1.59083 MAarrowhead1
% End of user PostScript
.19572 .66378 m
.16112 .62235 L
s
% Start of user PostScript
-1.42857 -0.642857 -1.59103 -0.837333 MAarrowhead1
% End of user PostScript
.19572 .81591 m
.14093 .80828 L
s
% Start of user PostScript
-1.42857 0.0714286 -1.68583 0.0355882 MAarrowhead1
% End of user PostScript
.19572 .96805 m
.14629 .98878 L
s
% Start of user PostScript
-1.42857 0.785714 -1.66067 0.883046 MAarrowhead1
% End of user PostScript
.19572 1.12019 m
.15776 1.15456 L
s
% Start of user PostScript
-1.42857 1.5 -1.60682 1.66136 MAarrowhead1
% End of user PostScript
.31743 .05522 m
.35202 .08829 L
s
% Start of user PostScript
-0.857143 -3.5 -0.694772 -3.34473 MAarrowhead1
% End of user PostScript
.31743 .20736 m
.35682 .23718 L
s
% Start of user PostScript
-0.857143 -2.78571 -0.672227 -2.64574 MAarrowhead1
% End of user PostScript
.31743 .3595 m
.36963 .3723 L
s
% Start of user PostScript
-0.857143 -2.07143 -0.612106 -2.01133 MAarrowhead1
% End of user PostScript
.31743 .51164 m
.35924 .47067 L
s
% Start of user PostScript
-0.857143 -1.35714 -0.660886 -1.54949 MAarrowhead1
% End of user PostScript
.31743 .66378 m
.28558 .61048 L
s
% Start of user PostScript
-0.857143 -0.642857 -1.00671 -0.893063 MAarrowhead1
% End of user PostScript
.31743 .81591 m
.25101 .81462 L
s
% Start of user PostScript
-0.857143 0.0714286 -1.16901 0.0653639 MAarrowhead1
% End of user PostScript
.31743 .96805 m
.27164 1.00545 L
s
% Start of user PostScript
-0.857143 0.785714 -1.07214 0.961304 MAarrowhead1
% End of user PostScript
.31743 1.12019 m
.28918 1.16505 L
s
% Start of user PostScript
-0.857143 1.5 -0.989804 1.71062 MAarrowhead1
% End of user PostScript
.43914 .05522 m
.45147 .10169 L
s
% Start of user PostScript
-0.285714 -3.5 -0.227861 -3.28185 MAarrowhead1
% End of user PostScript
.43914 .20736 m
.4546 .25559 L
s
% Start of user PostScript
-0.285714 -2.78571 -0.21315 -2.55928 MAarrowhead1
% End of user PostScript
.43914 .3595 m
.47162 .41414 L
s
% Start of user PostScript
-0.285714 -2.07143 -0.133244 -1.81491 MAarrowhead1
% End of user PostScript
.43914 .51164 m
.51484 .46383 L
s
% Start of user PostScript
-0.285714 -1.35714 0.069676 -1.58158 MAarrowhead1
% End of user PostScript
.43914 .66378 m
.41998 .58955 L
s
% Start of user PostScript
-0.285714 -0.642857 -0.375715 -0.991331 MAarrowhead1
% End of user PostScript
.43914 .81591 m
.33544 .84013 L
s
% Start of user PostScript
-0.285714 0.0714286 -0.772618 0.185116 MAarrowhead1
% End of user PostScript
.43914 .96805 m
.41522 1.03076 L
s
% Start of user PostScript
-0.285714 0.785714 -0.398027 1.08013 MAarrowhead1
% End of user PostScript
.43914 1.12019 m
.4282 1.17367 L
s
% Start of user PostScript
-0.285714 1.5 -0.337117 1.75109 MAarrowhead1
% End of user PostScript
.56086 .05522 m
.54853 .10169 L
s
% Start of user PostScript
0.285714 -3.5 0.227861 -3.28185 MAarrowhead1
% End of user PostScript
.56086 .20736 m
.5454 .25559 L
s
% Start of user PostScript
0.285714 -2.78571 0.21315 -2.55928 MAarrowhead1
% End of user PostScript
.56086 .3595 m
.52838 .41414 L
s
% Start of user PostScript
0.285714 -2.07143 0.133244 -1.81491 MAarrowhead1
% End of user PostScript
.56086 .51164 m
.48516 .46383 L
s
% Start of user PostScript
0.285714 -1.35714 -0.069676 -1.58158 MAarrowhead1
% End of user PostScript
.56086 .66378 m
.58002 .58955 L
s
% Start of user PostScript
0.285714 -0.642857 0.375715 -0.991331 MAarrowhead1
% End of user PostScript
.56086 .81591 m
.66456 .84013 L
s
% Start of user PostScript
0.285714 0.0714286 0.772618 0.185116 MAarrowhead1
% End of user PostScript
.56086 .96805 m
.58478 1.03076 L
s
% Start of user PostScript
0.285714 0.785714 0.398027 1.08013 MAarrowhead1
% End of user PostScript
.56086 1.12019 m
.5718 1.17367 L
s
% Start of user PostScript
0.285714 1.5 0.337117 1.75109 MAarrowhead1
% End of user PostScript
.68257 .05522 m
.64798 .08829 L
s
% Start of user PostScript
0.857143 -3.5 0.694772 -3.34473 MAarrowhead1
% End of user PostScript
.68257 .20736 m
.64318 .23718 L
s
% Start of user PostScript
0.857143 -2.78571 0.672227 -2.64574 MAarrowhead1
% End of user PostScript
.68257 .3595 m
.63037 .3723 L
s
% Start of user PostScript
0.857143 -2.07143 0.612106 -2.01133 MAarrowhead1
% End of user PostScript
.68257 .51164 m
.64076 .47067 L
s
% Start of user PostScript
0.857143 -1.35714 0.660886 -1.54949 MAarrowhead1
% End of user PostScript
.68257 .66378 m
.71442 .61048 L
s
% Start of user PostScript
0.857143 -0.642857 1.00671 -0.893063 MAarrowhead1
% End of user PostScript
.68257 .81591 m
.74899 .81462 L
s
% Start of user PostScript
0.857143 0.0714286 1.16901 0.0653639 MAarrowhead1
% End of user PostScript
.68257 .96805 m
.72836 1.00545 L
s
% Start of user PostScript
0.857143 0.785714 1.07214 0.961304 MAarrowhead1
% End of user PostScript
.68257 1.12019 m
.71082 1.16505 L
s
% Start of user PostScript
0.857143 1.5 0.989804 1.71062 MAarrowhead1
% End of user PostScript
.80428 .05522 m
.75699 .06082 L
s
% Start of user PostScript
1.42857 -3.5 1.20658 -3.4737 MAarrowhead1
% End of user PostScript
.80428 .20736 m
.75593 .20715 L
s
% Start of user PostScript
1.42857 -2.78571 1.2016 -2.78671 MAarrowhead1
% End of user PostScript
.80428 .3595 m
.75952 .33781 L
s
% Start of user PostScript
1.42857 -2.07143 1.21843 -2.17326 MAarrowhead1
% End of user PostScript
.80428 .51164 m
.79078 .46186 L
s
% Start of user PostScript
1.42857 -1.35714 1.36521 -1.59083 MAarrowhead1
% End of user PostScript
.80428 .66378 m
.83888 .62235 L
s
% Start of user PostScript
1.42857 -0.642857 1.59103 -0.837333 MAarrowhead1
% End of user PostScript
.80428 .81591 m
.85907 .80828 L
s
% Start of user PostScript
1.42857 0.0714286 1.68583 0.0355882 MAarrowhead1
% End of user PostScript
.80428 .96805 m
.85371 .98878 L
s
% Start of user PostScript
1.42857 0.785714 1.66067 0.883046 MAarrowhead1
% End of user PostScript
.80428 1.12019 m
.84224 1.15456 L
s
% Start of user PostScript
1.42857 1.5 1.60682 1.66136 MAarrowhead1
% End of user PostScript
.92599 .05522 m
.88664 .02863 L
s
% Start of user PostScript
2. -3.5 1.81528 -3.62487 MAarrowhead1
% End of user PostScript
.92599 .20736 m
.88963 .17623 L
s
% Start of user PostScript
2. -2.78571 1.82932 -2.93188 MAarrowhead1
% End of user PostScript
.92599 .3595 m
.9044 .31606 L
s
% Start of user PostScript
2. -2.07143 1.89865 -2.27538 MAarrowhead1
% End of user PostScript
.92599 .51164 m
.93417 .46283 L
s
% Start of user PostScript
2. -1.35714 2.03841 -1.58629 MAarrowhead1
% End of user PostScript
.92599 .66378 m
.96298 .62918 L
s
% Start of user PostScript
2. -0.642857 2.1737 -0.805263 MAarrowhead1
% End of user PostScript
.92599 .81591 m
.97619 .80558 L
s
% Start of user PostScript
2. 0.0714286 2.2357 0.0229293 MAarrowhead1
% End of user PostScript
.92599 .96805 m
.97549 .97951 L
s
% Start of user PostScript
2. 0.785714 2.2324 0.839509 MAarrowhead1
% End of user PostScript
.92599 1.12019 m
.96875 1.14585 L
s
% Start of user PostScript
2. 1.5 2.20076 1.62045 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.013631 0.97619 0.558891 MathSubStart
%% ContourGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.192308 0.692308 0.192308 [
[.11538 -0.0125 -7 -12 ]
[.11538 -0.0125 7 0 ]
[.30769 -0.0125 -7 -12 ]
[.30769 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.69231 -0.0125 -4 -12 ]
[.69231 -0.0125 4 0 ]
[.88462 -0.0125 -4 -12 ]
[.88462 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4 -24 ]
[.5 -0.0125 4 -12 ]
[-0.0125 .11538 -14 -6 ]
[-0.0125 .11538 0 6 ]
[-0.0125 .30769 -14 -6 ]
[-0.0125 .30769 0 6 ]
[-0.0125 .5 -14 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .69231 -8 -6 ]
[-0.0125 .69231 0 6 ]
[-0.0125 .88462 -8 -6 ]
[-0.0125 .88462 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -26 -4 ]
[-0.01875 .5 -14 4 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.30769 0 m
.30769 .00625 L
s
gsave
.30769 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.69231 0 m
.69231 .00625 L
s
gsave
.69231 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .11538 m
.00625 .11538 L
s
gsave
-0.0125 .11538 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .30769 m
.00625 .30769 L
s
gsave
-0.0125 .30769 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .69231 m
.00625 .69231 L
s
gsave
-0.0125 .69231 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .88462 m
.00625 .88462 L
s
gsave
-0.0125 .88462 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .15385 m
.00375 .15385 L
s
0 .19231 m
.00375 .19231 L
s
0 .23077 m
.00375 .23077 L
s
0 .26923 m
.00375 .26923 L
s
0 .34615 m
.00375 .34615 L
s
0 .38462 m
.00375 .38462 L
s
0 .42308 m
.00375 .42308 L
s
0 .46154 m
.00375 .46154 L
s
0 .53846 m
.00375 .53846 L
s
0 .57692 m
.00375 .57692 L
s
0 .61538 m
.00375 .61538 L
s
0 .65385 m
.00375 .65385 L
s
0 .73077 m
.00375 .73077 L
s
0 .76923 m
.00375 .76923 L
s
0 .80769 m
.00375 .80769 L
s
0 .84615 m
.00375 .84615 L
s
0 .07692 m
.00375 .07692 L
s
0 .03846 m
.00375 .03846 L
s
0 .92308 m
.00375 .92308 L
s
0 .96154 m
.00375 .96154 L
s
0 1 m
.00375 1 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -85 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
65 10 translate
90 rotate
-65 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .15385 m
1 .15385 L
s
.99625 .19231 m
1 .19231 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .26923 m
1 .26923 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .38462 m
1 .38462 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .46154 m
1 .46154 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .57692 m
1 .57692 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .65385 m
1 .65385 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .76923 m
1 .76923 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .84615 m
1 .84615 L
s
.99625 .07692 m
1 .07692 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .92308 m
1 .92308 L
s
.99625 .96154 m
1 .96154 L
s
.99625 1 m
1 1 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.48342 .5786 m
.51658 .5786 L
.53949 .58289 L
.54973 .58591 L
.58289 .60254 L
.59881 .61605 L
.61605 .63628 L
.62247 .6492 L
.63282 .68236 L
.63392 .71552 L
.62614 .74867 L
.61605 .77031 L
.60768 .78183 L
.58289 .80652 L
.57136 .81499 L
.54973 .82506 L
.51658 .83332 L
.48342 .83332 L
.45027 .82506 L
.42864 .81499 L
.41711 .80652 L
.39232 .78183 L
.38395 .77031 L
.37386 .74867 L
.36608 .71552 L
.36718 .68236 L
.37753 .6492 L
.38395 .63628 L
.40119 .61605 L
.41711 .60254 L
.45027 .58591 L
.46051 .58289 L
.48342 .5786 L
s
.45027 .57268 m
.48342 .56702 L
.51658 .56702 L
.54973 .57268 L
.578 .58289 L
.58289 .58543 L
.61605 .6092 L
.62238 .61605 L
.64403 .6492 L
.6492 .66202 L
.65436 .68236 L
.65628 .71552 L
.65059 .74867 L
.6492 .7539 L
.63616 .78183 L
.61605 .80903 L
.61022 .81499 L
.58289 .836 L
.55962 .84814 L
.54973 .85133 L
.51658 .85832 L
.48342 .85832 L
.45027 .85133 L
.44038 .84814 L
.41711 .836 L
.38978 .81499 L
.38395 .80903 L
.36384 .78183 L
.3508 .7539 L
.34941 .74867 L
.34372 .71552 L
.34564 .68236 L
.3508 .66202 L
.35597 .6492 L
.37762 .61605 L
.38395 .6092 L
.41711 .58543 L
.422 .58289 L
.45027 .57268 L
s
.38395 .58248 m
.41711 .56669 L
.45027 .55813 L
.48342 .55445 L
.51658 .55445 L
.54973 .55813 L
.58289 .56669 L
.61605 .58248 L
.61669 .58289 L
.6492 .61025 L
.65394 .61605 L
.67405 .6492 L
.68236 .6726 L
.68461 .68236 L
.68768 .71552 L
.6842 .74867 L
.68236 .75925 L
.67382 .78183 L
.65546 .81499 L
.6492 .82344 L
.62572 .84814 L
.61605 .85602 L
.58289 .87633 L
.57292 .8813 L
.54973 .88857 L
.51658 .89436 L
.48342 .89436 L
.45027 .88857 L
.42708 .8813 L
.41711 .87633 L
.38395 .85602 L
.37428 .84814 L
.3508 .82344 L
.34454 .81499 L
.32618 .78183 L
.31764 .75925 L
.3158 .74867 L
.31232 .71552 L
.31539 .68236 L
.31764 .6726 L
.32595 .6492 L
.34606 .61605 L
.3508 .61025 L
.38331 .58289 L
.38395 .58248 L
s
.41711 .54654 m
.45027 .54234 L
.48342 .5407 L
.51658 .5407 L
.54973 .54234 L
.58289 .54654 L
.59826 .54973 L
.61605 .55484 L
.6492 .56954 L
.66909 .58289 L
.68236 .59413 L
.70135 .61605 L
.71552 .63812 L
.72054 .6492 L
.73149 .68236 L
.73619 .71552 L
.73533 .74867 L
.72909 .78183 L
.71717 .81499 L
.71552 .81861 L
.69859 .84814 L
.68236 .86942 L
.67141 .8813 L
.6492 .90107 L
.6304 .91446 L
.61605 .92287 L
.58289 .93779 L
.54973 .94724 L
.54789 .94761 L
.51658 .95182 L
.48342 .95182 L
.45211 .94761 L
.45027 .94724 L
.41711 .93779 L
.38395 .92287 L
.3696 .91446 L
.3508 .90107 L
.32859 .8813 L
.31764 .86942 L
.30141 .84814 L
.28448 .81861 L
.28283 .81499 L
.27091 .78183 L
.26467 .74867 L
.26381 .71552 L
.26851 .68236 L
.27946 .6492 L
.28448 .63812 L
.29865 .61605 L
.31764 .59413 L
Mistroke
.33091 .58289 L
.3508 .56954 L
.38395 .55484 L
.40174 .54973 L
.41711 .54654 L
Mfstroke
.71779 .98077 m
.74867 .95077 L
.75148 .94761 L
.77694 .91446 L
.78183 .90693 L
.79624 .8813 L
.81051 .84814 L
.81499 .83531 L
.82033 .81499 L
.82603 .78183 L
.82773 .74867 L
.82534 .71552 L
.81856 .68236 L
.81499 .66973 L
.80666 .6492 L
.78836 .61605 L
.78183 .60673 L
.76068 .58289 L
.74867 .57214 L
.71552 .55032 L
.71438 .54973 L
.68236 .53674 L
.6492 .52913 L
.61605 .52578 L
.58289 .52513 L
.54973 .52573 L
.51658 .52639 L
.48342 .52639 L
.45027 .52573 L
.41711 .52513 L
.38395 .52578 L
.3508 .52913 L
.31764 .53674 L
.28562 .54973 L
.28448 .55032 L
.25133 .57214 L
.23932 .58289 L
.21817 .60673 L
.21164 .61605 L
.19334 .6492 L
.18501 .66973 L
.18144 .68236 L
.17466 .71552 L
.17227 .74867 L
.17397 .78183 L
.17967 .81499 L
.18501 .83531 L
.18949 .84814 L
.20376 .8813 L
.21817 .90693 L
Mistroke
.22306 .91446 L
.24852 .94761 L
.25133 .95077 L
.28221 .98077 L
Mfstroke
.01923 .53755 m
.04174 .51658 L
.05239 .50807 L
.08554 .48653 L
.09139 .48342 L
.1187 .47138 L
.15186 .46174 L
.18501 .45698 L
.21817 .45663 L
.25133 .46015 L
.28448 .46683 L
.31764 .47565 L
.34715 .48342 L
.3508 .48534 L
.38395 .49502 L
.41711 .50327 L
.45027 .5093 L
.48342 .51249 L
.51658 .51249 L
.54973 .5093 L
.58289 .50327 L
.61605 .49502 L
.6492 .48534 L
.65285 .48342 L
.68236 .47565 L
.71552 .46683 L
.74867 .46015 L
.78183 .45663 L
.81499 .45698 L
.84814 .46174 L
.8813 .47138 L
.90861 .48342 L
.91446 .48653 L
.94761 .50807 L
.95826 .51658 L
.98077 .53755 L
s
.48342 .11611 m
.51658 .11611 L
.53568 .1187 L
.54973 .12193 L
.58289 .13426 L
.61283 .15186 L
.61605 .15433 L
.64814 .18501 L
.6492 .18632 L
.6702 .21817 L
.68236 .24648 L
.68387 .25133 L
.6908 .28448 L
.69185 .31764 L
.68721 .3508 L
.68236 .36868 L
.6763 .38395 L
.65746 .41711 L
.6492 .43016 L
.62807 .45027 L
.61605 .46145 L
.58289 .48132 L
.57805 .48342 L
.54973 .49362 L
.51658 .4997 L
.48342 .4997 L
.45027 .49362 L
.42195 .48342 L
.41711 .48132 L
.38395 .46145 L
.37193 .45027 L
.3508 .43016 L
.34254 .41711 L
.3237 .38395 L
.31764 .36868 L
.31279 .3508 L
.30815 .31764 L
.3092 .28448 L
.31613 .25133 L
.31764 .24648 L
.3298 .21817 L
.3508 .18632 L
.35186 .18501 L
.38395 .15433 L
.38717 .15186 L
.41711 .13426 L
.45027 .12193 L
.46432 .1187 L
.48342 .11611 L
s
.48342 .25041 m
.51658 .25041 L
.52258 .25133 L
.54973 .25961 L
.58289 .28013 L
.58777 .28448 L
.6121 .31764 L
.61605 .31886 L
.62269 .3508 L
.62324 .38395 L
.61605 .41372 L
.61454 .41711 L
.59146 .45027 L
.58289 .45954 L
.54973 .47918 L
.53733 .48342 L
.51658 .48792 L
.48342 .48792 L
.46267 .48342 L
.45027 .47918 L
.41711 .45954 L
.40854 .45027 L
.38546 .41711 L
.38395 .41372 L
.37676 .38395 L
.37731 .3508 L
.38395 .31886 L
.3879 .31764 L
.41223 .28448 L
.41711 .28013 L
.45027 .25961 L
.47742 .25133 L
.48342 .25041 L
s
.45027 .30545 m
.48342 .29346 L
.51658 .29346 L
.54973 .30545 L
.56723 .31764 L
.58289 .33642 L
.58961 .3508 L
.59598 .38395 L
.59042 .41711 L
.58289 .43468 L
.56982 .45027 L
.54973 .46644 L
.51658 .47776 L
.48342 .47776 L
.45027 .46644 L
.43018 .45027 L
.41711 .43468 L
.40958 .41711 L
.40402 .38395 L
.41039 .3508 L
.41711 .33642 L
.43277 .31764 L
.45027 .30545 L
s
.48342 .31619 m
.51658 .31619 L
.52331 .31764 L
.54973 .33164 L
.56751 .3508 L
.5792 .38395 L
.57377 .41711 L
.55432 .45027 L
.54973 .45459 L
.51658 .46926 L
.48342 .46926 L
.45027 .45459 L
.44568 .45027 L
.42623 .41711 L
.4208 .38395 L
.43249 .3508 L
.45027 .33164 L
.47669 .31764 L
.48342 .31619 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{256, 147},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000500000^0800@400ooo@Ol00?oo@Ol00?oo@Ol0
0?oo@Ol00?oo@Ol00?oo@Ol00?oo@Ol00?oo@Ol005co00<`0>7o001Mo`03?03Po`00GOl00c`0h?l0
05co00<`0>7o003ood7o003ood7o003ood7o003ood7o003ood7o003lo`03<011o`00oOl00c`0@?l0
0?go00<l043o000_o`03000Eo`03000Co`03?00Do`03000Eo`03001]o`03<011o`00;ol00c`05_l0
0c`04Ol00c005_l00c`05?l00c`0/Ol002[o00<000Ol3_l00`001o`@o`03<00Fo`03?00Eo`03?02`
o`00;ol00c005_l00c`04Ol00c005_l00c`05?l00c00/Ol0033o00<<01Co00<<01?o00<l01Co00<<
01Ko00<<0;3o003ood7o003ood7o003ood7o003ood7o003Ao`03000Do`03000Bo`03?00Bo`03000D
o`03000Do`009Omb03[o00<l01Go00<l013o00<`01Co00<l01?o00<l01Co000Uo`03?006o`03?00E
o`03?00Eo`03?00Eo`03?00Eo`03?005o`03?00do`030006l`go00<000Ol3ol00c005?l00c`05?l0
0c`04ol002Go00<l06ko00<l03So00<`01Go00<l013o00<`01Co00<l01?o00<`01Co000Uo`03?009
o`03301Eo`03000:o`03?00io`03300Co`03300Bo`03?00Bo`03300Eo`03300Co`009Ol00``02?l0
0`00Eol00``02Ol00c`0Yol002Go00<l00Oo00<005Wo00<<00So00<l0:Oo000Uo`03?006o`03?00:
o`H02?l00c`02ol00c`02ol00c`02_l00c`01_l600co00<<00Ko00<l0:Oo000Uo`03?00Fo`040008
o`03?00:o`03?00:o`03?00:o`03?007o`03000Ho`03?02Wo`009Ol00``08ol00``02Ol00c`02_l0
0c`02?l00``09?l00c`0Yol002Go00<l02?o00<000Wo00<<00Wo00<<00Wo00<<02Co00<l02[oMP07
o`009Ol00c`09Ol00c`01ol00``02Ol00``02?l00``09Ol00c`0:_l8?`W?2Ll9c`W?2Ll9c`W?2Ll9
c`W?2Ll9c`G?00Co00009Ol00c`0<?l00c`02?l00``0<?l00c`0:_l00c`0L_l00c`01Ol002Go00<l
06ko00<l02[o00<l07;o00<l00Go000Uo`03301^o`03?00Zo`03?01bo`03?005o`009Ol00c`0K_l0
0c`0:_l00c`0LOl00``01_l002Go00<l06ko00<l02[o00<l07;o00<l00Go000No`043`07o6go00<l
02[o00<l07;o00<l00Go000Po`03?006lfgo00<l02[o00<l07;o00<l00Go000Io`030007o0K`<_l6
03Co00<<02_o00<l077o00<<00Ko000Po`03?006lbgo400`o`03?00Zo`03?01bo`03?005o`007_l0
10l01o`7o`03000PoaH08Ol00``02Ol00c`08_l00``01Ol00c`0L_l00c`01Ol002Go00<l00So00<<
01oo600Po`030009o`03?00To`03?007o77o00<l00Go000Uo`03?007o`03300Ooa/07ol00``02?l0
0c`07_l00`001_<7o77o00<l00Go000Uo`033006o`03?00:o`L01ol01So`01h01Ol00c`01_l600co
00<<00Ko00<l02Co00@o00K`<Ol<03?o00<<00Ko000Uo`03?00Go`03?008o`Do8006l`Oo00<<01Oo
00<l02;o00<<00Go00<l02oo00<000co00<<037o00<l00Go000Uo`03?00SobH09Ol00c`0:_l00c`0
;Ol00``04?l00`00;ol00c`01Ol002Go00<l02?o9P0Uo`03?00Zo`03?00[o`03300Eo`03?00/o`03
?005o`009Ol00c`08olV02Go00<l02[o00<l02[o00<l01Oo00<<02[o00<<00Ko000Uo`03300RobP0
9?l00c`0:_l00c`0:Ol00c`06_l00c`0:Ol00c`01Ol002Go00<l02;o:@0So`03?00Zo`03?00Xo`03
?00Lo`03?00Xo`03?005o`009Ol00c`08OlZ02?o00<l02[o00<l02Oo00<l01ko00<l02Oo00<l00Go
000Uo`03?00Pob`08_l00c`0:_l00c`09_l00c`08?l00c`09_l00c`01Ol002Go00<<023o;@0Qo`03
?00Zo`03?00Uo`03?00Qo`03?00Uo`033006o`009Ol00c`07ol^027o00<l02[o00<l02Go00<l02;o
00<l02Go00<l00Go000Uo`03?00Oobh08Ol00c`0:_l00c`09?l00c`09?l00c`09?l00c`01Ol002Go
00<l00So00<l01Co;P0Fo`03?008o`03?00Zo`03?00So`03?00Uo`03?00To`03?005o`009Ol00c`0
1ol00``05Ol_01Go00<<00So00<l02[o00<l02?o00<l02Ko00<l02;o00<<00Ko000Uo`033007o`03
300Eobl05_l00``01ol00c`0:_l00c`08_l00c`09ol00c`08ol00c`01Ol002Go00<l00Oo00<<00co
00<000Go<005o`03000>o`033007o`03?00Zo`03?00Ro`03?00@o`D04ol00c`08_l00c`01Ol002Go
00<l00Ko00<l00go00<000Go<006o`03000>o`03?006o`03?00Zo`03?00Ro`03?00=o`0<0?l000oo
00<l02;o00<l00Go000No`040`07o0Go00<l00[o00<000So<009o`03300<o`03?005o`03?00Zo`03
?00Ro`03?00<o`033009o`03300=o`03?00Ro`03?005o`007_l013l01o`Moc407ol00c`0:_l00c`0
8Ol00c`02ol00``03Ol00``02ol00c`08Ol00``01_l001Wo00<000Ol1_0Moc407_l00``0:ol00c`0
8Ol00c`02Ol00``04Ol00``02_l00c`08Ol00c`01Ol001ko00@c00Ol7Ola01oo00<l02;o00<000Go
00<l027o00<l00Wo00<l00Go1@08o`03?009o`03?00Qo`03?005o`007ol00``01o`Moc407ol00c`0
8_l00c`01Ol00c`08Ol00c`02?l01So`00G000Kl0006o`03?008o`03?00Qo`03?005o`009Ol00c`0
7_l`023o00<l01ko00<000Kc00Gl02;o00<l00Oo00@o00K`2?l00``01o`7o`03?00Po`033006o`00
9Ol00c`07_l`023o00<l02;o00<`00Go00<l027o00<l00Ko00<l00K`00?`00D000?l00G?1L<6o`03
?00Qo`03?005o`009Ol00``07ol_023o00<l02?o00@?00Ol8?l00c`01_l00c`01o<01Co01_05c`G?
1Ol00c`08Ol00c`01Ol002Go00<l01oo;`0Po`03?00Zo`03?00Qo`03?005o`03?00:l`Oo33l5o`03
?00Qo`03?005o`009Ol00c`07ol^027o00<l02[o00<l027o00<l00Go1Cl013`03?l00c`023l00o`0
1LlQo`03?005o`009Ol00c`07ol^027o00<l02[o00<l027o00<l00Go1Sl00``03Ol00c`023l7o23o
00<<00Ko000Uo`03?00Oobh08Ol00c`0:_l00c`08_l013l02O`00c`03_l00c001o`7o27o00<l00Go
000Uo`033005o`03?00=o`03?008obd02Ol00``03Ol00``01Ol00c`0:_l00c`08_l013l02O`00c`0
3_l00c001o`7o27o00<l00Go000Uo`03?005o`03?00<o`033009ob`02_l00``03Ol00``01Ol00c`0
:_l00c`08_l013l01_`00c004Ol00c001o`6lb;o00<l00Go000Uo`03?005o`03300<o`03300:obX0
3?l00``03?l00``01Ol00c`0:_l00c`08ol00c`01_`00c004_l00c001_<6lb7o00<<00Ko000Uo`03
?005o`03?00<o`03?00;obT03?l00c`03?l00c`01Ol00c`0:_l00c`08ol00c`01_`00c004Ol00c00
1o`5cb?o00<l00Go000Uo`033005o`03?00<o`03?00;obP03_l00c`02ol00c`01Ol00c`0:_l00c`0
9?l00c`01O<00c004Ol00c001_<6lb?o00<l00Go000Uo`03?006o`03?00:o`03?00<obL01Ll:o`03
?00;o`03?005o`03?00Zo`03?00To`03?006o003<00@o`03<006l`G?9?l00c`01Ol002Go00<l00Ko
00<l00[o00<l00_o1C`S00G?2_l00c`02ol00c`01Ol00c`0:_l00c`09Ol00c`01O<00c004?l00c00
1_<5cbCo00<l00Go000Uo`03?00Tob@09_l00c`0:_l00c`09_l013l01l`>o`03<006l`G?9?l00``0
1_l002Go00<l02Go8P0Wo`03?00Zo`03?00Vo`033005l`03<00>o`Hc1o`Vo`03?005o`009Ol00``0
9olO02So00<l02[o00<l02So1cl00c003?l00c002_<Wo`03?005o`009Ol00c`0:?lL02[o00<l02[o
00<l02So00D?`0D`00<l00So00@000W?:?l00c`01Ol002Go00<l02[o6@0[o`03?00Zo`03?00>o`l0
3Ol7?`040006o`04300:l`Wo400?o`033006o`007_l010<01o`ZoaH0;Ol00c`0:_l00c`02ol00`00
3ol010002_l73`H<1P09``Oo00@0013o00<000go00<l00Go000Oo`03?007o2go4@0_o`03?00Ro`03
0005o`03?009o`03300Eo`040008o`L?1`0:l0Go00@001Oo00<<00[o00<l00Go000?o`03?006l`G0
1_<6l2co00Hol00700Go00<l02_o00<<01Co00<l00Kc1ol013l01o`6o`03300Ko`030006o`050l0:
00K`00?l00G07?l00``02?l00c`01Ol000oo1P<:o`03?007o2co00<l00ko00<<02go00<l01?o1P<5
o`030006l`Ol00?l00G37ol010001Ol010001Ol500Go00<002;o00<l00Ko00<l00Go000Ao`03300:
o`043`07o2co00<<00ko00<<02go00<l01Go00<<00_o00Do`0K`1o`To`D000Co00D01Ol502Ko00D?
`0K`1Ol000oo00<<01?o00<l01go00<<00go00<l00ko00<<00co00<<01ko00<l01?o00<<00co00<<
00Go00<l00K`:ol>02go00<l00Ol00Co00009Ol00c`03ol00``03?l00``03Ol00c`03Ol00c`02ol0
0`003?l00``04?l00c`0:_l5?`03?01Xo`03?006l`04o`0002Go1Pl00c`02_l00``02ol00``03Ol0
0c`03?l00c`03?l00``02ol00`003?l00``01_<Yo`04?00SobL08ol8?`04o`0002Go00<l00K`2_l0
0``03?l00c`03?l00c`03?l00c`03?l00c`02ol00``02ol00``01o`Yo`03<00Qo`03000?o`T03ol0
10008?l010001ol002Go00@o00K`2ol00c`02ol00c`02ol00c`03?l00c`02ol00c`02ol00c`03?l0
0``01o`Yo`03?00No`03000;o`L02Ol800_o00<<023o00<l00Go000Uo`03?005o`03?00;o`03?00;
o`03?00;o`03?00;o`03?00;o`03?00;o`03?00:o`033005o`03?00Zo`03?00Mo`033009o`030006
o``01_l00``02_l00``07_l00c`01Ol002Go00<l00Ko00<l00[o00<l00_o00<l00_o00<l00_o00<l
00[o00<l00_o00<l00_o00<l00Go00<l02[o00<l01co00<l00So00X?o005?`0?0?l0o0G02Ol00c`0
7?l00c`01Ol002Go00<<06ko00<l02[o00<l01[o00<<00So00D?`0K`00[03o050005o005o`03?008
o`03?00Ko`03?005o`009Ol00c`0K_l00c`0:_l00c`06Ol00c`02?l013l02?05?0P01_05``K`1ol0
0``06Ol00``01_l002Go00<l06ko00<l02[o00<l01So00<l00So00<l00Sl1S09o`P?1Ll6l`Ko00<l
01Wo00<l00Go000Uo`03?01^o`03?00Zo`03?00Go`03?008o`03?009o003300>o`D?1o`6l`Ko00<l
01So00<l00Go000Uo`03?01^o`03?00Zo`03?00Fo`03?008o`03?009l003300Ao`D<1_<6l`Ko00<l
01Oo00<l00Go000Uo`03301^o`03?00Zo`03?00Fo`03?007o`03?007l0Kc4ol013`01_<6l`Ko00<l
01Go00<<00Ko000Uo`03?01^o`03?00Zo`03?00Eo`03?007o`03?009o003?00Fo`03<007o0G?1_l0
0c`05_l00c`01Ol002Go00<l06ko00<l02[o00<l01Go00<l00Oo00<l00Sc00<l01Oo00@l00Kc1_<6
o`03?00Eo`03?005o`009Ol00c`0K_l00c`0:_l00c`05?l00c`01ol00c`01_`013`06_l00c001o`6
l`Ko00<l01Co00<l00Go000Uo`03301^o`03?00Zo`03?00Do`03?007o`03?008l`03?00Jo`03<007
o0G?1_l00c`05?l00c`01Ol002Go00<l06ko00<l02[o00<l01?o00<l00Oo00<l00Kl00@l01co00@l
00Kc1Ll7o`03?00Bo`033006o`009Ol00c`0K_l00c`0:_l00c`04ol00c`01ol00c`02?<00c`06ol0
13`01_<6l`Ko00<l01?o00<l00Go000Oo`03?007o3?o00@003Ko00<l02Co00<l00Ol4Ol00c`02?l0
0c`02?<00c`07?l00c001o`5c`Ko00<l01?o00<l00Go000No`04<`07o3?o1@0eo`03?00So`04<`07
o17o00<l00Oo00<l00Kl00@l01ko00<`00Ol1Ll7o`03?00Bo`03?005o`007_l01C?01_0bo`H0=?l0
0``09?l01C?01_0Ao`03?007o`03?006o004?00No`03<007o0Kc1_l00c`04Ol00``01_l001ko00@c
00Kl00@000Wo00@000[o00<<01Go1P0Go`033008o`040009o`040006lb;o00@c00Ol4Ol00c`01ol0
0c`01_`013`07_l013`01_<6l`Ko00<l01;o00<l00Go000Oo`03?007o006c0001ol730Go200;o`07
0o`50003o005`0Wo2@05o`H32?l530Ol8ol00c`01o`Ao`03?007o`03?006o004?00No`04?006l`Kc
1_l00c`04_l00c`01Ol002Go00<l02So1@09o`03?007o`04000Zo`03?00Zo`03?00Ao`03?008o`03
?009l`03?00Lo`04?006l`Kc1_l00c`04_l00c`01Ol002Go00<l02?o1@0Lo`D09Ol00c`0:_l00c`0
4Ol00c`02?l00c`01_`013`07_l00c001o`6l`Ko00<l01;o00<l00Go000Uo`03300So`03000Po`03
000Uo`03?00Zo`03?00Ao`03?008o`03?006o004?00Mo`03?008?`Kc1ol00c`04?l00``01_l002Go
00<l06ko00<l02[o00<l017o00<l00So00<l00Wl00<l01_o00<l00Po1_<7o`03?00Ao`03?005o`00
9Ol00c`0K_l00c`0:_l00c`04Ol00c`02?l00c`02_`00c`06_l00c`023l6l`Oo00<l017o00<l00Go
000Uo`03?01^o`03?00Zo`03?00Ao`03?008o`03?00:o003?00Io`05?<07o0Kc1ol00c`04Ol00c`0
1Ol002Go00<l06ko00<l02[o00<l017o00<l00So00<l00Ol00?<00G?5ol00c`023l6l`So00<l013o
00<<00Ko000Uo`03301^o`03?00Zo`03?00Ao`03?008o`04?`0:o003?00Go``o1_<7o`03?00Bo`03
?005o`009Ol00c`0K_l00c`0:_l00c`04Ol00c`02Ol00c`02?`013`05ol53`05o005o`03?008o`03
?00Bo`03?005o`009Ol00c`0K_l00c`0:_l00c`04_l00c`02?l013l01o`00l`01LlBo`Po1Ll7o0Oo
00<l01;o00<l00Go000Uo`03?01^o`03?00Zo`03?00Bo`03?008o`04?`07o0K?00<l013o23l5c`Ol
2?l00c`04_l00c`01Ol002Go00<l06ko00<l02[o00<l01;o00<l00Wo00@o00Ol1/l00c`03_l5?`03
?006l`Ol2?l00c`04Ol00``01_l002Go00<<06ko00<l02[o00<l01;o00<l00Wo00<l00Go00<l00Kc
1L<:o`033006l0Kc00Gl00_o00<l01;o00<l00Go000Uo`03?01^o`03?00Zo`03?00Bo`03?00:o`04
?`07o0K`00o`3o0<1o`6l`03o005c`So00<l01?o00<l00Go000Uo`03?01^o`03?00Zo`03?00Co`03
?009o`03?005o`04?`07o003o00500Ko00@?00Ol00?l00G?2Ol00c`04ol00c`01Ol002Go00<l06ko
00<l02[o00<l01?o00<l00[o00<l00Go00H?l005`0_o00<<00Go00<l00Ko00<l00[o00<l01;o00<<
00Ko000Uo`053l06<0_o00<l00_o00<l00_o00<l00_o00<l00[o00<l00_o00<<00_o1@`7o2Wo00<l
01?o00<l00_o00<l00Go00<<00Ko3007o`03?006o`03?00:o`03?00Do`03?005o`009Ol5?003300:
o`04000=o`03?00;o`03?00<o`03?00;o`03300<o`03000;o`040006lb;o00@300Ol4ol00c`02_l0
0c`01ol00c`05Ol00``01ol00c`02ol00c`05?l00c`01Ol002Go00<l00ko00<000co00<`00ko00<l
00co00<l00go00<<00_o00@000oo00<l02Co00<l00Ol4ol00c`02ol00c`01ol00``04ol00c`01ol0
0``02ol00c`05Ol00c`01Ol001ko00@300Ol6ol00`003ol00c`03Ol00c`03?l00`007_l00c`09?l0
0c`01o`Do`03?00;o`03?008o`03300>o`030009o`03?00<o`03?00Eo`03?005o`007ol00c`01o`K
o`03300>o`03?00>o`03?00=o`03300Mo`03?00To`04?`06l1Co00<l00co00<l00Wo1@06o`04000;
o`03?00<o`03?00Eo`033006o`007ol013l01_0[o`03300?o`03300/o`03300To`043`07o1Go00<l
00co00<<00go1P0>o`03?00=o`03?00Fo`03?005o`007ol00c`01o`[o`03300?o`03300]o`03?00Z
o`03?00Fo`03?00=o`03300Oo`03?00=o`03?00Go`03?005o`007_l010l01o`[o`03300@o`03?00/
o`03?00Zo`03?00Go`03?00>o`03?00Ko`03300?o`03?00Go`03?005o`009Ol00c`0K_l00c`0:_l0
0c`06?l00c`03_l00``06?l00``04?l00c`05ol00``01_l002Go00<l06ko00<l02[o00<l01Wo00<l
00oo00<001Co00<<017o00<l01Wo00<l00Go000Uo`03301^o`03?00Zo`03?00Io`03?00Bo`03000>
o`03000Co`03?00Jo`03?005o`009Ol00c`0K_l00c`0:_l00c`06_l00c`05?l>01Go00<<01_o00<l
00Go000Uo`03?01^o`03?00Zo`03?00Ko`03?00fo`03?00Ko`03?005o`009Ol00c`0K_l00c`0:_l0
0c`07?l00c`0=?l00c`06ol00``01_l002Go00<l06ko00<l02[o00<l01go00<l03;o00<l01go00<l
00Go000Uo`03301^o`03?00Zo`03?00No`03?00`o`03?00No`03?005o`009Ol00c`0K_l00c`0:_l0
0c`02_l00c`05?l00c`04ol00c`05?l00c`04ol00c`02ol00c`01Ol002Go00<l00Ko00<l00[o00<l
00_o00<l00_o00<l00_o00<l00[o00<l00_o00<l00_o00<l00Go00<l02[oMP07o`009Ol01So000G3
2_l00``03?l00c`02ol00c`02ol00c`02ol00c`02ol00c`02ol013<01obVo`009Ol5?`03300;o`03
300=o`03?00;o`03?00<o`03?00;o`03?00<o`03300;o`030007o:Ko000Uo`H?00<l00Wo00<000co
00<<00go00<l00co00<l00co00<<00_o00<000co00<000KcY_l002Go00<l00oo00<<00co00<000co
00<000go00<<00co00<<00co00<<013o00<l0:Oo000Uo`03?00No`03300=o`03?00<o`03300=o`03
?00No`03?01So`033011o`009Ol00c`0;_l00c`03?l00``0;_l00c`0Hol00c00@Ol002Go00<<06ko
00<l06?o00<`047o000Uo`03?01^o`03?01So`033011o`009Omb06Go00<l047o003ood7o003ood7o
003ood7o003ood7o001Lo`03<03Qo`00G?l00``0hOl005go00<l0>3o001Lo`03303Qo`00oom1o`00
oom1o`00oom1o`00oom1o`00oom1o`00oom1o`00oom1o`00oom1o`00oom1o`00oom1o`00\
\>"],
  ImageRangeCache->{{{0, 319}, {182.75, 0}} -> {-2.599996, -3.588163, 
  0.020312, 0.020312}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Isolated Sphere"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Csp]; \)\), 
    \(\(Csp[R_] := 4\ \[Pi]\ eps0\ R; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(case3 = {R \[Rule] 10\ nano}; \)\), 
    \(Print["\<Csp = \>", \(N[Csp[R]\/atto] /. case3\) /. NSub, "\< [aF]\>"]
      \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("Csp = "\[InvisibleSpace]1.11265033029952831`
        \[InvisibleSpace]" [aF]"\),
      SequenceForm[ "Csp = ", 1.11265033029952831, " [aF]"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Sphere and Plane"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(case4 = {R \[Rule] 1., d \[Rule] 2.}; \)\), 
    \(\(nn = 5; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Position of Charges Inside the Sphere"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(h = Array[q, nn]; \)\), 
    \(\(h\[LeftDoubleBracket]1\[RightDoubleBracket] = 0; \)\), 
    \(\(h\[LeftDoubleBracket]2\[RightDoubleBracket] = R\^2\/\(2\ d\); \)\), 
    \(\(tbl1a = 
      Simplify[Table[
          h\[LeftDoubleBracket]n\[RightDoubleBracket] = 
            R\^2\/\(2\ d - 
                h\[LeftDoubleBracket]n - 1\[RightDoubleBracket]\), {n, 3, 
            nn}]]; \)\), 
    \(\(p11 = Table[h\[LeftDoubleBracket]n\[RightDoubleBracket], {n, 1, nn}]; 
    \)\), 
    \(p1 = Take[p11, 3]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, R\^2\/\(2\ d\), R\^2\/\(2\ d - R\^2\/\(2\ d\)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Magnitude of Charges Inside the Sphere"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g = Array[q, nn]; \)\), 
    \(\(g\[LeftDoubleBracket]1\[RightDoubleBracket] = 1; \)\), 
    \(\(g\[LeftDoubleBracket]2\[RightDoubleBracket] = r; \)\), 
    \(\(tbl2a = 
      Simplify[Table[
          g\[LeftDoubleBracket]n\[RightDoubleBracket] = 
            \(r\ g\[LeftDoubleBracket]n - 1\[RightDoubleBracket]\)\/\(1 - 
                \(r\ g\[LeftDoubleBracket]n - 1\[RightDoubleBracket]\)\/g
                    \[LeftDoubleBracket]n - 2\[RightDoubleBracket]\), {n, 3, 
            nn}]]; \)\), 
    \(\(c11 = 
      Table[g\[LeftDoubleBracket]n\[RightDoubleBracket], {n, 1, nn}] /. 
        r \[Rule] R\/\(2\ d\); \)\), 
    \(c1 = Take[c11, 3]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({1, R\/\(2\ d\), R\^2\/\(4\ d\^2\ \((1 - R\^2\/\(4\ d\^2\))\)\)}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Position of Charges Outside the Sphere"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p22 = 
      Table[2\ d - h\[LeftDoubleBracket]n\[RightDoubleBracket], {n, 1, nn}]; 
    \)\), 
    \(p2 = Take[p22, 3]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2\ d, 2\ d - R\^2\/\(2\ d\), 2\ d - R\^2\/\(2\ d - R\^2\/\(2\ d\)\)}
      \)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Magnitude of Charges Outside the Sphere"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(c22 = 
      Table[\(-g\[LeftDoubleBracket]n\[RightDoubleBracket]\), {n, 1, nn}] /. 
        r \[Rule] R\/\(2\ d\); \)\), 
    \(c2 = Take[c22, 3]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-1\), \(-\(R\/\(2\ d\)\)\), 
      \(-\(R\^2\/\(4\ d\^2\ \((1 - R\^2\/\(4\ d\^2\))\)\)\)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Table of Coefficients"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[tbl1]; \)\), 
    \(scx = N[c11 /. case4, 3]; sc4 = Take[scx, 4]; \), 
    \(spx = N[p11 /. case4, 3]; sp4 = Take[spx, 4]; \), 
    \(pcx = N[c22 /. case4, 3]; pc4 = Take[pcx, 4]; \), 
    \(ppx = N[p22 /. case4, 3]; pp4 = Take[ppx, 4]; \)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(tbl1 = 
      TableForm[{sc4, sp4, pc4, pp4}, 
        TableHeadings 
          \[Rule] {{"\<c1\>", "\<p1\>", "\<c2\>", "\<p2\>"}, {"\<1\>", 
              "\<2\>", "\<3\>", "\<4\>"}}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    TagBox[GridBox[{
          {\(""\), \("1"\), \("2"\), \("3"\), \("4"\)},
          {\("c1"\), 
            StyleBox["1.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], 
            StyleBox["0.25`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], 
            StyleBox["0.0666666666666666607`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], 
            StyleBox["0.0178571428571428558`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3]},
          {\("p1"\), "0", 
            StyleBox["0.25`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], 
            StyleBox["0.266666666666666651`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], 
            StyleBox["0.267857142857142838`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3]},
          {\("c2"\), 
            RowBox[{"-", 
              StyleBox["1.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}], 
            RowBox[{"-", 
              StyleBox["0.25`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}], 
            RowBox[{"-", 
              StyleBox["0.0666666666666666607`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}], 
            RowBox[{"-", 
              StyleBox["0.0178571428571428558`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}]},
          {\("p2"\), 
            StyleBox["4.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], 
            StyleBox["3.75`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], 
            StyleBox["3.73333333333333339`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], 
            StyleBox["3.7321428571428572`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[
       #, TableHeadings -> {{"c1", "p1", "c2", "p2"}, {"1", "2", "3", 
        "4"}}]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Potential and Field"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[vsp]; \)\), 
    \(\(vsp[x_, y_] := 
      \[Sum]\+\(i = 1\)\%nn\((
          scx\[LeftDoubleBracket]i
                \[RightDoubleBracket]\/\@\(x\^2 + 
                  \((y + spx\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2
                    \) + pcx\[LeftDoubleBracket]i
                \[RightDoubleBracket]\/\@\(x\^2 + 
                  \((y + ppx\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2
                    \))\); \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(discGraphics = 
      Graphics[{Disk[{0, 0}, 1], Rectangle[{\(-2\), \(-2.1\)}, {2, \(-2\)}]}, 
        AspectRatio \[Rule] Automatic, PlotLabel \[Rule] "\<a\>", opt1]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(fieldGraphics = 
      PlotGradientField[\(-vsp[x, y]\), {x, \(-1.5\), 1.5}, {y, \(-2\), 1.5}, 
        ScaleFunction \[Rule] \((2 + Log[1 + #1]&)\), 
        ScaleFactor \[Rule] 0.5, PlotPoints \[Rule] 8, 
        DisplayFunction \[Rule] Identity]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(discfieldGraphics = 
      Show[{discGraphics, fieldGraphics}, DisplayFunction \[Rule] Identity]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(potentialGraphics = 
      ContourPlot[vsp[x, y], {x, \(-2.5\), 2.5}, {y, \(-3.5\), 1.5}, 
        PlotPoints \[Rule] 30, Contours \[Rule] 10, 
        PlotLabel \[Rule] "\<b\>", ContourShading \[Rule] False, 
        DisplayFunction \[Rule] Identity, Evaluate[opt1]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig4 = Show[GraphicsArray[{discfieldGraphics, potentialGraphics}]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47279 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.47619 0.011257 0.47619 [
[ 0 0 0 0 ]
[ 1 .47279 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47279 L
0 .47279 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.02381 0.011257 0.477324 0.46153 MathSubStart
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.557744 0.238095 [
[.02381 -0.0125 -7 -12 ]
[.02381 -0.0125 7 0 ]
[.2619 -0.0125 -7 -12 ]
[.2619 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.7381 -0.0125 -4 -12 ]
[.7381 -0.0125 4 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4 -24 ]
[.5 -0.0125 4 -12 ]
[-0.0125 .08155 -14 -6 ]
[-0.0125 .08155 0 6 ]
[-0.0125 .31965 -14 -6 ]
[-0.0125 .31965 0 6 ]
[-0.0125 .55774 -8 -6 ]
[-0.0125 .55774 0 6 ]
[-0.0125 .79584 -8 -6 ]
[-0.0125 .79584 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .49643 -26 -4 ]
[-0.01875 .49643 -14 4 ]
[ 0 .99285 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.00535 -4 0 ]
[.5 1.00535 4 12 ]
[ 0 0 0 0 ]
[ 1 .99285 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .08155 m
.00625 .08155 L
s
gsave
-0.0125 .08155 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .31965 m
.00625 .31965 L
s
gsave
-0.0125 .31965 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .55774 m
.00625 .55774 L
s
gsave
-0.0125 .55774 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .79584 m
.00625 .79584 L
s
gsave
-0.0125 .79584 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .12917 m
.00375 .12917 L
s
0 .17679 m
.00375 .17679 L
s
0 .22441 m
.00375 .22441 L
s
0 .27203 m
.00375 .27203 L
s
0 .36727 m
.00375 .36727 L
s
0 .41489 m
.00375 .41489 L
s
0 .46251 m
.00375 .46251 L
s
0 .51012 m
.00375 .51012 L
s
0 .60536 m
.00375 .60536 L
s
0 .65298 m
.00375 .65298 L
s
0 .7006 m
.00375 .7006 L
s
0 .74822 m
.00375 .74822 L
s
0 .03393 m
.00375 .03393 L
s
0 .84346 m
.00375 .84346 L
s
0 .89108 m
.00375 .89108 L
s
0 .9387 m
.00375 .9387 L
s
0 .98632 m
.00375 .98632 L
s
.25 Mabswid
0 0 m
0 .99285 L
s
gsave
-0.01875 .49643 -85 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
65 10 translate
90 rotate
-65 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .9866 m
.02381 .99285 L
s
.2619 .9866 m
.2619 .99285 L
s
.5 .9866 m
.5 .99285 L
s
.7381 .9866 m
.7381 .99285 L
s
.97619 .9866 m
.97619 .99285 L
s
.125 Mabswid
.07143 .9891 m
.07143 .99285 L
s
.11905 .9891 m
.11905 .99285 L
s
.16667 .9891 m
.16667 .99285 L
s
.21429 .9891 m
.21429 .99285 L
s
.30952 .9891 m
.30952 .99285 L
s
.35714 .9891 m
.35714 .99285 L
s
.40476 .9891 m
.40476 .99285 L
s
.45238 .9891 m
.45238 .99285 L
s
.54762 .9891 m
.54762 .99285 L
s
.59524 .9891 m
.59524 .99285 L
s
.64286 .9891 m
.64286 .99285 L
s
.69048 .9891 m
.69048 .99285 L
s
.78571 .9891 m
.78571 .99285 L
s
.83333 .9891 m
.83333 .99285 L
s
.88095 .9891 m
.88095 .99285 L
s
.92857 .9891 m
.92857 .99285 L
s
.25 Mabswid
0 .99285 m
1 .99285 L
s
.99375 .08155 m
1 .08155 L
s
.99375 .31965 m
1 .31965 L
s
.99375 .55774 m
1 .55774 L
s
.99375 .79584 m
1 .79584 L
s
.125 Mabswid
.99625 .12917 m
1 .12917 L
s
.99625 .17679 m
1 .17679 L
s
.99625 .22441 m
1 .22441 L
s
.99625 .27203 m
1 .27203 L
s
.99625 .36727 m
1 .36727 L
s
.99625 .41489 m
1 .41489 L
s
.99625 .46251 m
1 .46251 L
s
.99625 .51012 m
1 .51012 L
s
.99625 .60536 m
1 .60536 L
s
.99625 .65298 m
1 .65298 L
s
.99625 .7006 m
1 .7006 L
s
.99625 .74822 m
1 .74822 L
s
.99625 .03393 m
1 .03393 L
s
.99625 .84346 m
1 .84346 L
s
.99625 .89108 m
1 .89108 L
s
.99625 .9387 m
1 .9387 L
s
.99625 .98632 m
1 .98632 L
s
.25 Mabswid
1 0 m
1 .99285 L
s
gsave
.5 1.00535 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
66.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 .99285 L
0 .99285 L
closepath
clip
newpath
.5 .55774 m
.5 .55774 .2381 0 365.72958 arc
F
.02381 .05774 m
.02381 .08155 L
.97619 .08155 L
.97619 .05774 L
F
.0001 w
.14286 .08155 m
.14286 .02897 L
s
% Start of user PostScript
-1.5 -2. -1.5 -2.22083 MAarrowhead1
% End of user PostScript
.14286 .2006 m
.12341 .15126 L
s
% Start of user PostScript
-1.5 -1.5 -1.58168 -1.70721 MAarrowhead1
% End of user PostScript
.14286 .31965 m
.10612 .27976 L
s
% Start of user PostScript
-1.5 -1. -1.65428 -1.16755 MAarrowhead1
% End of user PostScript
.14286 .4387 m
.09296 .41429 L
s
% Start of user PostScript
-1.5 -0.5 -1.70959 -0.602485 MAarrowhead1
% End of user PostScript
.14286 .55774 m
.08716 .55317 L
s
% Start of user PostScript
-1.5 0 -1.73392 -0.0192061 MAarrowhead1
% End of user PostScript
.14286 .67679 m
.08997 .69067 L
s
% Start of user PostScript
-1.5 0.5 -1.72211 0.558276 MAarrowhead1
% End of user PostScript
.14286 .79584 m
.09731 .82225 L
s
% Start of user PostScript
-1.5 1. -1.69132 1.11092 MAarrowhead1
% End of user PostScript
.14286 .91489 m
.10476 .94843 L
s
% Start of user PostScript
-1.5 1.5 -1.66001 1.64088 MAarrowhead1
% End of user PostScript
.2449 .08155 m
.2449 .02692 L
s
% Start of user PostScript
-1.07143 -2. -1.07143 -2.22944 MAarrowhead1
% End of user PostScript
.2449 .2006 m
.22673 .14816 L
s
% Start of user PostScript
-1.07143 -1.5 -1.14775 -1.72027 MAarrowhead1
% End of user PostScript
.2449 .31965 m
.20822 .2746 L
s
% Start of user PostScript
-1.07143 -1. -1.2255 -1.18921 MAarrowhead1
% End of user PostScript
.2449 .4387 m
.19031 .41026 L
s
% Start of user PostScript
-1.07143 -0.5 -1.3007 -0.619445 MAarrowhead1
% End of user PostScript
.2449 .55774 m
.18205 .55701 L
s
% Start of user PostScript
-1.07143 0 -1.3354 -0.00310158 MAarrowhead1
% End of user PostScript
.2449 .67679 m
.19012 .70117 L
s
% Start of user PostScript
-1.07143 0.5 -1.30152 0.602397 MAarrowhead1
% End of user PostScript
.2449 .79584 m
.20315 .8326 L
s
% Start of user PostScript
-1.07143 1. -1.24679 1.15438 MAarrowhead1
% End of user PostScript
.2449 .91489 m
.21298 .95628 L
s
% Start of user PostScript
-1.07143 1.5 -1.20547 1.67384 MAarrowhead1
% End of user PostScript
.34694 .08155 m
.34694 .02493 L
s
% Start of user PostScript
-0.642857 -2. -0.642857 -2.23782 MAarrowhead1
% End of user PostScript
.34694 .2006 m
.33309 .14416 L
s
% Start of user PostScript
-0.642857 -1.5 -0.701012 -1.73706 MAarrowhead1
% End of user PostScript
.34694 .31965 m
.31536 .26483 L
s
% Start of user PostScript
-0.642857 -1. -0.77548 -1.23025 MAarrowhead1
% End of user PostScript
.34694 .4387 m
.28752 .39705 L
s
% Start of user PostScript
-0.642857 -0.5 -0.892399 -0.674933 MAarrowhead1
% End of user PostScript
.34694 .55774 m
.26934 .56224 L
s
% Start of user PostScript
-0.642857 0 -0.968784 0.0189041 MAarrowhead1
% End of user PostScript
.34694 .67679 m
.29291 .71997 L
s
% Start of user PostScript
-0.642857 0.5 -0.869797 0.681355 MAarrowhead1
% End of user PostScript
.34694 .79584 m
.3144 .8456 L
s
% Start of user PostScript
-0.642857 1. -0.779527 1.20899 MAarrowhead1
% End of user PostScript
.34694 .91489 m
.32488 .96399 L
s
% Start of user PostScript
-0.642857 1.5 -0.735518 1.70624 MAarrowhead1
% End of user PostScript
.44898 .08155 m
.44898 .02364 L
s
% Start of user PostScript
-0.214286 -2. -0.214286 -2.24324 MAarrowhead1
% End of user PostScript
.44898 .2006 m
.44362 .14089 L
s
% Start of user PostScript
-0.214286 -1.5 -0.236814 -1.75078 MAarrowhead1
% End of user PostScript
.44898 .31965 m
.4349 .25304 L
s
% Start of user PostScript
-0.214286 -1. -0.273402 -1.27976 MAarrowhead1
% End of user PostScript
.44898 .4387 m
.40114 .36017 L
s
% Start of user PostScript
-0.214286 -0.5 -0.415232 -0.829795 MAarrowhead1
% End of user PostScript
.44898 .55774 m
.33047 .56901 L
s
% Start of user PostScript
-0.214286 0 -0.71204 0.0473378 MAarrowhead1
% End of user PostScript
.44898 .67679 m
.41767 .75235 L
s
% Start of user PostScript
-0.214286 0.5 -0.345776 0.817359 MAarrowhead1
% End of user PostScript
.44898 .79584 m
.43581 .85718 L
s
% Start of user PostScript
-0.214286 1. -0.269587 1.25762 MAarrowhead1
% End of user PostScript
.44898 .91489 m
.44095 .96921 L
s
% Start of user PostScript
-0.214286 1.5 -0.248013 1.72817 MAarrowhead1
% End of user PostScript
.55102 .08155 m
.55102 .02364 L
s
% Start of user PostScript
0.214286 -2. 0.214286 -2.24324 MAarrowhead1
% End of user PostScript
.55102 .2006 m
.55638 .14089 L
s
% Start of user PostScript
0.214286 -1.5 0.236814 -1.75078 MAarrowhead1
% End of user PostScript
.55102 .31965 m
.5651 .25304 L
s
% Start of user PostScript
0.214286 -1. 0.273402 -1.27976 MAarrowhead1
% End of user PostScript
.55102 .4387 m
.59886 .36017 L
s
% Start of user PostScript
0.214286 -0.5 0.415232 -0.829795 MAarrowhead1
% End of user PostScript
.55102 .55774 m
.66953 .56901 L
s
% Start of user PostScript
0.214286 0 0.71204 0.0473378 MAarrowhead1
% End of user PostScript
.55102 .67679 m
.58233 .75235 L
s
% Start of user PostScript
0.214286 0.5 0.345776 0.817359 MAarrowhead1
% End of user PostScript
.55102 .79584 m
.56419 .85718 L
s
% Start of user PostScript
0.214286 1. 0.269587 1.25762 MAarrowhead1
% End of user PostScript
.55102 .91489 m
.55905 .96921 L
s
% Start of user PostScript
0.214286 1.5 0.248013 1.72817 MAarrowhead1
% End of user PostScript
.65306 .08155 m
.65306 .02493 L
s
% Start of user PostScript
0.642857 -2. 0.642857 -2.23782 MAarrowhead1
% End of user PostScript
.65306 .2006 m
.66691 .14416 L
s
% Start of user PostScript
0.642857 -1.5 0.701012 -1.73706 MAarrowhead1
% End of user PostScript
.65306 .31965 m
.68464 .26483 L
s
% Start of user PostScript
0.642857 -1. 0.77548 -1.23025 MAarrowhead1
% End of user PostScript
.65306 .4387 m
.71248 .39705 L
s
% Start of user PostScript
0.642857 -0.5 0.892399 -0.674933 MAarrowhead1
% End of user PostScript
.65306 .55774 m
.73066 .56224 L
s
% Start of user PostScript
0.642857 0 0.968784 0.0189041 MAarrowhead1
% End of user PostScript
.65306 .67679 m
.70709 .71997 L
s
% Start of user PostScript
0.642857 0.5 0.869797 0.681355 MAarrowhead1
% End of user PostScript
.65306 .79584 m
.6856 .8456 L
s
% Start of user PostScript
0.642857 1. 0.779527 1.20899 MAarrowhead1
% End of user PostScript
.65306 .91489 m
.67512 .96399 L
s
% Start of user PostScript
0.642857 1.5 0.735518 1.70624 MAarrowhead1
% End of user PostScript
.7551 .08155 m
.7551 .02692 L
s
% Start of user PostScript
1.07143 -2. 1.07143 -2.22944 MAarrowhead1
% End of user PostScript
.7551 .2006 m
.77327 .14816 L
s
% Start of user PostScript
1.07143 -1.5 1.14775 -1.72027 MAarrowhead1
% End of user PostScript
.7551 .31965 m
.79178 .2746 L
s
% Start of user PostScript
1.07143 -1. 1.2255 -1.18921 MAarrowhead1
% End of user PostScript
.7551 .4387 m
.80969 .41026 L
s
% Start of user PostScript
1.07143 -0.5 1.3007 -0.619445 MAarrowhead1
% End of user PostScript
.7551 .55774 m
.81795 .55701 L
s
% Start of user PostScript
1.07143 0 1.3354 -0.00310158 MAarrowhead1
% End of user PostScript
.7551 .67679 m
.80988 .70117 L
s
% Start of user PostScript
1.07143 0.5 1.30152 0.602397 MAarrowhead1
% End of user PostScript
.7551 .79584 m
.79685 .8326 L
s
% Start of user PostScript
1.07143 1. 1.24679 1.15438 MAarrowhead1
% End of user PostScript
.7551 .91489 m
.78702 .95628 L
s
% Start of user PostScript
1.07143 1.5 1.20547 1.67384 MAarrowhead1
% End of user PostScript
.85714 .08155 m
.85714 .02897 L
s
% Start of user PostScript
1.5 -2. 1.5 -2.22083 MAarrowhead1
% End of user PostScript
.85714 .2006 m
.87659 .15126 L
s
% Start of user PostScript
1.5 -1.5 1.58168 -1.70721 MAarrowhead1
% End of user PostScript
.85714 .31965 m
.89388 .27976 L
s
% Start of user PostScript
1.5 -1. 1.65428 -1.16755 MAarrowhead1
% End of user PostScript
.85714 .4387 m
.90704 .41429 L
s
% Start of user PostScript
1.5 -0.5 1.70959 -0.602485 MAarrowhead1
% End of user PostScript
.85714 .55774 m
.91284 .55317 L
s
% Start of user PostScript
1.5 0 1.73392 -0.0192061 MAarrowhead1
% End of user PostScript
.85714 .67679 m
.91003 .69067 L
s
% Start of user PostScript
1.5 0.5 1.72211 0.558276 MAarrowhead1
% End of user PostScript
.85714 .79584 m
.90269 .82225 L
s
% Start of user PostScript
1.5 1. 1.69132 1.11092 MAarrowhead1
% End of user PostScript
.85714 .91489 m
.89524 .94843 L
s
% Start of user PostScript
1.5 1.5 1.66001 1.64088 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.011257 0.97619 0.46153 MathSubStart
%% ContourGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.192308 0.692308 0.192308 [
[.11538 -0.0125 -7 -12 ]
[.11538 -0.0125 7 0 ]
[.30769 -0.0125 -7 -12 ]
[.30769 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.69231 -0.0125 -4 -12 ]
[.69231 -0.0125 4 0 ]
[.88462 -0.0125 -4 -12 ]
[.88462 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4 -24 ]
[.5 -0.0125 4 -12 ]
[-0.0125 .11538 -14 -6 ]
[-0.0125 .11538 0 6 ]
[-0.0125 .30769 -14 -6 ]
[-0.0125 .30769 0 6 ]
[-0.0125 .5 -14 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .69231 -8 -6 ]
[-0.0125 .69231 0 6 ]
[-0.0125 .88462 -8 -6 ]
[-0.0125 .88462 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -26 -4 ]
[-0.01875 .5 -14 4 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.30769 0 m
.30769 .00625 L
s
gsave
.30769 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.69231 0 m
.69231 .00625 L
s
gsave
.69231 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .11538 m
.00625 .11538 L
s
gsave
-0.0125 .11538 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .30769 m
.00625 .30769 L
s
gsave
-0.0125 .30769 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .69231 m
.00625 .69231 L
s
gsave
-0.0125 .69231 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .88462 m
.00625 .88462 L
s
gsave
-0.0125 .88462 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .15385 m
.00375 .15385 L
s
0 .19231 m
.00375 .19231 L
s
0 .23077 m
.00375 .23077 L
s
0 .26923 m
.00375 .26923 L
s
0 .34615 m
.00375 .34615 L
s
0 .38462 m
.00375 .38462 L
s
0 .42308 m
.00375 .42308 L
s
0 .46154 m
.00375 .46154 L
s
0 .53846 m
.00375 .53846 L
s
0 .57692 m
.00375 .57692 L
s
0 .61538 m
.00375 .61538 L
s
0 .65385 m
.00375 .65385 L
s
0 .73077 m
.00375 .73077 L
s
0 .76923 m
.00375 .76923 L
s
0 .80769 m
.00375 .80769 L
s
0 .84615 m
.00375 .84615 L
s
0 .07692 m
.00375 .07692 L
s
0 .03846 m
.00375 .03846 L
s
0 .92308 m
.00375 .92308 L
s
0 .96154 m
.00375 .96154 L
s
0 1 m
.00375 1 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -85 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
65 10 translate
90 rotate
-65 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .15385 m
1 .15385 L
s
.99625 .19231 m
1 .19231 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .26923 m
1 .26923 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .38462 m
1 .38462 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .46154 m
1 .46154 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .57692 m
1 .57692 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .65385 m
1 .65385 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .76923 m
1 .76923 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .84615 m
1 .84615 L
s
.99625 .07692 m
1 .07692 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .92308 m
1 .92308 L
s
.99625 .96154 m
1 .96154 L
s
.99625 1 m
1 1 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.45027 .57919 m
.48342 .56793 L
.51658 .56793 L
.54973 .57919 L
.55628 .58289 L
.58289 .60707 L
.58924 .61605 L
.60458 .6492 L
.60974 .68236 L
.6054 .71552 L
.59035 .74867 L
.58289 .75875 L
.5559 .78183 L
.54973 .78496 L
.51658 .7954 L
.48342 .7954 L
.45027 .78496 L
.4441 .78183 L
.41711 .75875 L
.40965 .74867 L
.3946 .71552 L
.39026 .68236 L
.39542 .6492 L
.41076 .61605 L
.41711 .60707 L
.44372 .58289 L
.45027 .57919 L
s
.48342 .54841 m
.51658 .54841 L
.52449 .54973 L
.54973 .55767 L
.58289 .57815 L
.58819 .58289 L
.61408 .61605 L
.61605 .61826 L
.62732 .6492 L
.63195 .68236 L
.62869 .71552 L
.61682 .74867 L
.61605 .75021 L
.59243 .78183 L
.58289 .79036 L
.54973 .8101 L
.5358 .81499 L
.51658 .81886 L
.48342 .81886 L
.4642 .81499 L
.45027 .8101 L
.41711 .79036 L
.40757 .78183 L
.38395 .75021 L
.38318 .74867 L
.37131 .71552 L
.36805 .68236 L
.37268 .6492 L
.38395 .61826 L
.38592 .61605 L
.41181 .58289 L
.41711 .57815 L
.45027 .55767 L
.47551 .54973 L
.48342 .54841 L
s
.41711 .5432 m
.45027 .52831 L
.48342 .52131 L
.51658 .52131 L
.54973 .52831 L
.58289 .5432 L
.59315 .54973 L
.61605 .56893 L
.6284 .58289 L
.64913 .61605 L
.6492 .61615 L
.66064 .6492 L
.66515 .68236 L
.66311 .71552 L
.65426 .74867 L
.6492 .76105 L
.63709 .78183 L
.61605 .80738 L
.60788 .81499 L
.58289 .83272 L
.54973 .84749 L
.54763 .84814 L
.51658 .85426 L
.48342 .85426 L
.45237 .84814 L
.45027 .84749 L
.41711 .83272 L
.39212 .81499 L
.38395 .80738 L
.36291 .78183 L
.3508 .76105 L
.34574 .74867 L
.33689 .71552 L
.33485 .68236 L
.33936 .6492 L
.3508 .61615 L
.35087 .61605 L
.3716 .58289 L
.38395 .56893 L
.40685 .54973 L
.41711 .5432 L
s
.48342 .48085 m
.51658 .48085 L
.53765 .48342 L
.54973 .48579 L
.58289 .49603 L
.61605 .51247 L
.62258 .51658 L
.6492 .53706 L
.66211 .54973 L
.68236 .57466 L
.68772 .58289 L
.70469 .61605 L
.71524 .6492 L
.71552 .65043 L
.72014 .68236 L
.71993 .71552 L
.71552 .74464 L
.71458 .74867 L
.70362 .78183 L
.68622 .81499 L
.68236 .82084 L
.6602 .84814 L
.6492 .85888 L
.62013 .8813 L
.61605 .88385 L
.58289 .90053 L
.54973 .91099 L
.53103 .91446 L
.51658 .91602 L
.48342 .91602 L
.46897 .91446 L
.45027 .91099 L
.41711 .90053 L
.38395 .88385 L
.37987 .8813 L
.3508 .85888 L
.3398 .84814 L
.31764 .82084 L
.31378 .81499 L
.29638 .78183 L
.28542 .74867 L
.28448 .74464 L
.28007 .71552 L
.27986 .68236 L
.28448 .65043 L
.28476 .6492 L
.29531 .61605 L
.31228 .58289 L
.31764 .57466 L
.33789 .54973 L
Mistroke
.3508 .53706 L
.37742 .51658 L
.38395 .51247 L
.41711 .49603 L
.45027 .48579 L
.46235 .48342 L
.48342 .48085 L
Mfstroke
.71312 .98077 m
.71552 .97884 L
.74867 .94782 L
.74887 .94761 L
.77597 .91446 L
.78183 .90598 L
.79677 .8813 L
.81254 .84814 L
.81499 .84208 L
.82397 .81499 L
.83149 .78183 L
.83535 .74867 L
.83563 .71552 L
.8323 .68236 L
.82521 .6492 L
.81499 .61818 L
.81406 .61605 L
.79822 .58289 L
.78183 .55654 L
.77687 .54973 L
.74867 .5169 L
.74835 .51658 L
.71552 .4879 L
.70943 .48342 L
.68236 .4659 L
.6518 .45027 L
.6492 .44911 L
.61605 .43651 L
.58289 .4275 L
.54973 .42169 L
.51658 .41884 L
.48342 .41884 L
.45027 .42169 L
.41711 .4275 L
.38395 .43651 L
.3508 .44911 L
.3482 .45027 L
.31764 .4659 L
.29057 .48342 L
.28448 .4879 L
.25165 .51658 L
.25133 .5169 L
.22313 .54973 L
.21817 .55654 L
.20178 .58289 L
.18594 .61605 L
.18501 .61818 L
.17479 .6492 L
.1677 .68236 L
.16437 .71552 L
Mistroke
.16465 .74867 L
.16851 .78183 L
.17603 .81499 L
.18501 .84208 L
.18746 .84814 L
.20323 .8813 L
.21817 .90598 L
.22403 .91446 L
.25113 .94761 L
.25133 .94782 L
.28448 .97884 L
.28688 .98077 L
Mfstroke
.01923 .40674 m
.05239 .39424 L
.08326 .38395 L
.08554 .38324 L
.1187 .3736 L
.15186 .36521 L
.18501 .35795 L
.21817 .35171 L
.22352 .3508 L
.25133 .34641 L
.28448 .34197 L
.31764 .33831 L
.3508 .33536 L
.38395 .33307 L
.41711 .3314 L
.45027 .3303 L
.48342 .32976 L
.51658 .32976 L
.54973 .3303 L
.58289 .3314 L
.61605 .33307 L
.6492 .33536 L
.68236 .33831 L
.71552 .34197 L
.74867 .34641 L
.77648 .3508 L
.78183 .35171 L
.81499 .35795 L
.84814 .36521 L
.8813 .3736 L
.91446 .38324 L
.91674 .38395 L
.94761 .39424 L
.98077 .40674 L
s
.90288 .01923 m
.88285 .05239 L
.8813 .05466 L
.85748 .08554 L
.84814 .09606 L
.82529 .1187 L
.81499 .12779 L
.7835 .15186 L
.78183 .153 L
.74867 .17335 L
.7259 .18501 L
.71552 .1898 L
.68236 .20302 L
.6492 .21346 L
.63096 .21817 L
.61605 .22147 L
.58289 .22729 L
.54973 .23108 L
.51658 .23295 L
.48342 .23295 L
.45027 .23108 L
.41711 .22729 L
.38395 .22147 L
.36904 .21817 L
.3508 .21346 L
.31764 .20302 L
.28448 .1898 L
.2741 .18501 L
.25133 .17335 L
.21817 .153 L
.2165 .15186 L
.18501 .12779 L
.17471 .1187 L
.15186 .09606 L
.14252 .08554 L
.1187 .05466 L
.11715 .05239 L
.09712 .01923 L
s
.73353 .01923 m
.71552 .04961 L
.71356 .05239 L
.68505 .08554 L
.68236 .08814 L
.6492 .11458 L
.64286 .1187 L
.61605 .13338 L
.58289 .14643 L
.5647 .15186 L
.54973 .15472 L
.51658 .15875 L
.48342 .15875 L
.45027 .15472 L
.4353 .15186 L
.41711 .14643 L
.38395 .13338 L
.35714 .1187 L
.3508 .11458 L
.31764 .08814 L
.31495 .08554 L
.28644 .05239 L
.28448 .04961 L
.26647 .01923 L
s
.65987 .01923 m
.6492 .03535 L
.63494 .05239 L
.61605 .06985 L
.59327 .08554 L
.58289 .09109 L
.54973 .10384 L
.51658 .1099 L
.48342 .1099 L
.45027 .10384 L
.41711 .09109 L
.40673 .08554 L
.38395 .06985 L
.36506 .05239 L
.3508 .03535 L
.34013 .01923 L
s
.61554 .01923 m
.58289 .05168 L
.58195 .05239 L
.54973 .06947 L
.51658 .07764 L
.48342 .07764 L
.45027 .06947 L
.41805 .05239 L
.41711 .05168 L
.38446 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 134},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0000Z0800@400oooH_l00?ooH_l00?ooH_l0
0?ooH_l00?ooH_l00?ooH_l00?ooH_l00?ooH_l006Co00<`0:go00<`04[o001Uo`03?02]o`03?019
o`00IOl00c`0[Ol00c`0BOl006Co00<`0:go00<`04[o003oof;o003oof;o003oof;o003oof;o003o
of;o003oof;o003oof;o003oof;o000]o`03000Jo`03000Ho`03?00Io`03000Io`030019o`03000D
o`03000Bo`03?00Co`03000Do`03000Lo`00;Ol00c`06ol00c`05_l00c006ol00c`06?l00c`0BOl0
0c`05Ol00c`04?l00c005Ol00c`04ol00c`07?l002So00<000Ol4ol00`001o`Eo`03<00Ko`03?00I
o`03?013o`030007o0go00<000Ol3ol00c005Ol00c`05?l00c`06ol002go00<`01_o00<l01Ko00<`
01_o00<l01So00<`04Wo00<`01Go00<l013o00<`01Go00<l01?o00<`01co000^o`03300Io`03300H
o`03?00Io`03300Jo`033019o`03300Co`03300Bo`03?00Co`03300Eo`03300Ko`00oomRo`00oomR
o`00oomRo`00oomRo`00oomRo`00:Omj03OoN@0>o`00:Ol013`07?l00c`06Ol00c`06_l00c`06_l0
13`0=ol00c`02ol00c`05?l00c`05?l00c`05?l00c`05?l00c`02ol00c`03?l002Wo00<l07Ko00<l
03Go00<l00So00<l01;o00<l00Ko00<l00Kc6?l00c`01_<5o`03?00Ao`03?009o`03?00<o`00:Ol0
0c`03_l00c`02_l00c`02Ol00c`02Ol00c`02Ol00``02_l00c`02Ol00c`02Ol00c`03ol00c`0=Ol0
0c`02Ol00c`04Ol00c`01_l00c`01o`Fo`03?006l`Go00<l017o00<l00[o00<l00co000Yo`03300>
o`033009o`03300:o`03?009o`033009o`033009o`03300:o`03?009o`03300>o`03300fo`03?00:
o`03?00Ao`03?006o`03?007o1Co00<l00Ol1Ol00c`04Ol00c`02Ol00``03Ol002Wo00<l00ko00<<
00Wo00<<00Wo00<000[o00<<00Wo00<<00Wo00<<00[o00<<00Wo00<<00oo00<l03Go00<l00[o00<l
017o00<l00Oo00<l00Ol4_l00c`01o`5o`03?00Ao`03?00;o`03?00<o`00:Ol00c`03_l00``02Ol0
0``02_l00c`02Ol00c`02_l00c`02Ol00c`02Ol00``02Ol00``03ol00c`0=Ol00c`02ol00c`04Ol0
0c`01ol00c`01o`?o`043`07o0Go00<<017o00<<00co00<l00co000Ro`040`06o7@01_<do`03?00<
o`03?00Ao`03?006o`053l06l0go00@o00Ol1_l00c`04Ol00c`03?l00c`03?l002;o00@o00KlM006
lcCo00<l00co00<l01;o00<l00Oo00Do`0K`2?l00`001_l00c`01ol00c`04Ol00c`03Ol00c`03?l0
01go00<000Ol1O=d00Kc=?l00c`03Ol00c`04_l00c`01ol00c`01Ol:00Oo00<<00So00<l017o00<l
00go00<<00go000Ro`05<l05l7@01L<eo`03?00>o`03?00Bo`03?007o`03300Do`03?008o`03?00B
o`03?00>o`03?00<o`008ol00``01oaeo`03?00]o`033005o`03?00?o`03?00Ao`033009o`03300?
o`03000:o`03?00Ao`03300@o`03?00<o`00:Ol00c`0M_l00c`0;ol00c`01o`?o`03?00Bo`03?009
o`03000:o`03000;o`03300Co`03?00@o`03?00<o`00:Ol00c`0M_l00c`0:Ol00`001_<7o13o00<l
01;o00<l00_o2P0=o`03?00Co`03?00Ao`03?00<o`00:Ol00c`0M_l00c`0;ol013l01_0Ao`03?00B
o`03300Po`03300Co`03?00Ao`03300=o`00:Ol00``0MOl00``0;_l00``01Ol00c`04ol00c`04ol0
0``07?l00``04ol00``05?l00c`03?l002Wo00<l07Ko00<l03Go00<l01Co00<l01Co00<<01Oo00<0
01Go00<<01Go00<l00co000Yo`03?00Uo`03?00:o`03300;o`03?00:o`03300Vo`03?00eo`03?00E
o`03300Eo`03000Co`03300Fo`03?00Fo`03?00<o`00:Ol00c`03?l00c`02Ol00``02_l00``02_l0
0``02ol00c`02_l00``02_l00c`02_l00c`03?l00c`0=Ol00c`05ol00c`05_l010002_l501Oo00<<
01Oo00<<00go000Yo`03?00<o`03300:o`033009o`03300:o`03300:o`03000:o`03000:o`03300:
o`03300=o`03?00eo`03?00Ho`03300Io`X06ol00c`06Ol00c`03?l002Wo00<l00co00<<00[o00<<
00Wo00<<00_o00<l00[o00<l00Wo00<000[o00<<00Wo00<000ko00<l03Go00<l01[o00<l03[o00<<
01_o00<l00co000Yo`03300<o`03300;o`03?009o`03?00:o`03?00:o`03?00:o`03?009o`03?00:
o`03?00<o`03300fo`03?00Ko`03300go`03000Mo`03?00<o`00:Ol00c`03_l00c`02Ol00c`02Ol0
0c`02_l00c`02_l00c`02Ol00c`02_l00c`02Ol00c`03_l00c`0=Ol00c`07Ol00``0<ol00``07ol0
0c`03?l002Wo00<l00ko00<l00Wo00<l00[o00<l00Wo00<l00[o00<l00Wo00<l00[o00<l00Wo00<l
00ko00<l03Go00<l01oo00<002oo00<0023o00<<00go000Yo`03?00>o`03?00:o`03?009o`03?009
o`03?00:o`03?009o`03?009o`03?009o`03?00?o`03?00eo`03?00Ro`03300Yo`03000To`03?00<
o`00:Ol00c`0M_l00c`0=Ol00c`09?l010008ol00`009ol00c`03?l002Wo00<l07Ko00<l03Go00<l
02So00@001_o00@002[o00<l00co000Yo`03301eo`03300fo`03?00/o`L03Ol702ko00<l00co000Y
o`03?01fo`03?00eo`03?00co`d0=?l00``03Ol002Wo00<l07Ko00<l03Go00<l07Go00<l00co000Y
o`03?00bo`03?00<o`03?00bo`03?00eo`03?01eo`03?00<o`00:Ol00c`0<_l00c`03?l00c`0<_l0
0c`0=Ol00c`0MOl00c`03?l002Wo00<l02?o00<<00_o00<000co00<<00co00<<02Co00<l03Go00<l
07Co00<<00go000Yo`03300Fo`03300:o`03000;o`03000<o`03300;o`03300;o`03300Fo`03300f
o`03?01eo`03?00<o`00:Ol00c`02_l00``02Ol00`002ol00``02ol00c`02ol00c`02ol00``02_l0
0``02_l00``02ol00c`0;Ol00`001Ol00c`0MOl00c`03?l002Wo00<l00[o00<000[o00<<00_o00<l
00_o00<l00[o00<l00_o00<l00[o00<<00Wo00<<00co00<l02go00<l00Go00<l07Go00<l00co000R
o`040`07o0[o00<<00_o00<l00[o00<l00[o00<l00[o00<l00[o00<l00[o00<l00[o00<<00co00<l
02Wo00<000Kc1oado`03?00<o`008ol00c`01o`<o`03?009o`03?00:o`03?00:o`03?00:o`03?00:
o`03?009o`03?00:o`03?00=o`03?00]o`03<005o`03301do`03300=o`007Ol00`001o`6l0go00<l
00Wo00<<00[o00<l00Wo00@o00K`1o`8o`03?009o`03?009o`03300>o`03300_o`043`07o7Co00<l
00co000So`03?007o3?o300fo`03?00eo`03?00aoa00=?l00c`03?l002;o00@?00Ol;_lF037o00<l
03Go00<l02;o3`0@o`l09Ol00c`03?l002Wo00<l02go6P0_o`03?00eo`03?00Ko`L0;_l801co00<<
00go000Yo`03?00/oa`0;_l00c`0=Ol00c`05Ol603go1P0Go`03?00<o`00:Ol00c`0:_lP02co00<l
03Go00<l013o1@19o`04000Co`03?00<o`00:Ol00``0:OlR02[o00<<03Ko00<l00co00@005;o00@0
00oo00<l00co000Yo`03?00WobH0:Ol00c`0=Ol00c`02Ol00`00F_l010002ol00c`03?l002Wo00<l
02Ko:00Xo`03?00eo`03?005o`04001Qo`030007o`03300=o`00:Ol00c`09OlZ02Oo00<l03Go00@o
00K`I_l00`001Ol00c`03?l002Wo00<l023o1`<Y00G08Ol00c`0=Ol5?003?01[o`030006l`_o000Y
o`03?00Do`033009oc001L<9o`03300Eo`03?00eo`03<01bo`04?00>o`00:Ol00``02?l010002?l0
0`002_lb00Wo00@000So00<000[o00<<03Ko00<l03?o3@0eo`03?00<o`00:Ol00c`02Ol00`002Ol0
10002Ol`00Wo00<000[o00<000_o00<l03Go00<l02ko1@0=o`D0;ol00``03Ol002Wo00<l00co00<<
00[o00<<00Go<@07o`03300:o`03300=o`03?00eo`03?00Zo`04000Go`03000]o`03?00<o`00:Ol0
0c`03_l00c`02_l01So`03801Ol00c`02Ol00``03ol00c`0=Ol00c`0:?l00``07Ol00`00:_l00c`0
3?l002Wo00<l023o=00Ro`03?00eo`03?00Vo`03300Ro`03300Wo`03?00<o`00:Ol00c`07olf027o
00<l03Go00<l02Co00<<02Ko00<<02Co00<<00go000Yo`03300OocH08?l00``0=_l00c`08_l00``0
:_l00c`08ol00c`03?l002Wo00<l01oo=P0Qo`03?00]o`030005o`03?00Qo`03?00Co`D05?l00``0
8_l00c`03?l001;o00<l00Kc3_l00c`07_lg027o00<l01ko00<l00Kc1ol013l01o`No`03300@o`D0
1Ol5017o00<<023o00<l00co000Bo`H34Ol00c`07_lh023o00<l01ko1P<5o`030006l`Ol7Ol00c`0
3_l00`003ol00`003ol00c`07ol00c`03?l001Co00<<01;o00<l01ko>00Po`03?00Po`03300;o`05
?l06l1co00<l00go00<<01Co00<<00go00<<01go00<<00go000Bo`03300Do`03300NocP07ol00``0
7ol00``03?l00``01Ol00c`07?l00c`03?l00``06?l00``03Ol00c`07?l00c`03?l002Wo00<l01ko
>00Po`03?00eo`03?00Ko`03?00<o`03?009o`H02ol00``03?l00``07?l00c`03?l002Wo00<l01go
>@0Po`03?00eo`03?00Jo`03?00;o`033007o`040006o`040009o`03?00<o`03?00Jo`03?00<o`00
:Ol00c`07Olj01oo00<l03Go00<l01Wo00<l00_o00<l00Ko00<<00go00<<00Oo00<<00_o00<l01Wo
00<<00go000So`03?007o1co>P0Oo`03?00eo`03?00Ho`03?00;o`03?005o`03300Ao`033006o`03
?00;o`03?00Io`03?00<o`008_l013<01o`7o`03000:o`03?005ocX01_l00c`02Ol00`002_l00c`0
=Ol00c`05ol00``02ol00c`01Ol01`ol2`05o`03?005o`03?00;o`03?00Ho`03?00<o`008_l01C?0
1_07o`L000Co00T000?003P000?000L000?l00P02Ol00``0=_l00c`05ol00c`02_l00c`01Ol013l0
1_09o`043`06l003o005c`Wo00<<01So00<l00co000Ro`04<`07o1Co00<l00Go>P06o`03300Fo`03
?00eo`03?00Fo`03?00:o`03?005o`03?006l003`0060003o005c`Kc1o`9o`03?00Go`03?00<o`00
8ol00c`01o`LocX07ol00c`0=Ol00c`05Ol00c`02ol013l01o`6c`03?006o`030006l0Kc1o`9o`03
?00Eo`03300=o`00:Ol00c`07Olj01oo00<l03Go00<l01Go00<l00[o00@o00Ol2Ll9o`P?1Ll7o0Wo
00<<01Ko00<l00co000Yo`03?00MocT08?l00c`0=Ol00c`05?l00c`02ol013l02_`00``03_l01Cc0
1o`7o0Wo00<l01Go00<l00co000Yo`03?00NocP08?l00c`0=Ol00c`05?l00c`02_l013l02_`00c`0
4?l01Cc01o`6l`[o00<l01Co00<l00co000Yo`03300NocP07ol00``0=_l00c`04ol00c`02ol00c`0
1o`00l`01Ll@o`03?008?`Ol2Ol00c`05?l00c`03?l002Wo00<l01ko>00Po`03?00eo`03?00Co`03
?00:o`04?`0:o003?00Bo`D<1o`6l`Wo00<l01?o00<<00go000Yo`03?00NocP08?l00c`0=Ol00c`0
4ol00c`02_l00c`02_`00c`05?l00c`023l7o0Wo00<l01?o00<l00co000Yo`03?00NocL08Ol00c`0
=Ol00c`04_l00c`02_l013l02_`00c`05Ol00c001o`7o0Wo00<l01?o00<l00co000Yo`03?00OocH0
8Ol00c`0=Ol00c`04_l00c`02_l013l02O`00c`05_l00c`023l6l`Wo00<l01?o00<l00co000Yo`03
?00OocH08Ol00c`0=Ol00c`04_l00c`02_l013l01o06laGo00<l00Po1o`9o`03?00Ao`03300=o`00
:Ol00``07olf023o00<<03Ko00<l01;o00<l00[o00<l00[l00<l01Ko00<l00Po1o`9o`03?00Bo`03
?00<o`00:Ol00c`08?ld02;o00<l02oo00<l00Ol4?l00c`02ol00c`02_`00c`05ol00c001o`7o0Wo
00<l01;o00<l00co000Yo`03?00>o`03?00:o`05?l0c00Go00<l00Wo00<l00oo00<l02ko00@c00Ol
4?l00c`02_l013l02_`00c`05ol00c001o`7o0Wo00<l01;o00<l00co000Yo`03?009o`H02_l00``0
1Olb00Ko00<<00Wo1P0;o`03?00^o`04<`07o13o00<l00[o00@o00[l00<l01Oo00<`00Ll1o`:o`03
?00Ao`03?00<o`00:Ol00c`02?l00`002_l010002Ol`00Wo00@000Wo00@000[o00<l02ko00Dc`0K`
4?l00c`02_l013l02_`00c`05ol00c001o`7o0[o00<l013o00<<00go000Yo`03300Do`03000;obl0
2ol010005Ol00``0<?l00c`01o`@o`03?00:o`04?`0:o003?00Go`03<007o0Ol2_l00c`04Ol00c`0
3?l002Wo00<l027o<@0To`03?00eo`03?00Ao`03?00:o`04?`0:o003?00Fo`03?008?`Ol2_l00c`0
4Ol00c`03?l002Wo00<l027o<P0So`03?00eo`03?00Ao`03?00:o`04?`0:o003?00Fo`03?008?`Ol
2_l00c`04Ol00c`03?l002Wo00<l023o1PlY00Ol8?l00c`0=Ol00c`04Ol00c`02ol013l02_`00c`0
5Ol00c`023l7o0[o00<l013o00<<00go000Yo`03?00UobX09ol00c`0=Ol00c`04Ol00c`02ol013l0
2_`00c`05?l01Cc01o`7o0[o00<l017o00<l00co000Yo`03?00WobH0:Ol00c`0=Ol00c`04Ol00c`0
2ol013l01o`00l`01LlBo`03?008?`03o005c`[o00<l017o00<l00co000Yo`03300Xob@0:Ol00``0
=_l00c`04Ol00c`02ol013l01o`00l`01LlAo`D<1o`7o0_o00<l017o00<l00co000Yo`03?00Zob00
;?l00c`0=Ol00c`04Ol00c`03?l013l01o`00l`01Ll?o`D?00?l00G?1o`;o`03?00Ao`03?00<o`00
:Ol00c`0:olN02go00<l03Go00<l017o00<l00co00@o00Ol1O<00c`03_l8?`G?00?l00G?2ol00c`0
4?l00``03Ol002;o00@300Ol;?lJ02oo00<l03Go00<l017o00<l00co00<l00Go00<l00Kl00<<00_o
00<<00Kc1Ll00o`01Ll;o`03?00Bo`03?00<o`008ol00c`01o`]oaP0<?l00c`0=Ol00c`04Ol00c`0
3Ol00c`01Ol00c`01_<5``Ko00<000Ol1_<00o`01Ll;o`03?00Bo`03?00<o`008ol00c`01o`bo`h0
=Ol00c`0=Ol00c`04Ol00c`03Ol00c`01_l00c`01_000o001`05o`033007o003o005c`co00<l01;o
00<l00co000So`04?`06l0go00<l00Wo00<<00[o00<l00Wo00Xo`307o0So00<l00Wo00<l00Wo00<<
00ko00<<03Ko00<l01;o00<l00go00<l00Go00Do`0K`2ol010l01o`5o`03?00=o`03?00Bo`03?00<
o`008_l010l01o`9o`04000;o`03?00:o`03?00:o`03?00:o`03?00:o`03?009o`03300:o`03000=
o`03?00eo`03?00Bo`03?00=o`03?006o`033005o`033007o`030006o`033006o`03?00>o`03?00A
o`03300=o`00:Ol00c`02Ol00`002ol00``03?l00c`02_l00c`02_l00c`02_l00c`02ol00``02_l0
0``02ol00c`0=Ol00c`04_l00c`03_l00c`01_l00``01_l800So00<l00Oo00<l00go00<l01?o00<l
00co000Yo`03?009o`03000:o`03000<o`03?00;o`03?00:o`03?00;o`03?00:o`03000:o`03000;
o`03?00eo`03?00Bo`03?00?o`03?007o`03?00Bo`033008o`03?00>o`03?00Co`03?00<o`00:Ol0
0c`05_l00``02_l00`003?l00c`02ol00c`02ol00``02ol00``05ol00c`0=Ol00c`04ol00c`03_l0
0c`02?l00``03ol00`002Ol00c`03ol00c`04ol00c`03?l002Wo00<l02?o00<<00co00<<00_o00<<
00_o00<002Go00<l03Go00<l01?o00<l00oo00<<00Wo00<000[o00<000_o00<l00oo00<l01?o00<<
00go000Yo`03300So`03?00<o`03300;o`03300<o`03300So`03300fo`03?00Do`03?00?o`03?00;
o`/03?l00c`04?l00c`05?l00c`03?l002Wo00<l03;o00<l00co00<l03;o00<l02ko00@300Ol4ol0
0c`04?l00c`08?l00``04?l00c`05Ol00c`03?l002Wo00<l07Ko00<l02oo00<l00Ol5?l00c`04?l0
0``07_l00c`04Ol00c`05Ol00c`03?l002Wo00<l07Ko00<l02oo00<l00Ol5?l00c`04_l00c`06_l0
0``04_l00c`05_l00c`03?l002Wo00<l07Ko00<l02oo00@o00K`5Ol00c`04_l00``06?l00``04ol0
0c`05Ol00``03Ol002Wo00<<07Go00<<02oo00@?00Ol5Ol00c`05?l00``05?l00``05?l00c`05ol0
0c`03?l002Wo00<l07Ko00<l03Go00<l01Oo00<l01Go00<000oo00<001Ko00<l01So00<l00co000Y
o`03?01fo`03?00eo`03?00Ho`03?00Go`D01Ol501Wo00<l01So00<l00co000Yo`03?00>o`03?00:
o`03?009o`03?009o`03?00:o`03?009o`03?009o`03?009o`03?00?o`03?00eo`03?00Ho`03?00L
o`D07Ol00c`06?l00``03Ol002Wo00<l00go00<l00[o00<l00[o00<l00Wo00<l00[o00<l00Wo00<l
00[o00<l00Wo00<l00ko00<l03Go00<l01Wo00<l03co00<l01[o00<l00co000Yo`03?00;o`03300;
o`03?00:o`03?00:o`03?00:o`03?00:o`03?00:o`03?009o`03000=o`03?00eo`03?00Jo`03?00k
o`03?00Jo`03?00<o`00:Ol00``02_l00`002ol00``02ol00c`02_l00c`02_l00c`02_l00c`02_l0
0``02_l00`002ol00``0=_l00c`06ol00c`0>Ol00c`06ol00c`03?l002Wo00<l00[o00<<00[o00<0
00_o00<<00[o00<<00_o00<<00[o00<<00[o00<000_o00<<00_o00<l03Go00<l01co00<l03Oo00<l
01co00<l00co000Yo`03?00Go`03300:o`03000;o`03300;o`03300:o`03300;o`03300Ho`03?00e
o`03?00Mo`03?00eo`03?00Lo`03300=o`00:Ol00c`09?l00``02ol00``02ol00``02ol00``09Ol0
0c`0=Ol00c`07_l00c`0<ol00c`07_l00c`03?l002Wo00<l03;o00<l00_o00<<03?o00<l03Go00<l
01oo00<l033o00<<023o00<l00co000Yo`03?01fo`03?00eo`03?01eo`03?00<o`00:Ol010`01Ol0
0c`01_<6l`Kc1_<5c`Kc1_<6l`G?1_<6l`Kc1Ll6l`Kc1_<5c`Kc00?`00G3=Ol8?`G?2Ll5c`W?2Ll5
c`W?2Ll5c`W?2Ll5c`W?2Ll5c`G?2ol002WoNP0gogT03_l00?ooH_l00?ooH_l00?ooH_l00?ooH_l0
06Co00<`0:go00<<04[o001To`03302]o`03<01:o`00IOl00c`0[?l00c00B_l006Co00<<0:go00<<
04[o003ooaGo00<l04[o003oof;o003oof;o003oof;o003oof;o003oof;o003oof;o003oof;o003o
of;o0000\
\>"],
  ImageRangeCache->{{{0, 351.5}, {166.5, 0}} -> {-2.599996, -3.591451, 
  0.01844, 0.01844}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Potential Along the Axis of Symmetry"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(RR = R /. case4; \)\), 
    \(\(dd = d /. case4; \)\), 
    \(\(Fig5 = 
      Plot[vsp[0, y], {y, \(-dd\), \(-RR\)}, 
        FrameLabel \[Rule] {"\<y\>", "\<V\>"}, Evaluate[opt]]; \)\)}], "Input",\

  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
1.928572 0.952381 0.014715 0.589636 [
[.02381 -0.0125 -7 -12 ]
[.02381 -0.0125 7 0 ]
[.21429 -0.0125 -10 -12 ]
[.21429 -0.0125 10 0 ]
[.40476 -0.0125 -10 -12 ]
[.40476 -0.0125 10 0 ]
[.59524 -0.0125 -10 -12 ]
[.59524 -0.0125 10 0 ]
[.78571 -0.0125 -10 -12 ]
[.78571 -0.0125 10 0 ]
[.97619 -0.0125 -7 -12 ]
[.97619 -0.0125 7 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4 -24 ]
[.5 -0.0125 4 -12 ]
[-0.0125 .01472 -8 -6 ]
[-0.0125 .01472 0 6 ]
[-0.0125 .13264 -14 -6 ]
[-0.0125 .13264 0 6 ]
[-0.0125 .25057 -14 -6 ]
[-0.0125 .25057 0 6 ]
[-0.0125 .3685 -14 -6 ]
[-0.0125 .3685 0 6 ]
[-0.0125 .48642 -14 -6 ]
[-0.0125 .48642 0 6 ]
[-0.0125 .60435 -8 -6 ]
[-0.0125 .60435 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26 -5 ]
[-0.01875 .30902 -14 5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
0 .13264 m
1 .13264 L
s
0 .25057 m
1 .25057 L
s
0 .3685 m
1 .3685 L
s
0 .48642 m
1 .48642 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -71 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -71 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -71 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -71 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .13264 m
.00625 .13264 L
s
gsave
-0.0125 .13264 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .25057 m
.00625 .25057 L
s
gsave
-0.0125 .25057 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .3685 m
.00625 .3685 L
s
gsave
-0.0125 .3685 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .48642 m
.00625 .48642 L
s
gsave
-0.0125 .48642 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60435 m
.00625 .60435 L
s
gsave
-0.0125 .60435 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .0442 m
.00375 .0442 L
s
0 .07368 m
.00375 .07368 L
s
0 .10316 m
.00375 .10316 L
s
0 .16212 m
.00375 .16212 L
s
0 .19161 m
.00375 .19161 L
s
0 .22109 m
.00375 .22109 L
s
0 .28005 m
.00375 .28005 L
s
0 .30953 m
.00375 .30953 L
s
0 .33902 m
.00375 .33902 L
s
0 .39798 m
.00375 .39798 L
s
0 .42746 m
.00375 .42746 L
s
0 .45694 m
.00375 .45694 L
s
0 .51591 m
.00375 .51591 L
s
0 .54539 m
.00375 .54539 L
s
0 .57487 m
.00375 .57487 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -86 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(V) show
68.750000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13264 m
1 .13264 L
s
.99375 .25057 m
1 .25057 L
s
.99375 .3685 m
1 .3685 L
s
.99375 .48642 m
1 .48642 L
s
.99375 .60435 m
1 .60435 L
s
.125 Mabswid
.99625 .0442 m
1 .0442 L
s
.99625 .07368 m
1 .07368 L
s
.99625 .10316 m
1 .10316 L
s
.99625 .16212 m
1 .16212 L
s
.99625 .19161 m
1 .19161 L
s
.99625 .22109 m
1 .22109 L
s
.99625 .28005 m
1 .28005 L
s
.99625 .30953 m
1 .30953 L
s
.99625 .33902 m
1 .33902 L
s
.99625 .39798 m
1 .39798 L
s
.99625 .42746 m
1 .42746 L
s
.99625 .45694 m
1 .45694 L
s
.99625 .51591 m
1 .51591 L
s
.99625 .54539 m
1 .54539 L
s
.99625 .57487 m
1 .57487 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .01472 m
.06244 .03201 L
.10458 .05093 L
.14415 .0688 L
.18221 .08613 L
.22272 .1048 L
.26171 .12302 L
.30316 .14273 L
.34309 .16212 L
.3815 .18121 L
.42237 .20205 L
.46172 .22273 L
.49955 .24324 L
.53984 .26586 L
.57861 .28848 L
.61984 .31357 L
.65954 .33887 L
.69774 .3644 L
.73838 .39303 L
.77751 .42218 L
.81909 .45511 L
.85916 .489 L
.89771 .52391 L
.93871 .56387 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{167, 103},
  ImageMargins->{{82, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003A0000PA000`40l00?003`dOoo001cool00`0?
ooooo`1Kool007Coo`0300oooooo05[oo`00M?oo00<03oooool0F_oo001cool00`0?ool03`1Kool0
07?oo`0300ooo`0?05_oo`00Looo00<03ooo00l0Fooo003Aool00=7oo`00dOoo003Aool00=7oo`00
dOoo003Aool00=7oo`00:_oo0`0?6?oo0`0?00Goo`0?ooooo`0?01Ooo`<03`05ool03oooool03`0F
ool300l00ooo00ooo`02ool00`0?ooooo`0Dool300l00ooo00ooo`0300lHool300l<ool002[oo`03
00oooooo01Woo`0300oooooo00;oo`0300ooo`0?01Ooo`0300oooooo00;oo`0300ooo`0?01Koo`03
00oooooo00;oo`<03aOoo`0300oooooo00;oo`0300oooooo01Woo`0300oooooo00_oo`009Ooo0`0?
0ooo00<03oooool04ooo0`0?0_oo00<03oooool00ooo00<03oooool04?oo0`0?0ooo00<03oooool0
0_oo0P0?4_oo0`0?0_oo00<03oooool00_oo00<03ooo00l04Ooo0`0?0ooo00<03oooool00ooo00<0
3oooool04ooo0`0?0_oo00<03oooool02ooo000Zool00`0?ool03`0Iool00`0?ooooo`02ool00`0?
ool03`0Gool00`0?ooooo`02ool00`0?ooooo`0Fool00`0?ooooo`03ool200lGool00`0?ooooo`02
ool00`0?ool03`0Iool00`0?ooooo`0;ool002_oo`803aSoo`803`Goo`0300oooooo01Goo`803`Go
o`803aGoo`803`Koo`0300oooooo01Coo`803`Goo`803aSoo`803`goo`00dOoo003Aool00=7oo`00
dOoo003Aool00=7oo`007_oo00<03oooool01?ooX@0?2ooo000Mool00`0?ool03`05ool01@0?oooo
oooo00l07Ooo00<03oooool07?oo00<03oooool06ooo00<03oooool07?oo00<03oooool06ooo00D0
3oooooooo`0?00_oo`007Ooo00<03ooo00l01Ooo0P0?0_oo00<03oooool06ooo00<0Ooooool07?oo
00<0Soooool06ooo00<0Soooool07?oo00<0Ooooool07_oo0P0?2ooo000Mool00`0?ool03`05ool0
100?oooooooo100?6_oo00<0Soooool07?oo00<0Ooooool06ooo00<0Ooooool07?oo00<0Soooool0
7ooo00<03oooool02Ooo000Nool00`0?ooooo`04ool00`0?ooooo`04ool300lHool00`1oooooo`0L
ool00`2?ooooo`0Kool00`2?ooooo`0Lool00`1oooooo`0Oool00`0?ooooo`09ool002Goo`0300oo
oooo00Koo`<03aKoo`0308oooooo01coo`0307oooooo01_oo`0307oooooo01coo`0308oooooo01oo
o`0300oooooo00Woo`009Ooo00<03oooool02?oo0`0?5?oo00<0Ooooool07?oo00<0Soooool06ooo
00<0Soooool07?oo00<0Ooooool07ooo00<03oooool02Ooo000Uool00`0?ooooo`0:ool400lAool0
0`2?ooooo`0Lool00`1oooooo`0Kool00`1oooooo`0Lool00`2?ooooo`0Nool200l;ool002Goo`03
00oooooo00goo`<03`ooo`0307oooooo01coo`0308oooooo01_oo`0308oooooo01coo`0307oooooo
01ooo`0300oooooo00Woo`009Ooo00<03oooool03ooo0`0?3Ooo00<0Soooool07?oo00<0Ooooool0
6ooo00<0Ooooool07?oo00<0Soooool07ooo00<03oooool02Ooo000Uool00`0?ooooo`0Aool300l;
ool00`1oooooo`0Lool00`2?ooooo`0Kool00`2?ooooo`0Lool00`1oooooo`0Oool00`0?ooooo`09
ool002Goo`0300oooooo01?oo`<03`Woo`0308oooooo01coo`0307oooooo01_oo`0307oooooo01co
o`0308oooooo01ooo`0300oooooo00Woo`009Ooo00<03oooool05Ooo100?1_oo00<0Ooooool07?oo
00<0Soooool06ooo00<0Soooool07?oo00<0Ooooool07_oo0P0?2ooo000Uool00`0?ooooo`0Hool3
00l4ool00`2?ooooo`0Lool00`1oooooo`0Kool00`1oooooo`0Lool00`2?ooooo`0Oool00`0?oooo
o`09ool002Goo`0300oooooo01[oo`<03`;oo`0307oooooo01coo`0308oooooo01_oo`0308oooooo
01coo`0307oooooo01ooo`0300oooooo00Woo`009Ooo00<03oooool07?oo0`0?00<0Soooool07?oo
00<0Ooooool06ooo00<0Ooooool07?oo00<0Soooool07ooo00<03oooool02Ooo000Uool00`0?oooo
o`0Nool300lMool00`2?ooooo`0Kool00`2?ooooo`0Lool00`1oooooo`0Nool200l;ool002Goo`03
00oooooo01ooo`0408l03`0?00lKool00`1oooooo`0Kool00`1oooooo`0Lool00`2?ooooo`0Oool0
0`0?ooooo`09ool001Soo`0500oooooo00ooo`0300l5ool00`0?ooooo`0Oool00`1oooooo`0400lH
ool00`2?ooooo`0Kool00`2?ooooo`0Lool00`1oooooo`0Oool00`0?ooooo`09ool001Ooo`0300oo
o`0?00?oo`0300oooooo00Goo`0300oooooo01ooo`0308oooooo00?oo`<03aKoo`0307oooooo01_o
o`0307oooooo01coo`0308oooooo01ooo`0300oooooo00Woo`005ooo00<03ooo00l01?oo00<03ooo
ool01?oo00<03oooool07ooo00<0Ooooool01Ooo0`0?5?oo00<0Soooool06ooo00<0Soooool07?oo
00<0Ooooool07ooo00<03oooool02Ooo000Gool00`0?ool03`03ool00`0?ool03`05ool200l0:P2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`<03`1`07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l200l;ool001Soo`0300oooooo00?oo`803`Goo`0300oooooo01ooo`0307oooooo
00Woo`<03a3oo`0308oooooo01_oo`0308oooooo01coo`0307oooooo01ooo`0300oooooo00Woo`00
9Ooo00<03oooool07ooo00<0Soooool02ooo0`0?3_oo00<0Ooooool06ooo00<0Ooooool07?oo00<0
Soooool07ooo00<03oooool02Ooo000Uool00`0?ooooo`0Oool00`1oooooo`0=ool300l<ool00`2?
ooooo`0Kool00`2?ooooo`0Lool00`1oooooo`0Oool00`0?ooooo`09ool002Goo`0300oooooo01oo
o`0308oooooo00ooo`<03`[oo`0307oooooo01_oo`0307oooooo01coo`0308oooooo01ooo`0300oo
oooo00Woo`009Ooo00<03oooool07ooo00<0Ooooool04Ooo0`0?2?oo00<0Soooool06ooo00<0Sooo
ool07?oo00<0Ooooool07_oo0P0?2ooo000Uool00`0?ooooo`0Oool00`2?ooooo`0Cool300l6ool0
0`1oooooo`0Kool00`1oooooo`0Lool00`2?ooooo`0Oool00`0?ooooo`09ool002Goo`0300oooooo
01ooo`0307oooooo01Goo`<03`Coo`0308oooooo01_oo`0308oooooo01coo`0307oooooo01ooo`03
00oooooo00Woo`009Ooo00<03oooool07ooo00<0Soooool05ooo0`0?0_oo00<0Ooooool06ooo00<0
Ooooool07?oo00<0Soooool07ooo00<03oooool02Ooo000Uool00`0?ooooo`0Oool00`1oooooo`0I
ool300l00`2?ooooo`0Kool00`2?ooooo`0Lool00`1oooooo`0Nool200l;ool002Goo`0300oooooo
01ooo`0308oooooo01_oo`<03acoo`0307oooooo01coo`0308oooooo01ooo`0300oooooo00Woo`00
9Ooo00<03oooool07ooo00<0Ooooool07?oo00@0S`0?00l03a[oo`0308oooooo01coo`0307oooooo
01ooo`0300oooooo00Woo`009Ooo00<03oooool07ooo00<0Soooool07?oo00<0Ooooool00`0?6?oo
00<0Ooooool07?oo00<0Soooool07ooo00<03oooool02Ooo000Uool00`0?ooooo`0Oool00`1ooooo
o`0Lool00`2?ooooo`02ool300lFool00`2?ooooo`0Lool00`1oooooo`0Oool00`0?ooooo`09ool0
02Goo`0300oooooo01ooo`0308oooooo01coo`0307oooooo00Coo`<03aCoo`0307oooooo01coo`03
08oooooo01koo`803`_oo`009Ooo00<03oooool07ooo00<0Ooooool07?oo00<0Soooool01_oo0`0?
4_oo00<0Soooool07?oo00<0Ooooool07ooo00<03oooool02Ooo000Hool0100?ooooo`0?0ooo00<0
3oooool00ooo00<03oooool07ooo00<0Soooool07?oo00<0Ooooool02?oo0`0?4?oo00<0Ooooool0
7?oo00<0Soooool07ooo00<03oooool02Ooo000Gool00`0?ool03`03ool300l5ool00`0?ooooo`0O
ool00`1oooooo`0Lool00`2?ooooo`0:ool200l?ool00`2?ooooo`0Lool00`1oooooo`0Oool00`0?
ooooo`09ool001Ooo`0300ooo`0?00?oo`0300ooo`0?00Goo`0300oooooo01ooo`0308oooooo01co
o`0307oooooo00_oo`<03`goo`0307oooooo01coo`0308oooooo01ooo`0300oooooo00Woo`005ooo
00<03ooo00l01?oo0P0?1Ooo0P0?04l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`0300l0B`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0200l;ool001Soo`0300oooooo00Co
o`0300oooooo00?oo`0300oooooo01ooo`0308oooooo01coo`0307oooooo00ooo`<03`Woo`0307oo
oooo01coo`0308oooooo01ooo`0300oooooo00Woo`009Ooo00<03oooool07ooo00<0Ooooool07?oo
00<0Soooool04Ooo0P0?2?oo00<0Soooool07?oo00<0Ooooool07ooo00<03oooool02Ooo000Uool0
0`0?ooooo`0Oool00`2?ooooo`0Lool00`1oooooo`0Bool300l6ool00`1oooooo`0Lool00`2?oooo
o`0Oool00`0?ooooo`09ool002Goo`0300oooooo01ooo`0307oooooo01coo`0308oooooo01Coo`<0
3`Coo`0308oooooo01coo`0307oooooo01ooo`0300oooooo00Woo`009Ooo00<03oooool07ooo00<0
Soooool07?oo00<0Ooooool05_oo0`0?0_oo00<0Ooooool07?oo00<0Soooool07_oo0P0?2ooo000U
ool00`0?ooooo`0Oool00`1oooooo`0Lool00`2?ooooo`0Hool200l00ooo08ooo`0Mool00`1ooooo
o`0Oool00`0?ooooo`09ool000_oo`0300oooooo01Ooo`0300oooooo01ooo`0308oooooo01coo`03
07oooooo01Woo`<03akoo`0308oooooo01ooo`0300oooooo00Woo`002ooo0`0?5ooo00<03oooool0
7ooo00<0Ooooool07?oo00<0Soooool06ooo0`0?7?oo00<0Ooooool07ooo00<03oooool02Ooo000>
ool300lDool00`0?ooooo`0Oool00`2?ooooo`0Lool00`1oooooo`0Kool0101oool03`0?6ooo00<0
Soooool07_oo0P0?2ooo000;ool0100?ool03`0?5_oo00<03oooool07ooo00<0Ooooool07?oo00<0
Soooool06ooo00<0Soooool00`0?6Ooo00<0Ooooool07ooo00<03oooool02Ooo000;ool200lHool0
0`0?ooooo`0Oool00`2?ooooo`0Lool00`1oooooo`0Kool00`1oooooo`02ool200lHool00`2?oooo
o`0Oool00`0?ooooo`09ool002Goo`0300oooooo01ooo`0307oooooo01coo`0308oooooo01_oo`03
08oooooo00?oo`<03aKoo`0307oooooo01ooo`0300oooooo00Woo`009Ooo00<03oooool07ooo00<0
Soooool07?oo00<0Ooooool06ooo00<0Ooooool01Ooo0`0?5?oo00<0Soooool07ooo00<03oooool0
2Ooo000Uool00`0?ooooo`0Oool00`1oooooo`0Lool00`2?ooooo`0Kool00`2?ooooo`07ool200lC
ool00`1oooooo`0Nool200l;ool002Goo`0300oooooo01ooo`0308oooooo01coo`0307oooooo01_o
o`0307oooooo00Soo`<03a7oo`0308oooooo01ooo`0300oooooo00Woo`006?oo00@03oooool03`;o
o`0300oooooo00Coo`0300oooooo01ooo`0307oooooo01coo`0308oooooo01_oo`0308oooooo00[o
o`803a3oo`0307oooooo01ooo`0300oooooo00Woo`005ooo00<03ooo00l00ooo00<03ooo00l01Ooo
00<03oooool07ooo00<0Soooool07?oo00<0Ooooool06ooo00<0Ooooool02ooo0`0?3_oo00<0Sooo
ool07ooo00<03oooool02Ooo000Gool00`0?ool03`03ool200l6ool00`0?ooooo`0Oool00`1ooooo
o`0Lool00`2?ooooo`0Kool00`2?ooooo`0=ool200l=ool00`1oooooo`0Oool00`0?ooooo`09ool0
01Ooo`0300ooo`0?00?oo`0300oooooo00Goo`803`1^08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`803`0]08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00803`_oo`006?oo
00<03oooool00ooo0P0?1Ooo00<03oooool07ooo00<0Ooooool07?oo00<0Soooool06ooo00<0Sooo
ool03ooo0`0?2_oo00<0Ooooool07ooo00<03oooool02Ooo000Uool00`0?ooooo`0Oool00`2?oooo
o`0Lool00`1oooooo`0Kool00`1oooooo`0Aool200l9ool00`2?ooooo`0Oool00`0?ooooo`09ool0
02Goo`0300oooooo01ooo`0307oooooo01coo`0308oooooo01_oo`0308oooooo01;oo`<03`Ooo`03
07oooooo01ooo`0300oooooo00Woo`009Ooo00<03oooool07ooo00<0Soooool07?oo00<0Ooooool0
6ooo00<0Ooooool05?oo0P0?1_oo00<0Soooool07_oo0P0?2ooo000Uool00`0?ooooo`0Oool00`1o
ooooo`0Lool00`2?ooooo`0Kool00`2?ooooo`0Eool200l5ool00`1oooooo`0Oool00`0?ooooo`09
ool002Goo`0300oooooo01ooo`0308oooooo01coo`0307oooooo01_oo`0307oooooo01Koo`<03`?o
o`0308oooooo01ooo`0300oooooo00Woo`009Ooo00<03oooool07ooo00<0Ooooool07?oo00<0Sooo
ool06ooo00<0Soooool06?oo0P0?0_oo00<0Ooooool07ooo00<03oooool02Ooo000Uool00`0?oooo
o`0Oool00`2?ooooo`0Lool00`1oooooo`0Kool00`1oooooo`0Iool200l00ooo08ooo`0Pool00`0?
ooooo`09ool002Goo`0300oooooo01ooo`0307oooooo01coo`0308oooooo01_oo`0308oooooo01[o
o`<03b3oo`803`_oo`009Ooo00<03oooool07ooo00<0Soooool07?oo00<0Ooooool06ooo00<0Oooo
ool07?oo0P0?8?oo00<03oooool02Ooo000Uool00`0?ooooo`0Oool00`1oooooo`0Lool00`2?oooo
o`0Kool00`2?ooooo`0Lool00`1o00l03`0Oool00`0?ooooo`09ool002Goo`0300oooooo01ooo`03
08oooooo01coo`0307oooooo01_oo`0307oooooo01coo`0408ooo`0?00lNool00`0?ooooo`09ool0
02Goo`0300oooooo01ooo`0307oooooo01coo`0308oooooo01_oo`0308oooooo01coo`0307oooooo
00<03acoo`0300oooooo00Woo`009Ooo00<03oooool07ooo00<0Soooool07?oo00<0Ooooool06ooo
00<0Ooooool07?oo00<0Soooool00_oo0P0?6_oo0P0?2ooo000Uool00`0?ooooo`0Oool00`1ooooo
o`0Lool00`2?ooooo`0Kool00`2?ooooo`0Lool00`1oooooo`03ool200lJool00`0?ooooo`09ool0
01Soo`0400oooooo00l2ool00`0?ooooo`04ool00`0?ooooo`0Oool00`2?ooooo`0Lool00`1ooooo
o`0Kool00`1oooooo`0Lool00`2?ooooo`04ool200lIool00`0?ooooo`09ool001Ooo`0300ooo`0?
00?oo`0300ooo`0?00Goo`0300oooooo01ooo`0307oooooo01coo`0308oooooo01_oo`0308oooooo
01coo`0307oooooo00Goo`803aSoo`0300oooooo00Woo`005ooo00<03ooo00l01?oo00<03oooool0
1?oo00<03oooool07ooo00<0Soooool07?oo00<0Ooooool06ooo00<0Ooooool07?oo00<0Soooool0
1_oo0`0?5_oo00<03oooool02Ooo000Gool00`0?ool03`03ool00`0?ool03`05ool200l0Q`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0200l0502?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l200l;ool001Soo`0300oooooo00?oo`0300oooooo00Coo`0300oooooo01ooo`03
08oooooo01coo`0307oooooo01_oo`0307oooooo01coo`0308oooooo00Woo`803aCoo`0300oooooo
00Woo`009Ooo00<03oooool07ooo00<0Ooooool07?oo00<0Soooool06ooo00<0Soooool07?oo00<0
Ooooool02_oo0P0?4ooo00<03oooool02Ooo000Uool00`0?ooooo`0Oool00`2?ooooo`0Lool00`1o
ooooo`0Kool00`1oooooo`0Lool00`2?ooooo`0;ool200lBool00`0?ooooo`09ool002Goo`0300oo
oooo01ooo`0307oooooo01coo`0308oooooo01_oo`0308oooooo01coo`0307oooooo00coo`803a3o
o`803`_oo`009Ooo00<03oooool07ooo00<0Soooool07?oo00<0Ooooool06ooo00<0Ooooool07?oo
00<0Soooool03Ooo0P0?4?oo00<03oooool02Ooo000Uool00`0?ooooo`0Oool00`1oooooo`0Lool0
0`2?ooooo`0Kool00`2?ooooo`0Lool00`1oooooo`0>ool200l?ool00`0?ooooo`09ool002Goo`03
00oooooo01ooo`0308oooooo01coo`0307oooooo01_oo`0307oooooo01coo`0308oooooo00ooo`80
3`koo`0300oooooo00Woo`009Ooo00<03oooool07ooo00<0Ooooool07?oo00<0Soooool06ooo00<0
Soooool07?oo00<0Ooooool04?oo0P0?3Ooo00<03oooool02Ooo000Uool00`0?ooooo`0Oool00`2?
ooooo`0Lool00`1oooooo`0Kool00`1oooooo`0Lool00`2?ooooo`0Aool200l;ool200l;ool002Go
o`0300oooooo01ooo`0307oooooo01coo`0308oooooo01_oo`0308oooooo01coo`0307oooooo01;o
o`803`_oo`0300oooooo00Woo`009Ooo00<03oooool07ooo00<0Soooool07?oo00<0Ooooool06ooo
00<0Ooooool07?oo00<0Soooool04ooo0P0?2_oo00<03oooool02Ooo000Uool00`0?ooooo`0Oool0
0`1oooooo`0Lool00`2?ooooo`0Kool00`2?ooooo`0Lool00`1oooooo`0Dool200l9ool00`0?oooo
o`09ool002Goo`0300oooooo01ooo`0308oooooo01coo`0307oooooo01_oo`0307oooooo01coo`03
08oooooo01Goo`803`Soo`0300oooooo00Woo`009Ooo00<03oooool07ooo00<0Ooooool07?oo00<0
Soooool06ooo00<0Soooool07?oo00<0Ooooool05_oo0P0?1_oo0P0?2ooo000Uool00`0?ooooo`0O
ool00`2?ooooo`0Lool00`1oooooo`0Kool00`1oooooo`0Lool00`2?ooooo`0Gool200l6ool00`0?
ooooo`09ool001goo`<03`Goo`0300oooooo01ooo`0307oooooo01coo`0308oooooo01_oo`0308oo
oooo01coo`0307oooooo01Soo`803`Goo`0300oooooo00Woo`007_oo00<03oooool01?oo00<03ooo
ool07ooo00<0Soooool07?oo00<0Ooooool06ooo00<0Ooooool07?oo00<0Soooool06Ooo0P0?1?oo
00<03oooool02Ooo000Nool00`0?ooooo`04ool200lPool00`1oooooo`0Lool00`2?ooooo`0Kool0
0`2?ooooo`0Lool00`1oooooo`0Jool200l2ool200l;ool001koo`0300oooooo00Coo`0300oooooo
01ooo`0308oooooo01coo`0307oooooo01_oo`0307oooooo01coo`0308oooooo01ooo`0300oooooo
00Woo`007Ooo0P0?1_oo00D03oooooooo`0?00Koo`0300oooooo00Goo`0300oooooo00Coo`0300oo
oooo00Goo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo00Goo`0300oo
oooo00Coo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo00Goo`0300oo
oooo00Coo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`0300oo
oooo00Coo`0300oooooo00Goo`0500ooooooool03`0;ool002Gooj403`_oo`00dOoo003Aool00=7o
o`00\
\>"],
  ImageRangeCache->{{{0, 207.75}, {127.75, 0}} -> {-2.269248, -0.289824, 
  0.008199, 0.013243}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Capacitance"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Csp]; \)\), 
    \(\(Csp := 
      Function[{R, 
          s}, {alpha = Log[1 + s\/R + \@\(s\^2\/R\^2 + \(2\ s\)\/R\)]; 
            cap2 = 1 + \[Sum]\+\(n = 2\)\%100 Sinh[alpha]\/Sinh[n\ alpha]; 
            N[4.\ \[Pi]\ eps0\ R\ cap2] //. NSub}\[LeftDoubleBracket]1
          \[RightDoubleBracket]]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Cspa]; \)\), 
    \(\(Cspa[R_, s_] := N[2\ \[Pi]\ eps0\ R\ \((2 + R\/s)\)] /. NSub; \)\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Example"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(case5 = {R \[Rule] 10\ nano, s \[Rule] 50\ nano}; \)\), 
    \(\(RR = R /. case5; \)\), 
    \(\(ss = s /. case5; \)\), 
    \(Timing[Print["\<Csp  = \>", Csp[RR, ss]\/atto, "\< [aF]\>"]]\), 
    \(Timing[Print["\<Cspa = \>", Cspa[RR, ss]\/atto, "\< [aF]\>"]]\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("Csp  = "\[InvisibleSpace]1.21386474320153325`
        \[InvisibleSpace]" [aF]"\),
      SequenceForm[ "Csp  = ", 1.21386474320153326, " [aF]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0.0899959999999992987`\ Second, Null}\)], "Output"],

Cell[BoxData[
    InterpretationBox[
      \("Cspa = "\[InvisibleSpace]1.22391536332948103`
        \[InvisibleSpace]" [aF]"\),
      SequenceForm[ "Cspa = ", 1.22391536332948103, " [aF]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0.`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig6 = 
      Plot[Cspa[RR, s\ nano]\/Csp[RR, s\ nano], {s, RR\/nano, ss\/nano}, 
        FrameLabel \[Rule] {"\<s in nm\>", "\<Cspa over Csp\>"}, 
        Evaluate[opt]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
-0.214286 0.02381 -5.368863 5.339369 [
[.02381 -0.0125 -6 -12 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -12 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -6 -12 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -12 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -12 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -24 ]
[.5 -0.0125 14 -12 ]
[-0.0125 .07729 -18 -6 ]
[-0.0125 .07729 0 6 ]
[-0.0125 .18408 -18 -6 ]
[-0.0125 .18408 0 6 ]
[-0.0125 .29087 -18 -6 ]
[-0.0125 .29087 0 6 ]
[-0.0125 .39766 -18 -6 ]
[-0.0125 .39766 0 6 ]
[-0.0125 .50444 -14 -6 ]
[-0.0125 .50444 0 6 ]
[-0.0125 .61123 -18 -6 ]
[-0.0125 .61123 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30 -25.5 ]
[-0.01875 .30902 -18 25.5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .07729 m
1 .07729 L
s
0 .18408 m
1 .18408 L
s
0 .29087 m
1 .29087 L
s
0 .39766 m
1 .39766 L
s
0 .50444 m
1 .50444 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(30) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
68.062500 13.000000 moveto
(in) show
76.250000 13.000000 moveto
(nm) show
86.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .07729 m
.00625 .07729 L
s
gsave
-0.0125 .07729 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.02) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .18408 m
.00625 .18408 L
s
gsave
-0.0125 .18408 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.04) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .29087 m
.00625 .29087 L
s
gsave
-0.0125 .29087 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.06) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .39766 m
.00625 .39766 L
s
gsave
-0.0125 .39766 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.08) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .50444 m
.00625 .50444 L
s
gsave
-0.0125 .50444 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .61123 m
.00625 .61123 L
s
gsave
-0.0125 .61123 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.12) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .10399 m
.00375 .10399 L
s
0 .13069 m
.00375 .13069 L
s
0 .15738 m
.00375 .15738 L
s
0 .21078 m
.00375 .21078 L
s
0 .23747 m
.00375 .23747 L
s
0 .26417 m
.00375 .26417 L
s
0 .31756 m
.00375 .31756 L
s
0 .34426 m
.00375 .34426 L
s
0 .37096 m
.00375 .37096 L
s
0 .42435 m
.00375 .42435 L
s
0 .45105 m
.00375 .45105 L
s
0 .47775 m
.00375 .47775 L
s
0 .53114 m
.00375 .53114 L
s
0 .55784 m
.00375 .55784 L
s
0 .58453 m
.00375 .58453 L
s
0 .0506 m
.00375 .0506 L
s
0 .0239 m
.00375 .0239 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -110.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
86.5 10 translate
90 rotate
-86.5 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Cspa) show
80.875000 13.000000 moveto
(over) show
97.000000 13.000000 moveto
(Csp) show
109.375000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07729 m
1 .07729 L
s
.99375 .18408 m
1 .18408 L
s
.99375 .29087 m
1 .29087 L
s
.99375 .39766 m
1 .39766 L
s
.99375 .50444 m
1 .50444 L
s
.99375 .61123 m
1 .61123 L
s
.125 Mabswid
.99625 .10399 m
1 .10399 L
s
.99625 .13069 m
1 .13069 L
s
.99625 .15738 m
1 .15738 L
s
.99625 .21078 m
1 .21078 L
s
.99625 .23747 m
1 .23747 L
s
.99625 .26417 m
1 .26417 L
s
.99625 .31756 m
1 .31756 L
s
.99625 .34426 m
1 .34426 L
s
.99625 .37096 m
1 .37096 L
s
.99625 .42435 m
1 .42435 L
s
.99625 .45105 m
1 .45105 L
s
.99625 .47775 m
1 .47775 L
s
.99625 .53114 m
1 .53114 L
s
.99625 .55784 m
1 .55784 L
s
.99625 .58453 m
1 .58453 L
s
.99625 .0506 m
1 .0506 L
s
.99625 .0239 m
1 .0239 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .60332 m
.06244 .47793 L
.10458 .3802 L
.14415 .31245 L
.18221 .26221 L
.22272 .22014 L
.26171 .18778 L
.30316 .15988 L
.34309 .13783 L
.3815 .12009 L
.42237 .10416 L
.46172 .09112 L
.49955 .08031 L
.53984 .07033 L
.57861 .06196 L
.61984 .05417 L
.65954 .04758 L
.69774 .04195 L
.73838 .0366 L
.77751 .03201 L
.81909 .02764 L
.85916 .02385 L
.89771 .02055 L
.93871 .01737 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{167.125, 103.25},
  ImageMargins->{{82.1875, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003A0000PQ000`40l00?003`dOoo003Aool00=7o
o`00dOoo001/ool200l3ool01@0?ool03ooo00l00ooo00T03ooo00ooo`0?ool03ooo00l0Cooo001]
ool02@0?oooooooo00ooo`0?ool03`03ool02@0?ool03ooo00ooo`0?ool03`1?ool006coo`0300oo
oooo00;oo`0500ooo`0?ool03`03ool02@0?ool03ooo00ooo`0?ool03`1?ool006coo`803`?oo`04
00ooo`0?00l4ool200l2ool200l00ooo00ooo`1?ool00=7oo`00LOoo00<03oooool0GOoo003Aool0
0=7oo`00dOoo003Aool00=7oo`00dOoo000Xool300l2ool00`0?ooooo`0Nool300l2ool00`0?oooo
o`0Nool200l3ool00`0?ooooo`0Pool0100?ooooo`0?7ooo0P0?0ooo00<03oooool02_oo000Yool0
1P0?ooooo`0?ool03aooo`0700ooooooool03ooo00l08Ooo00D03ooo00ooo`0?01ooo`<03`04ool0
3ooo00lPool01@0?ool03ooo00l02ooo000Yool01P0?ooooo`0?ool03b3oo`0600oooooo00ooo`0?
8?oo00H03oooool03ooo00lOool01`0?ool03ooo00ooo`0?01koo`803`;oo`0300ooo`0?00_oo`00
:Ooo00H03oooool03ooo00lOool01`0?ool03ooo00ooo`0?027oo`0500ooo`0?ool03`0Pool200l0
1?oo00ooo`0?7_oo00L03oooooooo`0?ool03`0;ool002Soo`803`?oo`0300oooooo01ooo`803`;o
o`0300oooooo01koo`803`?oo`0300oooooo023oo`0400oooooo00lOool300l2ool00`0?ooooo`0:
ool00=7oo`00dOoo003Aool00=7oo`00dOoo000XoonP00l9ool002Soo`0500ooooooool03`06ool0
0`0?ooooo`05ool00`0?ooooo`04ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`04ool0
0`0?ooooo`05ool00`0?ooooo`04ool00`0?ooooo`05ool00`0?ooooo`04ool00`0?ooooo`05ool0
0`0?ooooo`04ool00`0?ooooo`05ool00`0?ooooo`05ool00`0?ooooo`04ool00`0?ooooo`05ool0
0`0?ooooo`04ool00`0?ooooo`05ool00`0?ooooo`04ool00`0?ooooo`05ool01@0?oooooooo00l0
2Ooo000Xool00`0?ooooo`0Wool00`1oooooo`0Rool00`2?ooooo`0Sool00`2?ooooo`0Wool00`0?
ooooo`07ool002Soo`0300oooooo02Ooo`0308oooooo02;oo`0307oooooo02?oo`0307oooooo01Wo
o`/03`?oo`0300oooooo00Ooo`00:?oo0P0?:?oo00<0Ooooool08_oo00<0Soooool08ooo00<0Sooo
ool03Ooo3@0?3?oo0P0?2Ooo000Xool00`0?ooooo`0Wool00`2?ooooo`0Rool00`1oooooo`0Sool0
0`1oooooo`03ool;00lIool00`0?ooooo`07ool002Soo`0300oooooo02Ooo`0307oooooo02;oo`03
08oooooo027oo`T03b?oo`0300oooooo00Ooo`00:?oo00<03oooool09ooo00<0Soooool08_oo00<0
Ooooool06_oo200?00?oo`1oool0:?oo00<03oooool01ooo000Xool200lXool00`1oooooo`0Rool0
0`2?ooooo`0Dool700l8ool00`2?ooooo`0Vool200l9ool002Soo`0300oooooo02Ooo`0308oooooo
02;oo`0307oooooo00koo`L03`koo`0307oooooo02Ooo`0300oooooo00Ooo`005_oo0`0?00Goo`0?
ooooo`0?00;oo`<03`Goo`0300oooooo02Ooo`0307oooooo02;oo`0308oooooo00Woo`H03aCoo`03
08oooooo02Ooo`0300oooooo00Ooo`005ooo00<03oooool00_oo00D03ooo00ooo`0?00Ooo`0300oo
oooo02Ooo`0308oooooo02;oo`0307oooooo00Coo`H03aWoo`0307oooooo02Ooo`0300oooooo00Oo
o`005ooo00<03oooool00_oo00<03ooo00l00_oo00<03oooool01?oo00<03oooool09ooo00<0Oooo
ool08_oo00<0Soooool01@0?7_oo00<0Soooool09ooo00<03oooool01ooo000Gool00`0?ooooo`02
ool01`0?ool03ooo00ooo`0?00Goo`803`1<08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l5
00l0B`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0200l9ool001Koo`803`Goo`0400oooooo
ool200l5ool00`0?ooooo`0Wool00`1oooooo`0Nool400l00`2?ooooo`0Sool00`2?ooooo`0Wool0
0`0?ooooo`07ool002Soo`0300oooooo02Ooo`0308oooooo01[oo`D03`?oo`0307oooooo02?oo`03
07oooooo02Ooo`0300oooooo00Ooo`00:?oo00<03oooool09ooo00<0Ooooool05ooo100?1ooo00<0
Soooool08ooo00<0Soooool09ooo00<03oooool01ooo000Xool200lXool00`2?ooooo`0Eool300l:
ool00`1oooooo`0Sool00`1oooooo`0Vool200l9ool002Soo`0300oooooo02Ooo`0307oooooo01;o
o`@03`coo`0308oooooo02?oo`0308oooooo02Ooo`0300oooooo00Ooo`00:?oo00<03oooool09ooo
00<0Soooool03ooo100?3ooo00<0Ooooool08ooo00<0Ooooool09ooo00<03oooool01ooo000Xool0
0`0?ooooo`0Wool00`1oooooo`0=ool300lBool00`2?ooooo`0Sool00`2?ooooo`0Wool00`0?oooo
o`07ool002Soo`803bSoo`0308oooooo00_oo`<03aCoo`0307oooooo02?oo`0307oooooo02Koo`80
3`Woo`00:?oo00<03oooool09ooo00<0Ooooool02Ooo0`0?5_oo00<0Soooool08ooo00<0Soooool0
9ooo00<03oooool01ooo000Xool00`0?ooooo`0Wool00`2?ooooo`07ool300lHool00`1oooooo`0S
ool00`1oooooo`0Wool00`0?ooooo`07ool002Soo`0300oooooo02Ooo`0307oooooo00Goo`<03a[o
o`0308oooooo02?oo`0308oooooo02Ooo`0300oooooo00Ooo`00:?oo0P0?:?oo00<0Soooool01?oo
0P0?7?oo00<0Ooooool08ooo00<0Ooooool09_oo0P0?2Ooo000Xool00`0?ooooo`0Wool00`1ooooo
o`02ool300lMool00`2?ooooo`0Sool00`2?ooooo`0Wool00`0?ooooo`07ool000coo`<03`Ooo`<0
3`05ool03oooool03`04ool00`0?ooooo`03ool00`0?ooooo`0Wool0102?oooooooo0P0?7ooo00<0
Ooooool08ooo00<0Ooooool09ooo00<03oooool01ooo000:ool200l3ool00`0?ooooo`05ool00`0?
ooooo`02ool0100?ool03ooo0`0?1Ooo00<03oooool09ooo00<0Oooo00l00P0?8?oo00<0Soooool0
8ooo00<0Soooool09ooo00<03oooool01ooo000:ool00`0?ooooo`02ool00`0?ooooo`05ool00`0?
ooooo`02ool01`0?ool03ooo00ooo`0?00Goo`0300oooooo02Ooo`0308l03`0?02;oo`0307oooooo
02?oo`0307oooooo02Ooo`0300oooooo00Ooo`002_oo00<03oooool00_oo00<03oooool01Ooo00<0
3oooool00_oo00<03ooo00l00_oo0P0?1Ooo0P0?02L0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l00`0?0780O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l200l9ool000[oo`803`;o
o`0300oooooo00Goo`803`Goo`0300oooooo00;oo`0300oooooo00?oo`0300oooooo02Goo`803`03
08oooooo02;oo`0307oooooo02?oo`0307oooooo02Ooo`0300oooooo00Ooo`003Ooo00<03ooo00l0
6?oo00<03oooool09?oo0P0?00?oo`1oool08ooo00<0Soooool08ooo00<0Soooool09ooo00<03ooo
ool01ooo000<ool200l00ooo00ooo`0Gool00`0?ooooo`0Sool200l2ool00`2?ooooo`0Rool00`1o
ooooo`0Sool00`1oooooo`0Wool00`0?ooooo`07ool000coo`0300ooo`0?01Woo`803b;oo`<03`?o
o`0307oooooo02;oo`0308oooooo02?oo`0308oooooo02Koo`803`Woo`003?oo1P0?5_oo00<03ooo
ool08?oo0P0?1Ooo00<0Soooool08_oo00<0Ooooool08ooo00<0Ooooool09ooo00<03oooool01ooo
000<ool01P0?ooooo`0?ool03aKoo`0300oooooo01ooo`803`Koo`0307oooooo02;oo`0308oooooo
02?oo`0308oooooo02Ooo`0300oooooo00Ooo`003?oo00@03oooool03aSoo`0300oooooo01koo`80
3`Ooo`0308oooooo02;oo`0307oooooo02?oo`0307oooooo02Ooo`0300oooooo00Ooo`003Ooo0P0?
6Ooo0P0?7_oo0P0?2?oo00<0Ooooool08_oo00<0Soooool08ooo00<0Soooool09_oo0P0?2Ooo000<
ool00`0?ool03`0Iool00`0?ooooo`0Lool200l9ool00`2?ooooo`0Rool00`1oooooo`0Sool00`1o
ooooo`0Wool00`0?ooooo`07ool000coo`803`03ool03ooo01Ooo`0300oooooo01_oo`803`[oo`03
07oooooo02;oo`0308oooooo02?oo`0308oooooo02Ooo`0300oooooo00Ooo`003Ooo0`0?6?oo00<0
3oooool06_oo0P0?2ooo00<0Soooool08_oo00<0Ooooool08ooo00<0Ooooool09ooo00<03oooool0
1ooo000?ool00`0?ooooo`0Fool200lKool00`0?ooooo`0:ool00`1oooooo`0Rool00`2?ooooo`0S
ool00`2?ooooo`0Vool200l9ool002Soo`0300oooooo01Woo`803`coo`0308oooooo02;oo`0307oo
oooo02?oo`0307oooooo02Ooo`0300oooooo00Ooo`003Ooo0P0?1ooo0`0?00Goo`0?ooooo`0?00?o
o`0300oooooo00Coo`0300oooooo01Soo`803`goo`0307oooooo02;oo`0308oooooo02?oo`0308oo
oooo02Ooo`0300oooooo00Ooo`003?oo00@03oooool03`Ooo`0300oooooo00;oo`0700ooo`0?ool0
3ooo00l01Ooo00<03oooool05ooo0P0?3_oo00<0Soooool08_oo00<0Ooooool08ooo00<0Ooooool0
9ooo00<03oooool01ooo000<ool0100?ooooo`0?1ooo00<03oooool00_oo00@03ooo00ooo`803`Ko
o`0300oooooo01Koo`803`ooo`0307oooooo02;oo`0308oooooo02?oo`0308oooooo02Ooo`0300oo
oooo00Ooo`003Ooo0P0?2?oo00<03oooool00_oo00D03ooo00ooo`0?00Ooo`803`2L08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o0P0?2Ooo000<ool00`0?ooooo`07ool200l5ool0100?oooooooo0P0?1Ooo00<03oooool05Ooo
0P0?4?oo00<0Ooooool08_oo00<0Soooool08ooo00<0Soooool09ooo00<03oooool01ooo000<ool2
00lJool00`0?ooooo`0Dool200lAool00`2?ooooo`0Rool00`1oooooo`0Sool00`1oooooo`0Wool0
0`0?ooooo`07ool000koo`803aSoo`0300oooooo01Coo`0300oooooo013oo`0307oooooo02;oo`03
08oooooo02?oo`0308oooooo02Ooo`0300oooooo00Ooo`003?oo0P0?6_oo0P0?5?oo0P0?4_oo00<0
Soooool08_oo00<0Ooooool08ooo00<0Ooooool09_oo0P0?2Ooo000=ool200lIool00`0?ooooo`0B
ool200lCool00`1oooooo`0Rool00`2?ooooo`0Sool00`2?ooooo`0Wool00`0?ooooo`07ool000co
o`803`03ool03ooo01Ooo`0300oooooo01;oo`0300oooooo01;oo`0308oooooo02;oo`0307oooooo
02?oo`0307oooooo02Ooo`0300oooooo00Ooo`003?oo0P0?00?oo`0?ool05ooo00<03oooool04Ooo
0P0?5?oo00<0Ooooool08_oo00<0Soooool08ooo00<0Soooool09ooo00<03oooool01ooo000>ool2
00lHool200lBool00`0?ooooo`0Cool00`2?ooooo`0Rool00`1oooooo`0Sool00`1oooooo`0Vool2
00l9ool000coo`@03aSoo`0300oooooo013oo`803aGoo`0307oooooo02;oo`0308oooooo02?oo`03
08oooooo02Ooo`0300oooooo00Ooo`003?oo00@03oooool03aSoo`0300oooooo00ooo`803aKoo`03
08oooooo02;oo`0307oooooo02?oo`0307oooooo02Ooo`0300oooooo00Ooo`00:?oo00<03oooool0
3ooo00<03oooool05Ooo00<0Ooooool08_oo00<0Soooool08ooo00<0Soooool09ooo00<03oooool0
1ooo000Xool200l?ool200lGool00`2?ooooo`0Rool00`1oooooo`0Sool00`1oooooo`0Vool200l9
ool002Soo`0300oooooo00koo`0300oooooo01Koo`0307oooooo02;oo`0308oooooo02?oo`0308oo
oooo02Ooo`0300oooooo00Ooo`003?oo0`0?1ooo0`0?00Goo`0?ooooo`0?00?oo`0300oooooo00Co
o`0300oooooo00goo`803aSoo`0308oooooo02;oo`0307oooooo02?oo`0307oooooo02Ooo`0300oo
oooo00Ooo`002_oo0P0?0ooo00<03oooool01Ooo00<03oooool00_oo00L03ooo00ooo`0?ool03`05
ool00`0?ooooo`0=ool00`0?ooooo`0Gool00`1oooooo`0Rool00`2?ooooo`0Sool00`2?ooooo`0W
ool00`0?ooooo`07ool000[oo`0300oooooo00;oo`0300oooooo00Goo`0300oooooo00;oo`0300oo
o`0?00;oo`0300oooooo00Coo`0300oooooo00coo`803aWoo`0308oooooo02;oo`0307oooooo02?o
o`0307oooooo02Ooo`0300oooooo00Ooo`002_oo00<03oooool00_oo00<03oooool01Ooo00<03ooo
ool00_oo00L03ooo00ooo`0?ool03`05ool200l0W01o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`803`Woo`002_oo0P0?0_oo
00<03oooool01Ooo0P0?1Ooo00D03oooooooo`0?00Koo`0300oooooo00_oo`803a[oo`0308oooooo
02;oo`0307oooooo02?oo`0307oooooo02Ooo`0300oooooo00Ooo`003Ooo00<03ooo00l06?oo00<0
3oooool02ooo00<03oooool06Ooo00<0Ooooool08_oo00<0Soooool08ooo00<0Soooool09ooo00<0
3oooool01ooo000<ool200l00ooo00ooo`0Gool00`0?ooooo`0;ool00`0?ooooo`0Iool00`2?oooo
o`0Rool00`1oooooo`0Sool00`1oooooo`0Wool00`0?ooooo`07ool000coo`0300ooo`0?01Woo`80
3`_oo`803a_oo`0307oooooo02;oo`0308oooooo02?oo`0308oooooo02Koo`803`Woo`003?oo1P0?
5_oo00<03oooool02_oo00<03oooool06_oo00<0Soooool08_oo00<0Ooooool08ooo00<0Ooooool0
9ooo00<03oooool01ooo000<ool01P0?ooooo`0?ool03aKoo`0300oooooo00Woo`803acoo`0307oo
oooo02;oo`0308oooooo02?oo`0308oooooo02Ooo`0300oooooo00Ooo`003?oo00@03oooool03aSo
o`0300oooooo00Woo`0300oooooo01_oo`0308oooooo02;oo`0307oooooo02?oo`0307oooooo02Oo
o`0300oooooo00Ooo`003Ooo0P0?6Ooo0P0?2Ooo0P0?7Ooo00<0Ooooool08_oo00<0Soooool08ooo
00<0Soooool09_oo0P0?2Ooo000Xool00`0?ooooo`08ool00`0?ooooo`0Lool00`2?ooooo`0Rool0
0`1oooooo`0Sool00`1oooooo`0Wool00`0?ooooo`07ool002Soo`0300oooooo00Soo`0300oooooo
01coo`0307oooooo02;oo`0308oooooo02?oo`0308oooooo02Ooo`0300oooooo00Ooo`00:?oo00<0
3oooool01ooo0P0?7_oo00<0Soooool08_oo00<0Ooooool08ooo00<0Ooooool09ooo00<03oooool0
1ooo000Xool200l8ool00`0?ooooo`0Mool00`1oooooo`0Rool00`2?ooooo`0Sool00`2?ooooo`0V
ool200l9ool002Soo`0300oooooo00Koo`803aooo`0308oooooo02;oo`0307oooooo02?oo`0307oo
oooo02Ooo`0300oooooo00Ooo`006_oo0`0?00?oo`0?ool00`0?1Ooo00<03oooool01_oo00<03ooo
ool07_oo00<0Ooooool08_oo00<0Soooool08ooo00<0Soooool09ooo00<03oooool01ooo000Kool0
0`0?ooooo`03ool00`0?ooooo`04ool00`0?ooooo`06ool00`0?ooooo`0Nool00`2?ooooo`0Rool0
0`1oooooo`0Sool00`1oooooo`0Wool00`0?ooooo`07ool001_oo`0300oooooo00?oo`0300oooooo
00Coo`0300oooooo00Koo`0300oooooo01koo`0307oooooo02;oo`0308oooooo02?oo`0308oooooo
02Ooo`0300oooooo00Ooo`006ooo00<03oooool00ooo00<03oooool01?oo0P0?00H0S`1o08l0O`2?
07l200l0U02?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o0P0?2Ooo000Jool200l4ool200l6ool00`0?ooooo`05ool00`0?ooooo`0Oool00`1oooooo`0R
ool00`2?ooooo`0Sool00`2?ooooo`0Wool00`0?ooooo`07ool002Soo`0300oooooo00Goo`0300oo
oooo01ooo`0308oooooo02;oo`0307oooooo02?oo`0307oooooo02Ooo`0300oooooo00Ooo`00:?oo
00<03oooool01?oo0P0?8Ooo00<0Ooooool08_oo00<0Soooool08ooo00<0Soooool09ooo00<03ooo
ool01ooo000Xool200l5ool00`0?ooooo`0Pool00`2?ooooo`0Rool00`1oooooo`0Sool00`1ooooo
o`0Vool200l9ool002Soo`0300oooooo00Coo`0300oooooo023oo`0307oooooo02;oo`0308oooooo
02?oo`0308oooooo02Ooo`0300oooooo00Ooo`00:?oo00<03oooool00ooo0P0?8_oo00<0Soooool0
8_oo00<0Ooooool08ooo00<0Ooooool09ooo00<03oooool01ooo000Xool00`0?ooooo`03ool00`0?
ooooo`0Qool00`1oooooo`0Rool00`2?ooooo`0Sool00`2?ooooo`0Wool00`0?ooooo`07ool002So
o`803`Coo`0300oooooo027oo`0308oooooo02;oo`0307oooooo02?oo`0307oooooo02Koo`803`Wo
o`00:?oo00<03oooool00_oo0P0?8ooo00<0Ooooool08_oo00<0Soooool08ooo00<0Soooool09ooo
00<03oooool01ooo000Xool00`0?ooooo`02ool00`0?ooooo`0Rool00`2?ooooo`0Rool00`1ooooo
o`0Sool00`1oooooo`0Wool00`0?ooooo`07ool002Soo`0300oooooo00;oo`0300oooooo02;oo`03
07oooooo02;oo`0308oooooo02?oo`0308oooooo02Ooo`0300oooooo00Ooo`00:?oo0P0?0ooo00<0
3oooool08_oo00<0Soooool08_oo00<0Ooooool08ooo00<0Ooooool09_oo0P0?2Ooo000Xool0100?
oooooooo0P0?9?oo00<0Ooooool08_oo00<0Soooool08ooo00<0Soooool09ooo00<03oooool01ooo
000Fool300l00ooo00ooo`0300l01?oo00l03`0?1Ooo00D03oooooooo`0?02Goo`0308oooooo02;o
o`0307oooooo02?oo`0307oooooo02Ooo`0300oooooo00Ooo`005ooo00<03oooool00ooo00@03ooo
ool03`Ooo`0500ooooooool03`0Uool00`1oooooo`0Rool00`2?ooooo`0Sool00`2?ooooo`0Wool0
0`0?ooooo`07ool001Ooo`0300oooooo00?oo`0500ooooooool03`06ool200lXool00`2?ooooo`0R
ool00`1oooooo`0Sool00`1oooooo`0Vool200l9ool001Ooo`0300oooooo00?oo`0600oooooo00oo
o`0?1Ooo00D03oooooooo`0?00Koo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`03
00oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`03
00oooooo00Coo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo00Goo`03
00oooooo00Coo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo00Coo`03
00oooooo00Goo`0500ooooooool03`09ool001Koo`803`Coo`803`?oo`803`Gooj003`Woo`00dOoo
003Aool00=7oo`00dOoo0000\
\>"],
  ImageRangeCache->{{{0, 207.875}, {128.0625, 0}} -> {-1.685429, 0.97606, 
  0.330554, 0.001474}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Two Spheres"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Capacitance: Exact Solution"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[R1, R2, s]; \)\), 
    \(Css := 
      Function[{R1, R2, 
          s}, {temp1 = 4.\ \[Pi]\ eps0\ R1 //. NSub; 
            temp2 = 4.\ \[Pi]\ eps0\ R2 //. NSub; R1sq = R1\ R1; 
            R2sq = R2\ R2; q = 1.; da = s + R1 + R2; d1 = da; qt = 0.; 
            qqt = 0.; 
            Do[{qq = \(-\(\(R2\ q\)\/da\)\); dd = d1 - R2sq\/da; qt = qt + q; 
                qqt = qqt + qq; q = \(-\(\(R1\ qq\)\/dd\)\); 
                da = d1 - R1sq\/dd; }, {i, 1, 100}]; c11 = qt\ temp1; 
            c12 = qqt\ temp1; q = 1.; da = s + R1 + R2; qt = 0.; qqt = 0.; 
            Do[{qq = \(-\(\(R1\ q\)\/da\)\); dd = d1 - R1sq\/da; qt = qt + q; 
                q = \(-\(\(R2\ qq\)\/dd\)\); da = d1 - R2sq\/dd; }, {i, 1, 
                100}]; c22 = qt\ temp2; c21 = c12; 
            N[\(c11\ c22 - c12\ c21\)\/\(c11 + c12 + c21 + c22\)]}
            \[LeftDoubleBracket]1\[RightDoubleBracket]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Example"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(case6
       = {R1 \[Rule] 100\ nano, R2 \[Rule] 10\ nano, s \[Rule] 1\ nano}; \)\),
   
    \(\(RR1 = R1 /. case6; \)\), 
    \(\(RR2 = R2 /. case6; \)\), 
    \(\(ss = s /. case6; \)\), 
    \(Print["\<Css = \>", Css[RR1, RR2, ss]\/atto, "\< [aF]\>"]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("Css = "\[InvisibleSpace]2.2840179955915274`
        \[InvisibleSpace]" [aF]"\),
      SequenceForm[ "Css = ", 2.28401799559152741, " [aF]"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Matrix Elements"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(tbl2 = 
      TableForm[{{N[c11\/atto], N[c12\/atto]}, {N[c21\/atto], N[c22\/atto]}}, 
        TableHeadings 
          \[Rule] {{"\<j=1\>", "\<j=2\>"}, {"\<i=1\>", "\<i=2\>"}}]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    TagBox[GridBox[{
          {\(""\), \("i=1"\), \("i=2"\)},
          {\("j=1"\), "13.0956546843663024`", \(-2.11674922002135668`\)},
          {\("j=2"\), \(-2.11674922002135668`\), "2.28660584089988772`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableHeadings -> {{"j=1", "j=2"}, {"i=1", "i=2"}}]&)]], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Capacitance: Approximate Solution"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Cssa]; \)\), 
    \(\(Cssa = 
      Function[{R1, R2, 
          s}, {R11 = Max[{R1, R2}]; R22 = Min[{R1, R2}]; 
            rb = 1.\/\(1. + R22\/R11\); N[rb\ Csp[R22, rb\ s]]}
            \[LeftDoubleBracket]1\[RightDoubleBracket]]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Example"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Timing[Print["\<Css  = \>", Css[RR1, RR2, ss]\/atto, "\< [aF]\>"]]\), 
    \(Timing[Print["\<Cssa = \>", Cssa[RR1, RR2, ss]\/atto, "\< [aF]\>"]]\)}],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("Css  = "\[InvisibleSpace]2.2840179955915274`
        \[InvisibleSpace]" [aF]"\),
      SequenceForm[ "Css  = ", 2.28401799559152741, " [aF]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0.629984000000007426`\ Second, Null}\)], "Output"],

Cell[BoxData[
    InterpretationBox[
      \("Cssa = "\[InvisibleSpace]2.22219122306465965`
        \[InvisibleSpace]" [aF]"\),
      SequenceForm[ "Cssa = ", 2.22219122306465966, " [aF]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0.00999899999999342981`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig7 = 
      Plot[Cssa[RR1, RR2, s\ nano]\/Css[RR1, RR2, s\ nano], {s, .1, 100.}, 
        FrameLabel \[Rule] {"\<s in nm\>", "\<Cssa over Css\>"}, 
        PlotRange \[Rule] {.9, 1.}, Evaluate[opt]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.02381 0.009524 -5.562306 6.18034 [
[.02381 -0.0125 -4 -12 ]
[.02381 -0.0125 4 0 ]
[.21429 -0.0125 -6 -12 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -12 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -12 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -12 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -8 -12 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -24 ]
[.5 -0.0125 14 -12 ]
[-0.0125 .12361 -18 -6 ]
[-0.0125 .12361 0 6 ]
[-0.0125 .24721 -18 -6 ]
[-0.0125 .24721 0 6 ]
[-0.0125 .37082 -18 -6 ]
[-0.0125 .37082 0 6 ]
[-0.0125 .49443 -18 -6 ]
[-0.0125 .49443 0 6 ]
[-0.0125 .61803 -8 -6 ]
[-0.0125 .61803 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30 -24.5 ]
[-0.01875 .30902 -18 24.5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
0 .12361 m
1 .12361 L
s
0 .24721 m
1 .24721 L
s
0 .37082 m
1 .37082 L
s
0 .49443 m
1 .49443 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
68.062500 13.000000 moveto
(in) show
76.250000 13.000000 moveto
(nm) show
86.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.92) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.94) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.96) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.98) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -109.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5 10 translate
90 rotate
-85.5 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Cssa) show
79.937500 13.000000 moveto
(over) show
96.062500 13.000000 moveto
(Css) show
107.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .0001 ] 0 setdash
.02476 .50303 m
.02594 .48846 L
.027 .47978 L
.02824 .47205 L
.0294 .46606 L
.03373 .44946 L
.03844 .4364 L
.04355 .42518 L
.05385 .4076 L
.06336 .39488 L
.08379 .37394 L
.10545 .35758 L
.12497 .34615 L
.14325 .3375 L
.18198 .32388 L
.20309 .31846 L
.22316 .3143 L
.26132 .30849 L
.28097 .30636 L
.30192 .30461 L
.3122 .30393 L
.32331 .30331 L
.33292 .30285 L
.34347 .30245 L
.35377 .30214 L
.36338 .30191 L
.3686 .30182 L
.37354 .30175 L
.37923 .30168 L
.38191 .30166 L
.38443 .30164 L
.38682 .30163 L
.38901 .30162 L
.39017 .30161 L
.39145 .30161 L
.39273 .3016 L
.39342 .3016 L
.39407 .3016 L
.39471 .3016 L
.39541 .3016 L
.39667 .3016 L
.39789 .3016 L
.39902 .3016 L
.40025 .30161 L
.4016 .30161 L
.40432 .30162 L
.40671 .30163 L
.4089 .30165 L
.41382 .30169 L
.42272 .30179 L
Mistroke
.43258 .30194 L
.44172 .30212 L
.46244 .30265 L
.50158 .30405 L
.54318 .30601 L
.58325 .30826 L
.62182 .31068 L
.66283 .31346 L
.70233 .3163 L
.74032 .31915 L
.78075 .32226 L
.81968 .32533 L
.86105 .32863 L
.90091 .33184 L
.93925 .33493 L
.97619 .33792 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{167, 103},
  ImageMargins->{{82.5625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003A0000PA000`40l00?003`dOoo003Aool00=7o
o`00Jooo0P0?0ooo00D03ooo00ooo`0?00?oo`0900ooo`0?ool03ooo00ooo`0?053oo`00K?oo00T0
3oooooooo`0?ool03ooo00l00ooo00T03ooo00ooo`0?ool03ooo00l0D?oo001[ool00`0?ooooo`02
ool01@0?ool03ooo00l00ooo00T03ooo00ooo`0?ool03ooo00l0D?oo001[ool200l3ool0100?ool0
3`0?1?oo0P0?0_oo0P0?00?oo`0?ool0D?oo003Aool0073oo`0300oooooo05koo`00dOoo003Aool0
0=7oo`00dOoo003Aool00=7oo`00:ooo00<03oooool06?oo0`0?0_oo00<03oooool06?oo00@03ooo
ool03aWoo`0500ooooooool03`0Hool01@0?oooooooo00l05_oo0`0?0_oo00D03oooooooo`0?00co
o`00:_oo00<03ooo00l06Ooo00L03oooooooo`0?ool03`0Gool300l01?oo00ooo`0?5ooo00L03ooo
00ooo`0?ool03`0Fool01`0?ool03ooo00ooo`0?01Koo`0:00oooooo00ooo`0?ool03ooo00l;ool0
02[oo`0300ooo`0?01[oo`0600oooooo00ooo`0?5ooo00L03ooo00ooo`0?ool03`0Gool200l2ool0
0`0?ool03`0Gool01P0?ooooo`0?ool03aKoo`0:00oooooo00ooo`0?ool03ooo00l;ool002[oo`03
00ooo`0?01Woo`0700ooo`0?ool03ooo00l06?oo0P0?00Coo`0?ool03aOoo`0700ooooooool03ooo
00l05_oo00L03ooo00ooo`0?ool03`0Fool02P0?ooooo`0?ool03ooo00ooo`0?2ooo000[ool00`0?
ooooo`0Iool200l2ool00`0?ooooo`0Hool0100?ooooo`0?6Ooo0P0?0_oo00<03oooool05_oo00D0
3oooooooo`0?01Koo`803`?oo`0500ooooooool03`0<ool00=7oo`00dOoo003Aool00=7oo`00dOoo
003Aool002Sooih03`_oo`00:?oo00D03oooooooo`0?01coo`0300oooooo01_oo`0300oooooo01_o
o`0300oooooo01_oo`0300oooooo01_oo`0500ooooooool03`0;ool002Soo`0300oooooo01koo`03
07oooooo01_oo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01ooo`0300oooooo00Woo`00
:?oo00<03oooool07_oo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool0
7ooo00<03oooool02Ooo000Xool00`0?ooooo`0Nool00`1oooooo`0Kool00`1oooooo`0Kool00`1o
ooooo`0Kool00`1oooooo`0Oool00`0?ooooo`09ool002Soo`0300oooooo01koo`0308oooooo01_o
o`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01koo`803`_oo`00:?oo00<03oooool07_oo
00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool07ooo00<03oooool02Ooo
000Xool00`0?ooooo`0Nool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?oooo
o`0Oool00`0?ooooo`09ool002Soo`0300oooooo01koo`0307oooooo01_oo`0307oooooo01_oo`03
07oooooo01_oo`0307oooooo01ooo`0300oooooo00Woo`00:?oo00<03oooool07_oo00<0Soooool0
6ooo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool07_oo0P0?2ooo000Xool00`0?ooooo`0N
ool00`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Oool00`0?ooooo`09
ool002Soo`0300oooooo01koo`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01_oo`0308oo
oooo01ooo`0300oooooo00Woo`00:?oo00<03oooool07_oo00<0Ooooool06ooo00<0Ooooool06ooo
00<0Ooooool06ooo00<0Ooooool07ooo00<03oooool02Ooo000Xool00`0?ooooo`0Nool00`2?oooo
o`0Kool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Oool00`0?ooooo`09ool002Soo`03
00oooooo01koo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01koo`80
3`_oo`00:?oo00<03oooool07_oo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool06ooo00<0
Soooool07ooo00<03oooool02Ooo000Xool00`0?ooooo`0Nool00`1oooooo`0Kool00`1oooooo`0K
ool00`1oooooo`0Kool00`1oooooo`0Oool00`0?ooooo`09ool001Ooo`0400oooooo00l2ool00`0?
ooooo`0300l5ool00`0?ooooo`0Nool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Kool0
0`2?ooooo`0Oool00`0?ooooo`09ool001Koo`0300ooo`0?00Goo`0300ooo`0?00Ooo`0300oooooo
01koo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01ooo`0300oooooo
00Woo`005_oo00<03ooo00l01?oo0P0?0_oo00<03oooool01?oo0P0?09X0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`803`_oo`00
5_oo00<03ooo00l00ooo00L03ooo00ooo`0?ool03`05ool00`0?ooooo`0Nool00`1oooooo`0Kool0
0`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Oool00`0?ooooo`09ool001Ooo`0300oooooo
00?oo`0400ooooooool200l5ool00`0?ooooo`0Nool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?
ooooo`0Kool00`2?ooooo`0Oool00`0?ooooo`09ool002Soo`0300oooooo01koo`0307oooooo01_o
o`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01ooo`0300oooooo00Woo`00:?oo00<03ooo
ool07_oo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool07ooo00<03ooo
ool02Ooo000Xool00`0?ooooo`0Nool00`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Kool0
0`1oooooo`0Nool200l;ool002Soo`0300oooooo01koo`0308oooooo01_oo`0308oooooo01_oo`03
08oooooo01_oo`0308oooooo01ooo`0300oooooo00Woo`003?oo0`0?6Ooo00<03oooool07_oo00<0
Ooooool06ooo00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool07ooo00<03oooool02Ooo000:
ool200l3ool00`0?ooooo`0Fool00`0?ooooo`0Nool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?
ooooo`0Kool00`2?ooooo`0Oool00`0?ooooo`09ool000[oo`0300oooooo00;oo`0300oooooo01Ko
o`0300oooooo01koo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01oo
o`0300oooooo00Woo`002_oo00<03oooool00_oo00<03oooool05_oo00<03oooool07_oo00<0Sooo
ool06ooo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool07_oo0P0?2ooo000:ool200l2ool0
0`0?ooooo`0Gool00`0?ooooo`0Nool00`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Kool0
0`1oooooo`0Oool00`0?ooooo`09ool000goo`0300ooo`0?01Soo`0300oooooo01koo`0308oooooo
01_oo`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01ooo`0300oooooo00Woo`003?oo0P0?
00?oo`0?ool05ooo00<03oooool07_oo00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool06ooo
00<0Ooooool07ooo00<03oooool02Ooo000<ool00`0?ool03`0Iool00`0?ooooo`0Nool00`2?oooo
o`0Kool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Oool00`0?ooooo`09ool002Soo`03
00oooooo01koo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01koo`80
3`_oo`003Ooo00<03ooo00l06?oo00<03oooool07_oo00<0Soooool06ooo00<0Soooool06ooo00<0
Soooool06ooo00<0Soooool07ooo00<03oooool02Ooo000<ool200l00ooo00ooo`06ool0100?oooo
o`0?0_oo00<03oooool00_oo00<03oooool00ooo00<03oooool07_oo00<0Ooooool06ooo00<0Oooo
ool06ooo00<0Ooooool06ooo00<0Ooooool07ooo00<03oooool02Ooo000<ool00`0?ool03`07ool0
0`0?ool03`05ool00`0?ool03`0200l5ool00`0?ooooo`0Nool00`2?ooooo`0Kool00`2?ooooo`0K
ool00`2?ooooo`0Kool00`2?ooooo`0Oool00`0?ooooo`09ool000coo`0300ooo`0?00Ooo`0300oo
o`0?00Coo`803`04ool03ooo00l5ool200l0VP2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o0P0?2ooo000<ool200l00ooo00ooo`05
ool00`0?ool03`03ool00`0?ool03`02ool200l5ool00`0?ooooo`0Nool00`2?ooooo`0Kool00`2?
ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Oool00`0?ooooo`09ool000goo`<03`Ooo`0300oo
oooo00?oo`0300oooooo00;oo`0300oooooo00?oo`0300oooooo01koo`0307oooooo01_oo`0307oo
oooo01_oo`0307oooooo01_oo`0307oooooo01ooo`0300oooooo00Woo`003ooo00<03oooool05_oo
00<03oooool07_oo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool07ooo
00<03oooool02Ooo000Xool00`0?ooooo`0Nool00`1oooooo`0Kool00`1oooooo`0Kool00`1ooooo
o`0Kool00`1oooooo`0Oool00`0?ooooo`09ool000goo`803aWoo`0300oooooo01koo`0308oooooo
01_oo`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01koo`803`_oo`003?oo00@03oooool0
3aSoo`0300oooooo01koo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo
01ooo`0300oooooo00Woo`003?oo00@03oooool03aSoo`0300oooooo01koo`0308oooooo01_oo`03
08oooooo01_oo`0308oooooo01_oo`0308oooooo01ooo`0300oooooo00Woo`003Ooo0P0?6Ooo00<0
3oooool07_oo00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool07ooo00<0
3oooool02Ooo000<ool00`0?ooooo`0Iool00`0?ooooo`0Nool00`2?ooooo`0:oolU00l:ool00`2?
ooooo`0Kool00`2?ooooo`0Oool00`0?ooooo`09ool000coo`803a[oo`0300oooooo01koo`0307oo
oooo00;oo`T03a3oo`0307oooooo013ooa803aOoo`0307oooooo01koo`803`_oo`003_oo0P0?6?oo
00<03oooool07Ooo1`0?6?oo00<0Soooool06ooo00<0Soooool00ooo3`0?2Ooo00<0Soooool07ooo
00<03oooool02Ooo000<ool200lJool00`0?ooooo`0Iool500l00`1oooooo`0Kool00`1oooooo`0K
ool00`1oooooo`0Aool>00lNool00`0?ooooo`09ool000goo`803aWoo`0300oooooo01Koo`@03`Co
o`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01_oo`0308oooooo00h03a7oo`0300oooooo
00Woo`003?oo0P0?00?oo`0?ool05ooo00<03oooool05?oo0`0?1ooo00<0Ooooool06ooo00<0Oooo
ool06ooo00<0Ooooool06ooo00<0Ooooool03Ooo3@0?1Ooo00<03oooool02Ooo000<ool200l00ooo
00ooo`0Gool00`0?ooooo`0Aool400l9ool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0K
ool00`2?ooooo`0Iool300l2ool200l;ool000koo`803aSoo`0300oooooo00ooo`<03`coo`0307oo
oooo01_oo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01ooo`0300oooooo00Woo`003?oo
100?1ooo00@03oooool03`;oo`0500ooooooool03`06ool00`0?ooooo`0>ool200l>ool00`2?oooo
o`0Kool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Oool00`0?ooooo`09ool000coo`04
00oooooo00l6ool00`0?ool03`05ool01@0?ool03ooo00l01Ooo00<03oooool03?oo0`0?3ooo00<0
Ooooool06ooo00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool07ooo00<03oooool02Ooo000F
ool00`0?ool03`04ool200l00ooo00l03`06ool00`0?ooooo`0;ool200lAool00`2?ooooo`0Kool0
0`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Oool00`0?ooooo`09ool001Koo`0300ooo`0?
00?oo`0500ooo`0?ool03`07ool200l02`2?07l0S`1o08l0O`2?07l0S`1o08l00P0?08d0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l00P0?2ooo000<ool300l8ool00`0?oooo
o`03ool0100?oooooooo0P0?1Ooo00<03oooool02Ooo0P0?4ooo00<0Soooool06ooo00<0Soooool0
6ooo00<0Soooool06ooo00<0Soooool07ooo00<03oooool02Ooo000:ool200l3ool00`0?ooooo`0F
ool00`0?ooooo`08ool200lDool00`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Kool00`1o
ooooo`0Oool00`0?ooooo`09ool000[oo`0300oooooo00;oo`0300oooooo01Koo`0300oooooo00Oo
o`803aGoo`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01ooo`0300oo
oooo00Woo`002_oo00<03oooool00_oo00<03oooool05_oo00<03oooool01_oo0P0?5_oo00<0Oooo
ool06ooo00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool07ooo00<03oooool02Ooo000:ool2
00l2ool00`0?ooooo`0Gool00`0?ooooo`05ool200lGool00`2?ooooo`0Kool00`2?ooooo`0Kool0
0`2?ooooo`0Kool00`2?ooooo`0Nool200l;ool002Soo`0300oooooo00Goo`0300oooooo01Koo`03
07oooooo01_oo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01ooo`0300oooooo00Woo`00
3Ooo00<03ooo00l06?oo00<03oooool01?oo0P0?6?oo00<0Soooool06ooo00<0Soooool06ooo00<0
Soooool06ooo00<0Soooool07ooo00<03oooool02Ooo000<ool200l00ooo00ooo`0Gool00`0?oooo
o`04ool00`0?ooooo`0Gool00`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Kool00`1ooooo
o`0Oool00`0?ooooo`09ool000coo`0300ooo`0?01Woo`0300oooooo00?oo`803aWoo`0308oooooo
01_oo`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01koo`803`_oo`003Ooo00<03ooo00l0
6?oo00<03oooool00ooo00<03oooool06?oo00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool0
6ooo00<0Ooooool07ooo00<03oooool02Ooo000<ool200l00ooo00ooo`0Gool00`0?ooooo`02ool2
00lJool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Oool00`0?oooo
o`09ool000coo`0300ooo`0?01Woo`0300oooooo00;oo`0300oooooo01Woo`0307oooooo01_oo`03
07oooooo01_oo`0307oooooo01_oo`0307oooooo01ooo`0300oooooo00Woo`00:?oo00<03oooool0
0_oo00<03oooool06Ooo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool0
7ooo00<03oooool02Ooo000Xool00`0?ooooo`02ool00`0?ooooo`0Iool00`1oooooo`0Kool00`1o
ooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Nool200l;ool002Soo`0400ooooooool200lKool0
0`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Oool00`0?ooooo`09ool0
02Soo`0500ooooooool03`0Lool00`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Kool00`1o
ooooo`0Oool00`0?ooooo`09ool001Ooo`0400oooooo00l2ool01@0?oooooooo00l01_oo00D03ooo
ooooo`0?01coo`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01ooo`03
00oooooo00Woo`005_oo00<03ooo00l01Ooo00D03ooo00ooo`0?00Goo`0500ooooooool03`0Lool0
0`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Oool00`0?ooooo`09ool0
01Koo`0300ooo`0?00Coo`803`;oo`0300oooooo00Coo`803`2J07l0S`0?08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l200l;ool001Koo`03
00ooo`0?00?oo`0700ooo`0?ool03ooo00l01Ooo00D03oooooooo`0?01coo`0307oooooo01_oo`03
07oooooo01_oo`0307oooooo01_oo`0307oooooo01ooo`0300oooooo00Woo`005ooo00<03oooool0
0ooo00D03oooooooo`0?00Koo`0300oooooo01koo`0308oooooo01_oo`0308oooooo01_oo`0308oo
oooo01_oo`0308oooooo01ooo`0300oooooo00Woo`00:?oo00<03oooool07_oo00<0Ooooool06ooo
00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool07ooo00<03oooool02Ooo000Xool00`0?oooo
o`0Nool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Oool00`0?oooo
o`09ool002Soo`0300oooooo01koo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01_oo`03
07oooooo01koo`803`_oo`00:?oo00<03oooool07_oo00<0Soooool06ooo00<0Soooool06ooo00<0
Soooool06ooo00<0Soooool07ooo00<03oooool02Ooo000Xool00`0?ooooo`0Nool00`1oooooo`0K
ool00`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0Oool00`0?ooooo`09ool002Soo`0300oo
oooo01koo`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01_oo`0308oooooo01ooo`0300oo
oooo00Woo`00:?oo00<03oooool07_oo00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool06ooo
00<0Ooooool07ooo00<03oooool02Ooo000Xool00`0?ooooo`0Nool00`2?ooooo`0Kool00`2?oooo
o`0Kool00`2?ooooo`0Kool00`2?ooooo`0Nool200l;ool002Soo`0300oooooo01koo`0307oooooo
01_oo`0307oooooo01_oo`0307oooooo01_oo`0307oooooo01ooo`0300oooooo00Woo`00:?oo00<0
3oooool07_oo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool07ooo00<0
3oooool02Ooo000Xool00`0?ooooo`0Nool00`1oooooo`0Kool00`1oooooo`0Kool00`1oooooo`0K
ool00`1oooooo`0Oool00`0?ooooo`09ool002Soo`0300oooooo01koo`0308oooooo01_oo`0308oo
oooo01_oo`0308oooooo01_oo`0308oooooo01ooo`0300oooooo00Woo`00:?oo00<03oooool07_oo
00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool06ooo00<0Ooooool07_oo0P0?2ooo000Xool0
0`0?ooooo`0Nool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Kool00`2?ooooo`0Oool0
0`0?ooooo`09ool0023oo`<03`Goo`0300oooooo01koo`0307oooooo01_oo`0307oooooo01_oo`03
07oooooo01_oo`0307oooooo01ooo`0300oooooo00Woo`008Ooo00<03oooool01?oo00<03oooool0
7_oo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool06ooo00<0Soooool07ooo00<03oooool0
2Ooo000Qool00`0?ooooo`04oonN00l;ool0027oo`0300oooooo0:goo`008?oo0P0?[ooo003Aool0
0=7oo`00dOoo003Aool00001\
\>"],
  ImageRangeCache->{{{0, 207.75}, {127.75, 0}} -> {-29.586302, 0.874215, 
  0.838038, 0.001291}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Electrostatic Force"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[F]; \)\), 
    \(\(F[R_, s_, v_] = \(-\(1\/2\)\)\ \[PartialD]\_s Cspa[R, s]\ v\^2; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig8 = 
      Plot[F[100\ nano, s\ nano, 1]\/nano, {s, 10, 100}, 
        FrameLabel \[Rule] {"\<s in nm\>", "\<F in nN\>"}, Evaluate[opt]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
-0.082011 0.010582 0.00877 0.213742 [
[.12963 -0.0125 -6 -12 ]
[.12963 -0.0125 6 0 ]
[.34127 -0.0125 -6 -12 ]
[.34127 -0.0125 6 0 ]
[.55291 -0.0125 -6 -12 ]
[.55291 -0.0125 6 0 ]
[.76455 -0.0125 -6 -12 ]
[.76455 -0.0125 6 0 ]
[.97619 -0.0125 -8 -12 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -24 ]
[.5 -0.0125 14 -12 ]
[-0.0125 .00877 -8 -6 ]
[-0.0125 .00877 0 6 ]
[-0.0125 .11564 -14 -6 ]
[-0.0125 .11564 0 6 ]
[-0.0125 .22251 -8 -6 ]
[-0.0125 .22251 0 6 ]
[-0.0125 .32938 -14 -6 ]
[-0.0125 .32938 0 6 ]
[-0.0125 .43625 -8 -6 ]
[-0.0125 .43625 0 6 ]
[-0.0125 .54312 -14 -6 ]
[-0.0125 .54312 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26 -14.5 ]
[-0.01875 .30902 -14 14.5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.12963 0 m
.12963 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.55291 0 m
.55291 .61803 L
s
.76455 0 m
.76455 .61803 L
s
0 .11564 m
1 .11564 L
s
0 .22251 m
1 .22251 L
s
0 .32938 m
1 .32938 L
s
0 .43625 m
1 .43625 L
s
0 .54312 m
1 .54312 L
s
0 g
.12963 0 m
.12963 .00625 L
s
gsave
.12963 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.55291 0 m
.55291 .00625 L
s
gsave
.55291 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.76455 0 m
.76455 .00625 L
s
gsave
.76455 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.18254 0 m
.18254 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.28836 0 m
.28836 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.5 0 m
.5 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
68.062500 13.000000 moveto
(in) show
76.250000 13.000000 moveto
(nm) show
86.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .00877 m
.00625 .00877 L
s
gsave
-0.0125 .00877 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .11564 m
.00625 .11564 L
s
gsave
-0.0125 .11564 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .22251 m
.00625 .22251 L
s
gsave
-0.0125 .22251 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .32938 m
.00625 .32938 L
s
gsave
-0.0125 .32938 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .43625 m
.00625 .43625 L
s
gsave
-0.0125 .43625 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .54312 m
.00625 .54312 L
s
gsave
-0.0125 .54312 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .03014 m
.00375 .03014 L
s
0 .05152 m
.00375 .05152 L
s
0 .07289 m
.00375 .07289 L
s
0 .09427 m
.00375 .09427 L
s
0 .13701 m
.00375 .13701 L
s
0 .15839 m
.00375 .15839 L
s
0 .17976 m
.00375 .17976 L
s
0 .20114 m
.00375 .20114 L
s
0 .24389 m
.00375 .24389 L
s
0 .26526 m
.00375 .26526 L
s
0 .28663 m
.00375 .28663 L
s
0 .30801 m
.00375 .30801 L
s
0 .35076 m
.00375 .35076 L
s
0 .37213 m
.00375 .37213 L
s
0 .3935 m
.00375 .3935 L
s
0 .41488 m
.00375 .41488 L
s
0 .45763 m
.00375 .45763 L
s
0 .479 m
.00375 .479 L
s
0 .50038 m
.00375 .50038 L
s
0 .52175 m
.00375 .52175 L
s
0 .5645 m
.00375 .5645 L
s
0 .58587 m
.00375 .58587 L
s
0 .60725 m
.00375 .60725 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -95.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.5 10 translate
90 rotate
-75.5 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(F) show
69.437500 13.000000 moveto
(in) show
77.625000 13.000000 moveto
(nN) show
87.375000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.12963 .61178 m
.12963 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.76455 .61178 m
.76455 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.18254 .61428 m
.18254 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.28836 .61428 m
.28836 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00877 m
1 .00877 L
s
.99375 .11564 m
1 .11564 L
s
.99375 .22251 m
1 .22251 L
s
.99375 .32938 m
1 .32938 L
s
.99375 .43625 m
1 .43625 L
s
.99375 .54312 m
1 .54312 L
s
.125 Mabswid
.99625 .03014 m
1 .03014 L
s
.99625 .05152 m
1 .05152 L
s
.99625 .07289 m
1 .07289 L
s
.99625 .09427 m
1 .09427 L
s
.99625 .13701 m
1 .13701 L
s
.99625 .15839 m
1 .15839 L
s
.99625 .17976 m
1 .17976 L
s
.99625 .20114 m
1 .20114 L
s
.99625 .24389 m
1 .24389 L
s
.99625 .26526 m
1 .26526 L
s
.99625 .28663 m
1 .28663 L
s
.99625 .30801 m
1 .30801 L
s
.99625 .35076 m
1 .35076 L
s
.99625 .37213 m
1 .37213 L
s
.99625 .3935 m
1 .3935 L
s
.99625 .41488 m
1 .41488 L
s
.99625 .45763 m
1 .45763 L
s
.99625 .479 m
1 .479 L
s
.99625 .50038 m
1 .50038 L
s
.99625 .52175 m
1 .52175 L
s
.99625 .5645 m
1 .5645 L
s
.99625 .58587 m
1 .58587 L
s
.99625 .60725 m
1 .60725 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .60332 m
.03279 .51398 L
.04262 .43741 L
.06244 .32782 L
.07298 .2859 L
.08426 .2496 L
.10458 .2 L
.12589 .16281 L
.14603 .1368 L
.166 .11701 L
.18444 .10255 L
.20476 .08973 L
.22379 .07996 L
.26163 .06515 L
.3004 .0543 L
.34162 .04587 L
.38133 .03978 L
.41952 .03524 L
.46017 .03142 L
.4993 .02847 L
.54088 .02593 L
.58095 .02392 L
.6195 .0223 L
.6605 .02085 L
.69999 .01966 L
.73796 .01867 L
.77838 .01776 L
.81729 .017 L
.85865 .01629 L
.8985 .01569 L
.93683 .01518 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{167, 103},
  ImageMargins->{{82.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003A0000PA000`40l00?003`dOoo003Aool00=7o
o`00JOoo0P0?0ooo00D03ooo00ooo`0?00?oo`0900ooo`0?ool03ooo00ooo`0?05;oo`00J_oo00T0
3oooooooo`0?ool03ooo00l00ooo00T03ooo00ooo`0?ool03ooo00l0D_oo001Yool00`0?ooooo`02
ool01@0?ool03ooo00l00ooo00T03ooo00ooo`0?ool03ooo00l0D_oo001Yool200l3ool0100?ool0
3`0?1?oo0P0?0_oo0P0?00?oo`0?ool0D_oo003Aool006koo`0300oooooo063oo`00dOoo003Aool0
0=7oo`00dOoo003Aool00=7oo`00<ooo0`0?0_oo00<03oooool07_oo00@03oooool03akoo`0500oo
ooooool03`0Nool01@0?oooooooo00l06ooo0`0?0_oo00D03oooooooo`0?00Woo`00<ooo00L03ooo
ooooo`0?ool03`0Mool300l01?oo00ooo`0?7?oo00L03ooo00ooo`0?ool03`0Lool01`0?ool03ooo
00ooo`0?01_oo`0:00oooooo00ooo`0?ool03ooo00l8ool003Coo`0600oooooo00ooo`0?7Ooo00L0
3ooo00ooo`0?ool03`0Lool200l2ool00`0?ool03`0Mool01P0?ooooo`0?ool03a_oo`0:00oooooo
00ooo`0?ool03ooo00l8ool003?oo`0700ooo`0?ool03ooo00l07_oo0P0?00Coo`0?ool03acoo`07
00ooooooool03ooo00l07?oo00L03ooo00ooo`0?ool03`0Kool02P0?ooooo`0?ool03ooo00ooo`0?
2?oo000dool200l2ool00`0?ooooo`0Nool0100?ooooo`0?7_oo0P0?0_oo00<03oooool07?oo00D0
3oooooooo`0?01_oo`803`?oo`0500ooooooool03`09ool00=7oo`00dOoo003Aool00=7oo`00dOoo
000Kool00`0?ooooo`2cool001[oo`0300ooo`0?00CoojL03`Woo`006_oo00<03ooo00l01?oo0P0?
5?oo00<03oooool08?oo00<03oooool08?oo00<03oooool08?oo00<03oooool08Ooo00@03ooo00l0
3`Woo`006_oo00<03ooo00l01?oo00<03oooool04ooo00<0Ooooool08?oo00<0Soooool08?oo00<0
Ooooool08?oo00<0Soooool03ooo4`0?0_oo00<03oooool01ooo000Kool00`0?ooooo`03ool00`0?
ooooo`0Cool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`09oolZ00lDool00`0?ooooo`07
ool0027oo`0300oooooo01?oo`0307oooooo023oo`0308oooooo01SooaD03aKoo`0308oooooo02Co
o`0300oooooo00Ooo`008Ooo0P0?5?oo00<0Soooool08?oo00<0Ooooool03?oo3@0?1ooo00<0Sooo
ool08?oo00<0Ooooool09?oo00<03oooool01ooo000Qool00`0?ooooo`0Cool00`1oooooo`0Pool0
0`2?ooooo`03ool:00lCool00`1oooooo`0Pool00`2?ooooo`0Tool00`0?ooooo`07ool0027oo`03
00oooooo01?oo`0308oooooo023oo`L03acoo`0308oooooo023oo`0307oooooo02Coo`0300oooooo
00Ooo`008Ooo0P0?5?oo00<0Ooooool06ooo1P0?8_oo00<0Ooooool08?oo00<0Soooool09?oo00<0
3oooool01ooo000Qool00`0?ooooo`0Cool00`2?ooooo`0Gool500l4ool00`1oooooo`0Pool00`2?
ooooo`0Pool00`1oooooo`0Tool00`0?ooooo`07ool0027oo`0300oooooo01?oo`0307oooooo01?o
o`D03`Soo`0308oooooo023oo`0307oooooo023oo`0308oooooo02Coo`0300oooooo00Ooo`008Ooo
00<03oooool04ooo00<0Soooool04Ooo0`0?3?oo00<0Ooooool08?oo00<0Soooool08?oo00<0Oooo
ool09?oo00<03oooool01ooo000Qool200lDool00`1oooooo`0>ool400l>ool00`2?ooooo`0Pool0
0`1oooooo`0Pool00`2?ooooo`0Tool00`0?ooooo`07ool0027oo`0300oooooo01?oo`0308oooooo
00coo`<03a7oo`0307oooooo023oo`0308oooooo023oo`0307oooooo02Coo`0300oooooo00Ooo`00
8Ooo00<03oooool04ooo00<0Ooooool02_oo0`0?4ooo00<0Soooool08?oo00<0Ooooool08?oo00<0
Soooool09?oo00<03oooool01ooo000Qool200lDool00`2?ooooo`08ool300lEool00`1oooooo`0P
ool00`2?ooooo`0Pool00`1oooooo`0Tool00`0?ooooo`07ool0027oo`0300oooooo01?oo`0307oo
oooo00Ooo`803aOoo`0308oooooo023oo`0307oooooo023oo`0308oooooo02Coo`0300oooooo00Oo
o`005Ooo00D03oooool03ooo00803`Goo`0300oooooo01?oo`0308oooooo00Goo`<03aSoo`0307oo
oooo023oo`0308oooooo023oo`0307oooooo02Coo`0300oooooo00Ooo`005?oo00<03ooo00l01Ooo
00<03oooool00_oo00<03oooool04ooo00<0Ooooool01?oo0P0?6_oo00<0Soooool08?oo00<0Oooo
ool08?oo00<0Soooool09?oo00<03oooool01ooo000Dool00`0?ool03`03ool200l5ool200l06P2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l200l0Q`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0200l9ool001Coo`0300ooo`0?00?oo`0300oooooo00Co
o`0300oooooo01?oo`0307oooooo00;oo`803acoo`0308oooooo023oo`0307oooooo023oo`0308oo
oooo02Coo`0300oooooo00Ooo`005Ooo00<03oooool00_oo0`0?1?oo00<03oooool04ooo00@0Sooo
ooooo`803agoo`0307oooooo023oo`0308oooooo023oo`0307oooooo02Coo`0300oooooo00Ooo`00
8Ooo00<03oooool04ooo00<0Ooooool00P0?7_oo00<0Soooool08?oo00<0Ooooool08?oo00<0Sooo
ool09?oo00<03oooool01ooo000Qool200lDool0102?ool03`0?7ooo00<0Ooooool08?oo00<0Sooo
ool08?oo00<0Ooooool09?oo00<03oooool01ooo000Qool00`0?ooooo`0Cool00`1o00l03`0Pool0
0`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Tool00`0?ooooo`07ool0027oo`0300oooooo
01?oo`803b7oo`0307oooooo023oo`0308oooooo023oo`0307oooooo02Coo`0300oooooo00Ooo`00
8Ooo0P0?5?oo00<03oooool08?oo00<0Soooool08?oo00<0Ooooool08?oo00<0Soooool09?oo00<0
3oooool01ooo000Qool00`0?ooooo`0Bool200lRool00`1oooooo`0Pool00`2?ooooo`0Pool00`1o
ooooo`0Tool00`0?ooooo`07ool0027oo`0300oooooo017oo`803`0307oooooo023oo`0308oooooo
023oo`0307oooooo023oo`0308oooooo02Coo`0300oooooo00Ooo`008Ooo00<03oooool04Ooo00<0
3ooo08l08_oo00<0Ooooool08?oo00<0Soooool08?oo00<0Ooooool09?oo00<03oooool01ooo000Q
ool200lAool200l00ooo07ooo`0Qool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Tool0
0`0?ooooo`07ool0027oo`0300oooooo013oo`0400oooooo08lRool00`1oooooo`0Pool00`2?oooo
o`0Pool00`1oooooo`0Tool00`0?ooooo`07ool0027oo`0300oooooo00ooo`803`;oo`0307oooooo
023oo`0308oooooo023oo`0307oooooo023oo`0308oooooo02Coo`0300oooooo00Ooo`008Ooo0P0?
4?oo00D03oooooooo`2?02;oo`0307oooooo023oo`0308oooooo023oo`0307oooooo02Coo`0300oo
oooo00Ooo`006_oo0`0?1?oo00<03oooool03_oo0P0?0ooo00<0Ooooool08?oo00<0Soooool08?oo
00<0Ooooool08?oo00<0Soooool09?oo00<03oooool01ooo000Kool00`0?ooooo`03ool00`0?oooo
o`0>ool00`0?ooooo`02ool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Pool00`1ooooo
o`0Tool00`0?ooooo`07ool001_oo`0300oooooo00?oo`0300oooooo00goo`803`Coo`0307oooooo
023oo`0308oooooo023oo`0307oooooo023oo`0308oooooo02Coo`0300oooooo00Ooo`006ooo00<0
3oooool00ooo0P0?0:<0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0200l9ool001[oo`803`Goo`03
00oooooo00coo`803`Goo`0307oooooo023oo`0308oooooo023oo`0307oooooo023oo`0308oooooo
02Coo`0300oooooo00Ooo`002?oo00<03oooool00_oo00<03oooool04Ooo00<03oooool03?oo00<0
3oooool01?oo00<0Soooool08?oo00<0Ooooool08?oo00<0Soooool08?oo00<0Ooooool09?oo00<0
3oooool01ooo0008ool600lCool200l=ool00`0?ooooo`04ool00`1oooooo`0Pool00`2?ooooo`0P
ool00`1oooooo`0Pool00`2?ooooo`0Tool00`0?ooooo`07ool000Soo`0400oooooo00lEool00`0?
ooooo`0;ool200l6ool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Pool00`1oooooo`0T
ool00`0?ooooo`07ool000Soo`0400oooooo00lEool00`0?ooooo`0;ool00`0?ooooo`05ool00`1o
ooooo`0Pool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Tool00`0?ooooo`07ool000So
o`803aOoo`0300oooooo00_oo`0300oooooo00Goo`0308oooooo023oo`0307oooooo023oo`0308oo
oooo023oo`0307oooooo02Coo`0300oooooo00Ooo`008Ooo0P0?2ooo0P0?1ooo00<0Ooooool08?oo
00<0Soooool08?oo00<0Ooooool08?oo00<0Soooool09?oo00<03oooool01ooo000Qool00`0?oooo
o`0:ool00`0?ooooo`06ool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Pool00`1ooooo
o`0Tool00`0?ooooo`07ool000_oo`0300ooo`0?01?oo`0300oooooo00[oo`0300oooooo00Koo`03
07oooooo023oo`0308oooooo023oo`0307oooooo023oo`0308oooooo02Coo`0300oooooo00Ooo`00
2?oo00<03ooo00l00`0?4ooo0P0?2_oo0P0?2?oo00<0Soooool08?oo00<0Ooooool08?oo00<0Sooo
ool08?oo00<0Ooooool09?oo00<03oooool01ooo000:ool400lCool00`0?ooooo`09ool00`0?oooo
o`07ool00`1oooooo`0Pool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Tool00`0?oooo
o`07ool000[oo`0400oooooo00lCool00`0?ooooo`09ool00`0?ooooo`07ool00`2?ooooo`0Pool0
0`1oooooo`0Pool00`2?ooooo`0Pool00`1oooooo`0Tool00`0?ooooo`07ool000[oo`0300oooooo
01Coo`0300oooooo00Woo`0300oooooo00Ooo`0307oooooo023oo`0308oooooo023oo`0307oooooo
023oo`0308oooooo02Coo`0300oooooo00Ooo`002ooo0`0?4ooo0P0?2Ooo0P0?2Ooo00<0Soooool0
8?oo00<0Ooooool08?oo00<0Soooool08?oo00<0Ooooool09?oo00<03oooool01ooo000Dool300l0
0ooo00ooo`0200l5ool00`0?ooooo`08ool00`0?ooooo`08ool00`1oooooo`0Pool00`2?ooooo`0P
ool00`1oooooo`0Pool00`2?ooooo`0Tool00`0?ooooo`07ool001Goo`0300oooooo00Coo`0300oo
oooo00;oo`0300oooooo00Soo`0300oooooo00Soo`0308oooooo023oo`0307oooooo023oo`0308oo
oooo023oo`0307oooooo02Coo`0300oooooo00Ooo`002_oo100?1ooo00<03oooool00_oo0P0?1Ooo
00<03oooool02?oo00<03oooool02?oo00<0Ooooool08?oo00<0Soooool08?oo00<0Ooooool08?oo
00<0Soooool09?oo00<03oooool01ooo000:ool0100?ooooo`0?1ooo00<03oooool00_oo00<03ooo
ool01?oo0P0?0:<0S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0200l9ool000[oo`0300oooooo00Oo
o`803`Coo`<03`Coo`0300oooooo00Ooo`0300oooooo00Woo`0307oooooo023oo`0308oooooo023o
o`0307oooooo023oo`0308oooooo02Coo`0300oooooo00Ooo`002ooo0`0?4ooo00<03oooool01ooo
00<03oooool02Ooo00<0Soooool08?oo00<0Ooooool08?oo00<0Soooool08?oo00<0Ooooool09?oo
00<03oooool01ooo0008ool00`0?ooooo`02ool00`0?ooooo`0Aool200l8ool00`0?ooooo`09ool0
0`1oooooo`0Pool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Tool00`0?ooooo`07ool0
00Soo`H03a?oo`0300oooooo00Ooo`0300oooooo00Woo`0308oooooo023oo`0307oooooo023oo`03
08oooooo023oo`0307oooooo02Coo`0300oooooo00Ooo`002Ooo0P0?5_oo00<03oooool01ooo00<0
3oooool02Ooo00<0Ooooool08?oo00<0Soooool08?oo00<0Ooooool08?oo00<0Soooool09?oo00<0
3oooool01ooo000;ool00`0?ooooo`0Cool00`0?ooooo`06ool200l;ool00`2?ooooo`0Pool00`1o
ooooo`0Pool00`2?ooooo`0Pool00`1oooooo`0Tool00`0?ooooo`07ool000Soo`H03a?oo`803`Oo
o`0300oooooo00[oo`0307oooooo023oo`0308oooooo023oo`0307oooooo023oo`0308oooooo02Co
o`0300oooooo00Ooo`002?oo00<03oooool05_oo00<03oooool01_oo00<03oooool02_oo00<0Sooo
ool08?oo00<0Ooooool08?oo00<0Soooool08?oo00<0Ooooool09?oo00<03oooool01ooo000Qool0
0`0?ooooo`06ool00`0?ooooo`0:ool00`1oooooo`0Pool00`2?ooooo`0Pool00`1oooooo`0Pool0
0`2?ooooo`0Tool00`0?ooooo`07ool0027oo`803`Ooo`0300oooooo00[oo`0308oooooo023oo`03
07oooooo023oo`0308oooooo023oo`0307oooooo02Coo`0300oooooo00Ooo`008Ooo00<03oooool0
1_oo00<03oooool02_oo00<0Ooooool08?oo00<0Soooool08?oo00<0Ooooool08?oo00<0Soooool0
9?oo00<03oooool01ooo000Qool00`0?ooooo`05ool200l<ool00`2?ooooo`0Pool00`1oooooo`0P
ool00`2?ooooo`0Pool00`1oooooo`0Tool00`0?ooooo`07ool0027oo`0300oooooo00Goo`0300oo
oooo00_oo`0307oooooo023oo`0308oooooo023oo`0307oooooo023oo`0308oooooo02Coo`0300oo
oooo00Ooo`008Ooo0P0?1_oo00<03oooool02ooo00<0Soooool08?oo00<0Ooooool08?oo00<0Sooo
ool08?oo00<0Ooooool09?oo00<03oooool01ooo000Jool300l4ool00`0?ooooo`05ool00`0?oooo
o`0;ool00`1oooooo`0Pool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Tool00`0?oooo
o`07ool001[oo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo00_oo`0308oooooo023oo`03
07oooooo023oo`0308oooooo023oo`0307oooooo02Coo`0300oooooo00Ooo`006ooo00<03oooool0
0ooo0P0?00D0O`2?07l0S`1o00803`2L08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o0P0?2Ooo000Jool00`0?ool03`04ool0
0`0?ooooo`04ool00`0?ooooo`0<ool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Pool0
0`1oooooo`0Tool00`0?ooooo`07ool001_oo`803`Coo`0300oooooo00Coo`0300oooooo00coo`03
07oooooo023oo`0308oooooo023oo`0307oooooo023oo`0308oooooo02Coo`0300oooooo00Ooo`00
8Ooo00<03oooool01?oo00<03oooool03?oo00<0Soooool08?oo00<0Ooooool08?oo00<0Soooool0
8?oo00<0Ooooool09?oo00<03oooool01ooo000Qool200l5ool00`0?ooooo`0<ool00`1oooooo`0P
ool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Tool00`0?ooooo`07ool0027oo`0300oo
oooo00Coo`0300oooooo00coo`0308oooooo023oo`0307oooooo023oo`0308oooooo023oo`0307oo
oooo02Coo`0300oooooo00Ooo`008Ooo00<03oooool01?oo00<03oooool03?oo00<0Ooooool08?oo
00<0Soooool08?oo00<0Ooooool08?oo00<0Soooool09?oo00<03oooool01ooo000Qool200l5ool0
0`0?ooooo`0<ool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Pool00`1oooooo`0Tool0
0`0?ooooo`07ool0027oo`0300oooooo00?oo`803`koo`0307oooooo023oo`0308oooooo023oo`03
07oooooo023oo`0308oooooo02Coo`0300oooooo00Ooo`008Ooo00<03oooool00ooo00<03oooool0
3Ooo00<0Soooool08?oo00<0Ooooool08?oo00<0Soooool08?oo00<0Ooooool09?oo00<03oooool0
1ooo000Qool00`0?ooooo`03ool00`0?ooooo`0=ool00`1oooooo`0Pool00`2?ooooo`0Pool00`1o
ooooo`0Pool00`2?ooooo`0Tool00`0?ooooo`07ool0027oo`803`Coo`0300oooooo00goo`0308oo
oooo023oo`0307oooooo023oo`0308oooooo023oo`0307oooooo02Coo`0300oooooo00Ooo`008Ooo
00<03oooool00ooo00<03oooool03Ooo00<0Ooooool08?oo00<0Soooool08?oo00<0Ooooool08?oo
00<0Soooool09?oo00<03oooool01ooo000Qool00`0?ooooo`03ool00`0?ooooo`0=ool00`2?oooo
o`0Pool00`1oooooo`0Pool00`2?ooooo`0Pool00`1oooooo`0Tool00`0?ooooo`07ool0027oo`03
00oooooo00?oo`0300oooooo00goo`0307oooooo023oo`0308oooooo023oo`0307oooooo023oo`03
08oooooo02Coo`0300oooooo00Ooo`008Ooo0P0?1?oo00<03oooool03Ooo00<0Soooool08?oo00<0
Ooooool08?oo00<0Soooool08?oo00<0Ooooool09?oo00<03oooool01ooo000Dool300l00ooo00oo
o`0200l5ool00`0?ooooo`02ool200l?ool00`1oooooo`0Pool00`2?ooooo`0Pool00`1oooooo`0P
ool00`2?ooooo`0Tool00`0?ooooo`07ool001Coo`0300oooooo00Goo`0300oooooo00;oo`0300oo
oooo00;oo`0300oooooo00koo`0308oooooo023oo`0307oooooo023oo`0308oooooo023oo`0307oo
oooo02Coo`0300oooooo00Ooo`005Ooo00<03oooool00_oo0P0?1Ooo0P0?0:<0O`2?07l03`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`0200l9ool001Coo`0300ooo`0?00?oo`0300oooooo00Coo`0300oooooo00;o
o`0300oooooo00koo`0308oooooo023oo`0307oooooo023oo`0308oooooo023oo`0307oooooo02Co
o`0300oooooo00Ooo`005Ooo0P0?0ooo0`0?1?oo00<03oooool00_oo00<03oooool03_oo00<0Oooo
ool08?oo00<0Soooool08?oo00<0Ooooool08?oo00<0Soooool09?oo00<03oooool01ooo000Qool0
0`0?ooooo`02ool00`0?ooooo`0>ool00`2?ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Pool0
0`1oooooo`0Tool00`0?ooooo`07ool0027oo`803`?oo`0300oooooo00koo`0307oooooo023oo`03
08oooooo023oo`0307oooooo023oo`0308oooooo02Coo`0300oooooo00Ooo`008Ooo00<03oooool0
0_oo00<03oooool03_oo00<0Soooool08?oo00<0Ooooool08?oo00<0Soooool08?oo00<0Ooooool0
9?oo00<03oooool01ooo000Qool00`0?ooooo`02ool00`0?ooooo`0>ool00`1oooooo`0Pool00`2?
ooooo`0Pool00`1oooooo`0Pool00`2?ooooo`0Tool00`0?ooooo`07ool0027oo`803`?oo`0300oo
oooo00koo`0308oooooo023oo`0307oooooo023oo`0308oooooo023oo`0307oooooo02Coo`0300oo
oooo00Ooo`008Ooo00@03oooooooo`803a3oo`0307oooooo023oo`0308oooooo023oo`0307oooooo
023oo`0308oooooo02Coo`0300oooooo00Ooo`008Ooo00D03oooooooo`0?017oo`0308oooooo023o
o`0307oooooo023oo`0308oooooo023oo`0307oooooo02Coo`0300oooooo00Ooo`008Ooo00D03ooo
ooooo`0?017oo`0307oooooo023oo`0308oooooo023oo`0307oooooo023oo`0308oooooo02Coo`03
00oooooo00Ooo`008Ooo0P0?5?oo00<03oooool08?oo00<03oooool08?oo00<03oooool08?oo00<0
3oooool08Ooo00@03oooool03`Woo`008OooY`0?2Ooo0000\
\>"],
  ImageRangeCache->{{{0, 207.75}, {127.75, 0}} -> {-11.502835, -0.747257, 
  0.711047, 0.035203}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"NeXT 3.0",
ScreenRectangle->{{0, 957}, {0, 768}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{615, 414},
WindowMargins->{{Automatic, 74}, {Automatic, 126}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"NeXTAutomaticEncoding",
Magnification->1.25
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 89, 2, 122, "Title"],
Cell[1823, 55, 55, 1, 31, "Input"],
Cell[1881, 58, 87, 2, 64, "Section"],
Cell[1971, 62, 85, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[2081, 68, 89, 2, 64, "Section"],
Cell[2173, 72, 97, 2, 31, "Input"],
Cell[2273, 76, 1875, 37, 773, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4185, 118, 98, 2, 64, "Section"],
Cell[4286, 122, 135, 3, 91, "Input"],
Cell[4424, 127, 218, 5, 65, "Input"],
Cell[4645, 134, 327, 7, 82, "Input"],
Cell[4975, 143, 166, 4, 48, "Input"],
Cell[5144, 149, 334, 6, 82, "Input"],

Cell[CellGroupData[{
Cell[5503, 159, 136, 3, 48, "Input"],
Cell[5642, 164, 58104, 2603, 172, 44399, 2428, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63795, 2773, 99, 2, 64, "Section"],
Cell[63897, 2777, 325, 8, 207, "Input"],
Cell[64225, 2787, 248, 6, 65, "Input"],
Cell[64476, 2795, 345, 7, 99, "Input"],
Cell[64824, 2804, 166, 4, 48, "Input"],
Cell[64993, 2810, 358, 7, 99, "Input"],

Cell[CellGroupData[{
Cell[65376, 2821, 136, 3, 48, "Input"],
Cell[65515, 2826, 50471, 2313, 134, 40614, 2187, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[116035, 5145, 100, 2, 64, "Section"],
Cell[116138, 5149, 347, 7, 267, "Input"],
Cell[116488, 5158, 224, 5, 65, "Input"],
Cell[116715, 5165, 345, 7, 99, "Input"],
Cell[117063, 5174, 166, 4, 48, "Input"],
Cell[117232, 5180, 358, 7, 99, "Input"],

Cell[CellGroupData[{
Cell[117615, 5191, 136, 3, 48, "Input"],
Cell[117754, 5196, 54841, 2472, 194, 42738, 2317, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[172644, 7674, 92, 2, 64, "Section"],
Cell[172739, 7678, 122, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[172886, 7685, 183, 4, 74, "Input"],
Cell[173072, 7691, 221, 5, 27, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[173342, 7702, 93, 2, 64, "Section"],
Cell[173438, 7706, 126, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[173589, 7713, 117, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[173731, 7719, 567, 13, 201, "Input"],
Cell[174301, 7734, 86, 1, 63, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[174436, 7741, 118, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[174579, 7747, 714, 15, 193, "Input"],
Cell[175296, 7764, 101, 2, 63, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[175446, 7772, 118, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[175589, 7778, 182, 5, 48, "Input"],
Cell[175774, 7785, 110, 2, 63, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[175933, 7793, 119, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[176077, 7799, 209, 5, 73, "Input"],
Cell[176289, 7806, 128, 2, 63, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[176466, 7814, 101, 2, 54, "Subsection"],
Cell[176570, 7818, 306, 6, 99, "Input"],

Cell[CellGroupData[{
Cell[176901, 7828, 243, 6, 48, "Input"],
Cell[177147, 7836, 2267, 63, 118, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[179463, 7905, 99, 2, 54, "Subsection"],
Cell[179565, 7909, 507, 11, 122, "Input"],
Cell[180075, 7922, 236, 5, 65, "Input"],
Cell[180314, 7929, 313, 6, 82, "Input"],
Cell[180630, 7937, 166, 4, 65, "Input"],
Cell[180799, 7943, 332, 6, 99, "Input"],

Cell[CellGroupData[{
Cell[181156, 7953, 136, 3, 48, "Input"],
Cell[181295, 7958, 52867, 2352, 178, 40424, 2192, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[234211, 10316, 116, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[234352, 10322, 248, 7, 82, "Input"],
Cell[234603, 10331, 28660, 936, 139, 14192, 751, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[263312, 11273, 91, 2, 54, "Subsection"],
Cell[263406, 11277, 373, 8, 224, "Input"],
Cell[263782, 11287, 158, 4, 73, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[263977, 11296, 87, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[264089, 11302, 325, 7, 154, "Input"],
Cell[264417, 11311, 223, 5, 27, "Print"],
Cell[264643, 11318, 72, 1, 32, "Output"],
Cell[264718, 11321, 223, 5, 27, "Print"],
Cell[264944, 11328, 53, 1, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[265034, 11334, 235, 5, 101, "Input"],
Cell[265272, 11341, 27184, 876, 140, 12488, 690, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[292517, 12224, 88, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[292630, 12230, 107, 2, 54, "Subsection"],
Cell[292740, 12234, 959, 17, 438, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[293736, 12256, 87, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[293848, 12262, 315, 8, 126, "Input"],
Cell[294166, 12272, 220, 5, 27, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[294435, 12283, 95, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[294555, 12289, 239, 6, 127, "Input"],
Cell[294797, 12297, 445, 11, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[295291, 12314, 113, 2, 54, "Subsection"],
Cell[295407, 12318, 305, 7, 163, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[295749, 12330, 87, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[295861, 12336, 208, 4, 125, "Input"],
Cell[296072, 12342, 222, 5, 27, "Print"],
Cell[296297, 12349, 71, 1, 32, "Output"],
Cell[296371, 12352, 223, 5, 27, "Print"],
Cell[296597, 12359, 73, 1, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[296707, 12365, 265, 5, 101, "Input"],
Cell[296975, 12372, 27480, 899, 139, 12987, 714, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[324516, 13278, 96, 2, 64, "Section"],
Cell[324615, 13282, 159, 4, 74, "Input"],

Cell[CellGroupData[{
Cell[324799, 13290, 209, 5, 81, "Input"],
Cell[325011, 13297, 28332, 921, 139, 12844, 724, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

