(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    835781,      27886]*)
(*NotebookOutlinePosition[    836722,      27918]*)
(*  CellTagsIndexPosition[    836678,      27914]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["NEAR-FIELD OPTICS"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Remove["\<Global`*\>"]\)], "Input"],

Cell[TextData["Highlights"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Abstract"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Introduction"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Off[General::"\<spell\>", General::"\<spell1\>"]; \)\), 
    \(Needs["\<Graphics`ParametricPlot3D`\>"]\), 
    \(\(Needs["\<Graphics`Arrow`\>"]; \)\), 
    \(Needs["\<Graphics`PlotField`\>"]; \nNeeds["\<Algebra`ReIm`\>"]; \n
    Needs["\<Calculus`VectorAnalysis`\>"]; \n\(tera = 10\^12; 
    micro = 1\/10\^6; \)\), 
    \(giga = 10\^9; nano = 1\/10\^9; \), 
    \(mega = 10\^6; pico = 1\/10\^12; \), 
    \(kilo = 10\^3; femto = 1\/10\^15; \), 
    \(milli = 1\/10.\^3; atto = 1\/10\^18; \), 
    \(\(NSub
       = {c \[Rule] 2.99792458\ 10\^8, e \[Rule] 1.6021773\/10\^19, 
        h \[Rule] 6.6260755\/10.\^34, hbar \[Rule] 1.05457\/10.\^34, 
        K \[Rule] 1.380658\/10\^23, me \[Rule] 9.109389\/10\^31, 
        mu0 \[Rule] \(4.\ \[Pi]\)\/10\^7, eps0 \[Rule] 8.85419\/10\^12}; \)\),
   
    \(ESi = 0.179\ tera; rhoSi = 2330; nuSi = 0.28; \), 
    \(ESiO2 = 0.06\ tera; rhoSiO2 = 2200; nuSiO2 = 0.3; \), 
    \(ESi3N4 = 0.15\ tera; rhoSi3N4 = 3100; nuSi3N4 = 0.24; \), 
    \(EAu = 0.08\ tera; rhoAu = 19300; nuAu = 0.42; \), 
    \(ENi = 0.207\ tera; rhoNi = 8900; nuNi = 0.41; \), 
    \(EW = 0.345\ tera; rhoW = 19300; nuW = 0.28; \), 
    \(EPt = 0.17\ tera; rhoPt = 21400; nuPt = 0.39; \), 
    \(EIr = 0.52\ tera; rhoIr = 22500; nuIr = 0.3; \), 
    \(EHOPG = 0.2\ tera; rhoHOPG = 2250; nuHOPG = 0.3; \), 
    \(EPol = 0.001\ tera; rhoPol = 1000; nuPol = 0.3; \), 
    \(\(xx = 0.8; \)\), 
    \(\(EPtIr = xx\ 0.8\ EPt + \((1 - xx)\)\ EIr; \)\), 
    \(\(rhoPtIr = xx\ rhoPt + \((1 - xx)\)\ rhoIr; \)\), 
    \(\(nuPtIr = 0.3; \)\), 
    \(opt = {PlotRange \[Rule] All, AxesOrigin \[Rule] {0, 0}, 
        Frame \[Rule] True, GridLines \[Rule] Automatic, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        PlotStyle 
          \[Rule] {Dashing[{.0001}], Dashing[{.0500}], Dashing[{.0200}], 
            Dashing[{.0001}]}}; \n
    opt2 = {PlotRange \[Rule] All, AxesOrigin \[Rule] {0, 0}, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>"}, Frame \[Rule] True, 
        GridLines \[Rule] Automatic}; \n\nnum = 45; \n\n
    optBW = {PlotPoints \[Rule] num, PlotRange \[Rule] All, 
        Axes \[Rule] True, DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        Axes \[Rule] True, Frame \[Rule] True, Mesh \[Rule] False}; \n
    \(optColor
       = {PlotPoints \[Rule] num, PlotRange \[Rule] All, Axes \[Rule] True, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, Axes \[Rule] True, 
        Frame \[Rule] True, Mesh \[Rule] False, ColorFunction \[Rule] Hue}; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Operating Conditions"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(lambda = 0.5\ micro; \)\), 
    \(\(a = lambda\/10; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(case
       = {k \[Rule] \(2\ \[Pi]\)\/lambda, 
        w \[Rule] \(2\ \[Pi]\ c\)\/lambda /. NSub, 
        m0 \[Rule] \(-\(\(2\ a\^3\)\/\(3\ \[Pi]\)\)\)}; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[atn]; \)\), 
    \(atn[x_, y_] := If[x == 0 && y == 0, 0, ArcTan[x, y]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(opt1 = optBW; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Far-Field Solution"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Vector Potential"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Ad = 
      \(1\/Rr\^2\) 
        \((m0\ \((1 - I\ k\ Rr)\)\ Exp[I\ \((k\ Rr - w\ t)\)]\ 
            Sin[Ttheta]\ {0, 0, 1})\); \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Ad0 = 
      \(m0\ Sin[Ttheta]\ \@\(1 + \((k\ Rr)\)\^2\)\ {0, 0, 1}\)\/Rr\^2; \)\), 
    \(psi = k\ Rr + ArcTan[1, \(-k\)\ Rr] - w\ t; \n\(Ad = Ad0\ Exp[I\ psi]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Electric Field"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Ed = \(-\(\[PartialD]\_t Ad\/c\)\); \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Ed0 = \(\(-I\)\ Simplify[Ed\ Exp[\(-I\)\ psi]] /. case\) /. NSub; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Edx]; \)\), 
    \(\(Edx[x_, y_, z_] := 
      \(\(Sin[Pphi]\ Ed0\[LeftDoubleBracket]3\[RightDoubleBracket] /. 
            Ttheta \[Rule] ArcCos[y\/\@\(x\^2 + y\^2 + z\^2\)]\) /. 
          Rr \[Rule] \@\(x\^2 + y\^2 + z\^2\)\) /. Pphi \[Rule] atn[x, z]; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Edz]; \)\), 
    \(\(Edz[x_, y_, z_] := 
      \(\(Cos[Pphi]\ Ed0\[LeftDoubleBracket]3\[RightDoubleBracket] /. 
            Ttheta \[Rule] ArcCos[y\/\@\(x\^2 + y\^2 + z\^2\)]\) /. 
          Rr \[Rule] \@\(x\^2 + y\^2 + z\^2\)\) /. Pphi \[Rule] atn[x, z]; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Edy]; \)\), 
    \(\(Edy[x_, y_, z_] := 0; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Electric Vector Field in the $x-z$ Plane"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig16x1 = 
      PlotVectorField[
        Evaluate[{Edx[x\ a, a, z\ a], \(-Edz[x\ a, a, z\ a]\)}], {x, \(-2\), 
          2, .5}, {z, \(-2\), 2, .5}, 
        AxesLabel \[Rule] {"\<x in a\>", "\<z in a\>"}, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        AxesOrigin \[Rule] {\(-2.24\), 0}, PlotRange \[Rule] All, 
        Axes \[Rule] True, Frame \[Rule] True]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.220181 0.5 0.220181 [
[.05964 -0.0125 -7 -12 ]
[.05964 -0.0125 7 0 ]
[.27982 -0.0125 -7 -12 ]
[.27982 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.72018 -0.0125 -4 -12 ]
[.72018 -0.0125 4 0 ]
[.94036 -0.0125 -4 -12 ]
[.94036 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05964 -14 -6 ]
[-0.0125 .05964 0 6 ]
[-0.0125 .27982 -14 -6 ]
[-0.0125 .27982 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .72018 -8 -6 ]
[-0.0125 .72018 0 6 ]
[-0.0125 .94036 -8 -6 ]
[-0.0125 .94036 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 22 6 ]
[.00679 1.025 -11 0 ]
[.00679 1.025 11 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05964 0 m
.05964 .00625 L
s
gsave
.05964 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.27982 0 m
.27982 .00625 L
s
gsave
.27982 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.72018 0 m
.72018 .00625 L
s
gsave
.72018 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.94036 0 m
.94036 .00625 L
s
gsave
.94036 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.10367 0 m
.10367 .00375 L
s
.14771 0 m
.14771 .00375 L
s
.19175 0 m
.19175 .00375 L
s
.23578 0 m
.23578 .00375 L
s
.32386 0 m
.32386 .00375 L
s
.36789 0 m
.36789 .00375 L
s
.41193 0 m
.41193 .00375 L
s
.45596 0 m
.45596 .00375 L
s
.54404 0 m
.54404 .00375 L
s
.58807 0 m
.58807 .00375 L
s
.63211 0 m
.63211 .00375 L
s
.67614 0 m
.67614 .00375 L
s
.76422 0 m
.76422 .00375 L
s
.80825 0 m
.80825 .00375 L
s
.85229 0 m
.85229 .00375 L
s
.89633 0 m
.89633 .00375 L
s
.0156 0 m
.0156 .00375 L
s
.9844 0 m
.9844 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05964 m
.00625 .05964 L
s
gsave
-0.0125 .05964 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .27982 m
.00625 .27982 L
s
gsave
-0.0125 .27982 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .72018 m
.00625 .72018 L
s
gsave
-0.0125 .72018 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .94036 m
.00625 .94036 L
s
gsave
-0.0125 .94036 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .10367 m
.00375 .10367 L
s
0 .14771 m
.00375 .14771 L
s
0 .19175 m
.00375 .19175 L
s
0 .23578 m
.00375 .23578 L
s
0 .32386 m
.00375 .32386 L
s
0 .36789 m
.00375 .36789 L
s
0 .41193 m
.00375 .41193 L
s
0 .45596 m
.00375 .45596 L
s
0 .54404 m
.00375 .54404 L
s
0 .58807 m
.00375 .58807 L
s
0 .63211 m
.00375 .63211 L
s
0 .67614 m
.00375 .67614 L
s
0 .76422 m
.00375 .76422 L
s
0 .80825 m
.00375 .80825 L
s
0 .85229 m
.00375 .85229 L
s
0 .89633 m
.00375 .89633 L
s
0 .0156 m
.00375 .0156 L
s
0 .9844 m
.00375 .9844 L
s
.25 Mabswid
0 0 m
0 1 L
s
.05964 .99375 m
.05964 1 L
s
.27982 .99375 m
.27982 1 L
s
.5 .99375 m
.5 1 L
s
.72018 .99375 m
.72018 1 L
s
.94036 .99375 m
.94036 1 L
s
.125 Mabswid
.10367 .99625 m
.10367 1 L
s
.14771 .99625 m
.14771 1 L
s
.19175 .99625 m
.19175 1 L
s
.23578 .99625 m
.23578 1 L
s
.32386 .99625 m
.32386 1 L
s
.36789 .99625 m
.36789 1 L
s
.41193 .99625 m
.41193 1 L
s
.45596 .99625 m
.45596 1 L
s
.54404 .99625 m
.54404 1 L
s
.58807 .99625 m
.58807 1 L
s
.63211 .99625 m
.63211 1 L
s
.67614 .99625 m
.67614 1 L
s
.76422 .99625 m
.76422 1 L
s
.80825 .99625 m
.80825 1 L
s
.85229 .99625 m
.85229 1 L
s
.89633 .99625 m
.89633 1 L
s
.0156 .99625 m
.0156 1 L
s
.9844 .99625 m
.9844 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .05964 m
1 .05964 L
s
.99375 .27982 m
1 .27982 L
s
.99375 .5 m
1 .5 L
s
.99375 .72018 m
1 .72018 L
s
.99375 .94036 m
1 .94036 L
s
.125 Mabswid
.99625 .10367 m
1 .10367 L
s
.99625 .14771 m
1 .14771 L
s
.99625 .19175 m
1 .19175 L
s
.99625 .23578 m
1 .23578 L
s
.99625 .32386 m
1 .32386 L
s
.99625 .36789 m
1 .36789 L
s
.99625 .41193 m
1 .41193 L
s
.99625 .45596 m
1 .45596 L
s
.99625 .54404 m
1 .54404 L
s
.99625 .58807 m
1 .58807 L
s
.99625 .63211 m
1 .63211 L
s
.99625 .67614 m
1 .67614 L
s
.99625 .76422 m
1 .76422 L
s
.99625 .80825 m
1 .80825 L
s
.99625 .85229 m
1 .85229 L
s
.99625 .89633 m
1 .89633 L
s
.99625 .0156 m
1 .0156 L
s
.99625 .9844 m
1 .9844 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.00679 0 m
.00679 1 L
s
gsave
.00679 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
68.500000 13.000000 moveto
(in) show
76.687500 13.000000 moveto
(a) show
80.187500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.05964 .05964 m
.09547 .02381 L
s
% Start of user PostScript
-2. -2. -1.83728 -2.16272 MAarrowhead1
% End of user PostScript
.05964 .16973 m
.09387 .12409 L
s
% Start of user PostScript
-2. -1.5 -1.84454 -1.70728 MAarrowhead1
% End of user PostScript
.05964 .27982 m
.08795 .2232 L
s
% Start of user PostScript
-2. -1. -1.87143 -1.25713 MAarrowhead1
% End of user PostScript
.05964 .38991 m
.07615 .32385 L
s
% Start of user PostScript
-2. -0.5 -1.92499 -0.800035 MAarrowhead1
% End of user PostScript
.05964 .5 m
.05964 .43007 L
s
% Start of user PostScript
-2. 0 -2. -0.317589 MAarrowhead1
% End of user PostScript
.05964 .61009 m
.04312 .54403 L
s
% Start of user PostScript
-2. 0.5 -2.07501 0.199965 MAarrowhead1
% End of user PostScript
.05964 .72018 m
.03133 .66356 L
s
% Start of user PostScript
-2. 1. -2.12857 0.742865 MAarrowhead1
% End of user PostScript
.05964 .83027 m
.02541 .78463 L
s
% Start of user PostScript
-2. 1.5 -2.15546 1.29272 MAarrowhead1
% End of user PostScript
.05964 .94036 m
.02381 .90453 L
s
% Start of user PostScript
-2. 2. -2.16272 1.83728 MAarrowhead1
% End of user PostScript
.16973 .05964 m
.21537 .02541 L
s
% Start of user PostScript
-1.5 -2. -1.29272 -2.15546 MAarrowhead1
% End of user PostScript
.16973 .16973 m
.21667 .12278 L
s
% Start of user PostScript
-1.5 -1.5 -1.2868 -1.7132 MAarrowhead1
% End of user PostScript
.16973 .27982 m
.21206 .21631 L
s
% Start of user PostScript
-1.5 -1. -1.30772 -1.28842 MAarrowhead1
% End of user PostScript
.16973 .38991 m
.19644 .30977 L
s
% Start of user PostScript
-1.5 -0.5 -1.37868 -0.863968 MAarrowhead1
% End of user PostScript
.16973 .5 m
.16973 .41231 L
s
% Start of user PostScript
-1.5 0 -1.5 -0.398245 MAarrowhead1
% End of user PostScript
.16973 .61009 m
.14302 .52995 L
s
% Start of user PostScript
-1.5 0.5 -1.62132 0.136032 MAarrowhead1
% End of user PostScript
.16973 .72018 m
.12739 .65668 L
s
% Start of user PostScript
-1.5 1. -1.69228 0.71158 MAarrowhead1
% End of user PostScript
.16973 .83027 m
.12278 .78333 L
s
% Start of user PostScript
-1.5 1.5 -1.7132 1.2868 MAarrowhead1
% End of user PostScript
.16973 .94036 m
.12409 .90613 L
s
% Start of user PostScript
-1.5 2. -1.70728 1.84454 MAarrowhead1
% End of user PostScript
.27982 .05964 m
.33644 .03133 L
s
% Start of user PostScript
-1. -2. -0.742865 -2.12857 MAarrowhead1
% End of user PostScript
.27982 .16973 m
.34332 .12739 L
s
% Start of user PostScript
-1. -1.5 -0.71158 -1.69228 MAarrowhead1
% End of user PostScript
.27982 .27982 m
.34429 .21534 L
s
% Start of user PostScript
-1. -1. -0.707177 -1.29282 MAarrowhead1
% End of user PostScript
.27982 .38991 m
.32596 .29762 L
s
% Start of user PostScript
-1. -0.5 -0.790418 -0.919164 MAarrowhead1
% End of user PostScript
.27982 .5 m
.27982 .39279 L
s
% Start of user PostScript
-1. 0 -1. -0.486918 MAarrowhead1
% End of user PostScript
.27982 .61009 m
.23367 .5178 L
s
% Start of user PostScript
-1. 0.5 -1.20958 0.080836 MAarrowhead1
% End of user PostScript
.27982 .72018 m
.21534 .65571 L
s
% Start of user PostScript
-1. 1. -1.29282 0.707177 MAarrowhead1
% End of user PostScript
.27982 .83027 m
.21631 .78794 L
s
% Start of user PostScript
-1. 1.5 -1.28842 1.30772 MAarrowhead1
% End of user PostScript
.27982 .94036 m
.2232 .91205 L
s
% Start of user PostScript
-1. 2. -1.25713 1.87143 MAarrowhead1
% End of user PostScript
.38991 .05964 m
.45597 .04312 L
s
% Start of user PostScript
-0.5 -2. -0.199965 -2.07501 MAarrowhead1
% End of user PostScript
.38991 .16973 m
.47005 .14302 L
s
% Start of user PostScript
-0.5 -1.5 -0.136032 -1.62132 MAarrowhead1
% End of user PostScript
.38991 .27982 m
.4822 .23367 L
s
% Start of user PostScript
-0.5 -1. -0.080836 -1.20958 MAarrowhead1
% End of user PostScript
.38991 .38991 m
.46776 .31206 L
s
% Start of user PostScript
-0.5 -0.5 -0.146447 -0.853553 MAarrowhead1
% End of user PostScript
.38991 .5 m
.38991 .40089 L
s
% Start of user PostScript
-0.5 0 -0.5 -0.450123 MAarrowhead1
% End of user PostScript
.38991 .61009 m
.31206 .53224 L
s
% Start of user PostScript
-0.5 0.5 -0.853553 0.146447 MAarrowhead1
% End of user PostScript
.38991 .72018 m
.29762 .67404 L
s
% Start of user PostScript
-0.5 1. -0.919164 0.790418 MAarrowhead1
% End of user PostScript
.38991 .83027 m
.30977 .80356 L
s
% Start of user PostScript
-0.5 1.5 -0.863968 1.37868 MAarrowhead1
% End of user PostScript
.38991 .94036 m
.32385 .92385 L
s
% Start of user PostScript
-0.5 2. -0.800035 1.92499 MAarrowhead1
% End of user PostScript
.5 .05964 m
.56993 .05964 L
s
% Start of user PostScript
0 -2. 0.317589 -2. MAarrowhead1
% End of user PostScript
.5 .16973 m
.58769 .16973 L
s
% Start of user PostScript
0 -1.5 0.398245 -1.5 MAarrowhead1
% End of user PostScript
.5 .27982 m
.60721 .27982 L
s
% Start of user PostScript
0 -1. 0.486918 -1. MAarrowhead1
% End of user PostScript
.5 .38991 m
.59911 .38991 L
s
% Start of user PostScript
0 -0.5 0.450123 -0.5 MAarrowhead1
% End of user PostScript
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .61009 m
.40089 .61009 L
s
% Start of user PostScript
0 0.5 -0.450123 0.5 MAarrowhead1
% End of user PostScript
.5 .72018 m
.39279 .72018 L
s
% Start of user PostScript
0 1. -0.486918 1. MAarrowhead1
% End of user PostScript
.5 .83027 m
.41231 .83027 L
s
% Start of user PostScript
0 1.5 -0.398245 1.5 MAarrowhead1
% End of user PostScript
.5 .94036 m
.43007 .94036 L
s
% Start of user PostScript
0 2. -0.317589 2. MAarrowhead1
% End of user PostScript
.61009 .05964 m
.67615 .07615 L
s
% Start of user PostScript
0.5 -2. 0.800035 -1.92499 MAarrowhead1
% End of user PostScript
.61009 .16973 m
.69023 .19644 L
s
% Start of user PostScript
0.5 -1.5 0.863968 -1.37868 MAarrowhead1
% End of user PostScript
.61009 .27982 m
.70238 .32596 L
s
% Start of user PostScript
0.5 -1. 0.919164 -0.790418 MAarrowhead1
% End of user PostScript
.61009 .38991 m
.68794 .46776 L
s
% Start of user PostScript
0.5 -0.5 0.853553 -0.146447 MAarrowhead1
% End of user PostScript
.61009 .5 m
.61009 .59911 L
s
% Start of user PostScript
0.5 0 0.5 0.450123 MAarrowhead1
% End of user PostScript
.61009 .61009 m
.53224 .68794 L
s
% Start of user PostScript
0.5 0.5 0.146447 0.853553 MAarrowhead1
% End of user PostScript
.61009 .72018 m
.5178 .76633 L
s
% Start of user PostScript
0.5 1. 0.080836 1.20958 MAarrowhead1
% End of user PostScript
.61009 .83027 m
.52995 .85698 L
s
% Start of user PostScript
0.5 1.5 0.136032 1.62132 MAarrowhead1
% End of user PostScript
.61009 .94036 m
.54403 .95688 L
s
% Start of user PostScript
0.5 2. 0.199965 2.07501 MAarrowhead1
% End of user PostScript
.72018 .05964 m
.7768 .08795 L
s
% Start of user PostScript
1. -2. 1.25713 -1.87143 MAarrowhead1
% End of user PostScript
.72018 .16973 m
.78369 .21206 L
s
% Start of user PostScript
1. -1.5 1.28842 -1.30772 MAarrowhead1
% End of user PostScript
.72018 .27982 m
.78466 .34429 L
s
% Start of user PostScript
1. -1. 1.29282 -0.707177 MAarrowhead1
% End of user PostScript
.72018 .38991 m
.76633 .4822 L
s
% Start of user PostScript
1. -0.5 1.20958 -0.080836 MAarrowhead1
% End of user PostScript
.72018 .5 m
.72018 .60721 L
s
% Start of user PostScript
1. 0 1. 0.486918 MAarrowhead1
% End of user PostScript
.72018 .61009 m
.67404 .70238 L
s
% Start of user PostScript
1. 0.5 0.790418 0.919164 MAarrowhead1
% End of user PostScript
.72018 .72018 m
.65571 .78466 L
s
% Start of user PostScript
1. 1. 0.707177 1.29282 MAarrowhead1
% End of user PostScript
.72018 .83027 m
.65668 .87261 L
s
% Start of user PostScript
1. 1.5 0.71158 1.69228 MAarrowhead1
% End of user PostScript
.72018 .94036 m
.66356 .96867 L
s
% Start of user PostScript
1. 2. 0.742865 2.12857 MAarrowhead1
% End of user PostScript
.83027 .05964 m
.87591 .09387 L
s
% Start of user PostScript
1.5 -2. 1.70728 -1.84454 MAarrowhead1
% End of user PostScript
.83027 .16973 m
.87722 .21667 L
s
% Start of user PostScript
1.5 -1.5 1.7132 -1.2868 MAarrowhead1
% End of user PostScript
.83027 .27982 m
.87261 .34332 L
s
% Start of user PostScript
1.5 -1. 1.69228 -0.71158 MAarrowhead1
% End of user PostScript
.83027 .38991 m
.85698 .47005 L
s
% Start of user PostScript
1.5 -0.5 1.62132 -0.136032 MAarrowhead1
% End of user PostScript
.83027 .5 m
.83027 .58769 L
s
% Start of user PostScript
1.5 0 1.5 0.398245 MAarrowhead1
% End of user PostScript
.83027 .61009 m
.80356 .69023 L
s
% Start of user PostScript
1.5 0.5 1.37868 0.863968 MAarrowhead1
% End of user PostScript
.83027 .72018 m
.78794 .78369 L
s
% Start of user PostScript
1.5 1. 1.30772 1.28842 MAarrowhead1
% End of user PostScript
.83027 .83027 m
.78333 .87722 L
s
% Start of user PostScript
1.5 1.5 1.2868 1.7132 MAarrowhead1
% End of user PostScript
.83027 .94036 m
.78463 .97459 L
s
% Start of user PostScript
1.5 2. 1.29272 2.15546 MAarrowhead1
% End of user PostScript
.94036 .05964 m
.97619 .09547 L
s
% Start of user PostScript
2. -2. 2.16272 -1.83728 MAarrowhead1
% End of user PostScript
.94036 .16973 m
.97459 .21537 L
s
% Start of user PostScript
2. -1.5 2.15546 -1.29272 MAarrowhead1
% End of user PostScript
.94036 .27982 m
.96867 .33644 L
s
% Start of user PostScript
2. -1. 2.12857 -0.742865 MAarrowhead1
% End of user PostScript
.94036 .38991 m
.95688 .45597 L
s
% Start of user PostScript
2. -0.5 2.07501 -0.199965 MAarrowhead1
% End of user PostScript
.94036 .5 m
.94036 .56993 L
s
% Start of user PostScript
2. 0 2. 0.317589 MAarrowhead1
% End of user PostScript
.94036 .61009 m
.92385 .67615 L
s
% Start of user PostScript
2. 0.5 1.92499 0.800035 MAarrowhead1
% End of user PostScript
.94036 .72018 m
.91205 .7768 L
s
% Start of user PostScript
2. 1. 1.87143 1.25713 MAarrowhead1
% End of user PostScript
.94036 .83027 m
.90613 .87591 L
s
% Start of user PostScript
2. 1.5 1.84454 1.70728 MAarrowhead1
% End of user PostScript
.94036 .94036 m
.90453 .97619 L
s
% Start of user PostScript
2. 2. 1.83728 2.16272 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{111.0625, 111.0625},
  ImageMargins->{{108.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002;0000R`800@400h_o002;o`00Rol008_o002;
o`00Rol008_o002;o`00Rol001Ko00<001;o00<001;o00<l01;o00<001;o00<001ko000Fo`03?00C
o`03?00@o`03<00Do`03?00Ao`03?00No`004Ol00`001o`<o`030006l`oo00<`01Co00<l01;o00<l
01go000Fo`03<00Co`03?00@o`03<00Do`03?00Ao`03<00No`005ol00``04Ol00``04_l00c`04_l0
0``04ol00``07Ol008_o002;o`00Rol008_o002;o`003omT01So000?o`03?007o17o00<l01?o00<l
01?o00<l01?o00<l00K`5_l000oo00<l00Ko00<l00Wo00<l04_o00<l01Ko0008o`040`07o006o000
2Ol00`002Ol00`00@Ol00c`05_l000So00@o00Ol00Gl00[o00<<00Wo00<000Wo00<003Go00<l01Ko
00001O`023l6l`Kc2?l00c`02?l00``02?l500Wo00<<02[o00<l01Ko0008o`04<`07o0Kc1ol00c`0
1ol00``02?l00``02?l80006o0002?l00``02?l00c`02?l00c`01_0Fo`002Ol00``01o`ko`D01Ol0
0`001ol00``02?l00c`01_<Eo`003ol00c`0B?l00`001ol00``01ol53aSo000?o`03?019o`033006
o`030007o`D?6?l000oo00<l05oo00<<01Oo000?o`03?01Po`03?00Fo`003ol00c`01_l00c`02Ol0
0c`0Bol00c`05_l000oo00Hol005`0So00<000[o00<0043o00<l01Ko000?o`06?o001L08o`033009
o`03000:o`03000do`03?00Fo`003ol013l01o`7o`03?009o`03?00:o`04000co`03300Go`003ol0
0c`01o`7o`03?008o`033009o`03000=o`03300Xo`03?00Fo`003ol00c`01o`7o`03?007o`03?008
o`033008o`X01L07o`033008o`03?008o`03?007o1Go000?o`03?00lo`D01Ol00c`01ol00c`02?l0
0c`01_<Eo`003ol00c`0?ol00`001Ol00`001ol00c`02?l531So000?o`03?018o`030007o`033007
o`D?6?l000oo00<l01;o00<l00Wo00<<02So00<<00Ko00<000Oo1@lHo`003ol00c`01Ol00c`02Ol0
0``02Ol00`00@?l00c`05_l000oo00Do`0K`2?l00``02_l00``02ol00`00<Ol00``05ol000oo00Do
`0K`2?l00c`02Ol00c`02ol00`00<ol00c`05_l000So00@300Ol1o`7o`03?009o`03?00:o`03300e
o`03?00Fo`002Ol00c`01o`6l`So00<l00So00<l00Wo00<<03Oo00<l01Ko00001O`023l6l`Kc1ol0
0c`02?l00c`02?l00``04?l00``09_l00c`05_l000Wo00<l00Ol1_<7o`03?007o`03?008o`03?008
o`d02Ol00c`02?l00c`02?l00c`01_0Fo`002?l010l01o`Lo`03?00Ko`033007o`03?008o`03?008
o`03?006laGo000?o`03?00Lo`03300No`033006o`03?008o`03?007o`03?006laGo000?o`03?00@
o`03?009o`03300;o`03300Bo`030005o`03?007o`03?008o`Po5Ol000oo00@o00Ol1ol00``02_l0
0c`02_l00`005?l00`001Ol00`001ol00``01_l60aSo000?o`04?`06l0So00<<00Wo00<l00_o00<<
01go00<<00Ko00<<00Oo1@lHo`003ol013l01_08o`03?009o`03?00:o`03?00Oo`03?006o`03?00:
o`03?00Fo`003ol013l01o`7o`03?008o`03?00:o`03?00fo`03?00Fo`003ol00c`01o`7o`03?009
o`03?009o`03?00fo`03300Go`003ol00c`01o`7o`03?008o`03?009o`03?00ho`03?00Fo`003ol0
0c`01o`7o`03?008o`03?008o`03?00?o`03000Wo`03?00Fo`003ol00c`01o`7o`03?007o`033008
o`03?008o`d02Ol00c`02?l00c`02?l00c`01o`Eo`003ol00c`06?l00``02?l00``05Ol00c`01ol0
0c`01ol00c`02?l00c`01o`Eo`003ol00c`03Ol00``02?l00``02?l00``05_l00c`01_l00c`02?l0
0c`02?l5?`03?00Fo`003ol00c`03Ol00``02?l00c`02?l00``05ol00c`01_l00c`01ol00c`02?l0
0c`01_<Eo`003ol00c`01_07o`033008o`03?008o`03?00Ho`03?005o`03?007o`03?008o`033006
laGo000?o`03?006l0So00<l00Oo00<l00So00<l01Wo00<l00Go00<l00Oo00<<00Oo00<<00Kc5Ol0
00oo00<l00K`2?l00c`01ol00c`02?l00c`06Ol00``01Ol00c`01ol00``01ol83aKo000?o`03?007
o0Oo00<l00Oo00<l00So00<l01[o00D?`0K`1_l00``03?l00c`05_l000Wo00<l00Ol1_<7o`03?007
o`03?008o`03?00Ro`033007o`03?00;o`04?`05c003l005c003l005c`002?l013<01o`6l`Oo00<l
00Oo00<l00So00<l02;o00<<01Go00<l00Ol1l`6l0700L0000So00Lco6@01Ol013l01l`7o0700008
o`04<`07o3So00<l00So00<l00So00<l00So00<l00Ol1L`00o001L<6l0700L0000Wo00<l00Ol4ol0
0c`08_l00c`02?l00c`02?l00c`02?l00c`01o`Eo`003ol00c`02ol00c`01_l00``08_l00c`02?l0
0c`02?l00c`02?l00c`01o`7o`03?00;o`003ol00c`02ol00``01_l00``01Ol00``06_l00c`02?l0
0c`02?l00c`02?l00c`01o`Eo`003ol8?`Ko00<<00Oo00Do`0K`6Ol00c`02?l00c`02?l00c`01ol0
10l01_0Fo`003ol5?`03?007o`03?007o`03?005o`03?00Ho`03?008o`03?008o`03?007o`043`07
o1Go000?o`Do00<l00Oo00<l00Oo00<l00Ko00<l01Oo00<l00So00<l00So00<<00So00<l00Ol5Ol0
00oo00<l00Kc1_l00c`02?l00c`01_l00c`05_l00``02?l00c`02?l00c`03_l00c`05_l000oo00<l
00Kc1ol00c`01ol00c`01ol00c`05Ol00``02?l00``02?l00c`03Ol00``05ol000oo00<l00Kc1ol0
0c`02?l00c`01ol00c`05?l00c`02?l00``06Ol00c`05_l000oo00<l00Ol1ol00c`01ol00c`02?l<
00[o00<l00So00<l00So00<l00So00<l00Ol5Ol000oo00<l02Go00<<017o00<l00So00<l00So00<l
00So00<l00Ol5Ol000oo00<l03So00<l00So00<l00So00<l00Wo00<l00Ol5Ol000oo00<l03Oo00<l
00Wo00<l00So00<l00So00@o00K`5_l000oo00<l03Ko00<l00Wo00<l00Wo00<l00So00@o00Ol5Ol0
00oo00<l00Wo00<<00Ko00<<023o00<l00[o00<l00So00<l00So00<<00Go00<l01Ko000?o`Ll1_l0
0``01Ol00`007Ol00`003?l00c`02Ol00c`02?l00``01Ol00c`05_l000oo1c`6o`033006o`063o00
1L0Do`03300<o`03?008o`033009o`053l06l1Ko000?o`Ll1ol00c`01ol01Co01L0Bo`03300<o`03
3009o`03300Ao`03?00Fo`002?l010<01o`5c`Ko00<l00Oo00<l00Go00<<01oo00<l01go00<l01Ko
0009o`03?007o0G?1ol00c`01ol00c`01_l00``07Ol00c`07Ol00c`05_l000Wo00<l00Ol1_<7o`03
?007o`03?007o`d02_l00c`02?l00c`02?l00c`02?l00c`01_0Fo`002Ol00c`01o`So`03000@o`03
3009o`03?009o`03?008o`03?007o1Go0008o`043`07o3Co00<<00[o00<l00Wo00<l00So00@o00Ol
5Ol000oo00<l03?o00<<00_o00<l00Wo00<l00Wo00@o00Ol5Ol000oo00<l033o00<000go00<l00[o
00<l00Oo00<<00Ko00<l01Ko000?o`03?00`o`03000;o`03300:o`033009o`033005o`03300Go`00
3ol00c`0?_l00``02_l00``02Ol00c`01_l00c`05_l000oo00@`00So00<<00Ko00<002Wo00<l00[o
00<l01;o00<l01Ko000?o`Ll1Ol00`001ol00``0B_l00c`05_l000oo1c`7o`03?006o`0;3o`0043o
00<<01Oo000?o`03?006l`Ko00<l00Oo00@?00Gl00<003ko00<l01Ko000?o`03?007o0Ko00<<00So
00<l00Oo1Pl700[o00<l00So00<l00So00<l00So00<l00Ol5Ol000oo00<l02Oo00<<00co00<000[o
00<l00So00<l00So00@o00Ol5Ol000oo00<l03;o00@000_o00<<00Wo00<l00Wo00@o00K`5_l000oo
00<l037o00<000_o00<<00Wo00<<00Wo00<<00Ko00<l01Ko000?o`03?00no`03000:o`033009o`03
3006o`03?00Fo`003ol00c`0B_l00``02_l00c`01_l00c`05_l000oo00<l063o00<l01Ko000?o`03
?01Oo`03300Go`003ol6<0Ko00<000Oo00<<04[o00<l01Ko0008o`040`06o0033007o`033006o`03
0007o`030010o`03?00Fo`002?l013l01o`5c`Ko00<l00Go00@`00Go00@003oo00<l01Ko0009o`03
?007o0Kc1_l00``02?l00c`01_l01P?`00P02Ol00``02Ol00c`02?l00c`02?l00c`01_0Fo`002?l0
13<01o`Xo`03?007o`D02_l00``02Ol00c`02?l013l01o`Eo`002Ol00``01o`bo`030009o`030009
o`030009o`033006o`03?00Fo`003ol00c`0?_l00`002Ol00`002Ol00`001ol00c`05_l000oo00<l
04[o00<<00Wo00<<00Ko00<<01Oo000?o`03?007o17o00<l01?o00<l01?o00<l01?o00<l00Ol5Ol0
00ooI00Ho`00Rol008_o002;o`00Rol008_o0007o`033005l`03<005o003?01ao`001ol00c`01O<0
13<01_1bo`002?l7?`04<`07o77o0007o`033005l`043`06l7;o002;o`003?l00c`0O?l008_o002;
o`00Rol008_o002;o`00Rol008_o002;o`00Rol00001\
\>"],
  ImageRangeCache->{{{0, 137.8125}, {137.8125, 0}} -> {-2.969299, -3.106794, 
  0.05729, 0.05729}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Electric Vector Field in the $x-y$ Plane"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig16x2 = 
      PlotVectorField[
        Evaluate[{Edx[x\ a, y\ a, a], Edy[x\ a, y\ a, a]}], {x, \(-2\), 
          2, .5}, {y, \(-2\), 2, .5}, PlotRange \[Rule] All, 
        Axes \[Rule] True, AxesOrigin \[Rule] {\(-2.18\), 0}, 
        AxesLabel \[Rule] {"\<x in a\>", "\<y in a\>"}, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, Frame \[Rule] True]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .98394 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.507649 0.234271 0.491968 0.234271 [
[.03911 -0.0125 -7 -12 ]
[.03911 -0.0125 7 0 ]
[.27338 -0.0125 -7 -12 ]
[.27338 -0.0125 7 0 ]
[.50765 -0.0125 -4 -12 ]
[.50765 -0.0125 4 0 ]
[.74192 -0.0125 -4 -12 ]
[.74192 -0.0125 4 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02343 -14 -6 ]
[-0.0125 .02343 0 6 ]
[-0.0125 .2577 -14 -6 ]
[-0.0125 .2577 0 6 ]
[-0.0125 .49197 -8 -6 ]
[-0.0125 .49197 0 6 ]
[-0.0125 .72624 -8 -6 ]
[-0.0125 .72624 0 6 ]
[-0.0125 .96051 -8 -6 ]
[-0.0125 .96051 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 .98394 .125 0 ]
[ 1 0 .125 0 ]
[1.025 .49197 0 -6 ]
[1.025 .49197 22 6 ]
[-0.00306 1.00894 -11 0 ]
[-0.00306 1.00894 11 12 ]
[ -0.00306 0 0 0 ]
[ 1 .98394 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03911 0 m
.03911 .00625 L
s
gsave
.03911 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.27338 0 m
.27338 .00625 L
s
gsave
.27338 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.50765 0 m
.50765 .00625 L
s
gsave
.50765 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74192 0 m
.74192 .00625 L
s
gsave
.74192 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.08596 0 m
.08596 .00375 L
s
.13282 0 m
.13282 .00375 L
s
.17967 0 m
.17967 .00375 L
s
.22652 0 m
.22652 .00375 L
s
.32023 0 m
.32023 .00375 L
s
.36709 0 m
.36709 .00375 L
s
.41394 0 m
.41394 .00375 L
s
.4608 0 m
.4608 .00375 L
s
.5545 0 m
.5545 .00375 L
s
.60136 0 m
.60136 .00375 L
s
.64821 0 m
.64821 .00375 L
s
.69507 0 m
.69507 .00375 L
s
.78877 0 m
.78877 .00375 L
s
.83563 0 m
.83563 .00375 L
s
.88248 0 m
.88248 .00375 L
s
.92934 0 m
.92934 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02343 m
.00625 .02343 L
s
gsave
-0.0125 .02343 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .2577 m
.00625 .2577 L
s
gsave
-0.0125 .2577 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .49197 m
.00625 .49197 L
s
gsave
-0.0125 .49197 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .72624 m
.00625 .72624 L
s
gsave
-0.0125 .72624 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .96051 m
.00625 .96051 L
s
gsave
-0.0125 .96051 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .07028 m
.00375 .07028 L
s
0 .11714 m
.00375 .11714 L
s
0 .16399 m
.00375 .16399 L
s
0 .21084 m
.00375 .21084 L
s
0 .30455 m
.00375 .30455 L
s
0 .35141 m
.00375 .35141 L
s
0 .39826 m
.00375 .39826 L
s
0 .44511 m
.00375 .44511 L
s
0 .53882 m
.00375 .53882 L
s
0 .58568 m
.00375 .58568 L
s
0 .63253 m
.00375 .63253 L
s
0 .67938 m
.00375 .67938 L
s
0 .77309 m
.00375 .77309 L
s
0 .81995 m
.00375 .81995 L
s
0 .8668 m
.00375 .8668 L
s
0 .91366 m
.00375 .91366 L
s
.25 Mabswid
0 0 m
0 .98394 L
s
.03911 .97769 m
.03911 .98394 L
s
.27338 .97769 m
.27338 .98394 L
s
.50765 .97769 m
.50765 .98394 L
s
.74192 .97769 m
.74192 .98394 L
s
.97619 .97769 m
.97619 .98394 L
s
.125 Mabswid
.08596 .98019 m
.08596 .98394 L
s
.13282 .98019 m
.13282 .98394 L
s
.17967 .98019 m
.17967 .98394 L
s
.22652 .98019 m
.22652 .98394 L
s
.32023 .98019 m
.32023 .98394 L
s
.36709 .98019 m
.36709 .98394 L
s
.41394 .98019 m
.41394 .98394 L
s
.4608 .98019 m
.4608 .98394 L
s
.5545 .98019 m
.5545 .98394 L
s
.60136 .98019 m
.60136 .98394 L
s
.64821 .98019 m
.64821 .98394 L
s
.69507 .98019 m
.69507 .98394 L
s
.78877 .98019 m
.78877 .98394 L
s
.83563 .98019 m
.83563 .98394 L
s
.88248 .98019 m
.88248 .98394 L
s
.92934 .98019 m
.92934 .98394 L
s
.25 Mabswid
0 .98394 m
1 .98394 L
s
.99375 .02343 m
1 .02343 L
s
.99375 .2577 m
1 .2577 L
s
.99375 .49197 m
1 .49197 L
s
.99375 .72624 m
1 .72624 L
s
.99375 .96051 m
1 .96051 L
s
.125 Mabswid
.99625 .07028 m
1 .07028 L
s
.99625 .11714 m
1 .11714 L
s
.99625 .16399 m
1 .16399 L
s
.99625 .21084 m
1 .21084 L
s
.99625 .30455 m
1 .30455 L
s
.99625 .35141 m
1 .35141 L
s
.99625 .39826 m
1 .39826 L
s
.99625 .44511 m
1 .44511 L
s
.99625 .53882 m
1 .53882 L
s
.99625 .58568 m
1 .58568 L
s
.99625 .63253 m
1 .63253 L
s
.99625 .67938 m
1 .67938 L
s
.99625 .77309 m
1 .77309 L
s
.99625 .81995 m
1 .81995 L
s
.99625 .8668 m
1 .8668 L
s
.99625 .91366 m
1 .91366 L
s
.25 Mabswid
1 0 m
1 .98394 L
s
0 .49197 m
1 .49197 L
s
gsave
1.025 .49197 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
-0.00306 0 m
-0.00306 .98394 L
s
gsave
-0.00306 1.00894 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
.03911 .02343 m
.03127 .02343 L
s
% Start of user PostScript
-2. -2. -2.03346 -2. MAarrowhead1
% End of user PostScript
.03911 .14056 m
.02912 .14056 L
s
% Start of user PostScript
-2. -1.5 -2.04262 -1.5 MAarrowhead1
% End of user PostScript
.03911 .2577 m
.02672 .2577 L
s
% Start of user PostScript
-2. -1. -2.05287 -1. MAarrowhead1
% End of user PostScript
.03911 .37483 m
.02466 .37483 L
s
% Start of user PostScript
-2. -0.5 -2.06169 -0.5 MAarrowhead1
% End of user PostScript
.03911 .49197 m
.02381 .49197 L
s
% Start of user PostScript
-2. 0 -2.0653 0 MAarrowhead1
% End of user PostScript
.03911 .6091 m
.02466 .6091 L
s
% Start of user PostScript
-2. 0.5 -2.06169 0.5 MAarrowhead1
% End of user PostScript
.03911 .72624 m
.02672 .72624 L
s
% Start of user PostScript
-2. 1. -2.05287 1. MAarrowhead1
% End of user PostScript
.03911 .84337 m
.02912 .84337 L
s
% Start of user PostScript
-2. 1.5 -2.04262 1.5 MAarrowhead1
% End of user PostScript
.03911 .96051 m
.03127 .96051 L
s
% Start of user PostScript
-2. 2. -2.03346 2. MAarrowhead1
% End of user PostScript
.15624 .02343 m
.14626 .02343 L
s
% Start of user PostScript
-1.5 -2. -1.54262 -2. MAarrowhead1
% End of user PostScript
.15624 .14056 m
.14255 .14056 L
s
% Start of user PostScript
-1.5 -1.5 -1.55845 -1.5 MAarrowhead1
% End of user PostScript
.15624 .2577 m
.13772 .2577 L
s
% Start of user PostScript
-1.5 -1. -1.57907 -1. MAarrowhead1
% End of user PostScript
.15624 .37483 m
.13287 .37483 L
s
% Start of user PostScript
-1.5 -0.5 -1.59978 -0.5 MAarrowhead1
% End of user PostScript
.15624 .49197 m
.13067 .49197 L
s
% Start of user PostScript
-1.5 0 -1.60918 0 MAarrowhead1
% End of user PostScript
.15624 .6091 m
.13287 .6091 L
s
% Start of user PostScript
-1.5 0.5 -1.59978 0.5 MAarrowhead1
% End of user PostScript
.15624 .72624 m
.13772 .72624 L
s
% Start of user PostScript
-1.5 1. -1.57907 1. MAarrowhead1
% End of user PostScript
.15624 .84337 m
.14255 .84337 L
s
% Start of user PostScript
-1.5 1.5 -1.55845 1.5 MAarrowhead1
% End of user PostScript
.15624 .96051 m
.14626 .96051 L
s
% Start of user PostScript
-1.5 2. -1.54262 2. MAarrowhead1
% End of user PostScript
.27338 .02343 m
.26099 .02343 L
s
% Start of user PostScript
-1. -2. -1.05287 -2. MAarrowhead1
% End of user PostScript
.27338 .14056 m
.25485 .14056 L
s
% Start of user PostScript
-1. -1.5 -1.07907 -1.5 MAarrowhead1
% End of user PostScript
.27338 .2577 m
.24517 .2577 L
s
% Start of user PostScript
-1. -1. -1.12042 -1. MAarrowhead1
% End of user PostScript
.27338 .37483 m
.233 .37483 L
s
% Start of user PostScript
-1. -0.5 -1.17237 -0.5 MAarrowhead1
% End of user PostScript
.27338 .49197 m
.22647 .49197 L
s
% Start of user PostScript
-1. 0 -1.20024 0 MAarrowhead1
% End of user PostScript
.27338 .6091 m
.233 .6091 L
s
% Start of user PostScript
-1. 0.5 -1.17237 0.5 MAarrowhead1
% End of user PostScript
.27338 .72624 m
.24517 .72624 L
s
% Start of user PostScript
-1. 1. -1.12042 1. MAarrowhead1
% End of user PostScript
.27338 .84337 m
.25485 .84337 L
s
% Start of user PostScript
-1. 1.5 -1.07907 1.5 MAarrowhead1
% End of user PostScript
.27338 .96051 m
.26099 .96051 L
s
% Start of user PostScript
-1. 2. -1.05287 2. MAarrowhead1
% End of user PostScript
.39051 .02343 m
.37606 .02343 L
s
% Start of user PostScript
-0.5 -2. -0.561692 -2. MAarrowhead1
% End of user PostScript
.39051 .14056 m
.36714 .14056 L
s
% Start of user PostScript
-0.5 -1.5 -0.599784 -1.5 MAarrowhead1
% End of user PostScript
.39051 .2577 m
.35013 .2577 L
s
% Start of user PostScript
-0.5 -1. -0.672375 -1. MAarrowhead1
% End of user PostScript
.39051 .37483 m
.32239 .37483 L
s
% Start of user PostScript
-0.5 -0.5 -0.790787 -0.5 MAarrowhead1
% End of user PostScript
.39051 .49197 m
.30378 .49197 L
s
% Start of user PostScript
-0.5 0 -0.870213 0 MAarrowhead1
% End of user PostScript
.39051 .6091 m
.32239 .6091 L
s
% Start of user PostScript
-0.5 0.5 -0.790787 0.5 MAarrowhead1
% End of user PostScript
.39051 .72624 m
.35013 .72624 L
s
% Start of user PostScript
-0.5 1. -0.672375 1. MAarrowhead1
% End of user PostScript
.39051 .84337 m
.36714 .84337 L
s
% Start of user PostScript
-0.5 1.5 -0.599784 1.5 MAarrowhead1
% End of user PostScript
.39051 .96051 m
.37606 .96051 L
s
% Start of user PostScript
-0.5 2. -0.561692 2. MAarrowhead1
% End of user PostScript
.50765 .02343 m
.49235 .02343 L
s
% Start of user PostScript
0 -2. -0.065302 -2. MAarrowhead1
% End of user PostScript
.50765 .14056 m
.48207 .14056 L
s
% Start of user PostScript
0 -1.5 -0.109181 -1.5 MAarrowhead1
% End of user PostScript
.50765 .2577 m
.46074 .2577 L
s
% Start of user PostScript
0 -1. -0.200238 -1. MAarrowhead1
% End of user PostScript
.50765 .37483 m
.42092 .37483 L
s
% Start of user PostScript
0 -0.5 -0.370213 -0.5 MAarrowhead1
% End of user PostScript
.50765 .49197 m
.39051 .49197 L
s
% Start of user PostScript
0 0 -0.5 0 MAarrowhead1
% End of user PostScript
.50765 .6091 m
.42092 .6091 L
s
% Start of user PostScript
0 0.5 -0.370213 0.5 MAarrowhead1
% End of user PostScript
.50765 .72624 m
.46074 .72624 L
s
% Start of user PostScript
0 1. -0.200238 1. MAarrowhead1
% End of user PostScript
.50765 .84337 m
.48207 .84337 L
s
% Start of user PostScript
0 1.5 -0.109181 1.5 MAarrowhead1
% End of user PostScript
.50765 .96051 m
.49235 .96051 L
s
% Start of user PostScript
0 2. -0.065302 2. MAarrowhead1
% End of user PostScript
.62478 .02343 m
.61033 .02343 L
s
% Start of user PostScript
0.5 -2. 0.438308 -2. MAarrowhead1
% End of user PostScript
.62478 .14056 m
.60141 .14056 L
s
% Start of user PostScript
0.5 -1.5 0.400216 -1.5 MAarrowhead1
% End of user PostScript
.62478 .2577 m
.5844 .2577 L
s
% Start of user PostScript
0.5 -1. 0.327625 -1. MAarrowhead1
% End of user PostScript
.62478 .37483 m
.55666 .37483 L
s
% Start of user PostScript
0.5 -0.5 0.209213 -0.5 MAarrowhead1
% End of user PostScript
.62478 .49197 m
.53805 .49197 L
s
% Start of user PostScript
0.5 0 0.129787 0 MAarrowhead1
% End of user PostScript
.62478 .6091 m
.55666 .6091 L
s
% Start of user PostScript
0.5 0.5 0.209213 0.5 MAarrowhead1
% End of user PostScript
.62478 .72624 m
.5844 .72624 L
s
% Start of user PostScript
0.5 1. 0.327625 1. MAarrowhead1
% End of user PostScript
.62478 .84337 m
.60141 .84337 L
s
% Start of user PostScript
0.5 1.5 0.400216 1.5 MAarrowhead1
% End of user PostScript
.62478 .96051 m
.61033 .96051 L
s
% Start of user PostScript
0.5 2. 0.438308 2. MAarrowhead1
% End of user PostScript
.74192 .02343 m
.72953 .02343 L
s
% Start of user PostScript
1. -2. 0.947129 -2. MAarrowhead1
% End of user PostScript
.74192 .14056 m
.7234 .14056 L
s
% Start of user PostScript
1. -1.5 0.920928 -1.5 MAarrowhead1
% End of user PostScript
.74192 .2577 m
.71371 .2577 L
s
% Start of user PostScript
1. -1. 0.879581 -1. MAarrowhead1
% End of user PostScript
.74192 .37483 m
.70154 .37483 L
s
% Start of user PostScript
1. -0.5 0.827625 -0.5 MAarrowhead1
% End of user PostScript
.74192 .49197 m
.69501 .49197 L
s
% Start of user PostScript
1. 0 0.799762 0 MAarrowhead1
% End of user PostScript
.74192 .6091 m
.70154 .6091 L
s
% Start of user PostScript
1. 0.5 0.827625 0.5 MAarrowhead1
% End of user PostScript
.74192 .72624 m
.71371 .72624 L
s
% Start of user PostScript
1. 1. 0.879581 1. MAarrowhead1
% End of user PostScript
.74192 .84337 m
.7234 .84337 L
s
% Start of user PostScript
1. 1.5 0.920928 1.5 MAarrowhead1
% End of user PostScript
.74192 .96051 m
.72953 .96051 L
s
% Start of user PostScript
1. 2. 0.947129 2. MAarrowhead1
% End of user PostScript
.85906 .02343 m
.84907 .02343 L
s
% Start of user PostScript
1.5 -2. 1.45738 -2. MAarrowhead1
% End of user PostScript
.85906 .14056 m
.84536 .14056 L
s
% Start of user PostScript
1.5 -1.5 1.44155 -1.5 MAarrowhead1
% End of user PostScript
.85906 .2577 m
.84053 .2577 L
s
% Start of user PostScript
1.5 -1. 1.42093 -1. MAarrowhead1
% End of user PostScript
.85906 .37483 m
.83568 .37483 L
s
% Start of user PostScript
1.5 -0.5 1.40022 -0.5 MAarrowhead1
% End of user PostScript
.85906 .49197 m
.83348 .49197 L
s
% Start of user PostScript
1.5 0 1.39082 0 MAarrowhead1
% End of user PostScript
.85906 .6091 m
.83568 .6091 L
s
% Start of user PostScript
1.5 0.5 1.40022 0.5 MAarrowhead1
% End of user PostScript
.85906 .72624 m
.84053 .72624 L
s
% Start of user PostScript
1.5 1. 1.42093 1. MAarrowhead1
% End of user PostScript
.85906 .84337 m
.84536 .84337 L
s
% Start of user PostScript
1.5 1.5 1.44155 1.5 MAarrowhead1
% End of user PostScript
.85906 .96051 m
.84907 .96051 L
s
% Start of user PostScript
1.5 2. 1.45738 2. MAarrowhead1
% End of user PostScript
.97619 .02343 m
.96835 .02343 L
s
% Start of user PostScript
2. -2. 1.96654 -2. MAarrowhead1
% End of user PostScript
.97619 .14056 m
.96621 .14056 L
s
% Start of user PostScript
2. -1.5 1.95738 -1.5 MAarrowhead1
% End of user PostScript
.97619 .2577 m
.9638 .2577 L
s
% Start of user PostScript
2. -1. 1.94713 -1. MAarrowhead1
% End of user PostScript
.97619 .37483 m
.96174 .37483 L
s
% Start of user PostScript
2. -0.5 1.93831 -0.5 MAarrowhead1
% End of user PostScript
.97619 .49197 m
.96089 .49197 L
s
% Start of user PostScript
2. 0 1.9347 0 MAarrowhead1
% End of user PostScript
.97619 .6091 m
.96174 .6091 L
s
% Start of user PostScript
2. 0.5 1.93831 0.5 MAarrowhead1
% End of user PostScript
.97619 .72624 m
.9638 .72624 L
s
% Start of user PostScript
2. 1. 1.94713 1. MAarrowhead1
% End of user PostScript
.97619 .84337 m
.96621 .84337 L
s
% Start of user PostScript
2. 1.5 1.95738 1.5 MAarrowhead1
% End of user PostScript
.97619 .96051 m
.96835 .96051 L
s
% Start of user PostScript
2. 2. 1.96654 2. MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 .98394 L
0 .98394 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{110.25, 108.3125},
  ImageMargins->{{106.9375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002:0000R0800@400h[o002:o`00R_l008[o002:
o`00R_l008[o002:o`00R_l001Co00<001Co00<001;o00<l01?o00<001Co00<001[o000Do`03?00E
o`03?00@o`03<00Eo`03?00Co`03?00Jo`003ol00`001o`=o`030007o0oo00<`01Go00<l01Co00<l
01Wo000Do`03<00Eo`03?00@o`03<00Eo`03?00Co`03<00Jo`005Ol00``04ol00``04_l00c`04ol0
0``05Ol00``06Ol008[o002:o`00R_l008[o002:o`002?l01P?`06@06?l000So00@o00K`1LlCo`03
?00Do`03?00Do`03?00Do`03<00Ho`0000Gl00Po1l<00c`01_l00`002?l00`002Ol00`002?l00`00
2Ol00`002?l00`002Ol00`002Ol010006?l000So00@c00K`1L<7o`033008o`033009o`033008o`03
3009o`033008o`033009o`033009o`03000Ho`002Ol00``01_1Oo`03?00Fo`003_l00``0H?l00c`0
5_l000ko00<<063o00<l01Ko000>o`03301Oo`03300Go`003_l00``0H?l00c`05_l000ko00<<063o
00<l01Ko000>o`03301Po`03?00Fo`003_l00``0Gol00``05ol000ko00<<063o00<l01Ko000>o`H?
00<l00Oo00<<00So00<<00So00<<00So00<<00Wo00<<00Wo00<<00Wo00<<00So00@001So000>o`H?
00<l00Ko00<000So00<000So00<000So00@000So00<000Wo00<000Wo00<000Wo00@001So000>o`03
301Po`03?00Fo`003_l00``0Gol00``05ol000ko00<<063o00<l01Ko000>o`03301Po`03?00Fo`00
3_l00``0H?l00c`05_l000ko00<<063o00<l01Ko000>o`03301Oo`03300Go`003_l00``0H?l00c`0
5_l000So00@300K`Gol00c`05_l000Wo00<l00K`Gol00c`05_l00005o008?`03`005`0Oo00<000So
00@000Ko1@06o`H01_l500So00@000So00<000Wo1@0Ho`002Ol00c`01_05c`Ko00<<00So00<<00Oo
00<<00So00<<00Wo00<<00[o00<<00Wo00<<00Wo00@<01So0008o`043`06l5oo00<l01Ko000>o`03
301Po`03?00Fo`003_l00``0H?l00c`05_l000ko00<<05oo00<<01Oo000>o`03301Po`03?00Fo`00
3_l00``0H?l00c`05_l000ko00<<063o00<l01Ko000>o`03301Oo`03300Go`003_l00``0H?l00c`0
5_l000ko20l7o`033006o`030006o`033007o`03300:o`03300;o`03000;o`033009o`04300Ho`00
3_l730Oo00<000Oo1@000o`020000o002@000o`02007o`D02?l00`002Ol50aSo000>o`03301Po`03
?00Fo`003_l00``0Gol00``05ol000ko00<<063o00<l01Ko000>o`03301Po`03?00Fo`003_l00``0
H?l00c`05_l000ko00<<063o00<l01Ko000>o`03301Oo`03300Go`003_l00``0H?l00c`05_l000Wo
00<l00K`Gol013l01L`00o001L`00o001Ll000So00@c00K`Gol00c`01o`7c0K`0L01`0002?l01S?`
06@01Ol013l01l`7o0700008o`04<`0:l0Oo00<<00Ko00<<00Go00<<00Go00<<00co00<l00co00<<
00_o00<l00Wo00D<`0Gl1Sl010l01_01`0700009o`03?006l5oo00<l01Ko000>o`03301Po`03?008
o`03?00;o`003_l00``0H?l00c`05_l000ko00<<05oo00<<01Oo000>o`03301Po`03?00Fo`003_l0
0``0H?l00c`05_l000ko00<<063o00<l01Ko000>o`03301Oo`03300Go`003_l00``0H?l00c`05_l0
00ko20l7o`033006o`030006o`033007o`03300:o`03300;o`03000;o`033009o`04300Ho`003_l7
30Oo00<000Oo1@000o`020000o002@000o`02007o`D02?l00`002Ol50aSo000>o`03301Po`03?00F
o`003_l00``0Gol00``05ol000ko00<<063o00<l01Ko000>o`03301Po`03?00Fo`003_l00``0H?l0
0c`05_l000ko00<<063o00<l01Ko000>o`03301Oo`03300Go`003_l00``0H?l00c`05_l000So00@3
00K`Gol00c`05_l000Wo00<l00K`Gol00c`05_l000Wo00<l00G`00<000So00<000So00@000Ko1@06
o`H01_l500So00@000So00<000Wo1@0Ho`002Ol00c`01_05c`Ko00<<00So00<<00Oo00<<00So00<<
00Wo00<<00[o00<<00Wo00<<00[o00<`01So0008o`043`06l5oo00<l01Ko000>o`03301Po`03?00F
o`003_l00``0H?l00c`05_l000ko00<<05oo00<<01Oo000>o`03301Po`03?00Fo`003_l00``0H?l0
0c`05_l000ko00<<063o00<l01Ko000>o`03301Oo`03300Go`003_l00``0H?l00c`05_l000ko1Pl0
0c`01_l00`002?l00`002?l00`002Ol00``02?l00`002Ol00`002Ol00`002Ol010006?l000ko1Pl0
0c`01_l00`002?l00`002?l00`002?l010002?l00`002Ol00`002Ol00`002Ol010006?l000ko00<<
063o00<l01Ko000>o`03301Oo`03300Go`003_l00``0H?l00c`05_l000ko00<<063o00<l01Ko000>
o`03301Po`03?00Fo`003_l00``0H?l00c`05_l000ko00<<05oo00<<01Oo000>o`03301Po`03?00F
o`002?l010<01_1Oo`03?00Fo`002?l013l01_1Oo`03?00Fo`002Ol00c`02?000c`01_l00`002?l0
0`002Ol00`002?l00`002Ol00`002?l00`002Ol00`002Ol010006?l000So00@c00K`1L<7o`033009
o`03?008o`033008o`033009o`033009o`03?008o`033009o`03000Ho`002Ol01@o0I00Ho`00R_l0
08[o002:o`001_l00c`0POl000Oo00<l083o0007o`04?`07c003l005cg3o0006o`03<005o004<`06
l7;o0006o`03<005o004<`07o77o0006o`03<005o0043`06l7;o002:o`003?l00c`0Nol008[o002:
o`00R_l008[o002:o`00R_l008[o002:o`00R_l00001\
\>"],
  ImageRangeCache->{{{0, 136.8125}, {134.375, 0}} -> {-2.829287, -2.87411, 
  0.054373, 0.054373}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Electric Field in the $x-y$ Plane"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig16x3 = 
      DensityPlot[
        Evaluate[Abs[Edx[x\ a, a\ y, a]]\^2], {x, \(-2\), 2}, {y, \(-2\), 2}, 
        AxesLabel \[Rule] {"\<x in a\>", "\<y in a\>"}, Evaluate[opt1]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25962 -0.0125 -7 -12 ]
[.25962 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.74038 -0.0125 -4 -12 ]
[.74038 -0.0125 4 0 ]
[.98077 -0.0125 -4 -12 ]
[.98077 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25962 -14 -6 ]
[-0.0125 .25962 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .74038 -8 -6 ]
[-0.0125 .74038 0 6 ]
[-0.0125 .98077 -8 -6 ]
[-0.0125 .98077 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000001010101010202020202020303030303
030302020202020201010101010000000000000000
000000000000010101010102020202030303030303040404
030303030303020202020101010101000000000000
000000000001010101020202020303030404040404050505
040404040403030302020202010101010000000000
000000000101010102020203030404040505050606060606
060605050504040403030202020101010100000000
000000010101010202030303040405050606070707070707
070707060605050404030303020201010101000000
000001010101020203030404050606070708080909090909
090908080707060605040403030202010101010000
00010101010202030304050506070808090A0B0B0C0C0C0C
0C0B0B0A0908080706050504030302020101010100
0001010102020303040506060708090A0C0C0D0E0F0F0F0F
0F0E0D0C0C0A090807060605040303020201010100
010101020203030405060708090A0C0D0E10111213131313
131211100E0D0C0A09080706050403030202010101
0101020203030405060708090B0C0E101214151618181818
1816151412100E0C0B090807060504030302020101
01010202030405060708090B0D0F111416181B1C1E1F1F1F
1E1C1B181614110F0D0B0908070605040302020101
010202030304050608090B0D101215181B1E212426272827
2624211E1B181512100D0B09080605040303020201
0102020304050607090B0D1013161A1E22262A2D30323232
302D2A26221E1A1613100D0B090706050403020201
02020304040607080A0C0F12161A1F24292F34393D3F403F
3D39342F29241F1A16120F0C0A0807060404030202
02020304050608090C0E11151A1F252B323A41474D505150
4D47413A322B251F1A15110E0C0908060504030202
020303040507080A0D1014181E242B343D46505960646664
605950463D342B241E1814100D0A08070504030302
020304050607090C0E12161B2229323D4855616C767C7E7C
766C6155483D3229221B16120E0C09070605040302
0203040506080A0C1014181E262F3A46556474828E969996
8E82746455463A2F261E1814100C0A080605040302
0203040507080B0D11151B212A34415061748799A8B3B6B3
A8998774615041342A211B15110D0B080705040302
0303040607090B0E12161C242D3947596C8299AFC1CED2CE
C1AF99826C5947392D241C16120E0B090706040303
0303040607090C0F13181E26303D4D60768EA8C1D7E5EAE5
D7C1A88E76604D3D30261E18130F0C090706040303
0304050607090C0F13181F27323F50647C96B3CEE5F4FAF4
E5CEB3967C64503F32271F18130F0C090706050403
0304050607090C0F13181F28324051667E99B6D2EAFAFFFA
EAD2B6997E66514032281F18130F0C090706050403
0304050607090C0F13181F27323F50647C96B3CEE5F4FAF4
E5CEB3967C64503F32271F18130F0C090706050403
0303040607090C0F13181E26303D4D60768EA8C1D7E5EAE5
D7C1A88E76604D3D30261E18130F0C090706040303
0303040607090B0E12161C242D3947596C8299AFC1CED2CE
C1AF99826C5947392D241C16120E0B090706040303
0203040507080B0D11151B212A34415061748799A8B3B6B3
A8998774615041342A211B15110D0B080705040302
0203040506080A0C1014181E262F3A46556474828E969996
8E82746455463A2F261E1814100C0A080605040302
020304050607090C0E12161B2229323D4855616C767C7E7C
766C6155483D3229221B16120E0C09070605040302
020303040507080A0D1014181E242B343D46505960646664
605950463D342B241E1814100D0A08070504030302
02020304050608090C0E11151A1F252B323A41474D505150
4D47413A322B251F1A15110E0C0908060504030202
02020304040607080A0C0F12161A1F24292F34393D3F403F
3D39342F29241F1A16120F0C0A0807060404030202
0102020304050607090B0D1013161A1E22262A2D30323232
302D2A26221E1A1613100D0B090706050403020201
010202030304050608090B0D101215181B1E212426272827
2624211E1B181512100D0B09080605040303020201
01010202030405060708090B0D0F111416181B1C1E1F1F1F
1E1C1B181614110F0D0B0908070605040302020101
0101020203030405060708090B0C0E101214151618181818
1816151412100E0C0B090807060504030302020101
010101020203030405060708090A0C0D0E10111213131313
131211100E0D0C0A09080706050403030202010101
0001010102020303040506060708090A0C0C0D0E0F0F0F0F
0F0E0D0C0C0A090807060605040303020201010100
00010101010202030304050506070808090A0B0B0C0C0C0C
0C0B0B0A0908080706050504030302020101010100
000001010101020203030404050606070708080909090909
090908080707060605040403030202010101010000
000000010101010202030303040405050606070707070707
070707060605050404030303020201010101000000
000000000101010102020203030404040505050606060606
060605050504040403030202020101010100000000
000000000001010101020202020303030404040404050505
040404040403030302020202010101010000000000
000000000000010101010102020202030303030303040404
030303030303020202020101010101000000000000
000000000000000001010101010202020202020303030303
030302020202020201010101010000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{110.25, 110.25},
  ImageMargins->{{106.9375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002:0000RQ000`40l00?003`R_oo002:ool008[o
o`00R_oo002:ool008[oo`00R_oo002:ool008[oo`004_oo0`0?5?oo0`0?4ooo00<03oooool05?oo
0`0?5?oo0`0?6_oo000Bool00`0?ooooo`0Eool00`0?ooooo`0Aool00`0?ool03`0Fool00`0?oooo
o`0Cool00`0?ooooo`0Jool000goo`<03`?oo`0300oooooo00ooo`<03`;oo`0300oooooo017oo`03
00ooo`0?01Koo`0300oooooo01Coo`0300oooooo01Woo`004_oo00<03ooo00l05Ooo00<03oooool0
4Ooo00<03ooo00l05_oo00<03oooool04ooo00<03ooo00l06_oo000Cool200lDool200lDool00`0?
ooooo`0Dool200lFool200lJool008[oo`00R_oo001fool00`0?ool03`03ool01@0?ool03ooo00l0
0ooo00<03ooo00l00ooo001gool00`0?ooooo`02ool01@0?ool03ooo00l00ooo0P0?1?oo0008ool3
00m/ool00`0?ooooo`02ool01@0?ool03ooo00l01?oo00<03oooool00_oo0008ool00`0?ooooo`04
oomS00l4ool00`0?ool03`03ool0100?ool03`0?1?oo0P0?1?oo0003ool300l3ool00`0?ooooo`03
ool00`0?ool03`0Fool00`0?ooooo`0Eool00`0?ooooo`0Dool00`0?ooooo`0Eool00`0?ool03`0H
ool000Soo`0300ooo`0?00Coo`0300ooo`0?01803`0540l03`0?00l@3`0300l01A0?00l03`0?40l0
0`0?01D@3`0?00l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l00`0?00D@3`0?00l0
3a0?00<03`0540l03`0?00l@3`0300l00a0?00l03`0@00l00ooo00l03`0:ool00`0?ooooo`0;ool0
00Woo`803`Coo`0300ooo`0?01003`050@l03`0?00l13`0300l01@4?00l03`0O0@l00P0?00H07`4?
00l03`0O0@l200l03P0O0@l03`4?01l13`0?0@l07`4?00l13`0O0@l200l01P0O0@l03`0?01l13`80
3`0301l13`0?00803`050@l03`0?00l13`0300l00`4?00l03`0>00l2ool00`0?ooooo`0Fool000oo
o`0300ooo`0?01P03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00T@3`0?00l03a0?00l@
3`0?40l00`0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l00a0?00l03`0F00l2ool00`0?
ooooo`0Fool000ooo`0300ooo`0?00d03`0501l03`0?00l07`0300l01P0O0@l03`0?01l13`803`0R
01l13`0O00l07`4?01l03`0O0@l07`0?01l13`0O0@l07`4?01l13`0O0@l07`0?01l13`0O00l07`4?
01l03`0O0@l200l01@0O0@l03`0?01l00`0?00D07`0?00l03`0O00l03`;oo`0300oooooo01Koo`00
3ooo00<03ooo00l02P0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l0:A0?00l@3`0?40l0
3a0?00l@3`0?40l03a0?00l@3`0?40l03a0?0@l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l0
3a0?00l@3`0?40l00`0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0:00l2ool00`0?ooooo`0F
ool000ooo`0300ooo`0?00`03`050@l03`0?00l13`0200l0;P0O0@l03`0?01l13`0?0@l07`4?00l1
3`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l1
3`0?0@l07`4?0P0?00H07`4?00l03`0O0@l300l01@4?00l03`0?0@l0300?00?oo`0?00l06?oo000?
ool00`0?ool03`0D00l01A0?00l03`0?40l00`0?024@3`0?00l03a0?00l@3`0?40l03a0?00l@3`0?
40l03a0?00l@7`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l00`0?00D@3`0?00l03a0?00<03`03
40l03`0?01803`;oo`0300oooooo01Koo`003ooo00<03ooo00l02@0?00D07`0?00l03`0O00<03`0f
01l13`0?00l07`4?01l03`0O0@l07`4?01l13`0O0@l07`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?
41l13`0O0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l07`4?01l13`0O00l07`4?0P0?00D07`4?00l0
3`0O00<03`0301l03`0?00T03`;oo`0300oooooo01Koo`003ooo00<03ooo00l02P0?00D@3`0?00l0
3a0?00<03`0e40l03`0?00l@3`0?40l03a0?00l@3`0?40l03a0?0@l@3`0?40l13a0?00l@7`4?40l0
3a0O0@l@3`0?41l13a0?00l@7`4?40l03a0?0@l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0300l0
1A0?00l03`0?40l00`0?00<@3`0?00l0200?0_oo00<03oooool05_oo000?ool00`0?ool03`0800l0
1@4?00l03`0?0@l00P0?03h07`4?00l13`0O0@l03`4?01l13`0O0@l07`4?01l13`0O0@l@7`4?01l1
3a0O0@l07`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l@7`4?01l13`0O0@l07`4?01l1
3`0O0@l03`4?01l13`0?0@l07`4?0`0?00D13`0?00l03`4?00P03`03ool03`0?01Soo`003ooo00<0
3ooo00l0400?00D@3`0?00l03a0?00<03`0]40l03a0?00l@3`0?41l03a0?00l@7`4?40l03a0O0@l@
7`0?41l13a0O00l@7`4?41l03a0O0@l@7`0?41l13a0?00l@7`4?40l03a0O00l@3`0?40l03a0?00<0
3`0540l03`0?00l@3`0@00l2ool00`0?ooooo`0Fool000ooo`0300ooo`0?00D03`0501l03`0?00l0
7`0300l0@P0O0@l03`0?01l13`0O0@l07`4?01l13`0O0@l@7`4?01l13a0O0@l@7`4?41l13a0O0@l@
7`4?41l17a0O0@l@7`4O41l13a0O0Al@7`4?41l13a0O0@l@7`4?41l13a0O0@l@7`4?01l13a0O0@l0
7`4?01l13`0O0@l07`0?01l13`803`0501l03`0?00l07`0700l2ool00`0?ooooo`0Fool000ooo`03
00ooo`0?00H03`0540l03`0?00l@3`0300l0@A0?00l@3`0?40l03a0?00l@3`0?40l13a0?00l@7`4?
40l13a0O0@l@3`4?41l13a0O4@l@7`4?41lA3a0O0@l@7a4?41l13a0O4@l@7`4?41l13a0O0@l@3`4?
41l13a0?00l@7`4?40l03a0?00l@3`0?40l03a0?00l@3`0?40l00`0?00D@3`0?00l03a0?00H03`;o
o`0300oooooo01Koo`003ooo00<03ooo00l0100?00D13`0?00l03`4?00803`1601l13`0?0@l07`4?
00l13`0O0@l07`4?01l13a0O0@l07`4?41l13a0O0@lA7`4?41l17a4O0@lA7`4O4Al17a4O0AlA7`4O
4Al17a4O0AlA7`4O4Al13a4O0AlA7`4?41l13a0O0@l@7`4?41l13`0O0@l07`4?01l13`0O0@l07`4?
00l13`0O0@l300l01@4?00l03`0?0@l0100?0_oo00<03oooool05_oo000?ool00`0?ool03`0<00l0
@A0?00l03`0?40l03a0?00l@3`0?41l03a0?00l@7`4?41l13a0O0@l@7`4?41l13a0O4@l@7`4?41lA
3a0O4@l@7a4?41lA3a0O4@l@7a4?41lA3a0O0@l@7a4?41l13a0O0@l@7`4?41l03a0O0@l@3`0?41l0
3a0?00l@3`0?40l00`0?00<@3`0?00l02P0?00?oo`0?00l06?oo000?ool01@0?ool03`0?01l00`0?
00H07`0?00l03`0O0@l200l0600O0@l07`4?01l13a0O0@l07`4?41l13a0O0@l@7`4?41l17a4O0@lA
7`4O4Al17`<A7`030AlA7a4O00TA7`0O0AlA7a4O4Al17a4O0AlA7`4?41l17a0O0@l@7`4?41l13`0O
0@l@7`4?01l13`0O0@l07`4?01l03`0O0@l00P0?00D07`0?00l03`0O00<03`;oo`0300oooooo01Ko
o`003ooo00<03ooo00l00P0?00D@3`0?00l03a0?00<03`0M40l03a0?00l@3`0?40l03a0?00l@7`4?
40l03a0O0@l@7`4?41l13a0O4@l@7a4?41lA3a0O4@l@7`024Al01A4?4AlA7a4O4@l00a4O028A3a4O
4AlA7a4?41lA3a0O4@l@7a4?41l13a0O4@l@7`4?40l13a0O0@l@3`0?41l13a0?00l@3`0?40l03a0?
00l@3`<03`0540l03`0?00l@3`0200l2ool00`0?ooooo`0Fool000ooo`0400ooo`0?0@l300l07`4?
00l03`0O0@l03`4?01l13`0?0@l07`4?01l13`0O0@l@7`4?41l13a4O0@l@7`4O4Al17a4O0AlA7`4O
00DA7`054QlA7a4O4BlB7`024Al01Q4_4QlA7a4O4BlB7`DA7`0K0AlA7`4O4Al17a4O0AlA7`4?41l1
3a0O0@l07`4?41l13`0O0@l07`4?01l13`0?0@l07`4?00<03`050@l03`0?00l13`02ool00`0?oooo
o`0Fool000ooo`0300ooo`0?00P03`0I40l03`0?00l@3`0?40l03a0?00l@7`4?41l03a0O0@l@7`4?
41l13a0O4@l@7a4?41l00a4O00<@7a4O4Al01A4O00DQ7a4O4AlA7b4O00LA7`0I41lA7a4O4@l@7a4O
41lA3a0O4@l@7`4?41l13a0O0@l@7`0?41l03a0?00l@3`0?40l00`0?00<@3`0?00l01P0?0_oo00<0
3oooool05_oo000?ool01@0?ool03`0?01l00`0?01P07`4?00l03`0O0@l07`4?01l13a0O0@l07`4?
41l13a0O0Al@7`4O41l17a4O0Al44Al06A4_4AlA;a4O4BlB7b4_4QlQ;a8O8BlB7b4_4QlQ;a8O8BlB
7b4_4QlA;a8O4BlA7a4_00HA7`0G0AlA7`4O4Al13a0O0@l@7`4?41l13a0O0@l07`4?01l13`0O0@l0
7`0?01l13`0200l01@0O00l03`0?ool00P0?6?oo000?ool00`0?ool03`0200l07A0?00l03`0?40l0
3a0?00l@3`0?40l03a0?00l@7`4?40l13a0O0@l@7a4?41lA3a0O4@lA7a4?41l00a4O01TQ7a4O8AlA
7b4O4AlQ7a8O8AlB7b4_4QlQ7a8O8BlB7b4O4QlQ7a8O8AlA7b4O4AlQ7`024Al06Q4?41lA7a0O4@l@
7a4?41l13a0O0@l@7`4?40l03a0O0@l@3`0?40l03a0?00l@3`0?40l300l00a0?00l03`02ool00`0?
ooooo`0Fool000Soo`<03`Coo`0400ooo`0?0@l200l0600O0@l03`0?01l13`0?0@l07`4?01l13`0O
0@l@7`4?41l13a4O0@lA7`4O4Al17`@A7`0<4BlB7a4_4QlA;a8O8RlB7b8_4RlR;a8_0b8_00lB;b8_
8RlR;a8_8RlB;b8_4QlQ;a8O8BlB7a4_4Ql01A4O01<17a4O0AlA7`4?41l13a0O0@l07`4?41l13`0O
0@l07`4?01l13`0200l00`0O0@l03`0200l0104?ooooo`0?6?oo0009ool00`0?ooooo`03ool00`0?
ool03`0400l05A0?00l03`0?40l03a0?00l@3`0?41l13a0O00l@7`4?41l13a0O0@l@7`074Al03B4O
4AlQ;a8O8BlR7b4_4QlQ;b8_8BlR7b4_008R;`0>8QlQ;b8_8BlR7b4_8QlQ;a8O8BlA7b4_4AlQ7`<A
7`0E41lA7a0O4@l@7a4?41l13a0O0@l@7`4?41l03a0O00l@3`0?40l03a0?00<03`0340l03`0?0080
3`;oo`0300oooooo01Koo`000ooo0`0?0ooo00<03oooool00ooo00H03ooo00l03`0O0@l200l04@0O
0@l07`0?01l13`0O0@l07`4?41l13a0O0Al@7`4O41l01Q4O00TB7a4_4QlQ;a8O8BlB;b8_4Rl0128_
00dR?b<_<SlS;b8o8blb?b<_8SlS;b8o8RlR?`028Rl02Q8_8RlB;b8_4QlQ;a8O4BlA7a4_0Q4O01<1
7a4O0AlA7`4O41l17a0O0@l07`4?41l13`0O0@l07`0?01l13`0200l01@0O0@l03`0?ool00P0?6?oo
0009ool00`0?ooooo`03ool00`0?ool03`0200l0910?00l03`0?40l03a0?00l@3`0?40l13a0?00l@
7`4?41lA3a0O4@l@7a4?4AlA3b4O4AlQ7a4O8AlB7b4_4QlQ;b8O8RlR7`@R;`09<RlR;c8_8blb;b8_
<RlR;c8_00HR;`068QlQ;b8O8BlB7b4O1Q4O018A3a0O4@l@7`4?41l13a0O0@l@3`0?40l03a0?00l@
3`0?40l300l00a0?00l03`02ool00`0?ooooo`0Fool000Soo`803`Goo`0400ooo`0?0@l200l07P0O
0@l03`4?01l13`0O0@l07`4?41l13`0O0@lA7`4?4Al17a4O0AlA7a8O4AlB7a4_4QlR;a8O8RlB;`8R
;`088SlS;c8o8blc?b<o<clS?`<c?`0<8clc?c<o<clS?c<o8clc?b<_<SlS;b8o0R8_00PB;b8_4QlQ
;a8O4BlA7a4_0Q4O01<17a4O0AlA7`4?41l13a0O0@l07`4?01l13`0O0@l03`4?01l13`0300l0104?
ooooo`0?6?oo000?ool00`0?ool03`0400l04A0?00l03`0?40l03a0O00l@3`0?41l13a0O0@l@7`4?
41l00a4O00TQ7a4O8BlA7b4_4QlQ;b8O8Bl00b8_00Tb;b<_<SlS;c8o<clb?c<o<Sl00c<o00Tb?c<o
<Slc;c8o<blb?b<_<Rl00b8_00DQ;b8_8BlB7b4O00<A7`0A41lA7a0O4@l@7a4?41l13a0O00l@7`4?
40l03a0O00l@3`0300l00a0?00l03`0200l2ool00`0?ooooo`0Fool000ooo`0600ooo`0?00l07`4?
0P0?01007`4?01l13`0O0@l@7`4?01l13a0O0@l@7`4O4Al17`@A7`084BlB7b4_4QlQ;a8_8RlB;`8R
;`068SlS;c8o8blc?b<o2c<o00HS?c8o8blb?b<_8Sl28Rl01a8_8RlB;b4_4QlA;a8O00DA7`0?0Al@
7`4O41l13a0O0@l@7`4?01l13`0O0@l07`4?00803`0401l13`0?00l2ool00`0?ooooo`0Fool000oo
o`0300ooo`0?00803`0M40l03a0?00l@3`0?40l03a0?00l@7`4?41l13a0O0@l@7a4?4AlA3b4O4AlQ
7a8O8BlR7b8_8QlQ;`028Rl00b<_<Rlc;`02<cl04D<o<cm3Cc@o@dm4?d=?A3m3Cd@o@dld?d=?A3m3
Cc@o@cl00S<o00<c;c8_8bl00R8_00DQ;b8_8BlB7b4O00HA7`0B4@l@7a4?41l13a0O0@l@7`4?40l0
3a0?00l@3`0?40l03a0?0P0?00?oo`0?00l06?oo000?ool0100?ool07`4?0P0?01007`4?01l13`0O
0@l07`4?01l13a0O0@l@7`4O4Al17`DA7`044QlA;a8O8Bl28Rl01a8_8SlS;c8o8blc?b<o008c?`0?
<dld?dA?=3m4CcA?A4ldCdA?=4m4Cc@o@dld?d=?008c?`0?8clc?b<_8SlS;b8_4RlR;a8O8RlB7a4_
4QlA7`4O00<A7`0?0Al@7`4O41l13`0O0@l@7`4?01l13`0O0@l07`4?00803`0501l13oooool03`0H
ool000ooo`0400ooo`0?40l300l0410?00l@3`0?40l03a0O0@l@7`4?41l13a0O4@lA7a4?0Q4O00LQ
7a4O8BlB7b8_8Qlb;`028Rl06R<_<Slc?c<o=3m3CdA?@dm4CeA?ADmDGdE?E5mECeAOADmDGdE?E5m5
CeA?A4m3Cd@o@dl3<cl02C8o8blR;b8_8BlR;b4_4QlQ7`064Al03Q4?41l13a0O0@l@7`0?41l03a0?
00l@3`0?40l300l0110?ooooo`0?6?oo000?ool0500?ool03`0?01l13`0O00l07`4?01l13`0O0@l@
7`4?41l17a0O0Al54Al0118O4BlB7b4_0b8_00@R?b<_<SlS;`8c?`0C@dld?dA?A4m4GdA?E5m5GeEO
AEmEGdEOEEm5GeAOAEmDGdA?A5l00TA?00hd?d=?<clc?b<_<SlS;b8o4RlR;a8_8BlB7a4_1Q4O00l1
7a0O0Al@7`4?01l13a0O0@l07`4?01l03`0O0@l00P0?0_oo00<03oooool05_oo000?ool00`0?ool0
3`0200l0410?00l@3`0?40l03a0?0@l@3`4?41l13a0O4@lA7a4?0Q4O00/Q7a4O8AlB7b8_8Qlb;b8_
<SlS;c8o008c?`0:=3m3CdA?A4mECeAOEEmUGeIOIFl6IVl01eIOIFmVGfEOEEmDGeE?0094C`06@dm4
?c<o<clb?c<_0R8_01TQ;b8O8BlB7b4O4AlQ7a4?4AlA3a4O0@l@7`4?41l13a0?00l@3`0?40l03a0?
00l@3`0200l2ool00`0?ooooo`0Fool000ooo`0L00ooo`0O0@l03`4?01l13`0O0@l07`4?01l13`0O
0@l@7`4?41l17a4O0AlA7a8O4AlB7a4_4Rl28Rl0428o8blc?b<_<cld?dA?=3m4GdE?EEm5CeE_EUmV
KeIO1fI_02aFGfE_EUmEKdE?EEm5CdA?=3m3Cc@o<clS;c8o8blR;a8_8RlB7b4_4QlA;a8O4Al17a4O
0AlA7`4?41l13a0O0@l07`4?01l13`0O0@l03`4?01l13ooo0P0?6?oo000?ool0100?ool03a0?0`0?
00d@3`0?41l03a0?00l@7`4?41l13a0O4@l@7`034Al0124O4AlQ;a8O0R8_00<b?b<_<Sl00S<o00@d
?d=?A4mDC`9EG`04IUmUKfM_MVl3Mgl01HMoMgn7SgMoQgl00gMo00AfKfI_IFmFG`9EG`04E4m4Cd=?
A3l2<cl02C8o8RlR;b8_8BlR7b4_4AlQ7`024Al03Q4?41lA3a0O0@l@7`0?41l13a0?00l@7`0?40l3
00l0110?ooooo`0?6?oo000?ool0500?ool03`0?01l13`0O0@l07`4?41l13`0O0@l@7`4?41l17a4O
0Al34Al00a8O4BlB;`038Rl00b<_<Slc?`02<cl014A?=3m4GdE?0UEO00AUKeI_MWmWK`9gO`06Qhmh
OhN?N7n7SgQo0gMo00AWKfIoEVmVK`9EG`04ADm4Gc@o@dl2<cl02R<_<SlR;b8_4QlQ;a8O8BlB7a4_
0Q4O00l17a4O0Al@7`4?41l13a0O0@l07`4?01l13`0O0@l00P0?0_oo00<03oooool05_oo000?ool0
0`0?ool03`0200l07A0?00l@3`4?40l03a0O0@l@7`4?41l13a0O4@lA7a4?8AlA7b4_4QlQ;b8O<RlR
;c8o<bm3Cc@o@cl00TA?0UEO0VI_00MgKgIoR7n7ShV?V8nIS`03VIl02iV?VIn9SiR?R8n7SgQoMWmg
KfI_IUl00UEO0TA?00E3?c@o<clc;c8_008R;`068QlQ7a8O8BlA7b4O0Q4O00hA3a0O4@l@7`4?41l0
3a0O0@l@3`0?40l03a0?0P0?0_oo00<03oooool05_oo000?ool04P0?ool07`4?00l13`0O0@l07`4?
01l13a0O0@l@7`4O4Al17`<A7`0?4QlA;a8O8BlB;b8_8blR?b<o<cld?d=?=3m4GdE?009EG`9VK`08
MgmWOhN?N8nHWhV?VIn9W`>IW`08RInHWhV?R9mhShR?IgmgO`9VK`9EG`0?ADm4Cc@o<dlS?c<o8blR
?a8_8RlB7a4_4QlA7a8O00<A7`0?0Al@7`4O41l13`0O0@l07`4?01l13`0?0@l07`4?00;oo`0300oo
oooo01Koo`003ooo00@03ooo00l@3`<03`0<40l03a0O00l@7`0?41l13a0O4@l@7a4?0Q4O00@Q7a4O
8BlR7`8R;`0=<SlS;c<o<cm3CdA?@dm5CeAOIUmUKgM_MWl00XR?0YVO0ZZ_00J[[kZo^jnj_j^_^[l2
ZZl00jZOVInIW`02R8l027IoMgmUKeIOE5mECd=?A3l2<cl02C8o8blQ;b8_8BlB7b4_4AlQ7`034Al0
2a0O0@l@7`4?41l13a0O00l@7`0?40l00`0?00@@3ooo00l03aSoo`003ooo01403ooo00l03`0O0@l0
7`4?01l13a0O0@l@7`4?41l17a0O00@A7`044QlA;a8O8Bl28Rl01B<_<Slc?c<o=4l00TA?00IEGdEO
IFmFKgMoIgl2R8l2VIl2ZZl01[ZoZjnj_j^o^[n[[`>Z[`:IW`:8S`06IgmgOeI_IVm5GeAO0TA?00@c
?c=?8blb?`8R;`054RlR;a8O4BlB7`054Al02`4O41l13a0O0@l07`4?01l13`0O0@l00P0?0_oo00<0
3oooool05_oo000?ool04P0?ool03a0?00l@3`0?40l13a0?00l@7`4?41lA3a0O4@l@7`<A7`0C8AlA
7b4_8Qlb;b8_<Slc;d<o<cmDCdA?E4mEGfEOIfmfKhQoQhl00YVO00BZ[kZ__;o;_`;<c`09cLoLclc?
c<nl_l^o^knj[j^_00:IW`0<QhmhOgI_IVmUGeEOE4m4Cd=?=3lb?c<_0R8_00DQ;b8O8BlB7b4O008A
7`0@4@l@7a4?41l13a0O0@l@7`4?40l03a0?00l@3`0?40l2ool00`0?ooooo`0Fool000ooo`0H00oo
o`0O0@l03`4?01l13a0O0@l07`4?41l13a0O0AlA7`4O4AlB7a4O4QlA;a8_0R8_00hR?b<o<cld?c=?
ADm4CdE?EFmFGgIoIfn7SgR?0YVO00nZ_j^_^lnl_lcOcLo<glg?c=o=ck_?_;nkcj^_Z[l00YVO02Eh
ShR?IfmVOeIOEFm5CdAO=3m3Cb<_<clS;b8_4QlR;a8_4BlB7a4O4QlA7`4O4Al17a4O0@l07`4?41l1
3`0O0@l03`4?01l13`02ool00`0?ooooo`0Fool000ooo`0400ooo`0?40l300l02Q0?00l@7`4?41l0
3a0O0@l@7a4?0Q4O014Q7a4O8BlB7b4_8Rlb;b8_<Slc?d=?=3mDGdE?E5mFGfE_009gO`0GRHnHSjZ_
ZZnk_l^ogLoLgmkOkNo^gng_g]o]kmg?g=o=cl^o^knZ[jZOV8n8S`02Mgl04FE_IUmDGdE?@dm4?c8o
<blb;b8_8BlR7b4_4AlQ;a4O8Al00Q4O00XA3a0O0@l@7`4?41l03a0O00l@3`<03`0440ooo`0?00lH
ool000ooo`0@00ooo`0O00l07`4?01l13`0O0@l@7`4?41l17a0O0Al44Al0414_4QlQ;a8_8RlS;b8o
8clc?cA?A4m5CeAOAEmVKeIO0WMo01>HWhV?ZZnZ[l_?_;oLglgOkNoNgnk_g^o]kmkOg=o=gmgO_;nk
c`02ZZl02XV?R9mgOgMoEUmUKdEOE5ld?d=?0S<o00LS;b8o8RlR;a8_8BlB7`054Al03@4O41l17a0O
0@l07`4?01l13`0O0@l07`0?00;oo`0300oooooo01Koo`002Ooo00<03oooool00ooo01403ooo00l@
3`0?40l03a0?0@l@3`0?41l13a0O4@l@7a4?00@A7`0=8AlB7b8_8Qlb;b8_<clc;d=?A3mDGeE?E5l0
0VI_00IhOhMoVHnIWj^_^[l2c<l02mkOkMo^kok_onononk_o^oNgngOg]l00/c?00bj_j^_VInIShMo
MgmVKfIOE5mECd=?A3l2<cl00c8_8blQ;`028Rl0518O8AlA7a4O4@lA7a4?41l13a0O0@l@7`4?40l0
3a0?00l@3`0?40l2ool00`0?ooooo`0Fool000Soo`0300ooo`0?00Coo`0G00ooo`0O0@l07`4?01l1
3a0O0@l07`4?41l13a0O0AlA7`4O4AlB7a4O4QlA;`028Rl02B<_8Slc?c<o=4m4CdEOEEm5C`02IVl0
6gN?N7nIWhVO^[n[[lcOcLo]kmkOk_o_koookno^ono_kNoNgmg_cLo<cj^_^[n9WiVON7mgS`02IVl0
2DE?EEldCdA?8clc?b<_8SlB;`028Rl0524_4QlA;a8O4Al17a4O0AlA7`4?01l13a0O0@l07`4?01l1
3`0O0@l2ool00`0?ooooo`0Fool000Soo`0300ooo`0?00Coo`0A00ooo`0?40l03a0?00l@3`0?41l1
3a0O00l@7`4?41lA3`024Al03b4O4AlQ;a8O8BlR;c8o8blb?c<o@dm4?eAOEDmDG`02IVl037MoQhnI
WiVO^jnj_lc?g<o^gng_knono`;oo`09knononkOkNo^gmc?c<nj_j^_00:IW`08QhmhOfI_IVmDGeE?
@dm4?`8c?`09<RlR;b8_8QlQ;a4O8BlA7b4O008A7`0>4@l@7`4?41l13a0O00l@7`0?40l03a0?00l@
3`;oo`0300oooooo01Koo`002?oo00<03ooo00l01?oo01003ooo01l03`0O0@l@7`4?01l13a0O0@l@
7`4O41l17`@A7`074BlB7b4_4RlR;b<_<Sl00S<o00DdCdA?AEmEGdEO009VK`0<QhmhOiVOVInj_j^o
g=o=cnk_g^ooonoo0ooo00S_onk_g^o^klg?c=n[_k^o0YVO00QhOhN?IVmVKdEOEEldCdA?0S<o00LS
;b8o8RlR;a8_8BlB7`054Al03P4O41l17a0O0@l07`4?41l13`0O0@l07`0?ool200lHool000Woo`03
00oooooo00?oo`0A00ooo`0?40l03a0?00l@3`4?40l03a0O0@l@7a4?41lA3`044Al03B4O4QlR;b8O
<RlR;c<o<bm3Cd@oE5mECeAO009VK`0<N7n7OiVOVInk[kZoc<oLcnkOkNookoko0_oo00Wokokok]o]
knkOg<o=ckZo^jl00YVO00R7OgQoIVmVKeAOEDm3Cd@o0S<o00<b?b<_8Bl00R8_01@B7b4O4AlA7a4?
4AlA3a0O0@l@7`4?41l13a0?00l@3`0?40l03a0?0_oo00<03oooool05_oo000?ool05`0?ool07`4?
01l13`0O0@l@7`4?01l13a0O0@l@7`4O4Al17a4O4QlA7a8O4Bl00R8_00TS;b8o<clc?cA?A4m5GeEO
ADl00VI_01]gSgQoVIn9WkZoZjo<glg?kNoNgnkoknooono_k_o_kng_g]oMklg?c<n[[kZoRInIWgQo
Mhl00VI_00U5CeEO=4m4Cb<o<clS;b8o4Rl00R8_01@Q;a8O4BlB7a4O0AlA7`4O4Al13`0O0@l@7`4?
01l13`0O0@l07`4?0_oo00<03oooool05_oo000?ool04@0?ool03a0?00l@3`0?40l03a0O0@l@7`0?
41l13a0O4@l00Q4O038Q7a4O8BlB7b4_8Rlb?b8_<Slc?d=?A3mDGeE?E5mVGfE_Mgn7SiV?V9n[[kZo
c<oLcmgOkNo^kok_onononk_o^oMgng_g]oLclc?^[n[[iROVIn7SgMoIFmVKeAOADm3Cd@o0S<o00Tb
;b8_8RlR7b4_4AlQ;a4O8Al00Q4O00hA3a0O0@l@7`4?41l03a0O00l@3`0?40l03a0?0_oo00<03ooo
ool05_oo000?ool0400?ool07`0?01l13`0O0@l07`4?41l13a0O0Al@7`4O114O010A;a8O8BlB;b8_
8blR?b<o<cldCdA?ADmDGdEOIVmFG`9gO`0CV9n9SjZ_ZZo;ckbog=o=gng_g]o^kmk_kNoNgmcOcMoM
gkbo^ll00ZZ_00Z9ShROMgmgOeIOIFm5GeAO=3m3C`8c?`078blR?b8_8RlB;b4_4Ql01A4O00d17a0O
0Al@7`4?01l13`0O0@l07`4?01l03`02ool00`0?ooooo`0Fool000ooo`0A00ooo`0?40l03a0?00l@
3`4?40l03a0O0@l@7a4?41lA3`044Al0:24O4QlR;b8O<RlR;c<o<bm3Cd@oE5m5CeAOIUmUKgM_Mgn8
SiROZYnY[k^obko=cmcOg]o]knkOkNoNgng_cLoLgmg?bknl_jV_ZZnHWhV?0WMo00mUKeIOE5mECd=?
=3lb?c<_<RlR;b4_8QlR;a8O8Al00Q4O014A3a4O4@l@7`4?41l13a0O0@l@3`0?40l03a0?00l@3ooo
00803aSoo`003ooo01P03ooo01l13`0?0@l07`4?41l13`0O0@l@7`4?41l17a4O0AlA7a8O4AlB7a4_
4Rl28Rl03R8o8clc?c@o<dm5CdA?ADmEKeIOMWmWKhN?N8l2VIl03jZoZjnkckboc=o=clcOcLo<glg?
^lnl_k_?ZjnZ_`02VIl09GR?R8mWKfIoEUmEKdE?A5ld?d=?8blc?b<_8RlB7b8_4RlA;a8O4AlB7a4O
0AlA7`4O4Al13`0O0@l@7`4?01l13`0?0@l07`4?00;oo`0300oooooo01Koo`003ooo00@03ooo00l@
3`<03`0<40l03a0O0@l@7`0?41l13a0O4@lA7a4?0Q4O00@Q;a4O8BlR7`8R;`05<Slc;d=?=3mDC`02
A4l01UEOIEmVKgIoN7n7S`:IW`0?ZZnj[k^oblo<cmc?c<oLglc?g<nk_l_?^knj[jZ_00:IW`06Qhn8
OgIoIfmUGeEO0TA?00]3?c<o<SlS;c8_8RlQ;a8O8BlA7b4_00@A7`0:0@l@7`4?41l13a0O00l@7`0?
40l300l0110?ooooo`0?6?oo000?ool04@0?ool03`0?01l13`0O0@l07`4?41l13a0O0@l@7`4O41l0
114O00@B7a4_4QlQ;`8R;`058blb?c<o<cldC`02A4l01UEOAEmUKeI_MgmWO`:8S`:IW`:Z[`06^[n[
[kZoZknj_j^_0jZ_0YVO0XR?00IWOgMoEVmVKdEOE5l2A4l013<o<dlS;c8o0R8_00DB;b8_4QlA;a8O
00DA7`0;0Al@7`4?41l13`0O0@l07`4?01l13`0200l2ool00`0?ooooo`0Fool000ooo`0300ooo`0?
00803`0>40l03a0?0@l@3`0?41l13a0O0@l@7a4?41lA3`8A7`048AlA7b4_4Ql28Rl03c8o8bm3?c<o
A4m4?d=?EDmDGfIOIFmgKgMoR7n8S`02VIl02jZOZJn[[kZo^jnj_j^_^[nZWjV_ZZl00YVO0XR?00Qg
OgM_IFmVGeAOEDm3Cd@o0S<o00Tb?b<_8RlR7b4_8QlQ;a4O8Al00Q4O00hA3a0O4@l@7`4?41l13a0O
0@l@3`0?40l03a0?0P0?00?oo`0?00l06?oo000?ool04P0?ool07`4?00l13`0O0@l07`4?01l13a0O
0@l@7`4O4Al17`<A7`0?4QlA;a8O8BlB;b8_8blR?b<o<cld?d=?=3m4GdE?009EG`9VK`08MgmWOhN?
N8nHWhV?VIn9W`>IW`08RInHWhV?R9mhShR?IgmgO`9VK`9EG`0?ADm4Cc@o<dlS?c<o8blR?a8_8RlB
7a4_4QlA7a8O00<A7`0?0Al@7`4O41l13`0O0@l07`4?01l13`0?0@l07`4?00;oo`0300oooooo01Ko
o`003ooo00@03ooo00l@3`<03`0=40l03a0O00l@3`0?41l13a0O4@l@7a4?41l00a4O00dQ;a4O8BlR
7c8_8Rlb?c<_@dlc?d=?A4mDC`02EEl02VIOIFmgOgIoN7n7ShR?V9nISiRO0YVO00^ISiROR8nHWhV?
Qhn8OgIoMfmUKfI_009EG`0=E4m4Cd=?=3lb?c<o<RlR;b4_8RlQ;a8O8Bl00a4O00d@7a4?41l13a0O
0@l@7`4?40l03a0O00l@3`0300l0110?ooooo`0?6?oo000?ool0500?ool03`0?01l13`0O0@l07`4?
41l13`0O0@l@7`4?41l17a4O0Al34Al00a8O4BlB;`038Rl00b<_<Slc?`02<cl014A?=3m4GdE?0UEO
00AUKeI_MWmWK`9gO`06QhmhOhN?N7n7SgQo0gMo00AWKfIoEVmVK`9EG`04ADm4Gc@o@dl2<cl02R<_
<SlR;b8_4QlQ;a8O8BlB7a4_0Q4O00l17a4O0Al@7`4?41l13a0O0@l07`4?01l13`0O0@l00P0?0_oo
00<03oooool05_oo000?ool00`0?ool03`0200l05Q0?00l@3`4?40l03a0O0@l@3`4?41l13a0O4@lA
7a4?8AlA7b4O4QlQ;b8O0R8_00Tb;b<_<clc;c<oA3m3CdA?E4l00UEO00EVGfE_IVmfOgM_009gO`06
QgmhOhMoMgn7OgM_0WMo00AfOfM_IFmVG`9EG`04E4m4Cd=?=3l2<cl02c8o8blR;b8_8BlB7b4O4AlQ
7a4O8Al00Q4O00hA3a0O4@l@7`4?40l03a0O0@l@3`0?40l03a0?0P0?0_oo00<03oooool05_oo000?
ool0700?ool07`4?00l13`0O0@l07`4?01l13`0O0@l07`4?41l13a0O0AlA7`4O4AlB7a4O4QlA;a8_
0R8_010R?b<_<clS;c<o=3m4Cc@oA5m5CeEOADmEKeIOIVmFG`MVK`0/EUmUKeIOEFm5CeEOADm4Cc@o
@dld?c<o8blb?b<_8RlB;b8_4QlQ;a8O4BlB7a4O0AlA7`4O4Al13a0O0@l@7`4?01l13`0O0@l07`4?
00l13`0O0@ooo`803aSoo`003ooo00@03ooo00l@3`<03`0=40l03a0?00l@3`0?41l13a0O0@l@7`4?
41l00a4O00DQ7a4O8BlB7b4_00<R;`03<SlS;c8o008c?`0<A3m3CdA?E4mECeAOEEmUGfIOIFmVGfE_
0VI_00eVGfE_IUmUKeIOIEmEGeAOADmDCdA?@dld?`02<cl01c8o8blb;b8_8BlR7b4_00<A7`0A8AlA
7a4O4@l@7a4?41l13a0O00l@7`0?40l03a0?00l@3`0300l0110?ooooo`0?6?oo000?ool0500?ool0
3`0?01l13`0O00l07`4?01l13`0O0@l@7`4?41l17a0O0Al54Al0118O4BlB7b4_0b8_00@R?b<_<SlS
;`8c?`0C@dld?dA?A4m4GdA?E5m5GeEOAEmEGdEOEEm5GeAOAEmDGdA?A5l00TA?00hd?d=?<clc?b<_
<SlS;b8o4RlR;a8_8BlB7a4_1Q4O00l17a0O0Al@7`4?01l13a0O0@l07`4?01l03`0O0@l00P0?0_oo
00<03oooool05_oo000?ool00`0?ool03`0200l04A0?00l@3`0?40l03a0?0@l@3`0?41l13a0O4@l@
7a4?41l00a4O02@Q7a4O8BlB7b4_8Rlb;b8_<Rlc;c8o<blc?c@o@dm4?d=?A4mDCdE?E5mECeAOEDmD
GeE?E5m5CeAOEDmDCdA?@dm4?d=?=3l2<cl00c8o8blb;`028Rl0128O8BlR7b4O114O018A3a0O4@l@
7`4?41l13a0O0@l@3`0?40l03a0?00l@3`0?40l200l2ool00`0?ooooo`0Fool000ooo`0400ooo`0O
0@l200l0400O0@l07`4?01l13`0O0@l07`4?41l13a0O0AlA7`4O1A4O00@B7a4_4QlQ;`8R;`074RlR
?b<_<SlS;c<o8cl00S<o00lcCc@oA4ld?dA?=4m4CcA?A4ldCdA?=3m3Cc@o@dl00S<o00lS?c<o8blR
?b<_8RlB;b8_4QlR;a8O4BlB7a4O0Al00a4O00l17a0O0Al@7`4?01l13a0O0@l07`4?01l13`0O0@l0
0P0?00D07`4?ooooo`0?01Soo`003ooo00@03ooo00l@3`<03`0A40l03a0?00l@3`0?41l13a0O00l@
7`4?41lA3a0O4@l@7`034Al01B4O4AlQ;a8O8Bl00b8_00Db;b8_<Slc;c8o008c?`0>=3m3?d@o@dm4
?d=?A3m3Cd@o@dm4?d=?=3m3?`<c?`05<Slc?c8o8blb;`028Rl0128O8BlB7b4_1A4O014@7a4?41l1
3a0O0@l@7`4?41l03a0O00l@3`0?40l03a0?00<03`0440ooo`0?00lHool000ooo`0600ooo`0?00l0
7`4?0P0?01007`4?01l13`0O0@l@7`4?01l13a0O0@l@7`4O4Al17`@A7`084BlB7b4_4QlQ;a8_8RlB
;`8R;`068SlS;c8o8blc?b<o2c<o00HS?c8o8blb?b<_8Sl28Rl01a8_8RlB;b4_4QlA;a8O00DA7`0?
0Al@7`4O41l13a0O0@l@7`4?01l13`0O0@l07`4?00803`0401l13`0?00l2ool00`0?ooooo`0Fool0
00Soo`<03`Coo`0300ooo`0?00803`0D40l03`0?00l@3`0?40l03a0?00l@7`4?40l13a0O0@l@7a4?
4AlA3`@A7`068AlA7b4_4QlQ;b8O128_00Lb;b<_<Slc;c8o<blb?`02<cl033<_<clc?c<o<blb?c<_
<Slc;c8o8blb;`@R;`068QlQ;b8O8AlB7b4O0Q4O018A3a0O4@lA7a4?41lA3a0O0@l@3`0?41l13a0?
00l@3`0?40l300l00a0?00l03`02ool00`0?ooooo`0Fool000Woo`0300oooooo00?oo`0400ooo`0?
0@l200l0500O0@l03`4?01l13`0?0@l07`4?01l13`0O0@l@7`4?41l17a4O0Al54Al0?A8O4BlB7a4_
4QlR;a8O8RlB;b8_4RlR?b<_8SlS;b8o8blb?b<_8SlS;b8o8blR?b<_8RlB;b8_4RlR;a8O8BlB7b4_
4QlA;a8O4Al17a4O0AlA7`4?4Al17a4O0@l@7`4?41l13`0O0@l07`4?01l13`0?0@l07`4?00<03`04
0@oooooo00lHool000Woo`0300oooooo00?oo`0300ooo`0?00@03`0E40l03`0?00l@3`0?40l03a0?
00l@7`4?41l13a0O0@l@7a4?41lA3a0O00<A7`098AlA7b4O4QlQ;b8O8BlR7b4_00<R;`0=<RlR;c8_
8Rlb;b8_<SlR;c8_8Rlb;b8_<Rl00b8_00LQ;b8_8BlB7b4_4AlQ7`054Al04A0O4Al@7`4?41l13a0O
0@l@7`0?41l03a0?00l@3`0?40l00`0?00<@3`0?00l00P0?0_oo00<03oooool05_oo0009ool00`0?
ooooo`03ool01P0?ool03`0?01l13`803`0A01l13`0O00l07`4?01l13`0O0@l@7`4?41l17a0O0Al@
7`064Al02A8O4BlB7b4_4QlQ;a8_8RlB;`048Rl03B8o8blb?b<_8SlS;c8o8blR?b<_8SlR;b8o008R
;`0:4RlR;a8_8RlB7b4_4QlA;a4O4Bl24Al04`4O4Al17a4O0Al@7`4O41l13`0O0@l@7`4?01l13`0O
00l07`4?00803`0501l13`0?00ooo`0200lHool000Soo`803`Goo`0300ooo`0?00803`0H40l03`0?
00l@3`0?40l03a0?00l@3`4?40l03a0O0@l@7`4?41l13a0O4@lA7a4?1Q4O00/Q7a8O8AlB7b4_4QlQ
;b8O8BlR7b4_008R;`0@8QlQ;b8_8RlR7b4_8QlQ;b8O8BlR7b4_4QlQ7a4O8Al44Al05Q4?41lA3a0O
4@l@7a4?41l13a0O0@l@7`4?40l03a0?00l@3`0?40l03a0?0`0?00<@3`0?00l00_oo00<03oooool0
5_oo000?ool0100?ool03`4?0P0?01P07`4?00l03`0O0@l03`4?01l13`0O0@l07`4?41l13a0O0@lA
7`4?4Al17a4O0Al44Al0314_4QlA;a8O4BlB7b8_4QlR;a8_8RlB;`<R;`0?4RlR;b8_8RlB;b8_4RlR
;a8O8BlB7b4_4QlA;a8O00DA7`0C0AlA7`4O4Al13a0O0@l@7`4?01l13a0O0@l07`4?01l13`0O0@l0
0P0?00<07`4?00l00P0?00@13oooool03aSoo`003ooo00<03ooo00l0100?00D@3`0?00l03a0?00<0
3`0A40l03a0O00l@3`0?41l13a0O0@l@7`4?41lA3a0O4@l@7`034Al06A0O4AlA7a4O8AlA7b4O4AlQ
7a4O8BlB7b4_4AlQ;a8O8BlA7b4_4QlQ7a4O8AlA7b4O00<A7`0E41lA7a4O4@l@7a4?41l13a0O0@l@
7`4?41l03a0O0@l@3`0?41l03a0?00<03`0540l03`0?00l@3`0400l2ool00`0?ooooo`0Fool000oo
o`0500ooo`0?00l07`0300l0600O0@l03`0?01l13`0O0@l07`4?41l13`0O0@l@7`4?41l17a0O0Al@
7`4O4Al17`@A7`0I4BlA7a4_4AlA;a8O8BlB7b4_4QlQ;a8O8BlB7b4_4QlQ;a8O8BlB7a4_4QlA;a4O
4Bl01Q4O01L17a4O0AlA7`4?41l13a0O0@l@7`4?41l13`0O0@l07`4?01l13`0O00l07`4?00803`05
01l03`0?00ooo`0200lHool000ooo`0300ooo`0?00803`0540l03`0?00l@3`0300l06A0?00l@3`0?
40l03a0?0@l@3`0?41l13a0O0@l@7`4?41lA3a0O4@l@7a4?4AlA3a0O00LA7`058AlA7a4O4AlQ7`03
4Al00b4O4AlA7`044Al06Q4?41lA7a4O4@l@7a4?41l13a0O4@l@7`4?40l13a0O0@l@3`0?40l03a0?
00l@3`0?40l300l01A0?00l03`0?40l00P0?0_oo00<03oooool05_oo000?ool0100?ool03`4?0`0?
01l13`0?00l07`4?00l13`0O0@l03`4?01l13`0O0@l07`4?41l13a0O0@lA7`4?41l17a4O0AlA7`4O
4Al17`054Al01A8O4AlA7a4_4Ql00Q4O00HA;a8O4AlA7a4_4Ql54Al06`4O4Al17a4O0AlA7`4O4Al1
3a0O0@l@7`4?01l13a0O0@l07`4?01l13`0O0@l03`4?01l13`0300l01@4?00l03`0?0@l00_oo00<0
3oooool05_oo000?ool00`0?ool03`0800l01A0?00l03`0?40l00`0?01T@3`0?41l03a0?00l@7`4?
41l03a0O0@l@7`4?41l13a0O4@l@7a4?41lA7a0O4@l@7`034Al01A0O4AlA7a4O41l00a4O01T@7a4O
41lA3a0O4@l@7a4?41lA3a0O0@l@7`4?41l13a0?00l@7`4?40l03a0O00l@3`0300l01A0?00l03`0?
40l0200?0_oo00<03oooool05_oo000?ool01@0?ool03`0?01l00`0?00H07`0?00l03`0O0@l200l0
600O0@l07`4?01l13a0O0@l07`4?41l13a0O0@l@7`4?41l17a4O0@lA7`4O4Al17`<A7`030AlA7a4O
00TA7`0O0AlA7a4O4Al17a4O0AlA7`4?41l17a0O0@l@7`4?41l13`0O0@l@7`4?01l13`0O0@l07`4?
01l03`0O0@l00P0?00D07`0?00l03`0O00<03`;oo`0300oooooo01Koo`003ooo00<03ooo00l00P0?
00D@3`0?00l03a0?00<03`1540l03`0?00l@3`0?40l03a0?00l@3`4?40l03a0O0@l@3`4?41l13a0O
0@l@7`4?41lA3a0O4@l@7a4?41lA3a0O4@l@7a4?41lA3a0O4@l@7a4?41lA3a0O4@l@7`4?41lA3a0O
0@l@7`4?41l13a0?00l@3`4?40l03a0?00l@3`0?40l03a0?00<03`0540l03`0?00l@3`0300l0110?
00l03ooo0P0?6?oo000?ool00`0?ool03`0400l01@4?00l03`0?0@l00P0?04H07`4?00l13`0O0@l0
3`4?01l13`0O0@l07`4?41l13`0O0@l@7`4?41l13a4O0@l@7`4O4Al13a4O0AlA7`4O4Al17a4O0AlA
7`4O4Al17a4O0AlA7`4?4Al17a4O0@l@7`4?41l13a0O0@l@7`4?01l13`0O0@l07`4?01l13`0O0@l0
3`4?01l13`<03`050@l03`0?00l13`0400l2ool00`0?ooooo`0Fool000ooo`0300ooo`0?00`03`05
40l03`0?00l@3`0300l0=A0?00l@3`0?40l03a0O0@l@3`0?41l13a0O00l@7`4?41l13a0O0@l@7`4?
41l13a0O0@l@7`4?41l13a0O0@l@7`4?41l13a0O0@l@7`4?41l03a0O0@l@3`0?41l03a0?00l@3`0?
40l00`0?00D@3`0?00l03a0?00`03`;oo`0300oooooo01Koo`003ooo00<03ooo00l01@0?00D07`0?
00l03`0O00<03`1201l13`0?00l07`4?01l13`0O0@l07`4?01l13a0O0@l07`4?41l13a0O0@l@7`4?
41l13a0O0@l@7`4O41l13a0O0Al@7`4?41l17a0O0@l@7`4?41l13a0O0@l@7`4?41l13a0O0@l07`4?
41l13`0O0@l07`4?01l13`0O00l07`4?0P0?00D07`0?00l03`0O00L03`;oo`0300oooooo01Koo`00
3ooo00<03ooo00l01P0?00D@3`0?00l03a0?00<03`0m40l03`0?00l@3`0?40l03a0?00l@3`0?40l0
3a0?0@l@3`0?40l13a0?00l@7`4?40l13a0O0@l@3`4?41l13a0?0@l@7`4?40l13a0O0@l@3`4?41l1
3a0?00l@3`4?40l03a0?00l@3`0?40l03a0?00l@3`0?40l00`0?00D@3`0?00l03a0?00<03`0340l0
3`0?00@03`;oo`0300oooooo01Koo`003ooo00<03ooo00l0200?00D13`0?00l03`4?00803`0n01l1
3`0?0@l07`4?00l13`0O0@l07`4?01l13`0O0@l07`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?41l1
3`0O0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l07`4?01l13`0O0@l07`4?00l13`0O0@l03`4?01l1
3`<03`050@l03`0?00l13`0800l00ooo00l03`0Hool000ooo`0300ooo`0?01003`0540l03`0?00l@
3`0300l0:A0?00l@3`0?40l03a0?00l@3`0?41l03a0?00l@7`4?40l03a0O0@l@3`0?41l13a0?00l@
7`4?40l03a0O00l@3`0?41l03a0?00l@3`0?40l00`0?00D@3`0?00l03a0?00<03`0340l03`0?00h0
3`;oo`0300oooooo01Koo`003ooo00<03ooo00l02@0?00D07`0?00l03`0O00<03`0f01l13`0?00l0
7`4?01l03`0O0@l07`4?01l13`0O0@l07`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l@
7`4?01l13a0O0@l07`4?41l13`0O0@l07`4?01l13`0O00l07`4?0P0?00D07`4?00l03`0O00<03`03
01l03`0?00T03`;oo`0300oooooo01Koo`003ooo00<03ooo00l02P0?00D@3`0?00l03a0?00<03`05
40l03`0?00l@3`0300l0:A0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?0@l@3`0?
40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l00`0?00D@3`0?00l03a0?00<03`05
40l03`0?00l@3`0:00l2ool00`0?ooooo`0Fool000ooo`0300ooo`0?00`03`050@l03`0?00l13`02
00l0;P0O0@l03`0?01l13`0?0@l07`4?00l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?
01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0?0@l07`4?0P0?00H07`4?00l03`0O0@l300l01@4?
00l03`0?0@l0300?00?oo`0?00l06?oo000?ool00`0?ool03`0H00l01A0?00l03`0?40l00`0?00D@
3`0?00l03a0?00<03`0940l03`0?00l@3`0?40l03a0?00<03`0540l03`0?00l@3`0300l01A0?00l0
3`0?40l00`0?00<@3`0?00l05P0?0_oo00<03oooool05_oo000?ool00`0?ool03`0=00l01@0O00l0
3`0?01l00`0?00H07`4?00l03`0O0@l200l08P0O0@l07`0?01l13`0O00l07`4?01l03`0O0@l07`4?
01l13`0O0@l07`4?01l03`0O0@l07`0?01l13`0O00l07`4?0P0?00D07`4?00l03`0O00<03`0501l0
3`0?00l07`0?00l2ool00`0?ooooo`0Fool000Soo`<03`Coo`0300ooo`0?00h03`0540l03`0?00l@
3`0300l01A0?00l03`0?40l00`0?024@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@
3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l00`0?00D@3`0?00l03a0?00<03`0540l03`0?00l@
3`0>00l2ool00`0?ooooo`0Fool000Soo`0300oooooo00Coo`0300ooo`0?01003`050@l03`0?00l1
3`0300l01@4?00l03`0O0@l00P0?00H07`4?00l03`0O0@l200l03P0O0@l03`4?01l13`0?0@l07`4?
00l13`0O0@l200l01P0O0@l03`0?01l13`803`0301l13`0?00803`050@l03`0?00l13`0300l00`4?
00l03`0>00l2ool00`0?ooooo`0Fool000Woo`0300oooooo00?oo`0300ooo`0?01`03`0540l03`0?
00l@3`0300l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l01A0?
00l03`0?40l0700?00?oo`0?00l06?oo0008ool00`0?ool03`04ool00`0?ool03`0Fool00`0?oooo
o`0Eool00`0?ooooo`0Dool00`0?ooooo`0Eool00`0?ool03`0Hool000Woo`803`Coof<03aSoo`00
R_oo002:ool008[oo`001_oo00<03oooool0POoo0007ool00`0?ooooo`20ool000Ooo`0300oooooo
00;oo`0500ooo`0?ool03`03ool00`0?ool03`1cool000Koo`0300ooo`0?00?oo`0500ooo`0?ool0
3`03ool200mdool000Koo`0300ooo`0?00?oo`0500ooo`0?ool03`04ool00`0?ooooo`1bool000Ko
o`0300ooo`0?00?oo`0400ooo`0?00l4ool200mdool008[oo`003?oo00<03oooool0Nooo002:ool0
08[oo`00R_oo002:ool008[oo`00R_oo002:ool008[oo`00R_oo0000\
\>"],
  ImageRangeCache->{{{0, 136.8125}, {136.8125, 0}} -> {-2.725507, -2.852683, 
  0.05299, 0.05299}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig16x4 = 
      DensityPlot[
        Evaluate[Abs[Edz[x\ a, y\ a, a]]\^2], {x, \(-2\), 2}, {y, \(-2\), 2}, 
        AxesLabel \[Rule] {"\<x in a\>", "\<y in a\>"}, Evaluate[opt1]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25962 -0.0125 -7 -12 ]
[.25962 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.74038 -0.0125 -4 -12 ]
[.74038 -0.0125 4 0 ]
[.98077 -0.0125 -4 -12 ]
[.98077 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25962 -14 -6 ]
[-0.0125 .25962 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .74038 -8 -6 ]
[-0.0125 .74038 0 6 ]
[-0.0125 .98077 -8 -6 ]
[-0.0125 .98077 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1A1A1A1A19181716151412100E0C0A080604030100000000
0001030406080A0C0E10121415161718191A1A1A1A
1D1D1D1C1C1B1A1918161513110E0C0A0705030200000000
00020305070A0C0E1113151618191A1B1C1C1D1D1D
202020201F1F1E1D1B1A181613110E0B0906040201000000
01020406090B0E111316181A1B1D1E1F1F20202020
23232323232222211F1E1C191714110E0A07050301000000
010305070A0E111417191C1E1F2122222323232323
26262727272626252422201D1A1714100D09060301000000
010306090D1014171A1D2022242526262727272626
292A2B2B2B2B2B2A292725221F1B18130F0B070402000000
0204070B0F13181B1F222527292A2B2B2B2B2B2A29
2D2E2F303030302F2E2D2B2824211C17120D090502000000
0205090D12171C2124282B2D2E2F303030302F2E2D
31323335353636363534312F2B27221C16100B0603000000
03060B10161C22272B2F3134353636363535333231
3537383A3B3C3D3D3C3B3936332E28221B140E0803000000
03080E141B22282E3336393B3C3D3D3C3B3A383735
393C3E4042434445454442403C3730292119110A04010001
040A1119212930373C4042444545444342403E3C39
3E414346484A4C4E4E4E4D4A46413A32291F150D06010001
060D151F29323A41464A4D4E4E4E4C4A484643413E
4246494C4F52555758595856534D463C32261A1007010001
07101A26323C464D53565859585755524F4C494642
474B4F53575B5E6164656564615B53493D2F211409020002
0914212F3D49535B6164656564615E5B57534F4B47
4C50555A5E63686C70727473716B63584A3A29190C030003
0C19293A4A58636B71737472706C68635E5A55504C
50555B60666C72777C808384827E75695A47331F0F030003
0F1F33475A69757E828483807C77726C66605B5550
555A60676E757C83898F939696928A7D6C563E2712040004
12273E566C7D8A929696938F89837C756E67605A55
595F666D757D858E969EA4A8AAA7A09380674B2F16060006
162F4B678093A0A7AAA8A49E968E857D756D665F59
5C636B737C858F98A2ACB4BABEBDB6A9957A5A391B070007
1B395A7A95A9B6BDBEBAB4ACA2988F857C736B635C
60676F78828C97A2ADB9C3CBD1D2CCC0AA8D694320080008
2043698DAAC0CCD2D1CBC3B9ADA2978C82786F6760
626A737C86929DAAB7C4D0DAE1E4E0D4BE9E774C25090009
254C779EBED4E0E4E1DAD0C4B7AA9D92867C736A62
646C757F8A96A3B0BECCDAE6EFF3F0E4CEAD8254290B000B
295482ADCEE4F0F3EFE6DACCBEB0A3968A7F756C64
656E77818C99A6B4C2D1E0EDF7FCFAEFD9B68A592C0B000B
2C598AB6D9EFFAFCF7EDE0D1C2B4A6998C81776E65
666E77828D99A7B5C4D3E2EFFAFFFEF3DCBA8D5B2D0C000C
2D5B8DBADCF3FEFFFAEFE2D3C4B5A7998D82776E66
656E77818C99A6B4C2D1E0EDF7FCFAEFD9B68A592C0B000B
2C598AB6D9EFFAFCF7EDE0D1C2B4A6998C81776E65
646C757F8A96A3B0BECCDAE6EFF3F0E4CEAD8254290B000B
295482ADCEE4F0F3EFE6DACCBEB0A3968A7F756C64
626A737C86929DAAB7C4D0DAE1E4E0D4BE9E774C25090009
254C779EBED4E0E4E1DAD0C4B7AA9D92867C736A62
60676F78828C97A2ADB9C3CBD1D2CCC0AA8D694320080008
2043698DAAC0CCD2D1CBC3B9ADA2978C82786F6760
5C636B737C858F98A2ACB4BABEBDB6A9957A5A391B070007
1B395A7A95A9B6BDBEBAB4ACA2988F857C736B635C
595F666D757D858E969EA4A8AAA7A09380674B2F16060006
162F4B678093A0A7AAA8A49E968E857D756D665F59
555A60676E757C83898F939696928A7D6C563E2712040004
12273E566C7D8A929696938F89837C756E67605A55
50555B60666C72777C808384827E75695A47331F0F030003
0F1F33475A69757E828483807C77726C66605B5550
4C50555A5E63686C70727473716B63584A3A29190C030003
0C19293A4A58636B71737472706C68635E5A55504C
474B4F53575B5E6164656564615B53493D2F211409020002
0914212F3D49535B6164656564615E5B57534F4B47
4246494C4F52555758595856534D463C32261A1007010001
07101A26323C464D53565859585755524F4C494642
3E414346484A4C4E4E4E4D4A46413A32291F150D06010001
060D151F29323A41464A4D4E4E4E4C4A484643413E
393C3E4042434445454442403C3730292119110A04010001
040A1119212930373C4042444545444342403E3C39
3537383A3B3C3D3D3C3B3936332E28221B140E0803000000
03080E141B22282E3336393B3C3D3D3C3B3A383735
31323335353636363534312F2B27221C16100B0603000000
03060B10161C22272B2F3134353636363535333231
2D2E2F303030302F2E2D2B2824211C17120D090502000000
0205090D12171C2124282B2D2E2F303030302F2E2D
292A2B2B2B2B2B2A292725221F1B18130F0B070402000000
0204070B0F13181B1F222527292A2B2B2B2B2B2A29
26262727272626252422201D1A1714100D09060301000000
010306090D1014171A1D2022242526262727272626
23232323232222211F1E1C191714110E0A07050301000000
010305070A0E111417191C1E1F2122222323232323
202020201F1F1E1D1B1A181613110E0B0906040201000000
01020406090B0E111316181A1B1D1E1F1F20202020
1D1D1D1C1C1B1A1918161513110E0C0A0705030200000000
00020305070A0C0E1113151618191A1B1C1C1D1D1D
1A1A1A1A19181716151412100E0C0A080604030100000000
0001030406080A0C0E10121415161718191A1A1A1A
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{109.5, 109.5},
  ImageMargins->{{109.3125, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000290000RA000`40l00?003`ROoo0029ool008Wo
o`00ROoo0029ool008Woo`00ROoo0029ool008Woo`004_oo0`0?5?oo0`0?4ooo00<03oooool04ooo
0`0?5Ooo0`0?6Ooo000Bool00`0?ooooo`0Eool00`0?ooooo`0Aool00`0?ool03`0Eool00`0?oooo
o`0Dool00`0?ooooo`0Iool000goo`<03`?oo`0300oooooo00koo`<03`?oo`0300oooooo017oo`03
00ooo`0?01Goo`0300oooooo01Goo`0300oooooo01Soo`004_oo00<03ooo00l05Ooo00<03oooool0
4Ooo00<03ooo00l05Ooo00<03oooool05?oo00<03ooo00l06Ooo000Cool200lDool200lDool00`0?
ooooo`0Cool200lGool200lIool008Woo`00ROoo001eool00`0?ool03`03ool01@0?ool03ooo00l0
0ooo00<03ooo00l00ooo001fool00`0?ooooo`02ool01@0?ool03ooo00l00ooo0P0?1?oo0008ool3
00m[ool00`0?ooooo`02ool01@0?ool03ooo00l01?oo00<03oooool00_oo0008ool00`0?ooooo`04
oomR00l4ool00`0?ool03`03ool0100?ool03`0?1?oo0P0?1?oo0003ool300l3ool00`0?ooooo`03
ool00`0?ooooo`1Nool00`0?ooooo`0Fool000Soo`0300ooo`0?00Coo`0J00ooob4_4QlR;a8O8BlB
7b8_4QlQ;a8O8BlB7a4_4QlQ;a8O4BlB7a4_4QlA;a8O4Al17`<A7`0?0AlA7`4O4Al13a0O0@l@7`4?
01l13`0?0@l03`4?00/03`0?0@l03`4?01l13a0O0@l@7`4?4Al13a4O0AlA7`4O00DA7`0E4QlA7a8O
4BlB7a4_4QlA;a8O8BlB7b4_4QlR;a8O8BlB7b8_4QlQ;a8O00803`[oo`0300oooooo00_oo`002Ooo
0P0?1?oo01@03ooo4QlQ;a8O8BlB7b4_4QlQ;a8O8BlA7b4_4QlQ7a4O8BlA7b4O1a4O00d@7a4O41lA
3a0O4@l@7`4?40l03a0?00l@3`0C00l03A0?00l@7`4?41lA3a0O4@l@7a4?4AlA3a0O00<A7`0G8AlA
7b4O4AlQ7a4O8BlB7b4_4AlQ;a8O8BlB7b4_4QlQ;a8O8BlB7b4_ool03`0Hool000ooo`0J00ooob8_
4RlR;a8_8RlB;b4_4RlR;a8_8BlB;b8_4QlQ;a8O8BlB7b4_4QlQ;a8O4BlB7`DA7`0;0AlA7`4O4Al1
3a0O0@l@7`0?01l13`0>00l0300O0@l@7`4?41l13a4O0@lA7`4O4Al17`@A7`0J4BlB7a4_4QlA;a8O
8BlB7b4_4RlQ;a8O8BlB;b8_4RlQ;a8_8RlB;b8_4RlR;a8_ool03aSoo`003ooo01X03ooo8QlQ;b8O
8BlR7b4_8QlQ;b8O8BlB7b4_8QlQ;a8O8BlB7b4_4QlQ7a4O8AlA7b4O0a4O00d@7a4O41lA3a0O4@l@
7`4?40l03a0?00l@3`0?00l02A0?00l@3`4?40lA3a0O4@l@7`024Al00a4?4AlA7`024Al06B4O4AlQ
7a8O8AlB7b4_4QlQ;b8O8BlB7b4_8QlQ;b8O8BlR7b4_8QlQ;b8O8Booo`0?01Soo`003ooo00<03ooo
8Rl00R8_00DB;b8_8RlR;a8_00<R;`0?4RlR;a8_8RlB;b8_4RlR;a8O8BlB7b4_4QlA;a8O00DA7`0;
0@lA7`4?4Al13`0O0@l07`4?01l13`0:00l0300O0@l07`4?01l13a4O0@lA7`4O4Al17`@A7`0<4BlB
7a4_4QlA;a8O8RlB7b4_4RlR;a8_0b8_00DB;b8_8RlR;a8_00<R;`054RlR;b8_ool03`0Hool000oo
o`0400ooob8O8Bl28Rl01R8O8BlR;b8_8QlQ;`8R;`0>8QlQ;b8_8BlR7b4_8QlQ;a8O8BlA7b4_4AlQ
7`<A7`0=41lA7a0O0@l@7`4?41l13a0?00l@3`0?40l02`0?00T@3`0?40l13a0?0@l@7`4?41l01a4O
00dQ7a4O8BlB7b4_4QlQ;a8O8BlR7b4_8QlQ;`028Rl01R8O8BlR;b8_8QlQ;`8R;`048QlQ;ooo00lH
ool000ooo`0500ooob8_8RlR?`038Rl00b8o8RlR;`088Rl0318_8RlR;b8_4RlQ;a8O8BlB7a4_4QlA
;`@A7`0:0@l@7`4?41l13`0O0@l07`0?01l700l0300O00l07`0?01l13a0O0@l@7`4O4Al17`8A7`0:
4BlA7a4_4QlQ;a8O8BlB;b8_4Rl<8Rl01B8o8RlR;b8_8Sl00b8_00?oo`0?ool05ooo000?ool00`0?
oolR;`028Rl01C8_8RlR;b8_<Rl02R8_00XR7b4_8QlQ;b8O8BlB7b4_4QlQ7`<A7`0=41lA7a0O0@l@
3`4?40l13a0?00l@3`0?40l01`0?00T@3`0?40l13a0?0@l@7`4?41l01A4O00/Q7a4O8AlA7b4_4QlQ
;b8O8RlR7b4_008R;`038QlR;b8_008R;`05<RlR;b8_8Rlb;`038Rl01C8_8RlR;ooo00l06?oo000?
ool0100?oolR;b<_0b8_00DS;b8_8RlR;b<_00DR;`0>4RlR;b8_8RlB;b8_4RlR;a8O8BlB7b4_4QlA
;`8A7`0;0AlA7`4O4Al13`0O0@l07`4?01l13`0:00l0200O0@l07`4?01l13a4O0@l44Al0314_4QlA
7a8O4BlB7b4_4QlR;a8_8RlB;`TR;`058blR;b8_8RlS;`038Rl00b<_ool03`0Hool000ooo`0@00oo
ob8_<RlR;c8_8Rlb;b8_<SlR;c8_8Rlb;b8_<Rl38Rl03C8_8RlR;b8_8BlR;b4_8QlQ;a8O8BlB7b4O
00<A7`0941lA7a0O0@l@3`0?41l03a0?00/03`0940l03a0O0@l@7a4O41lA7a0O008A7`094QlQ7a4O
8BlB7b4_8QlR;b8O00@R;`0C<RlR;c8_8Rlb;b8_<SlR;c8_8Rlb?b8_<RlR;c8_8Rlb;ooo00l06?oo
000?ool05@0?oolR?b<_8SlS;c8o8blR?b<_<SlS;b8o8blR?b<_8SlS;b8o8RlR?`028Rl02Q8_8RlB
;b8_4QlQ;a8O8BlA7a4_0Q4O00X17a4O0Al@7`4?01l13`0O00l07`L03`0801l03`0O00l07`4?41l1
3`@A7`084BlB7b4_4QlA;a8_8BlB;`DR;`0E8blR;b8_8SlS;b8o8blR?b<_<SlS;b8o8blb?b<_8SlS
;b8o8booo`0?01Soo`003ooo01P03ooo8blb?b<_<Slc;c8o8blb?c<_<SlS;c8o<blb?b<_<SlS;c8o
8blb;b8_<Rl48Rl01R8O8BlR7b4_4QlQ7`8A7`0:4@l@7a4?41l13a0?00l@3`0?40l700l0210?00l@
3`4?40lA3a0O4@l34Al01Q8O8AlR7b4_4QlQ;`<R;`0I<RlR;c8_8blb;b<_<SlS;c8o<blb?b<_<Slc
;c8o8blb?c<_<SlS;c8o8blb?ooo00l06?oo000?ool0600?oolR?b<_<SlS;c8o8blc?b<_<SlS;c<o
8blb?b<_<clS;c8o8blb?b<_8SlS;`DR;`064QlQ;a8O8BlA7a4_0Q4O00L13a4O0@l@7`4?01l13`0:
00l0400O0@l@7`4?4Al17a4O0AlA;a8O8BlB7b4_4RlR;a8_0b8_01TS;b8o8blR?b<_8SlS;c8o8blb
?b<_<clS;c8o8blc?b<_<SlS;c8o8blR?b<_ool03`0Hool000ooo`0L00ooob<_<Slc;c8o<blb?c<o
<Slc;c8o<clb?c<_<Slc?c8o<blb?c<_<SlS;c8o8blb?b<_<Rl38Rl0124_8QlQ;a8O0Q4O00L@7a4?
41l13a0O00l@3`0;00l01A0?0@l@7a4?41l00Q4O00HB7b4O8QlQ;b8_8Bl38Rl06c8_8Rlb?b<_<Slc
;c8o<blb?c<o<Slc;c8o<clb?c<_<Slc?c8o<blb?c<_<SlS;c8oool03`0Hool000ooo`0800oooc<o
8clc?b<o<clS?`<c?`058clc?c<o<clS?`03<cl02R<o<clS?c<o8blb?b<_<SlR;b8o0R8_00HB;b4_
4QlQ;a4O4Bl24Al01`4?41l17a0O0@l07`4?00H03`0>01l13a0O0@l@7`4O4Al17a4_4AlQ;a8O8BlB
;`<R;`0;8blR;b<_8SlS?c8o8clb?b<o<clS?`03<cl01B<o<clc?c<o8cl00c<o00LS?c<o8clc?b<o
ool03`0Hool000ooo`0500oooc<o<clc;`04<cl02D<o<clc?c<o@clc?d<o<cm3?`03<cl02D<o<clc
?c<_<Slc;c8o8blb;`038Rl0124_8QlQ7a8O0Q4O00L@7a4?41l03a0O00l@3`0700l01A0?00l@7a4?
41l00Q4O00@B7b4O8QlQ;`<R;`07<RlS;c8o<blc?c<_<Sl00c<o00U3?c<o@clc?d<o<cm3?c<o@cl0
1S<o00Hc;c<o<clc?ooo00lHool000ooo`0300oooc<o008c?`038clc?c<o008c?`0:<dld?c<o=3lc
Cc@o<cld?c=?=3l5<cl01R<o<clS;c<o8blR?`8R;`0=4QlR;a8O4Bl17a4O0AlA7`4?01l13`0?0@l0
1`0?00D13`0O0@lA7`4?008A7`044BlB7b8_4Rl28Rl02R8o8blR?b<_<SlS?c<o8clc?c@o0S<o00Hc
Cc@o<cld?c=?=3l2<cl00c=?=3lc?`04<cl01B<o<clc?ooo00l06?oo000?ool0600?oolc?d<o<cm3
?c<o@clc?d=?=3m3Cc@o@dld?d=?A3m3Cc@o@dld?d=?=3m3?`Dc?`03<Slc;c8_00<R;`058BlR7a4O
4Al@7`024Al00`4?41l03`0900l00`4?41lA7`024Al00b4O8QlQ;`038Rl0138o<blb?c<_0S<o01]3
?c<o@dld?d=?=3m3Cc@o@dm4?d=?=3m3Cc@o@dld?d=?<cm3Cc<o@clc?d<o<cm3?ooo00l06?oo000?
ool06`0?oolc?c<o<dld?d=?=3m3Cc@o@dld?d=?=4m3Cc@o@dldCdA?=3m3Cc@o@dld?c=?=3lcC`02
<cl012<o<clS;b8o0R8_00DB7b4_4QlA;`4O008A7`0441l13`0O0@l600l0100O0@l@7`4?0Q4O00@A
;a4O8BlB;`8R;`048SlS;c<o8cl4<cl05S=?=3m3Cc@o@dldCd=?=3m3CcA?A4ld?d=?=3m3Cc@o@dld
?d=?=3lcCc@o0S<o00?oo`0?ool05ooo000?ool02P0?oolc?d=?=3m3Cd@o@dm4?d=?0TA?00=4?dA?
A4l00TA?00=DCdA?A4l014A?00I4?d=?A3m3Cc@o@cl2<cl01c<_<RlS;b8_8QlQ;a8O00<A7`044@l@
7`0?40l700l00a0?4@l@7`024Al0418O8BlR7b8_8blb?c<_<Slc?d<o<cm3Cd@o@dm4?d=?0dA?00=D
CdA?A4l014A?00i4?d=?A4m3Cd@o@dm4?d=?=3m3Cc<o@dooo`0?6?oo000?ool02P0?oolcCc@oA4ld
?dA?=4m4CcA?0dA?00<dCdA?A4l00dA?00=5CdA?A4l00dA?00XdCdA?=3m4Cc@o<dlS?c<o8blR?`8R
;`034QlQ;a4O008A7`0641l17`0O0@l03`4?0`0?00D13`0O0@l@7`4O008A7`0@8BlB7b8_4RlR?b<_
<clS?c=?=3lcCc@o@dldCdA?=4l5A4l00dE?A4m4C`03A4l03CA?A4ldCdA?=3m4Cc@oA4ld?c=?=3oo
o`0?01Soo`002?oo0`0?1?oo00P03ooo=3m3CdA?@dm4Cd=?0dA?01EDCdA?E5m5CeAOADmDGdE?E5mE
CeAOADmDGdE?E5m5CeA?A4m3Cd@o@dl00c<o00/b?b8_8RlR7b4O4AlQ7a4?41l03a0O00L03`0?41lA
3a0O4AlQ7b8O8BlR;c8o<clb?c<o@dm4?d=?00=4C`0AE4m4CeAOADmDGeE?E5m5CeAOEDmDGdE?E4m4
CeA?A4mDC`03A4l01d=?A4m3Cc@o@dooo`0?01Soo`002Ooo00<03oooool00ooo00@03oooA4ldC`A4
C`0EA5m5CdAOADm4GdE?E5m5CeAOAEmEGdE?E5m5GeEOADmDGdE?E5m4CdAO0094C`06=3m3Cc<o<clS
;c8o0R8_00LB7a4_4QlA7`4O01l13`0600l02P0O0@lA7`4O4BlB7b8_4Rlb?b<_0S<o01U3Cc@oA4ld
CdA?ADm4CdE?A5m5GeAOADmDGdEOEEm5CeAOADmDGdE?A5m5CdAOA4m4G`02A4l01cA?A4m4CdA?=4oo
o`0?01Soo`000ooo0`0?0ooo00<03oooool00ooo00<03oooA4l00TA?00YDCdA?E4m5CeAOEDmDGeE?
E5mEC`9EG`09IEmEGfEOEEmUGeEOIEmEGfEO009EG`03EDmDGeE?0094C`09@dm4?c<o<blb;b8_8BlB
7b4_008A7`030@l@3`0?00D03`0B0@l@3a4O4AlB7b4_8Rlb;c<_<cm4?d=?A4mDCeE?E5m5CeAO0eEO
00EUGeEOIEmEGfEO00IEG`06EDmDGeE?E5m5CeA?0dA?00=DCdA?A4l00P0?6?oo0009ool00`0?oooo
o`03ool00`0?oom4C`03A4l024AOADmDGdE?EEm5GeEOAEl4EEl01UE_EUmEGeIOEFmFG`EEG`06ADmD
GdE?A4ld?d=?0S<o00DS;b8o4QlR;a8O008A7`0441l13`0?0@l300l00`4?41l13`024Al0228_4QlR
?b<_<clS?d=?=3l2A4l03UAOADmEGdEOEEmFGeEOEUmEKeIOEFmFGeE_EUl3EEl02DEOEEm5CeEOADmD
GdE?A5m5C`04A4l00ooo00ooo`0Gool000Soo`803`Goo`0800ooodA?E4m4CeAOADmDG`=EG`09IEmE
GfE_EUmUKeIOIFmFGfE_00=VK`0AIFmVKfI_IUmUKfIOIFmFGeAOEEmDGdA?@dm4?c8o<blQ;`028Rl0
1Q4O8Al13a0O00l@3`<03`0540l13a0O4AlQ7`028Rl01S<_<Sm4?d=?A4mDC`9EG`06EUmUGeEOIFmF
GfE_0fI_00UUKfI_IVmVGfE_IUmUKeIOIEl00eEO00]DGeEOE5m5CeAOA4mDGdA?E4ooo`0?01Soo`00
3ooo00P03oooA5m4CeAOADmEGdEO15EO00QEKeIOIFmFGfE_EVmVKeI_1fI_00YFKfE_EUmUKdEOEEm5
CeAO=3m3C`8c?`<R;`044BlA7a0O0Al600l0110O0AlA;a4O0R8_00Hc?b<o@dldCeAOADl2EEl01VE_
EUmEKeI_IVmFK`MVK`0CEVmUKeI_IFmFGeE_EUmEGdEOEEm5GeEOADmDGdE?A5m4Cooo00l06?oo000?
ool01P0?oom5CeAOEDmDG`9EG`07EUmUGfIOIFmVGfE_IUl00VI_00efKfI_MWmWKgIoMfmgOgM_MWmg
KgIoIfmfK`02IVl046IOIEmEGeAOADm3?c@o<SlS;c8_4QlQ;a4?41l03a0?0`0?01l@3a4?41lB7b4_
8blb;c@o@dm5CeA?EEmUGfIOIFmVKgI_IfmfOgM_MWmgKgIoMfmfOgM_MWmgKgIoIfmfK`02IVl01FIO
IFmVGfEOEUl00UEO00MDGeE?E5m5CeAOool03`0Hool000ooo`0600oooeAOADmEGdE?0UEO02QEKeIO
IFmFGfI_EVmVKfM_IVmWKfIoIfmgOfM_MgmWOgMoIgmgOfMoMgmWKfIoEVmVKeIOEFm5CeAO=3lcCb<_
<SlS;b4_4QlA7`4O01l13`803`0W01l13a4O0AlQ;a8O<SlS;c=?=3mDGdE?EFmFGfI_EVmVOfM_IWmW
KgIoIgmgOfMoMgmWOgMoIfmfOfM_MWmVKfIoEVmVKeIOIFmFGeE_009EG`07AEmEGdE?E5m5Cooo00l0
6?oo000?ool0100?oom5CeAO0UEO00AFGfEOIUmUK`=VK`04MWmWKgIoMfl2Mgl03XMoMgn7SgQoQhn8
OhN?R7n7ShQoQhmhOgIoMgl2IVl016EOEEm4CdA?0c<o00HR7b4_4AlA7`0?40l300l01A0?4AlA7b8O
8Bl00S<o00I4CeA?EEmUKfI_MVl2Mgl037QoQhmgOhN?N7n7ShQoQhmhOhN?N7n7S`=gO`03MWmWKgI_
00=VK`04IFmVGfE_EUl3EEl014E?E5ooo`0?6?oo000?ool0100?oomEGdEO0UEO00AUKeIOIFmFK`9V
K`05IWmWKgIoIgmfO`02Mgl057QoMhmhOhN?N8n7SgR?R8mhOhN?N7n7SfMoMgmWKfIoEUmEKdE?A5l3
<cl01B8_4RlA7a4O01l00`0?00H07`0?4AlA7b8_4Rl2<cl01TAOA4mEKeIOIWmVK`9gO`0=QhmhOhN?
N8n8SgR?R8mhShR?N7n7SgQoQhl00WMo00AWOgMoIfmVO`9VK`04EUmUKeIOIFl4EEl00dEOool03`0H
ool000ooo`0C00oooeEOEEmFGfEOIUmUKfI_MVmWKgIoMfmfOgMoQgmhOhN?R7l00XR?00ZHShV?V9n9
SiROVHnIWiV?V9nIS`:8S`0?QgmgOgIoIfmUGeEO@dm4?d=?8Rlb;a4O8Al03a0?00<03`0740lA7b4O
8Rlb;d@o@dl00UEO01IWKgI_Mgn7ShR?V8nISiRORHnHWiV?VInISiROVHnHWhV?V8n8ShN?R7n7O`9g
O`03MfmfOfM_009VK`05IFmVGfEOEUmUG`02EEl00ooo00ooo`0Gool000ooo`0800oooeEOEEmEKeIO
IFmFK`9VK`0KMWmWKgMoIgmgOgQoMhmhOhR?RHn8ShV?R9n9WiVORInIWhVOVIn9SiRORHn8SgQoMhmW
KgIo009EG`05=4m4Cc@o8SlS;`024Al01P0O0@l03`0?01l13`8A7`0:8SlS;dA?=3mEGeIOMWmWKgN?
N7l2R8l02iRORHnIWhVOVIn9WiVORHnHWhV?V9l00XR?00AhShR?N7mgS`9gO`09IfmfOfM_IVmFGfE_
EUmEKeIO009EG`03ool03ooo01Ooo`003ooo00H03oooEEmUGfIOIFl3IVl04WIoMfmfOgMoQhmhOhN?
R8nHWhV?V9nIWjV_VInY[jZOZZnZW`:Z[`08ZJnZWjVOVInHWhV?QhmhO`9VK`09E5m4CeAO<blb?a4O
8Bl13a0?00803`080@l@3a4O8Blc;c8oA4mDG`9VK`08N7n7ShV?V9nIWjV_ZYnY[`>Z[`0=ZJnZ[jV_
VYnYWiVOV9nISiR?R8n7ShQoQgl00WMo00=gKgIoIVl00VI_00MUKfIOIFmEGfEOool03`0Hool000oo
o`0600oooeE_EUmUKeI_0VI_015fOfM_MgmWOgN?N7n7SgR?R8n9SiRORInIWiZOZJnJWjV_00JZ[`06
VYnI[hVOVImhOhN?0VI_00U5CeAOADlc?b<o4BlB7a0O0@l00P0?00P@7`4?4BlB7c<o8cmDGdE?0VI_
00R7SgQoVIn9SiV_VYnZ[iZ_0jZ_00JJ[jZ_VZnZ[iZOVJl2VIl01XV?R9n8ShR?N7mgS`9gO`0;Ifmf
OfI_IVmFGfE_EVmEKeIOool03`0Hool000ooo`0600oooeEOIEmFGfE_0VI_019WKgI_MgmgOgQoQgmg
OhR?R7nHShR?VInISjVOVInY[iZOZJl3ZZl04jV_ZYnY[iZOV9nIShN?N7mfKfI_E5m5CeA?<blc?a8O
8Al03a0O00<03`0741lB7b4O<blc?dE?E4l00VI_00UhOhN?VHnHWiZOZInZWjZ_ZYl00jZ_016ZWjV_
ZYnYWiZOV9nISiRORHn7ShQoQhmhOgIoMgmfOfM_009VK`07IFmFGfE_EEmUGooo00l06?oo000?ool0
700?oomEKeIOIVmFKfIoIfmgOfMoMhmhOhR?N8n8ShV?V9n9WiVOVYnY[jZ_Z[n[[k^oZknk_kbo0[^o
01:kcj^o^knJ[jZ_RInIWgQoMhmFGeE_EUlcCc@o8RlB7`0O0@l200l0300O0@lR;a8O<dld?eE_EUmg
SgQoVIn9W`:Z[`07^kn[[k_?_;nk_kbo^ll00[^o00J[[kZoZjnZ[iZOZJl2VIl04HV?R9mhShR?N7mg
SfMoMgmWKfIoEVmVKeI_EFmFGooo00l06?oo000?ool04@0?oomFGfE_IVmUKfI_MVmgKgIoMgn7OhR?
Qhn8OiROR8l00YVO00JY[iZOZZnZ[kZoZjl2^kl01/^o^knk_k^o^[nk[`:Z[`0=V9nISgMoMgmUGeEO
IFld?d<o8QlQ;`4?41l00P0?01813a0O8QlQ;c@o@cmEGfE_Mgn7OiV?V9nZ[jV_^jnj_k^obkl3^kl0
6kZo^knj_j^_^ZnZ[jV_VYnHWiVOV9n9ShN?R8n7SgMoMWmgKgIoIVmUKfI_IFmFGfE_ool03`0Hool0
00ooo`0E00ooofI_EUmVOfI_MWmWKgN?Mgn8SgQoR9n9ShRORInIWiZOZJnZ[jZo00:k_`08_;o;clc?
c<o=clcOcLoLg`;<c`09_;nkcjZ_ZZn9SiROIVmVOfM_0094C`8R;`0641l13`0?00l@7`4?0R8_0TA?
00AVOfM_V9n9S`:Z[`09^lnl_lc?c<oLglg?c=o=clcO00;<c`08_;o;cj^o^kn[[jZoVYnY[`:IW`0:
RHn8WgR?R8mgOgN?IgmfOfI_IWl2IVl00eIOool03`0Hool000ooo`0I00ooofIOIFmVKgI_MfmfOgMo
Qgn8OhN?R8nHShR?VInISjV_VYnj[jZ_^[nk_l_?_;l00/c?00?Lclc?g<l00lc?00W;_k^oZZnZ[iR?
R8mfKfI_MVl00TA?00@R7b4_0@l@7`803`040@l@7b8O8Bl2A4l016I_MVn8SiR?0ZZ_00>k_l^oc<l0
0/c?00?Lclg?g<l00/c?00o<_l^o_;nk_k^_^ZnZ[jV_VYnHWiVOV8n8ShN?R7l00WMo00UfOgM_IVmV
KgI_IUmUKooo00l06?oo000?ool02P0?oomVKeI_IWmWKgMoIgmgSgQo0XR?00FIWhV?V9nJWiV_00:Z
[`0DZknk_kboblo=clc?cMoMgmkOgMoNgmg_g]oMglg?c=nl_k^oVYnI[`=gO`06E5m5Cb8_8bl@7`4?
0P0?00H@7`4?8RlS;eAOADl2Mgl01YV_VYnk_kboc=o=c`;Mg`0=gNoNgng_g]oMklgOgMo=clcO_;o;
cj^o^kl00ZZ_016JWiV_RHnIWgR?R8mhOgN?IgmgOfM_IWmWKfI_EVooo`0?01Soo`003ooo01403ooo
IUmUKfI_MVmgKgIoMgn7ShQoQhn9SiRORHnYWiVO00:Z[`0D^[nk[l_?_;oLclc?g=oMcngOgMo]kmkO
kMoMgmcOcLo;_k^oZJnIW`=gO`06ADmDGb8_8Rl13a0O0P0?00H13a0O8RlR;dE?E5l2Mgl01YVOZInk
_k^ocLoLg`;Mg`03g]o]gmgO00;Mg`08g=oMglc?c<o;ckbo^[nk[`:Z[`0AZInIWiRORHn8ShQoQgmg
OgIoMfmfKfI_MVmVGfE_ool03`0Hool000ooo`0:00ooofI_EVmVOfM_MgmWOhN?N7l2R8l3VIl01YZO
ZJn[[kZo^knkc`;<c`0CcMoMgmkOkNo^knkokno^onk_k_oNgng_c<o<gj^_Z[mhOhN?N8l00UEO00@b
?b<_4Al17`803`044Al17c8o8bl2EEl03HN?N8nZ_jZ_c=o=cng_g]o^onk_k_o_knko00;^k`04g]o]
kmgOgMl2c<l03;bo^ln[[jZoVZnY[hVOVIn9ShR?N7n7S`9gO`07IfmVOfM_IVmFKooo00l06?oo000?
ool01P0?oomVKfI_IfmfK`9gO`0=N7n7ShR?R8nISiROVHnY[iZO^ZnZ[l^o^kl00/c?00CMgmg?kNoN
g`;^k`06o^o^knk_k^o]gmgO0/c?00Fj[jZ_QhmhOhN?009EG`048blb;a4?41l200l0114?41lS;c8_
0UEO01=hOhN?ZZnj[lc?g<oMgng_k^onknk_o^o^kok_k^o]kmkOg=oMc`02c<l04L^o^knj[j^_ZJnZ
WiVOVHnHShR?QhmhOgIoMgmfOfM_MVl00VI_00?oo`0?ool05ooo0009ool00`0?ooooo`03ool01P0?
oomVKfI_MWmWK`9gO`04R8mhOhRORHl3VIl04YZ_ZZn[[kZo_;o;clg?c=oNgmgOg^o^kno_o_o_oooo
koooo`;^k`05cMoMgj^_^kn9S`02R8l01UE_EUlc?b<_4Al17`803`064Al17c<o8bmEKeIO0XR?00fk
_j^ogMo=gnk_knooono_ooo_ooooknono`02k^l02]gOgNo=clcO_;nkcj^_^knJ[jZ_0YVO00B9ShRO
N7n8S`9gO`03IfmfOfM_009VK`03ool03ooo01Ooo`002?oo00<03ooo00l01?oo00H03oooIVmUKfM_
MWl2Mgl017QoQhn8SiR?0iVO00ZY[jZO^[n[[l^o^koLclc?kMoMg`;^k`06o_o_kokoononooo_0^k_
00GLgmg?^[n[[iR?00:8S`06EEmUGc<_<Sl13a0O0P0?00H13a0O<blb?eEOIEl2R8l01:^_^[oMcmcO
0^k_00Wokokoononooooo_o_kng_k^l00]gO00SLclc?blnl_kZoZjnY[jZO0YVO00BHShR?QhmhO`9g
O`07MWmWKgIoIVmUKooo00l06?oo0008ool00`0?ool03`04ool01P0?oomVKfI_MWmWK`9gO`04Qhmh
SiRORHl3VIl02YZ_ZZn[_k^o_;o;clg?g=oNgmg_0^k_00?_ookoool00ooo00C_knkogMoMg`:k_`09
RHn8WhV?IFmFGc8o8clA7`4O00803`084Al17c8o8cmUKeIOR9n9S`:k_`;Mg`03k_o_kooo00Coo`0<
koooonk_k_oNgmg_cLo<gkbobln[[kZo0ZZ_0YVO00B9SiRON7n7S`9gO`03IfmfOfM_009VK`803aSo
o`002?oo00<03ooo00l01?oo00H03oooIVmVKfM_MWl2Mgl017QoQhn8SiR?0iVO00jZ[jZO^[nk[l_?
_;oLclc?kMoMgok_k^onooo_0ooo00Gokok_k^oMgmg?00:k_`09V8n9SiR?EEmUKc<_<SlA3a0O0080
3`084@l@7c<_<SmEGfE_RHnHS`:k_`05gLoMgnk_o^ook`04ool03_koono^knk_kMoMgmcOcLo;ckbo
^[n[[jV_ZYl2VIl019R?R8n7SgQo0WMo00=fOfM_MWl00VI_00?oo`0?ool05ooo0009ool00`0?oooo
o`03ool01P0?oomVKfI_MWmWK`9gO`04R8mhOhRORHl3VIl04YZ_ZZn[[kZo_;o;clg?c=oNgmgOg^o^
kno_o_o_ooookoooo`;^k`05cMoMgj^_^kn9S`02R8l01UE_EUlc?b<_4Al17`803`064Al17c<o8bmE
KeIO0XR?00fk_j^ogMo=gnk_knooono_ooo_ooooknono`02k^l02]gOgNo=clcO_;nkcj^_^knJ[jZ_
0YVO00B9ShRON7n8S`9gO`03IfmfOfM_009VK`03ool03ooo01Ooo`003ooo00H03oooIVmUKfM_MWl2
Mgl017QoQhn8SiR?0iVO00ZY[jZO^[n[[l^o^koLclc?kMoMg`;^k`06o_o_kokoononooo_0^k_00GL
gmg?^[n[[iR?00:8S`06EEmUGc<_<Sl13a0O0P0?00H13a0O<blb?eEOIEl2R8l01:^_^[oMcmcO0^k_
00Wokokoononooooo_o_kng_k^l00]gO00SLclc?blnl_kZoZjnY[jZO0YVO00BHShR?QhmhO`9gO`07
MWmWKgIoIVmUKooo00l06?oo000?ool02P0?oomVKeI_IWmWKgMoIgn7SgQo0XR?0iVO00JJWjV_Zjnj
_k^o^ll2c<l04lgOgMoNgng_k^o^ono_k_o^knkog]o]klc?c=n[[jZoN7n7SgR?009EG`04<SlS;a4O
0Al200l0114O0Alb?b<_0UEO00f7SgR?Z[nZ[lcOcLo]kmkOk_o^knkokno^o`02k^l01=kOkNoMgmgO
0/c?00bl_k_?ZjnZ_iZ_ZJn9WiVORHn8SgQoQhl2Mgl01fM_IWmWKfI_EVooo`0?01Soo`003ooo00H0
3oooIVmVKfM_MVl2Mgl03GQoQhn8ShR?VHnHWiV?ZJnJWkZ_ZZo;_k^o00;<c`04gMoMcng_g]l2k^l0
1_k_k^o^knk_kMoMg`;<c`05^ZnZ[hN?N7n7S`02EEl012<_<RlA3a0O0P0?00@A3a0O8blb;`9EG`0C
N7n7SjZ_^Zo<cmc?gMo]knk_o^o^kok_k^onknk_kNoNgmcOgLl00/c?017;_k^o^Zn[[jV_ZYnIWiV?
V8n8ShN?N7mfOgMoMWmWKgI_009VK`03ool03ooo01Ooo`003ooo00X03oooIVmFKfIoIfmgOfMoMhmh
O`:8S`05VIn9SiROVYnI[`02ZZl05:^o^knl_l_?cLo<clgOgMoNgmgOg]oMkmkOgMo=clcO_;nk_iZO
VJl3Mgl01UAOADlR;b<_41l13`803`0641l13b8_8bmDGdE?0WMo00JI[iZO^knl_lcOcLl2gMl03Mg_
g]o]kmkOgNo=gmgOcLo<gkbobln[_k^o00:Z[`0AVYnI[hV?VImhShR?N7mgSfMoMgmWKfIoIfmVKeI_
ool03`0Hool000ooo`0A00ooofIOIFmVKgI_MfmfOgMoQhn8OhN?RHnHWhV?ZInIW`02ZZl05;Zo^jo;
ckbog<o<cmcOgLo]gmgOkNoNgngOgMoLglg?bknk_jV_VIl3Mgl01TE?E5lR;b8_0@l@7`803`060@l@
7b8_8Rm5CeAO0WMo00JIWjVO^knk_lg?g=l2gMl00mkOkMoMg`02gMl02=cOgMo<clc?blnl_kZo^jl2
ZZl04JVOVInHWhV?R8n8OhMoMgmfOgM_MVmVKgI_IUmUKooo00l06?oo000?ool05@0?oomVKeIOIWmV
KgIoIfmgSgMoR8mhOhRORHn8WhVOVInJWjV_ZZnZ_`02^kl02;boblo<clc?cLo<glg?g=l2c<l02Kbo
^lnZ[jZ_RHnHWfI_IWmWK`02A4l28Rl01Q0O0@l03`0?41l13`8R;`94C`04IWmWKiRORHl2ZZl02K_?
_;o<clc?g=o=clcOcLo<g`02c<l02;bobln[_k^oZjnZ_iZOZJl2VIl02XV?R9mhShR?MgmgSfMoMWmV
KfIo0VI_00=FGooo00l06?oo000?ool06@0?oomVGfE_IVmfKgM_MWmgOhMoR7n7ShR?V8n8SiVOVHnY
[iZO^ZnZ[kZo^ko;ckbo00;<c`03g<o<cmc?00?<c`09bknk_jZ_ZZnHShR?MVmVKgI_0094C`048QlQ
;`4?41l200l0104?41lR7b4_0TA?00AVKgI_R8nHS`:Z[`03^ko;_lc?00;<c`03g<o=cmc?00;<c`0?
c;o;_kbo^knk[kZ_ZZnY[iZOV9nIWiR?R8n7ShQo009gO`09MWmgKfI_IVmfKfIOIFooo`0?01Soo`00
3ooo01`03oooEFmFGfI_EVmVOfM_MgmWOgN?N7n8SgR?R8n9SiRORInIWiZOZJnZ[jZoZjnk_j^o^knl
_`:k_`0B^ln[_k^oVZnZ[hVOVImhOgN?EUmEKeIO<dld?b8_4Ql07`4?0P0?00`07`4?8RlB7c=?=3mE
KeIOMhmhOiVORIl2ZZl01k^oZjnkckbo^knl_k_?00:k_`06Zjnj_j^_ZZnJWjV_0YVO0169ShRON8n8
SgQoMhmWOgMoIfmVOeI_IVmFKeE_EUooo`0?01Soo`003ooo01403oooEUmUKfI_IFmVKgI_MfmfOgMo
Qgn8ShN?R7nHWhR?00:IW`06ZJnJWjZ_ZZnj_j^_0[^o00K;_k^o^knk_kZo^jl2ZZl03IROVHmgOgMo
IEmEGfE_=3m3?b8O8Bl13a0O00803`0B0@l@7b8O8Bld?d<oEEmUKgMoQgnISiROZZnY[k^_^[nk_l^o
0k^o01^j_k^o^[n[[kZ_ZZnY[iZOV9nIWiRORHn7ShR?QhmgOgIoMfmfOfI_IFmVKfE_EUmUKooo00l0
6?oo000?ool01P0?oomEKeIOIFmFK`9VK`0AMWmWKgMoIgmgSgQoQhmhShR?RHnHWhVOVInJWjV_VYnY
[`06ZZl01YZOVJn9WiVON7n7S`9VK`09ADmDGdE?<clS?a4_4Ql@7`4?00803`0841l13a4_4Qlc?b<o
E5m5C`9VK`08QhmhOiVORHnI[iZOZZnJ[`>Z[`06VZnZ[iZ_ZZnJWiV_0YVO00J9ShROR8n8SgQoMhl2
Mgl02fM_MWmVKfI_EUmUKeI_EFmFGooo00l06?oo000?ool01P0?oomEGfEOEUmUK`9VK`0BIfmfKgMo
MgmhOhMoMgn8ShQoV8n8SiVOVHnYWiVOZJnJWjV_0jZ_01>Y[jZOZJnJWiROVHn7SgQoMVmVKeAOADmD
Cc<_<clB7b4O00l@7`0300l01a0O4QlQ7c<_<cm5CeA?009VK`09N7n7SiV?V9nJWjVOZYnZ[jZO00>Z
[`0AZYnY[jZOZInJWiROVHnHWhV?Qhn8OhN?N7mfOgMoMWmWK`02IVl01fE_EUmUKeEOIEooo`0?01So
o`003ooo00P03oooEEmEGeE_EUmUKeI_0VI_01]fOfM_MgmWOgMoN7mgSgQoR8n9ShR?RHn8WhVOVIn9
WiVORInIWhV?V9n9ShR?N7mgSfM_MWl00UEO00DdCdA?=3lR?b<_008A7`0601l13`0?00l07`4?0Q4O
00XR?b<_A4ld?eEOEUmfOfM_MhmhO`:8S`0;V9n9SiVORInIWhVOVIn9SiRORHnHW`02R8l017R?R8mh
OgN?0WMo00UWKgIoIfmVKeIOIFmFGeE_EUl00UEO00?oo`0?ool05ooo000?ool00`0?oomEG`02EEl0
0fE_EUmUK`02IVl02FM_MWmgOgMoMfn7OgMoQhmhO`02R8l049RORHnHWiV?V9nISiROVInHWhV?V8n8
ShN?N7mfKfI_0UEO00E3Cd@o@dlR;c8_008A7`0300l@3`0?00803`0740lA7a4O8Rlb;d@o@dl00UEO
00AVKgIoN7n7O`:8S`0:RHnHWhV?V9nISiROVInHWhV?V9l3R8l028N?R7n7SgMoMWmgOgIoIfl2IVl0
1FE_EUmUGeEOIFl00UEO00?oo`0?ool05ooo000?ool0300?oomEGeEOEFmFGfI_EUmVOfI_MWmWK`=g
O`03N7mgSgR?00:8S`05R9n9SiRORHnHW`02VIl02XVOVIn9WiROR8n8WgQoQhmWKfIo0UEO00TdCd=?
=4lb?b<_4BlA7`0O0@l00P0?00P07`4?4BlA7c8o8bm3CcA?0UEO00UVOfM_QhmhOhRORHnHWhV?V9l0
0YVO00J9WiVORInIWhV?V9l2R8l03gR?QhmhOhN?IgmgOfM_MWmVKfIoEVmVKeIOEFmFG`02EEl00ooo
00ooo`0Gool000ooo`0400oooeE?E5l3EEl00fE_EUmUK`02IVl01FM_MVmVKgIoMfl00WMo01B7OgQo
QhmhOhN?R7n7ShQoQhmhOhMoN7mgOgM_MVmVKfEOEUmDCdA?0c<o0R8_00@A3a4O00l@3`<03`0340lA
3a4O008R;`8c?`0DA4mDCeIOIEmVKgI_MfmfOgQoQhmhOhN?R7n7ShQoQhn8OhN?N7n7O`=gO`04MWmg
KgIoIfl2IVl00fE_EUmUG`04EEl015E?E5ooo`0?6?oo000?ool0100?oomEGdEO0UEO00AEKeIOIVmF
G`9VK`04MWmWKfIoIgl3Mgl037QoMhmhOhN?N8n8SgR?R8mhShR?N7mgS`9gO`06IfmVOeIOEFm5CdAO
0c<o0R8_00@A7`4O01l13`803`0401l13a4O0Al28Rl2<cl05DAOADmEKeIOIWmWKgMoIgmgSgQoQhmh
OhN?N8n8SgQoR8mhOhN?N7mgS`02Mgl016M_MgmWKgIo0VI_00AFKfI_EUmEK`AEG`03AEooo`0?01So
o`003ooo00H03oooADmDGeE?E5l3EEl066E_EUmUKfI_IFmVGgI_IVmfOfM_MWmWKgIoIfmfOgMoMWmg
KgIoMfmfOfI_IFmVK`9EG`0=E4m4Cd=?=3lb?b8_<SlB7b4_4@l@7`0?40l00`0?01d@3a4?41lB7b4_
8Rlb?c@o@dm4CeAOEEmUGfI_IFmVKgI_IVmfOfM_MWmgKgIoMfmfOgM_MWmWKgI_00=VK`05IFmVKfE_
EUmUG`03EEl01eAOEDmDGdE?E5ooo`0?01Soo`003ooo00H03oooE5m5CeAOAEl2EEl015E_EUmUKeIO
16I_01mVOfM_MWmWKgIoIgmgOfMoMgmWOgMoIfmfOfM_MWmFKfI_EUmEKdE?A5ld?d=?8blb?b<_8BlB
7a4O0Al07`0300l03P0O00lA7`4O8BlB7c8o8bm3Cc@oA5m5CeE_EEl2IVl01WIoIfmVOfMoMgmWO`=g
O`0>IgmfOfMoMWmWKfIoIfmVKeI_IVmFKfE_EUmEK`9EG`07AEmDGdEOE5m5Cooo00l06?oo0008ool3
00l4ool02P0?oom4CeA?ADmDCeE?E5mECeAO0UEO00UFGfEOEEmUKeIOIFmVGfI_IUl00fI_00IVGfE_
IVmUKfIOIEl2EEl03UE?E4m4Cd=?=3lb?c<_8RlR7b8_4AlQ7`4?41l600l05@4?41lA7b4O8QlR;c<_
<cld?d=?A4mDCeE?E5mEGfE_EUmUKfIOIVmVG`03IVl02VIOIFmVKfE_IUmUKfIOIFmFGfEO0UEO00YE
CeAOEDmDGdE?E4m4CeA?ool03aSoo`002Ooo00<03oooool00ooo01803oooA5m5CeAOADmEGdEOEEm5
GeE_EUmUKeIOEFmFGfI_EUl3IVl02UI_IVmVKfI_EVmVKeI_IVmFGeE_0UEO00I5CdAO=4m4Cb<o<cl2
8Rl01a8_4BlB7a4O0@l07`4?00803`0D01l13a4O0@lA;a8O8RlB;c<o8cm4Cc@oA5m5CeEOAEmEKeIO
IFmFG`=VK`0>EVmVKfI_IVmFKfI_EVmVKeIOIFmFGfE_EEmEK`9EG`09ADmEGdE?E5m5CdAOADooo`0?
01Soo`002Ooo00<03oooool00ooo00@03oooA3m3C`=4C`08E4m5CeAOADmDGeEOE5mEC`AEG`05IEmE
GfEOEEmUG`03EEl04eAOEEmDGdE?E4m4Cd=?=3lb?c<o<RlR;b4_4QlQ;a4O41l03a0O00L03`0741lA
7a0O4QlQ;b8_<Rl00S<o00Td?d=?A4m4CdE?E5m5CeEOEDl015EO00EUGeEOEEmEGfEO00=EG`09E5mE
GeAOADmDGdE?E5m4CeA?0094C`04A3m3Cooo00lHool000Woo`0300oooooo00?oo`0<00ooodA?=4m4
GdE?E5m5CeAOADmEGdEO1EEO00QFGeEOEEmEKeIOEFmEGeE_0UEO00Q5GeEOAEmDGdA?A5ldCd=?0S<o
00DS;b8o4QlQ;a8_008A7`0341l13`0?00D03`0841l13a4O4AlQ;a8_8SlS;`8c?`07@dld?dAOADmD
GdE?E5l00eEO00UEKeIOEFmFGeE_EUmEKeEOEFl00UEO00e5GeEOAEmEGdE?E5m5CeAOA4m4GdE?A4ld
C`0200lHool000Soo`803`Goo`0600oood@o@dm4?d=?0dA?015DCdA?E4m5CeA?A4mDGdE?E5mECeAO
ADmDGeE?E5m5CeA?00=4C`04@dm4?d=?=3l2<cl02c8o8blQ;b8_8AlA7b4O4@lA7`4?40l01P0?00<1
3a0?4@l00Q4O00DQ7b8_8RlS;c8_008c?`0F=3m3?d@oA4m4?eA?A4mDGdE?E5mECeAOADmDGeE?E5m5
CeAOADmDGdE?E4l6A4l01T@o@dm4?d=?ool03aSoo`003ooo00H03oooA4ldCdA?=4l4A4l09TAOADmD
GdE?A5m5CeAOADmDGdEOEEm5CeAOADmEGdE?A5m5CdA?=4m4Cc@o@dlS?c<o8blb?a8_8RlB7a4_4QlA
7`4O41l13`0?0@l300l01`4?41l13a4O0AlA;a8O008R;`08<SlS;c<o<cm3Cc@oA4ldC`94C`0LA5m5
CeAOADmDGdEOEEm5CeAOAEmEGdE?E5m5CeAOADm4GdE?A4ldCdA?=4m4CcA?A4ldCooo00lHool000oo
o`0<00oooc@o@cld?d=?=3m3Cd@o@dm4?d=?2dA?0113CdA?@dm4?d=?=3m3?c<o<Slc?c8o8blQ;b8_
8BlB7`<A7`040@l@7`0?40l700l00a0?0@l@7`024Al04A8O8BlR;b8_8blb?c<o<Slc?d<o<cm3Cc@o
@dm4?dA?A3l024A?00m3CdA?A4m4?d=?A3m3Cc@o@dld?d=?=3m3?ooo00l06?oo000?ool0300?oom3
Cc@o@dldCdA?=4m4CcA?A4ldC`Q4C`0?A5m4CdA?=4m4CcA?A4ld?d=?=3lcCb<o<clS;c8o008R;`03
4QlQ;a4O00<A7`030@l07`4?00H03`0401l13a4O0@l24Al01R4_4QlR;b8_<SlS;`8c?`06<dld?c=?
=4m3CcA?24A?00=4GdA?A4l014A?00/dCdA?=4m4Cc@o@dldCd=?=3ooo`0?01Soo`003ooo00<03ooo
<cl00S<o01E3?c<o@cld?d<o=3m3Cc@o@dm4?d=?=3m3Cd@o@dld?d=?=3m3Cc@o@cl00c<o00@b?c<_
<SlS;`8R;`038BlB7b4O008A7`064@l@7`4?41l03a0?1`0?00T@3`4?41lA3a0O4AlQ7a8O8Bl00R8_
00DS;c8_<blb?c<_008c?`0G@clc?d<o<cm3Cc@o@dm4?d=?=3m3Cd@o@dld?d=?=3m3Cc@o@clc?d<o
<cm3?`02<cl00ooo00ooo`0Gool000ooo`0K00oooc=?=3lcCc@o<dld?d=?=3m3Cc@oA4ld?d=?=4m4
Cc@o@dld?dA?=3m3Cc@o@dld?c=?008c?`048clc?b<_<Sl28Rl0118_8RlB7a4_0Q4O00D17a0O0@l0
3`4?00L03`090@l@7`4?4Al17a4_4QlR;a8O008R;`04<SlS;c<o8cl3<cl06c@o<cld?c=?=3m3Cc@o
@dldCdA?=3m3Cc@oA4ld?d=?=3m3Cc@o<dld?c=?=3lcCc@oool03`0Hool000ooo`0400oooc<_<Sl7
<cl01D<o<clc?c<o@cl00c<o00]3?c<o<clc?c8o<clb?c<_<SlS;c8o00<R;`038BlB7b4O00<A7`05
41lA3a0O0@l@3`0:00l02P4?40lA3a0O4Al@7a4O8BlB7b4_0b8_00Db;b8_<SlS;c8o008c?`03<blc
?c<o008c?`05@clc?c<o<cm3?`03<cl01D<o<clc?c<o<Sl00S<o00@c;c8oool03aSoo`003ooo00@0
3ooo<clS?`@c?`0=<dld?c<o<clcCc@o<dlc?c=?=3lcCc<o<dl00S<o00PS?c<o<clc?b<_<SlS;c8o
0R8_00@B;b8_4QlA;`8A7`070Al@7`4O41l13`0O0@l01P0?00H07`4?41l13a0O0Al24Al0114_4QlR
;a8_0R8_00Hb?b<_8SlS?c8o8cl4<cl02S=?=3lc?c<o<dld?c=?<clcCc@o0S<o00<cCc<o<cl013<o
00<S?ooo00l06?oo000?ool06P0?oolc;c8o<blb?c<_<clc;c8o<blc?c<_<Slc;c<o<blb?c<_<Slc
;c8o<blb?b<_<Rl58Rl00b4_8QlQ7`034Al02A0O4@l@7`4?41l03a0?00l@3`0700l01Q0?00l@3`4?
41lA3`8A7`058AlA7b4_8QlQ;`028Rl07R8O<RlR;c8o8blb?c<_<Slc;c8o<blc?c<_<Slc;c<o<blb
?c<_<clc;c8o<blb?c<_<Slc;c8oool03aSoo`003ooo02`03ooo<clS?c<o8clc?b<o<clS?c<o8clc
?b<o<clS?c<o8clc?b<o<clS;c<o8blc?b<_8SlS;b8_4RlR;a8_8RlB7a4_4QlA7`4O4Al13a4O0@l0
7`4?2P0?00H07`4?4Al13a4O0Al24Al0114_4QlR;a8O128_01`R?b<_<SlS;c8o8clc?b<o<clS?c<o
8clc?b<o<clS?c<o8clc?b<o<clS?c<o8clc?b<oool03aSoo`003ooo01P03ooo8blb?b<_<SlS;c8o
8blb?b<_<SlS;c8o8blb?b<_<SlS;c8o8Rlb?b8_<Rl38Rl01B4_8RlQ;a8O8Bl00a4O00T@7a4O41l1
3a0O00l@7`0?40l02`0?00D@3`0?41l13a0O00<A7`088AlA7b4_4QlQ;b8O8RlR7`@R;`0G<RlR;c8o
8blb?b<_<SlS;c8o8blb?b<_<SlS;c8o8blb?b<_<SlS;c8oool03`0Hool000ooo`0I00oooc8o8blb
?b<_<SlS;c8o8clb?b<_<SlS?c8o8blb?b<_<SlS;c8o8blb?b8_8Sl00R8_00LB;b8_4RlR;a8O8BlB
7`034Al02@4O4Al13a0O0@l07`4?01l13`0600l0200O0@l07`4?41l13a4O0Al44Al01B4_4QlR;a8O
8Bl0128_01TS;b8o8blR?b<_<SlS;c8o8clb?b<_<SlS?c8o8blb?b<o<SlS;c8o8blb?b<_ool03`0H
ool000ooo`0B00ooob8_<RlR;c8_8Rlb;b<_<RlR;c8_8Rlb;b8_<RlR;c8_1R8_00PR7b4_8QlQ;a8O
8AlA7b4O114O00XA3a0O4@l@7`4?40l03a0?00l@3`L03`0940l03a0?0@l@3a4?41lA3a0O00<A7`09
8AlA7b4_4QlQ;b8O8BlR7b4_00<R;`0E<RlR;c8_8Rlb;b8_<RlR;c8_8Rlb;b<_<RlR;c8_8Rlb;b8_
<Rooo`0?01Soo`003ooo01@03ooo8SlS;b8o8blR?b<_8SlS;b8o8blR?b<_8SlS;b8o8blR?b<_1B8_
01<B;b8_4QlR;a8O4BlB7a4O0AlA7`4O4Al13a0O0@l@7`4?01l13`0:00l0200O0@l@7`4?41l13a4O
0Al34Al02A8O4BlB7b4_4QlQ;a8_8RlB;`048Rl0528o8blR;b<_8SlS;b8o8blR?b<_8SlS;b8o8blR
?b<_8SlS;ooo00lHool000ooo`0300ooob8_010R;`098BlR;b4_8QlQ;b8O8BlB7b4O00HA7`0:4@l@
7a4?41l13a0?00l@7`0?40l;00l02A0?00l@7`4?41lA3a0O4@l@7`034Al02B4O4AlQ;a8O8BlB7b4_
4QlQ;`028Rl00b8O8BlR;`0?8Rl00ooo00ooo`0Gool000ooo`0500ooob8_8RlR?`038Rl00b8o8RlR
;`088Rl0318_8RlR;b8_4RlQ;a8O8BlB7a4_4QlA;`@A7`0:0@l@7`4?41l13`0O0@l07`0?01l700l0
300O00l07`0?01l13a0O0@l@7`4O4Al17`8A7`0:4BlA7a4_4QlQ;a8O8BlB;b8_4Rl<8Rl01B8o8RlR
;b8_8Sl00b8_00?oo`0?ool05ooo000?ool01P0?oolR;b8_8QlQ;`8R;`068QlQ;b8_8RlR7b4_0R8_
00XR7b4_8QlQ;a8O8BlR7b4_4QlQ7`HA7`0:4@l@7a4?41l13a0?00l@3`0?40l300l00a0?00l03`05
00l03A0?00l03`0?40l03a0O0@l@7a4?41lA3a0O00<A7`0A8AlA7b4O4QlQ7a8O8BlB7b4_8QlQ;b8O
8BlR7b8_8QlQ;`028Rl01R8O8BlR;b8_8QlQ;`8R;`03ool03ooo01Ooo`003ooo00<03ooo8Rl00R8_
00DB;b8_8RlR;a8_00<R;`0?4RlR;a8_8RlB;b8_4RlR;a8O8BlB7b4_4QlA;a8O00DA7`0;0@lA7`4?
4Al13`0O0@l07`4?01l13`0:00l0300O0@l07`4?01l13a4O0@lA7`4O4Al17`@A7`0<4BlB7a4_4QlA
;a8O8RlB7b4_4RlR;a8_0b8_00DB;b8_8RlR;a8_00<R;`054RlR;b8_ool03`0Hool000ooo`0400oo
ob8O8Bl28Rl01R8O8BlR;b8_8QlQ;`8R;`0>8QlQ;b8_8BlR7b4_8QlQ;a8O8BlA7b4_4AlQ7`<A7`0=
41lA7a0O0@l@7`4?41l13a0?00l@3`0?40l02`0?00T@3`0?40l13a0?0@l@7`4?41l01a4O00dQ7a4O
8BlB7b4_4QlQ;a8O8BlR7b4_8QlQ;`028Rl01R8O8BlR;b8_8QlQ;`8R;`048QlQ;ooo00lHool000oo
o`0J00ooob8_4RlR;a8_8RlB;b4_4RlR;a8_8BlB;b8_4QlQ;a8O8BlB7b4_4QlQ;a8O4BlB7`DA7`0;
0AlA7`4O4Al13a0O0@l@7`0?01l13`0>00l0300O0@l@7`4?41l13a4O0@lA7`4O4Al17`@A7`0J4BlB
7a4_4QlA;a8O8BlB7b4_4RlQ;a8O8BlB;b8_4RlQ;a8_8RlB;b8_4RlR;a8_ool03aSoo`002?oo0`0?
1?oo01X03ooo8QlQ;b8O8BlR7b4_8QlQ;b8O8BlB7b4_8QlQ;a8O8BlB7b4_4QlQ7a4O8AlA7b4O0a4O
00d@7a4O41lA3a0O4@l@7`4?40l03a0?00l@3`0?00l02A0?00l@3`4?40lA3a0O4@l@7`024Al00a4?
4AlA7`024Al06B4O4AlQ7a8O8AlB7b4_4QlQ;b8O8BlB7b4_8QlQ;b8O8BlR7b4_8QlQ;b8O8Booo`0?
01Soo`002?oo00<03oooool01?oo01X03ooo8BlB7b8_4QlQ;a8O8RlB7b4_4QlQ;a8O4BlB7b4_4QlA
;a8O4BlB7a4_4QlA7`4O0a4O00l17a4O0AlA7`4?41l13a0O0@l07`4?00l13`0?0@l02`0?00l13`0?
0@l07`4?41l13a0O0@lA7`4?4Al17a4O0Al01A4O01LB7a4O4QlA;a8O4BlB7a4_4QlQ;a8O8BlB7b8_
4QlQ;a8O8RlB7b4_4Qooo`0?01Soo`002Ooo00<03oooool00ooo01@03ooo4QlQ;a8O8BlB7b4_4QlQ
;a8O8BlA7b4_4QlQ7a4O8BlA7b4O1a4O00d@7a4O41lA3a0O4@l@7`4?40l03a0?00l@3`0C00l03A0?
00l@7`4?41lA3a0O4@l@7a4?4AlA3a0O00<A7`0E8AlA7b4O4AlQ7a4O8BlB7b4_4AlQ;a8O8BlB7b4_
4QlQ;a8O8BlB7b4_00803aSoo`002?oo00<03ooo00l01?oo00<03ooo00l05_oo00<03oooool05?oo
00<03oooool05Ooo00<03oooool05?oo00<03ooo00l06?oo0009ool200l4oomR00lHool008Woo`00
ROoo0029ool000Koo`0300oooooo083oo`001ooo00<03oooool0Oooo0007ool00`0?ooooo`02ool0
1@0?ool03ooo00l00ooo00<03ooo00l0L_oo0006ool00`0?ool03`03ool01@0?ool03ooo00l00ooo
0P0?Looo0006ool00`0?ool03`03ool01@0?ool03ooo00l01?oo00<03oooool0LOoo0006ool00`0?
ool03`03ool0100?ool03`0?1?oo0P0?Looo0029ool000coo`0300oooooo07[oo`00ROoo0029ool0
08Woo`00ROoo0029ool008Woo`00ROoo0029ool008Woo`00\
\>"],
  ImageRangeCache->{{{0, 135.875}, {135.875, 0}} -> {-2.731022, -2.85938, 
  0.053482, 0.053482}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Magnetic Field"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(SetCoordinates[Spherical]; \)\), 
    \(\(Hd = Curl[Ad]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Hd01 = Simplify[Hd\ Exp[\(-I\)\ psi]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Hd0 = 
      \({Hd01\[LeftDoubleBracket]1\[RightDoubleBracket], 
            \[Sqrt]\((
                \((I\ \(ComplexExpand[Hd01]\)\[LeftDoubleBracket]2, 1
                          \[RightDoubleBracket])\)\^2 + 
                  \(ComplexExpand[Hd01]\)\[LeftDoubleBracket]2, 2
                      \[RightDoubleBracket]\^2)\), 0} /. case\) /. NSub; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Poynting Vector and Intensity"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Sd = \(c\ Ed0\[Cross]Hd0\)\/\(4\ \[Pi]\) /. NSub; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Id = \@\(Sd.Sd\); \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig16x5 = 
      SphericalPlot3D[
        Evaluate[Id /. Rr \[Rule] a\ 200], {Ttheta, \[Pi]\/100, \[Pi]}, {
          Pphi, \[Pi]\/2, \(-\(\[Pi]\/2\)\)}, Axes \[Rule] True, 
        Boxed \[Rule] True, 
        PlotRange \[Rule] {{0, 5}, {\(-5\), 5}, {\(-5\), 5}}, 
        ViewVertical \[Rule] {1, 0, 0}, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        AxesLabel \[Rule] {"\<z\>", "\<x\>", "\<y\>"}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .71057 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
-0.017978 1.017978 -0.095521 1.017978 [
[.98305 .23408 0 -8.65656 ]
[.98305 .23408 8 3.34344 ]
[.98861 .29604 0 -8.50811 ]
[.98861 .29604 8 3.49189 ]
[.9943 .35944 0 -8.35689 ]
[.9943 .35944 8 3.64311 ]
[1.00011 .42431 0 -8.20283 ]
[1.00011 .42431 8 3.79717 ]
[1.00606 .49071 0 -8.04584 ]
[1.00606 .49071 8 3.95416 ]
[1.01214 .5587 0 -7.88584 ]
[1.01214 .5587 8 4.11416 ]
[1.05666 .36908 0 -8.28022 ]
[1.05666 .36908 8 3.71978 ]
[.37631 .02882 -14 -8.5841 ]
[.37631 .02882 0 3.4159 ]
[.28278 .09212 -14 -8.39237 ]
[.28278 .09212 0 3.60763 ]
[.19759 .14977 -8 -8.22712 ]
[.19759 .14977 0 3.77288 ]
[.11967 .20249 -8 -8.08323 ]
[.11967 .20249 0 3.91677 ]
[.04814 .2509 -8 -7.9568 ]
[.04814 .2509 0 4.0432 ]
[.13794 .12763 -8 -8.22712 ]
[.13794 .12763 0 3.77288 ]
[.92551 .20641 -7.56314 -12 ]
[.92551 .20641 6.43686 0 ]
[.83106 .16392 -7.44421 -12 ]
[.83106 .16392 6.55579 0 ]
[.72946 .11821 -4.17953 -12 ]
[.72946 .11821 3.82047 0 ]
[.61987 .06892 -4.09793 -12 ]
[.61987 .06892 3.90207 0 ]
[.50133 .0156 -4.00792 -12 ]
[.50133 .0156 3.99208 0 ]
[.7266 .05465 -4.17953 -12 ]
[.7266 .05465 3.82047 0 ]
[ 0 0 0 0 ]
[ 1 .71057 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.97142 .23923 m
1 .56252 L
s
.97142 .23923 m
.9656 .2418 L
s
gsave
.98305 .23408 -61 -12.65656 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97687 .30095 m
.971 .3034 L
s
gsave
.98861 .29604 -61 -12.50811 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98246 .36409 m
.97653 .36641 L
s
gsave
.9943 .35944 -61 -12.35689 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98817 .42869 m
.9822 .43089 L
s
gsave
1.00011 .42431 -61 -12.20283 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99401 .49482 m
.98799 .49687 L
s
gsave
1.00606 .49071 -61 -12.04584 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
1 .56252 m
.99393 .56443 L
s
gsave
1.01214 .5587 -61 -11.88584 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.9725 .25146 m
.969 .25299 L
s
.97359 .26375 m
.97008 .26527 L
s
.97468 .27609 m
.97117 .27759 L
s
.97577 .28849 m
.97226 .28998 L
s
.97798 .31346 m
.97445 .31492 L
s
.97909 .32603 m
.97556 .32747 L
s
.98021 .33866 m
.97667 .34009 L
s
.98133 .35134 m
.97778 .35276 L
s
.98359 .37689 m
.98003 .37827 L
s
.98473 .38975 m
.98116 .39112 L
s
.98587 .40267 m
.9823 .40402 L
s
.98702 .41565 m
.98344 .41698 L
s
.98933 .4418 m
.98574 .4431 L
s
.99049 .45496 m
.98689 .45624 L
s
.99166 .46818 m
.98806 .46945 L
s
.99283 .48147 m
.98923 .48272 L
s
.9952 .50823 m
.99158 .50945 L
s
.99639 .52171 m
.99277 .52291 L
s
.99759 .53525 m
.99396 .53643 L
s
.99879 .54885 m
.99516 .55001 L
s
gsave
1.05666 .36908 -61 -12.28022 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
66.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25 Mabswid
.43822 0 m
.02665 .27748 L
s
.388 .03386 m
.39385 .03637 L
s
gsave
.37631 .02882 -75 -12.5841 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.2946 .09683 m
.30051 .09919 L
s
gsave
.28278 .09212 -75 -12.39237 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.20952 .15419 m
.21548 .15641 L
s
gsave
.19759 .14977 -69 -12.22712 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.13169 .20666 m
.1377 .20875 L
s
gsave
.11967 .20249 -69 -12.08323 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.06023 .25484 m
.06628 .25682 L
s
gsave
.04814 .2509 -69 -11.9568 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.3638 .05017 m
.36732 .05165 L
s
.34019 .06609 m
.34371 .06755 L
s
.31712 .08164 m
.32066 .08308 L
s
.27259 .11167 m
.27615 .11306 L
s
.25109 .12617 m
.25465 .12754 L
s
.23007 .14034 m
.23364 .14169 L
s
.18942 .16774 m
.193 .16905 L
s
.16976 .181 m
.17335 .18229 L
s
.15052 .19397 m
.15412 .19524 L
s
.11326 .21909 m
.11687 .22032 L
s
.09522 .23126 m
.09883 .23247 L
s
.07754 .24317 m
.08117 .24437 L
s
.4128 .01714 m
.41629 .01867 L
s
.04327 .26628 m
.04691 .26745 L
s
gsave
.13794 .12763 -69 -12.22712 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25 Mabswid
.97142 .23923 m
.43822 0 L
s
.92653 .21909 m
.92704 .22543 L
s
gsave
.92551 .20641 -68.56314 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.83186 .17661 m
.83226 .18296 L
s
gsave
.83106 .16392 -68.44421 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.73003 .13092 m
.73031 .13728 L
s
gsave
.72946 .11821 -65.17953 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.62019 .08164 m
.62034 .088 L
s
gsave
.61987 .06892 -65.09793 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.50135 .02833 m
.50137 .03469 L
s
gsave
.50133 .0156 -65.00792 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.9035 .20875 m
.90379 .21256 L
s
.88005 .19823 m
.88032 .20204 L
s
.85617 .18752 m
.85643 .19133 L
s
.80711 .16551 m
.80733 .16932 L
s
.78189 .15419 m
.7821 .15801 L
s
.7562 .14267 m
.75639 .14648 L
s
.70335 .11896 m
.70351 .12277 L
s
.67616 .10676 m
.6763 .11057 L
s
.64845 .09432 m
.64856 .09814 L
s
.59136 .06871 m
.59144 .07253 L
s
.56196 .05552 m
.56201 .05934 L
s
.53196 .04206 m
.53199 .04588 L
s
.94917 .22925 m
.94949 .23305 L
s
.47011 .01431 m
.4701 .01813 L
s
gsave
.7266 .05465 -65.17953 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25 Mabswid
.97142 .23923 m
.43822 0 L
s
.43822 0 m
.02665 .27748 L
s
.02665 .27748 m
.52718 .43592 L
s
.52718 .43592 m
.97142 .23923 L
s
1 .56252 m
.52895 .71057 L
s
.52895 .71057 m
0 .59155 L
s
0 .59155 m
.43437 .37832 L
s
.43437 .37832 m
1 .56252 L
s
.97142 .23923 m
.43822 0 L
s
.43822 0 m
.43437 .37832 L
s
.43437 .37832 m
1 .56252 L
s
1 .56252 m
.97142 .23923 L
s
.52718 .43592 m
.52895 .71057 L
s
.52895 .71057 m
0 .59155 L
s
0 .59155 m
.02665 .27748 L
s
.02665 .27748 m
.52718 .43592 L
s
0 0 m
1 0 L
1 .71057 L
0 .71057 L
closepath
clip
newpath
.5 Mabswid
.43397 .35055 m .39043 .35548 L .39173 .38953 L p .642 .451 .61 r
F P
0 g
s
.39043 .35548 m .3477 .35256 L .34878 .38989 L p .735 .524 .607 r
F P
0 g
s
.34878 .38989 m .39173 .38953 L .39043 .35548 L p .735 .524 .607 r
F P
0 g
s
.3477 .35256 m .31258 .34216 L .3134 .38008 L p .834 .604 .59 r
F P
0 g
s
.3134 .38008 m .34878 .38989 L .3477 .35256 L p .834 .604 .59 r
F P
0 g
s
.47191 .33859 m .43397 .35055 L .43534 .37918 L p .53 .365 .602 r
F P
0 g
s
.39173 .38953 m .43534 .37918 L .43397 .35055 L p .642 .451 .61 r
F P
0 g
s
.43534 .37918 m .39173 .38953 L .39693 .42125 L p .633 .424 .582 r
F P
0 g
s
.39173 .38953 m .34878 .38989 L .35407 .42474 L p .729 .49 .566 r
F P
0 g
s
.35407 .42474 m .39693 .42125 L .39173 .38953 L p .729 .49 .566 r
F P
0 g
s
.34878 .38989 m .3134 .38008 L .31842 .41546 L p .834 .563 .53 r
F P
0 g
s
.31842 .41546 m .35407 .42474 L .34878 .38989 L p .834 .563 .53 r
F P
0 g
s
.43534 .37918 m .47313 .36053 L .47191 .33859 L p .53 .365 .602 r
F P
0 g
s
.47313 .36053 m .43534 .37918 L .44004 .40577 L p .523 .351 .589 r
F P
0 g
s
.39693 .42125 m .44004 .40577 L .43534 .37918 L p .633 .424 .582 r
F P
0 g
s
.31258 .34216 m .2912 .32581 L .29181 .36147 L p .956 .708 .522 r
F P
0 g
s
.29181 .36147 m .3134 .38008 L .31258 .34216 L p .956 .708 .522 r
F P
0 g
s
.49914 .32151 m .47191 .33859 L .47313 .36053 L p .359 .236 .573 r
F P
0 g
s
.44004 .40577 m .39693 .42125 L .40602 .44987 L p .618 .392 .552 r
F P
0 g
s
.39693 .42125 m .35407 .42474 L .36355 .45624 L p .716 .446 .516 r
F P
0 g
s
.36355 .45624 m .40602 .44987 L .39693 .42125 L p .716 .446 .516 r
F P
0 g
s
.44004 .40577 m .47696 .38082 L .47313 .36053 L p .523 .351 .589 r
F P
0 g
s
.47696 .38082 m .44004 .40577 L .44805 .42965 L p .513 .334 .575 r
F P
0 g
s
.40602 .44987 m .44805 .42965 L .44004 .40577 L p .618 .392 .552 r
F P
0 g
s
.35407 .42474 m .31842 .41546 L .32765 .44744 L p .827 .508 .449 r
F P
0 g
s
.32765 .44744 m .36355 .45624 L .35407 .42474 L p .827 .508 .449 r
F P
0 g
s
.3134 .38008 m .29181 .36147 L .29634 .39465 L p .958 .653 .413 r
F P
0 g
s
.29634 .39465 m .31842 .41546 L .3134 .38008 L p .958 .653 .413 r
F P
0 g
s
.47313 .36053 m .50007 .33653 L .49914 .32151 L p .359 .236 .573 r
F P
0 g
s
.50007 .33653 m .47313 .36053 L .47696 .38082 L p .366 .247 .582 r
F P
0 g
s
.47696 .38082 m .50281 .35033 L .50007 .33653 L p .366 .247 .582 r
F P
0 g
s
.50281 .35033 m .47696 .38082 L .48335 .39893 L p .375 .258 .591 r
F P
0 g
s
.44805 .42965 m .48335 .39893 L .47696 .38082 L p .513 .334 .575 r
F P
0 g
s
.44805 .42965 m .40602 .44987 L .4189 .4746 L p .597 .353 .517 r
F P
0 g
s
.40602 .44987 m .36355 .45624 L .37717 .48355 L p .694 .389 .454 r
F P
0 g
s
.37717 .48355 m .4189 .4746 L .40602 .44987 L p .694 .389 .454 r
F P
0 g
s
.48335 .39893 m .44805 .42965 L .45927 .45016 L p .501 .315 .561 r
F P
0 g
s
.4189 .4746 m .45927 .45016 L .44805 .42965 L p .597 .353 .517 r
F P
0 g
s
.2912 .32581 m .28784 .30609 L .28835 .33692 L p .836 .657 .113 r
F P
0 g
s
.28835 .33692 m .29181 .36147 L .2912 .32581 L p .836 .657 .113 r
F P
0 g
s
.31842 .41546 m .29634 .39465 L .30479 .42454 L p .936 .565 .253 r
F P
0 g
s
.30479 .42454 m .32765 .44744 L .31842 .41546 L p .936 .565 .253 r
F P
0 g
s
.36355 .45624 m .32765 .44744 L .34104 .47513 L p .806 .426 .336 r
F P
0 g
s
.34104 .47513 m .37717 .48355 L .36355 .45624 L p .806 .426 .336 r
F P
0 g
s
.51298 .30218 m .49914 .32151 L .50007 .33653 L p .03 0 .474 r
F P
0 g
s
.48335 .39893 m .5073 .36257 L .50281 .35033 L p .375 .258 .591 r
F P
0 g
s
.5073 .36257 m .48335 .39893 L .49219 .41435 L p .385 .27 .599 r
F P
0 g
s
.45927 .45016 m .49219 .41435 L .48335 .39893 L p .501 .315 .561 r
F P
0 g
s
.50007 .33653 m .51356 .311 L .51298 .30218 L p .03 0 .474 r
F P
0 g
s
.51356 .311 m .50007 .33653 L .50281 .35033 L p .091 .066 .533 r
F P
0 g
s
.29181 .36147 m .28835 .33692 L .29224 .36549 L p .706 .497 0 r
F P
0 g
s
.29224 .36549 m .29634 .39465 L .29181 .36147 L p .706 .497 0 r
F P
0 g
s
.49219 .41435 m .45927 .45016 L .47351 .46668 L p .485 .295 .547 r
F P
0 g
s
.45927 .45016 m .4189 .4746 L .4354 .4947 L p .569 .304 .476 r
F P
0 g
s
.4354 .4947 m .47351 .46668 L .45927 .45016 L p .569 .304 .476 r
F P
0 g
s
.4189 .4746 m .37717 .48355 L .39475 .50583 L p .658 .31 .373 r
F P
0 g
s
.39475 .50583 m .4354 .4947 L .4189 .4746 L p .658 .31 .373 r
F P
0 g
s
.50281 .35033 m .5152 .31908 L .51356 .311 L p .091 .066 .533 r
F P
0 g
s
.5152 .31908 m .50281 .35033 L .5073 .36257 L p .156 .138 .584 r
F P
0 g
s
.49219 .41435 m .51345 .3729 L .5073 .36257 L p .385 .27 .599 r
F P
0 g
s
.51345 .3729 m .49219 .41435 L .50331 .42664 L p .395 .282 .606 r
F P
0 g
s
.47351 .46668 m .50331 .42664 L .49219 .41435 L p .485 .295 .547 r
F P
0 g
s
.32765 .44744 m .30479 .42454 L .3171 .45032 L p .857 .412 .01 r
F P
0 g
s
.3171 .45032 m .34104 .47513 L .32765 .44744 L p .857 .412 .01 r
F P
0 g
s
.5073 .36257 m .51787 .32619 L .5152 .31908 L p .156 .138 .584 r
F P
0 g
s
.51787 .32619 m .5073 .36257 L .51345 .3729 L p .22 .204 .627 r
F P
0 g
s
.29634 .39465 m .29224 .36549 L .29952 .39109 L p 0 0 .31 r
F P
0 g
s
.29952 .39109 m .30479 .42454 L .29634 .39465 L p 0 0 .31 r
F P
0 g
s
.37717 .48355 m .34104 .47513 L .35842 .49771 L p .755 .299 .168 r
F P
0 g
s
.35842 .49771 m .39475 .50583 L .37717 .48355 L p .755 .299 .168 r
F P
0 g
s
.28784 .30609 m .30368 .28622 L .30417 .31045 L p .051 0 .458 r
F P
0 g
s
.30417 .31045 m .28835 .33692 L .28784 .30609 L p .051 0 .458 r
F P
0 g
s
.50331 .42664 m .47351 .46668 L .49049 .47867 L p .467 .272 .532 r
F P
0 g
s
.47351 .46668 m .4354 .4947 L .45524 .50947 L p .529 .246 .429 r
F P
0 g
s
.45524 .50947 m .49049 .47867 L .47351 .46668 L p .529 .246 .429 r
F P
0 g
s
.51345 .3729 m .52152 .33214 L .51787 .32619 L p .22 .204 .627 r
F P
0 g
s
.52152 .33214 m .51345 .3729 L .52114 .38103 L p .28 .262 .66 r
F P
0 g
s
.50331 .42664 m .52114 .38103 L .51345 .3729 L p .395 .282 .606 r
F P
0 g
s
.52114 .38103 m .50331 .42664 L .51648 .4354 L p .406 .293 .612 r
F P
0 g
s
.49049 .47867 m .51648 .4354 L .50331 .42664 L p .467 .272 .532 r
F P
0 g
s
.51394 .28389 m .51298 .30218 L .51356 .311 L p 0 0 .141 r
F P
0 g
s
.4354 .4947 m .39475 .50583 L .41603 .5223 L p .597 .201 .264 r
F P
0 g
s
.41603 .5223 m .45524 .50947 L .4354 .4947 L p .597 .201 .264 r
F P
0 g
s
.51499 .29181 m .51421 .28803 L p .51427 .28975 L 0 0 .329 r
F P
0 g
s
.5152 .31908 m .51499 .29181 L p .51427 .28975 L 0 0 .329 r
F P
0 g
s
.51625 .29512 m .51499 .29181 L p .51515 .29371 L 0 0 .495 r
F P
0 g
s
.51787 .32619 m .51625 .29512 L p .51515 .29371 L 0 0 .495 r
F P
0 g
s
.51625 .29512 m .51795 .29787 L p .51735 .29654 L 0 0 .49 r
F P
0 g
s
.51499 .29181 m .51625 .29512 L p .51571 .29388 L .713 .367 0 r
F P
0 g
s
.51356 .311 m .51421 .28803 L p .51392 .28539 L 0 0 .141 r
F P
0 g
s
.51421 .28803 m .51356 .311 L .5152 .31908 L p 0 0 .329 r
F P
0 g
s
.51499 .29181 m .5152 .31908 L .51787 .32619 L p 0 0 .495 r
F P
0 g
s
.50635 .27215 m .51499 .29181 L p .51571 .29388 L .713 .367 0 r
F P
0 g
s
.51421 .28803 m .51499 .29181 L p .51451 .29068 L .89 .58 .076 r
F P
0 g
s
.50611 .27095 m .51421 .28803 L p .51451 .29068 L .89 .58 .076 r
F P
0 g
s
.51499 .29181 m .50635 .27215 L .50611 .27095 L p .89 .58 .076 r
F P
0 g
s
.50675 .27321 m .50635 .27215 L p .50663 .27279 L .713 .367 0 r
F P
0 g
s
.51625 .29512 m .50675 .27321 L p .50663 .27279 L .713 .367 0 r
F P
0 g
s
.50729 .27408 m .50675 .27321 L p .50706 .27389 L 0 0 .49 r
F P
0 g
s
.51795 .29787 m .50729 .27408 L p .50706 .27389 L 0 0 .49 r
F P
0 g
s
.51421 .28803 m .50611 .27095 L .50602 .26962 L p .971 .717 .294 r
F P
0 g
s
.50729 .27408 m .50797 .27474 L p .50752 .27426 L 0 .029 .546 r
F P
0 g
s
.49599 .26167 m .50675 .27321 L p .50687 .27361 L .754 .28 0 r
F P
0 g
s
.50675 .27321 m .51625 .29512 L p .51735 .29654 L 0 0 .49 r
F P
0 g
s
.49606 .26178 m .49599 .26167 L p .49607 .26176 L .754 .28 0 r
F P
0 g
s
.50729 .27408 m .49606 .26178 L p .49607 .26176 L .754 .28 0 r
F P
0 g
s
.49606 .26178 m .49615 .26187 L .49605 .26181 L p .649 .098 0 r
F P
0 g
s
.49605 .26181 m .49101 .25868 L .49606 .26178 L p .649 .098 0 r
F P
0 g
s
.49606 .26178 m .50729 .27408 L p .50752 .27426 L 0 .029 .546 r
F P
0 g
s
.50675 .27321 m .50729 .27408 L p .50687 .27361 L .754 .28 0 r
F P
0 g
s
.51421 .28803 m .51394 .28389 L p .51392 .28539 L 0 0 .141 r
F P
0 g
s
.28835 .33692 m .30417 .31045 L .30734 .33279 L p .097 .045 .504 r
F P
0 g
s
.30734 .33279 m .29224 .36549 L .28835 .33692 L p .097 .045 .504 r
F P
0 g
s
.52114 .38103 m .52604 .33676 L .52152 .33214 L p .28 .262 .66 r
F P
0 g
s
.52604 .33676 m .52114 .38103 L .53018 .38669 L p .335 .312 .684 r
F P
0 g
s
.51648 .4354 m .53018 .38669 L .52114 .38103 L p .406 .293 .612 r
F P
0 g
s
.34104 .47513 m .3171 .45032 L .33311 .47122 L p .655 .16 0 r
F P
0 g
s
.33311 .47122 m .35842 .49771 L .34104 .47513 L p .655 .16 0 r
F P
0 g
s
.30479 .42454 m .29952 .39109 L .3101 .41301 L p 0 0 .504 r
F P
0 g
s
.3101 .41301 m .3171 .45032 L .30479 .42454 L p 0 0 .504 r
F P
0 g
s
.51625 .29512 m .51787 .32619 L .52152 .33214 L p 0 .091 .62 r
F P
0 g
s
.53018 .38669 m .51648 .4354 L .53139 .44029 L p .416 .304 .617 r
F P
0 g
s
.51648 .4354 m .49049 .47867 L .50987 .48564 L p .447 .249 .517 r
F P
0 g
s
.50987 .48564 m .53139 .44029 L .51648 .4354 L p .447 .249 .517 r
F P
0 g
s
.49049 .47867 m .45524 .50947 L .47804 .51829 L p .477 .175 .374 r
F P
0 g
s
.47804 .51829 m .50987 .48564 L .49049 .47867 L p .477 .175 .374 r
F P
0 g
s
.39475 .50583 m .35842 .49771 L .37954 .51437 L p .633 .09 0 r
F P
0 g
s
.37954 .51437 m .41603 .5223 L .39475 .50583 L p .633 .09 0 r
F P
0 g
s
.52152 .33214 m .51795 .29787 L .51625 .29512 L p 0 .091 .62 r
F P
0 g
s
.51795 .29787 m .52152 .33214 L .52604 .33676 L p .116 .227 .703 r
F P
0 g
s
.53018 .38669 m .53134 .33991 L .52604 .33676 L p .335 .312 .684 r
F P
0 g
s
.53134 .33991 m .53018 .38669 L .54035 .3897 L p .383 .353 .701 r
F P
0 g
s
.53139 .44029 m .54035 .3897 L .53018 .38669 L p .416 .304 .617 r
F P
0 g
s
.29224 .36549 m .30734 .33279 L .31318 .35267 L p .147 .102 .546 r
F P
0 g
s
.31318 .35267 m .29952 .39109 L .29224 .36549 L p .147 .102 .546 r
F P
0 g
s
.52604 .33676 m .52007 .29999 L .51795 .29787 L p .116 .227 .703 r
F P
0 g
s
.52007 .29999 m .52604 .33676 L .53134 .33991 L p .243 .328 .752 r
F P
0 g
s
.30368 .28622 m .33599 .26948 L .33645 .28645 L p .408 .261 .568 r
F P
0 g
s
.33645 .28645 m .30417 .31045 L .30368 .28622 L p .408 .261 .568 r
F P
0 g
s
.45524 .50947 m .41603 .5223 L .4406 .53225 L p .495 .045 .112 r
F P
0 g
s
.4406 .53225 m .47804 .51829 L .45524 .50947 L p .495 .045 .112 r
F P
0 g
s
.50602 .26962 m .51394 .28389 L .51421 .28803 L p .971 .717 .294 r
F P
0 g
s
.54035 .3897 m .53727 .3415 L .53134 .33991 L p .383 .353 .701 r
F P
0 g
s
.53727 .3415 m .54035 .3897 L .5514 .38993 L p .424 .385 .711 r
F P
0 g
s
.54035 .3897 m .53139 .44029 L .54769 .44107 L p .427 .313 .622 r
F P
0 g
s
.54769 .44107 m .5514 .38993 L .54035 .3897 L p .427 .313 .622 r
F P
0 g
s
.53134 .33991 m .52254 .3014 L .52007 .29999 L p .243 .328 .752 r
F P
0 g
s
.52254 .3014 m .53134 .33991 L .53727 .3415 L p .342 .401 .778 r
F P
0 g
s
.53139 .44029 m .50987 .48564 L .53119 .48722 L p .424 .224 .503 r
F P
0 g
s
.53119 .48722 m .54769 .44107 L .53139 .44029 L p .424 .224 .503 r
F P
0 g
s
.3171 .45032 m .3101 .41301 L .32384 .43059 L p 0 .107 .643 r
F P
0 g
s
.32384 .43059 m .33311 .47122 L .3171 .45032 L p 0 .107 .643 r
F P
0 g
s
.30417 .31045 m .33645 .28645 L .33883 .30201 L p .405 .257 .564 r
F P
0 g
s
.33883 .30201 m .30734 .33279 L .30417 .31045 L p .405 .257 .564 r
F P
0 g
s
.53727 .3415 m .5253 .30208 L .52254 .3014 L p .342 .401 .778 r
F P
0 g
s
.5253 .30208 m .53727 .3415 L .54368 .34146 L p .418 .452 .789 r
F P
0 g
s
.5514 .38993 m .54368 .34146 L .53727 .3415 L p .424 .385 .711 r
F P
0 g
s
.35842 .49771 m .33311 .47122 L .35259 .48648 L p 0 .153 .661 r
F P
0 g
s
.35259 .48648 m .37954 .51437 L .35842 .49771 L p 0 .153 .661 r
F P
0 g
s
.29952 .39109 m .31318 .35267 L .3216 .36953 L p .199 .157 .583 r
F P
0 g
s
.3216 .36953 m .3101 .41301 L .29952 .39109 L p .199 .157 .583 r
F P
0 g
s
.50987 .48564 m .47804 .51829 L .50327 .52065 L p .407 .089 .311 r
F P
0 g
s
.50327 .52065 m .53119 .48722 L .50987 .48564 L p .407 .089 .311 r
F P
0 g
s
.50729 .27408 m .51795 .29787 L .52007 .29999 L p 0 .156 .697 r
F P
0 g
s
.54368 .34146 m .5514 .38993 L .56302 .3873 L p .46 .411 .717 r
F P
0 g
s
.5514 .38993 m .54769 .44107 L .56494 .43762 L p .437 .322 .625 r
F P
0 g
s
.56494 .43762 m .56302 .3873 L .5514 .38993 L p .437 .322 .625 r
F P
0 g
s
.52007 .29999 m .50797 .27474 L .50729 .27408 L p 0 .156 .697 r
F P
0 g
s
.50797 .27474 m .52007 .29999 L .52254 .3014 L p .111 .337 .806 r
F P
0 g
s
.54368 .34146 m .52826 .302 L .5253 .30208 L p .418 .452 .789 r
F P
0 g
s
.52826 .302 m .54368 .34146 L .55039 .33978 L p .477 .488 .79 r
F P
0 g
s
.56302 .3873 m .55039 .33978 L .54368 .34146 L p .46 .411 .717 r
F P
0 g
s
.52254 .3014 m .50875 .27518 L .50797 .27474 L p .111 .337 .806 r
F P
0 g
s
.50875 .27518 m .52254 .3014 L .5253 .30208 L p .286 .451 .85 r
F P
0 g
s
.41603 .5223 m .37954 .51437 L .404 .52439 L p .377 0 0 r
F P
0 g
s
.404 .52439 m .4406 .53225 L .41603 .5223 L p .377 0 0 r
F P
0 g
s
.54769 .44107 m .53119 .48722 L .55391 .48316 L p .399 .2 .49 r
F P
0 g
s
.55391 .48316 m .56494 .43762 L .54769 .44107 L p .399 .2 .49 r
F P
0 g
s
.5253 .30208 m .50962 .27538 L .50875 .27518 L p .286 .451 .85 r
F P
0 g
s
.50962 .27538 m .5253 .30208 L .52826 .302 L p .406 .52 .861 r
F P
0 g
s
.30734 .33279 m .33883 .30201 L .34308 .31576 L p .402 .252 .56 r
F P
0 g
s
.34308 .31576 m .31318 .35267 L .30734 .33279 L p .402 .252 .56 r
F P
0 g
s
.55039 .33978 m .53137 .30115 L .52826 .302 L p .477 .488 .79 r
F P
0 g
s
.53137 .30115 m .55039 .33978 L .55722 .33648 L p .523 .512 .785 r
F P
0 g
s
.55039 .33978 m .56302 .3873 L .57491 .38186 L p .49 .431 .718 r
F P
0 g
s
.57491 .38186 m .55722 .33648 L .55039 .33978 L p .49 .431 .718 r
F P
0 g
s
.52826 .302 m .51056 .27534 L .50962 .27538 L p .406 .52 .861 r
F P
0 g
s
.51056 .27534 m .52826 .302 L .53137 .30115 L p .49 .561 .855 r
F P
0 g
s
.56302 .3873 m .56494 .43762 L .58267 .42992 L p .446 .329 .627 r
F P
0 g
s
.58267 .42992 m .57491 .38186 L .56302 .3873 L p .446 .329 .627 r
F P
0 g
s
.47804 .51829 m .4406 .53225 L .46794 .53509 L p .326 0 0 r
F P
0 g
s
.46794 .53509 m .50327 .52065 L .47804 .51829 L p .326 0 0 r
F P
0 g
s
.53137 .30115 m .51154 .27506 L .51056 .27534 L p .49 .561 .855 r
F P
0 g
s
.51154 .27506 m .53137 .30115 L .53451 .29956 L p .551 .586 .842 r
F P
0 g
s
.55722 .33648 m .53451 .29956 L .53137 .30115 L p .523 .512 .785 r
F P
0 g
s
.4959 .2612 m .50602 .26962 L .50611 .27095 L p .967 .7 .477 r
F P
0 g
s
.33599 .26948 m .37826 .25825 L .37864 .2685 L p .553 .374 .592 r
F P
0 g
s
.37864 .2685 m .33645 .28645 L .33599 .26948 L p .553 .374 .592 r
F P
0 g
s
.50611 .27095 m .49591 .26137 L .4959 .2612 L p .967 .7 .477 r
F P
0 g
s
.49591 .26137 m .50611 .27095 L .50635 .27215 L p .958 .626 .336 r
F P
0 g
s
.50635 .27215 m .49594 .26153 L .49591 .26137 L p .958 .626 .336 r
F P
0 g
s
.49594 .26153 m .50635 .27215 L .50675 .27321 L p .906 .499 .123 r
F P
0 g
s
.53451 .29956 m .55722 .33648 L .56398 .33165 L p .559 .528 .776 r
F P
0 g
s
.55722 .33648 m .57491 .38186 L .58671 .37371 L p .515 .445 .715 r
F P
0 g
s
.58671 .37371 m .56398 .33165 L .55722 .33648 L p .515 .445 .715 r
F P
0 g
s
.50675 .27321 m .49599 .26167 L .49594 .26153 L p .906 .499 .123 r
F P
0 g
s
.53451 .29956 m .51253 .27454 L .51154 .27506 L p .551 .586 .842 r
F P
0 g
s
.51253 .27454 m .53451 .29956 L .53762 .29727 L p .596 .599 .826 r
F P
0 g
s
.56398 .33165 m .53762 .29727 L .53451 .29956 L p .559 .528 .776 r
F P
0 g
s
.49615 .26187 m .49625 .26193 L .49615 .26187 L p 0 .243 .66 r
F P
0 g
s
.49615 .26187 m .49101 .25868 L .49615 .26187 L p 0 .243 .66 r
F P
0 g
s
.49615 .26187 m .49606 .26178 L p .49614 .26187 L 0 .029 .546 r
F P
0 g
s
.50797 .27474 m .49615 .26187 L p .49614 .26187 L 0 .029 .546 r
F P
0 g
s
.49615 .26187 m .50797 .27474 L .50875 .27518 L p 0 .318 .8 r
F P
0 g
s
.3101 .41301 m .3216 .36953 L .33245 .38288 L p .249 .207 .613 r
F P
0 g
s
.33245 .38288 m .32384 .43059 L .3101 .41301 L p .249 .207 .613 r
F P
0 g
s
.50875 .27518 m .49625 .26193 L .49615 .26187 L p 0 .318 .8 r
F P
0 g
s
.49625 .26193 m .50875 .27518 L .50962 .27538 L p .199 .498 .905 r
F P
0 g
s
.53762 .29727 m .51351 .2738 L .51253 .27454 L p .596 .599 .826 r
F P
0 g
s
.51351 .2738 m .53762 .29727 L .5406 .29434 L p .629 .605 .807 r
F P
0 g
s
.53762 .29727 m .56398 .33165 L .57048 .32541 L p .588 .537 .765 r
F P
0 g
s
.57048 .32541 m .5406 .29434 L .53762 .29727 L p .588 .537 .765 r
F P
0 g
s
.50962 .27538 m .49636 .26195 L .49625 .26193 L p .199 .498 .905 r
F P
0 g
s
.49636 .26195 m .50962 .27538 L .51056 .27534 L p .383 .591 .926 r
F P
0 g
s
.33311 .47122 m .32384 .43059 L .34049 .44323 L p .113 .251 .728 r
F P
0 g
s
.34049 .44323 m .35259 .48648 L .33311 .47122 L p .113 .251 .728 r
F P
0 g
s
.53119 .48722 m .50327 .52065 L .53032 .51622 L p .319 0 .238 r
F P
0 g
s
.53032 .51622 m .55391 .48316 L .53119 .48722 L p .319 0 .238 r
F P
0 g
s
.51056 .27534 m .49649 .26195 L .49636 .26195 L p .383 .591 .926 r
F P
0 g
s
.49649 .26195 m .51056 .27534 L .51154 .27506 L p .499 .637 .916 r
F P
0 g
s
.56398 .33165 m .58671 .37371 L .59809 .36306 L p .536 .454 .71 r
F P
0 g
s
.59809 .36306 m .57048 .32541 L .56398 .33165 L p .536 .454 .71 r
F P
0 g
s
.33645 .28645 m .37864 .2685 L .38019 .27785 L p .543 .351 .57 r
F P
0 g
s
.38019 .27785 m .33883 .30201 L .33645 .28645 L p .543 .351 .57 r
F P
0 g
s
.5406 .29434 m .51445 .27286 L .51351 .2738 L p .629 .605 .807 r
F P
0 g
s
.51445 .27286 m .5406 .29434 L .54337 .29085 L p .656 .606 .787 r
F P
0 g
s
.5406 .29434 m .57048 .32541 L .57652 .31793 L p .61 .54 .751 r
F P
0 g
s
.57652 .31793 m .54337 .29085 L .5406 .29434 L p .61 .54 .751 r
F P
0 g
s
.51154 .27506 m .49661 .26191 L .49649 .26195 L p .499 .637 .916 r
F P
0 g
s
.49661 .26191 m .51154 .27506 L .51253 .27454 L p .576 .659 .894 r
F P
0 g
s
.31318 .35267 m .34308 .31576 L .34914 .32731 L p .398 .246 .557 r
F P
0 g
s
.34914 .32731 m .3216 .36953 L .31318 .35267 L p .398 .246 .557 r
F P
0 g
s
.57491 .38186 m .58267 .42992 L .60037 .41809 L p .454 .335 .627 r
F P
0 g
s
.60037 .41809 m .58671 .37371 L .57491 .38186 L p .454 .335 .627 r
F P
0 g
s
.51253 .27454 m .49674 .26184 L .49661 .26191 L p .576 .659 .894 r
F P
0 g
s
.49674 .26184 m .51253 .27454 L .51351 .2738 L p .629 .668 .869 r
F P
0 g
s
.51794 .26473 m .55166 .26875 L .55187 .26428 L p .717 .529 .634 r
F P
0 g
s
.55187 .26428 m .51802 .26331 L .51794 .26473 L p .717 .529 .634 r
F P
0 g
s
.59488 .26053 m .55187 .26428 L .55166 .26875 L p .659 .479 .63 r
F P
0 g
s
.54337 .29085 m .51532 .27175 L .51445 .27286 L p .656 .606 .787 r
F P
0 g
s
.51532 .27175 m .54337 .29085 L .54585 .28689 L p .676 .603 .766 r
F P
0 g
s
.54337 .29085 m .57652 .31793 L .58194 .30941 L p .628 .54 .735 r
F P
0 g
s
.58194 .30941 m .54585 .28689 L .54337 .29085 L p .628 .54 .735 r
F P
0 g
s
.56494 .43762 m .55391 .48316 L .5774 .4734 L p .373 .176 .479 r
F P
0 g
s
.5774 .4734 m .58267 .42992 L .56494 .43762 L p .373 .176 .479 r
F P
0 g
s
.51351 .2738 m .49687 .26174 L .49674 .26184 L p .629 .668 .869 r
F P
0 g
s
.49687 .26174 m .51351 .2738 L .51445 .27286 L p .667 .67 .843 r
F P
0 g
s
.51445 .27286 m .49699 .26162 L .49687 .26174 L p .667 .67 .843 r
F P
0 g
s
.49699 .26162 m .51445 .27286 L .51532 .27175 L p .696 .667 .817 r
F P
0 g
s
.51771 .2662 m .55092 .27338 L .55166 .26875 L p .716 .552 .666 r
F P
0 g
s
.55166 .26875 m .51794 .26473 L .51771 .2662 L p .716 .552 .666 r
F P
0 g
s
.59448 .2702 m .55166 .26875 L .55092 .27338 L p .66 .499 .655 r
F P
0 g
s
.55166 .26875 m .59448 .2702 L .59488 .26053 L p .659 .479 .63 r
F P
0 g
s
.54585 .28689 m .5161 .27049 L .51532 .27175 L p .676 .603 .766 r
F P
0 g
s
.5161 .27049 m .54585 .28689 L .54798 .28258 L p .692 .595 .744 r
F P
0 g
s
.54585 .28689 m .58194 .30941 L .58656 .3001 L p .642 .535 .718 r
F P
0 g
s
.58656 .3001 m .54798 .28258 L .54585 .28689 L p .642 .535 .718 r
F P
0 g
s
.49745 .26055 m .51794 .26473 L .51802 .26331 L p .77 .574 .634 r
F P
0 g
s
.51802 .26331 m .49746 .26037 L .49745 .26055 L p .77 .574 .634 r
F P
0 g
s
.51532 .27175 m .49711 .26147 L .49699 .26162 L p .696 .667 .817 r
F P
0 g
s
.49711 .26147 m .51532 .27175 L .5161 .27049 L p .718 .66 .791 r
F P
0 g
s
.49742 .26075 m .51771 .2662 L .51794 .26473 L p .766 .6 .672 r
F P
0 g
s
.51794 .26473 m .49745 .26055 L .49742 .26075 L p .766 .6 .672 r
F P
0 g
s
.5161 .27049 m .49721 .26131 L .49711 .26147 L p .718 .66 .791 r
F P
0 g
s
.49721 .26131 m .5161 .27049 L .51677 .26912 L p .735 .649 .764 r
F P
0 g
s
.54798 .28258 m .51677 .26912 L .5161 .27049 L p .692 .595 .744 r
F P
0 g
s
.51731 .26767 m .54968 .27803 L .55092 .27338 L p .712 .57 .694 r
F P
0 g
s
.55092 .27338 m .51771 .2662 L .51731 .26767 L p .712 .57 .694 r
F P
0 g
s
.59293 .28021 m .55092 .27338 L .54968 .27803 L p .658 .515 .678 r
F P
0 g
s
.55092 .27338 m .59293 .28021 L .59448 .2702 L p .66 .499 .655 r
F P
0 g
s
.51677 .26912 m .54798 .28258 L .54968 .27803 L p .703 .585 .72 r
F P
0 g
s
.54798 .28258 m .58656 .3001 L .59026 .29028 L p .651 .527 .699 r
F P
0 g
s
.59026 .29028 m .54968 .27803 L .54798 .28258 L p .651 .527 .699 r
F P
0 g
s
.49737 .26094 m .51731 .26767 L .51771 .2662 L p .759 .62 .705 r
F P
0 g
s
.51771 .2662 m .49742 .26075 L .49737 .26094 L p .759 .62 .705 r
F P
0 g
s
.51677 .26912 m .4973 .26113 L .49721 .26131 L p .735 .649 .764 r
F P
0 g
s
.4973 .26113 m .51677 .26912 L .51731 .26767 L p .749 .636 .736 r
F P
0 g
s
.54968 .27803 m .51731 .26767 L .51677 .26912 L p .703 .585 .72 r
F P
0 g
s
.54968 .27803 m .59026 .29028 L .59293 .28021 L p .658 .515 .678 r
F P
0 g
s
.51731 .26767 m .49737 .26094 L .4973 .26113 L p .749 .636 .736 r
F P
0 g
s
.57048 .32541 m .59809 .36306 L .60869 .35018 L p .553 .46 .703 r
F P
0 g
s
.60869 .35018 m .57652 .31793 L .57048 .32541 L p .553 .46 .703 r
F P
0 g
s
.37954 .51437 m .35259 .48648 L .37515 .49547 L p .035 .403 .856 r
F P
0 g
s
.37515 .49547 m .404 .52439 L .37954 .51437 L p .035 .403 .856 r
F P
0 g
s
.49591 .26137 m .49101 .25868 L .4959 .2612 L closepath p .906 .649 .539 r
F P
0 g
s
.49594 .26153 m .49101 .25868 L .49591 .26137 L closepath p .907 .593 .439 r
F P
0 g
s
.49599 .26167 m .49101 .25868 L .49594 .26153 L closepath p .89 .504 .293 r
F P
0 g
s
.49606 .26178 m .49101 .25868 L .49599 .26167 L closepath p .826 .353 .067 r
F P
0 g
s
.49636 .26195 m .49101 .25868 L .49625 .26193 L closepath p .073 .518 .9 r
F P
0 g
s
.49649 .26195 m .49101 .25868 L .49636 .26195 L closepath p .34 .656 .971 r
F P
0 g
s
.49661 .26191 m .49101 .25868 L .49649 .26195 L closepath p .499 .712 .966 r
F P
0 g
s
.49674 .26184 m .49101 .25868 L .49661 .26191 L closepath p .596 .732 .939 r
F P
0 g
s
.64061 .25039 m .59488 .26053 L .59448 .2702 L p .587 .418 .62 r
F P
0 g
s
.49687 .26174 m .49101 .25868 L .49674 .26184 L closepath p .658 .735 .907 r
F P
0 g
s
.57652 .31793 m .60869 .35018 L .61819 .33544 L p .567 .461 .693 r
F P
0 g
s
.61819 .33544 m .58194 .30941 L .57652 .31793 L p .567 .461 .693 r
F P
0 g
s
.49699 .26162 m .49101 .25868 L .49687 .26174 L closepath p .701 .731 .874 r
F P
0 g
s
.49711 .26147 m .49101 .25868 L .49699 .26162 L closepath p .732 .723 .842 r
F P
0 g
s
.49746 .26037 m .49101 .25868 L .49745 .26055 L closepath p .818 .616 .63 r
F P
0 g
s
.49721 .26131 m .49101 .25868 L .49711 .26147 L closepath p .756 .712 .811 r
F P
0 g
s
.49745 .26055 m .49101 .25868 L .49742 .26075 L closepath p .811 .643 .675 r
F P
0 g
s
.4973 .26113 m .49101 .25868 L .49721 .26131 L closepath p .775 .699 .78 r
F P
0 g
s
.49742 .26075 m .49101 .25868 L .49737 .26094 L closepath p .802 .665 .713 r
F P
0 g
s
.49737 .26094 m .49101 .25868 L .4973 .26113 L closepath p .79 .684 .747 r
F P
0 g
s
.33883 .30201 m .38019 .27785 L .38289 .28606 L p .527 .323 .547 r
F P
0 g
s
.38289 .28606 m .34308 .31576 L .33883 .30201 L p .527 .323 .547 r
F P
0 g
s
.58671 .37371 m .60037 .41809 L .61749 .40242 L p .462 .339 .627 r
F P
0 g
s
.61749 .40242 m .59809 .36306 L .58671 .37371 L p .462 .339 .627 r
F P
0 g
s
.64002 .26719 m .59448 .2702 L .59293 .28021 L p .589 .433 .638 r
F P
0 g
s
.59448 .2702 m .64002 .26719 L .64061 .25039 L p .587 .418 .62 r
F P
0 g
s
.58194 .30941 m .61819 .33544 L .6263 .31927 L p .577 .459 .682 r
F P
0 g
s
.6263 .31927 m .58656 .3001 L .58194 .30941 L p .577 .459 .682 r
F P
0 g
s
.4817 .25642 m .49077 .2586 L .49077 .2586 L p .812 .575 .579 r
F P
0 g
s
.49077 .2586 m .48172 .25671 L .4817 .25642 L p .812 .575 .579 r
F P
0 g
s
.48172 .25671 m .49077 .2586 L .49077 .2586 L p .809 .529 .514 r
F P
0 g
s
.49077 .2586 m .48177 .25698 L .48172 .25671 L p .809 .529 .514 r
F P
0 g
s
.48177 .25698 m .49077 .2586 L .49077 .2586 L p .796 .464 .426 r
F P
0 g
s
.49077 .2586 m .48186 .25721 L .48177 .25698 L p .796 .464 .426 r
F P
0 g
s
.48186 .25721 m .49077 .2586 L .49077 .2586 L p .765 .367 .3 r
F P
0 g
s
.49077 .2586 m .48198 .2574 L .48186 .25721 L p .765 .367 .3 r
F P
0 g
s
.48198 .2574 m .49077 .2586 L .49077 .2586 L p .692 .214 .11 r
F P
0 g
s
.49077 .2586 m .48212 .25755 L .48198 .2574 L p .692 .214 .11 r
F P
0 g
s
.48212 .25755 m .49077 .2586 L .49077 .2586 L p .532 0 0 r
F P
0 g
s
.49077 .2586 m .48229 .25764 L .48212 .25755 L p .532 0 0 r
F P
0 g
s
.48229 .25764 m .49077 .2586 L .49077 .2586 L p .228 0 0 r
F P
0 g
s
.49077 .2586 m .48248 .25769 L p .48247 .25766 L .228 0 0 r
F P
0 g
s
.48269 .25768 m .48248 .25769 L p .48266 .25771 L .154 .681 .869 r
F P
0 g
s
.49077 .2586 m .48269 .25768 L p .48266 .25771 L .154 .681 .869 r
F P
0 g
s
.48269 .25768 m .4829 .25761 L p .48272 .25764 L .296 .793 .816 r
F P
0 g
s
.48248 .25769 m .48269 .25768 L p .48249 .25771 L .051 0 0 r
F P
0 g
s
.46272 .26113 m .48248 .25769 L p .48249 .25771 L .051 0 0 r
F P
0 g
s
.48248 .25769 m .49077 .2586 L .49077 .2586 L p .154 .681 .869 r
F P
0 g
s
.46393 .26106 m .46272 .26113 L p .46355 .26098 L .051 0 0 r
F P
0 g
s
.48269 .25768 m .46393 .26106 L p .46355 .26098 L .051 0 0 r
F P
0 g
s
.46393 .26106 m .48269 .25768 L p .48272 .25764 L .296 .793 .816 r
F P
0 g
s
.48248 .25769 m .46272 .26113 L .4616 .26087 L p .358 0 0 r
F P
0 g
s
.46519 .26068 m .46393 .26106 L p .46472 .26092 L .296 .793 .816 r
F P
0 g
s
.4829 .25761 m .46519 .26068 L p .46472 .26092 L .296 .793 .816 r
F P
0 g
s
.48229 .25764 m .4616 .26087 L .4606 .2603 L p .55 .067 .063 r
F P
0 g
s
.4616 .26087 m .48229 .25764 L .48248 .25769 L p .358 0 0 r
F P
0 g
s
.4606 .2603 m .48212 .25755 L .48229 .25764 L p .55 .067 .063 r
F P
0 g
s
.46648 .25999 m .46519 .26068 L p .46594 .26055 L .553 .924 .935 r
F P
0 g
s
.48312 .25749 m .46648 .25999 L p .46594 .26055 L .553 .924 .935 r
F P
0 g
s
.48212 .25755 m .4606 .2603 L .45974 .25943 L p .653 .242 .251 r
F P
0 g
s
.46648 .25999 m .46775 .259 L p .46702 .25942 L .565 .922 .744 r
F P
0 g
s
.46519 .26068 m .46648 .25999 L p .46567 .26044 L 0 0 0 r
F P
0 g
s
.48248 .25769 m .48229 .25764 L p .48247 .25766 L .228 0 0 r
F P
0 g
s
.46519 .26068 m .4829 .25761 L .48312 .25749 L p .553 .924 .935 r
F P
0 g
s
.44161 .27392 m .46519 .26068 L p .46567 .26044 L 0 0 0 r
F P
0 g
s
.46393 .26106 m .46519 .26068 L p .46431 .26114 L 0 0 0 r
F P
0 g
s
.438 .275 m .46393 .26106 L p .46431 .26114 L 0 0 0 r
F P
0 g
s
.46519 .26068 m .44161 .27392 L .438 .275 L p 0 0 0 r
F P
0 g
s
.44529 .27193 m .44161 .27392 L p .44302 .27313 L 0 0 0 r
F P
0 g
s
.46648 .25999 m .44529 .27193 L p .44302 .27313 L 0 0 0 r
F P
0 g
s
.44529 .27193 m .46648 .25999 L p .46702 .25942 L .565 .922 .744 r
F P
0 g
s
.46393 .26106 m .438 .275 L .43455 .27516 L p .227 0 0 r
F P
0 g
s
.43455 .27516 m .46272 .26113 L .46393 .26106 L p .227 0 0 r
F P
0 g
s
.44895 .26909 m .44529 .27193 L p .44657 .27119 L .565 .922 .744 r
F P
0 g
s
.46775 .259 m .44895 .26909 L p .44657 .27119 L .565 .922 .744 r
F P
0 g
s
.46272 .26113 m .43455 .27516 L .43138 .27439 L p .411 0 .085 r
F P
0 g
s
.48186 .25721 m .45905 .25829 L .45855 .25691 L p .738 .435 .47 r
F P
0 g
s
.45905 .25829 m .48186 .25721 L .48198 .2574 L p .708 .357 .379 r
F P
0 g
s
.48198 .2574 m .45974 .25943 L .45905 .25829 L p .708 .357 .379 r
F P
0 g
s
.45974 .25943 m .48198 .2574 L .48212 .25755 L p .653 .242 .251 r
F P
0 g
s
.43138 .27439 m .4616 .26087 L .46272 .26113 L p .411 0 .085 r
F P
0 g
s
.45247 .26546 m .44895 .26909 L p .45009 .26844 L .73 .988 .803 r
F P
0 g
s
.46897 .25775 m .45247 .26546 L p .45009 .26844 L .73 .988 .803 r
F P
0 g
s
.42614 .27019 m .45974 .25943 L .4606 .2603 L p .602 .255 .353 r
F P
0 g
s
.4606 .2603 m .42855 .27271 L .42614 .27019 L p .602 .255 .353 r
F P
0 g
s
.42855 .27271 m .4606 .2603 L .4616 .26087 L p .529 .135 .24 r
F P
0 g
s
.4616 .26087 m .43138 .27439 L .42855 .27271 L p .529 .135 .24 r
F P
0 g
s
.48177 .25698 m .45855 .25691 L .45825 .25532 L p .753 .492 .537 r
F P
0 g
s
.45855 .25691 m .48177 .25698 L .48186 .25721 L p .738 .435 .47 r
F P
0 g
s
.45576 .26116 m .45247 .26546 L p .45348 .26494 L .831 1 .807 r
F P
0 g
s
.4701 .25627 m .45576 .26116 L p .45348 .26494 L .831 1 .807 r
F P
0 g
s
.42201 .25833 m .45825 .25532 L .45855 .25691 L p .694 .453 .554 r
F P
0 g
s
.45855 .25691 m .42283 .2629 L .42201 .25833 L p .694 .453 .554 r
F P
0 g
s
.42283 .2629 m .45855 .25691 L .45905 .25829 L p .677 .404 .502 r
F P
0 g
s
.45905 .25829 m .42422 .26689 L .42283 .2629 L p .677 .404 .502 r
F P
0 g
s
.42422 .26689 m .45905 .25829 L .45974 .25943 L p .648 .341 .437 r
F P
0 g
s
.45974 .25943 m .42614 .27019 L .42422 .26689 L p .648 .341 .437 r
F P
0 g
s
.45576 .26116 m .45872 .2563 L p .45804 .25738 L .617 .805 .383 r
F P
0 g
s
.45247 .26546 m .45576 .26116 L p .45485 .26249 L 0 0 0 r
F P
0 g
s
.44895 .26909 m .46775 .259 L .46897 .25775 L p .73 .988 .803 r
F P
0 g
s
.45247 .26546 m .46897 .25775 L .4701 .25627 L p .831 1 .807 r
F P
0 g
s
.44028 .28375 m .45247 .26546 L p .45485 .26249 L 0 0 0 r
F P
0 g
s
.4471 .27483 m .44028 .28375 L p .44108 .28259 L 0 0 0 r
F P
0 g
s
.45576 .26116 m .4471 .27483 L p .44108 .28259 L 0 0 0 r
F P
0 g
s
.4471 .27483 m .45576 .26116 L p .45804 .25738 L .617 .805 .383 r
F P
0 g
s
.45327 .26471 m .4471 .27483 L p .4477 .27387 L .617 .805 .383 r
F P
0 g
s
.45872 .2563 m .45327 .26471 L p .4477 .27387 L .617 .805 .383 r
F P
0 g
s
.48172 .25671 m .45825 .25532 L .45815 .25357 L p .759 .533 .59 r
F P
0 g
s
.45825 .25532 m .48172 .25671 L .48177 .25698 L p .753 .492 .537 r
F P
0 g
s
.42178 .25332 m .45815 .25357 L .45825 .25532 L p .703 .49 .596 r
F P
0 g
s
.45825 .25532 m .42201 .25833 L .42178 .25332 L p .703 .49 .596 r
F P
0 g
s
.45815 .25357 m .4817 .25642 L .48172 .25671 L p .759 .533 .59 r
F P
0 g
s
.45327 .26471 m .45872 .2563 L .46127 .25101 L p .695 .821 .372 r
F P
0 g
s
.45859 .25368 m .45327 .26471 L p .45369 .264 L .695 .821 .372 r
F P
0 g
s
.46127 .25101 m .45859 .25368 L p .45369 .264 L .695 .821 .372 r
F P
0 g
s
.46292 .24206 m .46334 .24545 L .46487 .23976 L p .745 .757 .246 r
F P
0 g
s
.46334 .24545 m .46292 .24206 L .45859 .25368 L p .738 .804 .326 r
F P
0 g
s
.45859 .25368 m .46292 .24206 L p .46339 .24359 L 0 0 .276 r
F P
0 g
s
.46648 .25999 m .48312 .25749 L .48333 .25733 L p .703 .955 .951 r
F P
0 g
s
.48333 .25733 m .46775 .259 L .46648 .25999 L p .703 .955 .951 r
F P
0 g
s
.46775 .259 m .48333 .25733 L .48354 .25712 L p .788 .946 .926 r
F P
0 g
s
.48354 .25712 m .46897 .25775 L .46775 .259 L p .788 .946 .926 r
F P
0 g
s
.45576 .26116 m .4701 .25627 L .47112 .2546 L p .895 .987 .782 r
F P
0 g
s
.47112 .2546 m .45872 .2563 L .45576 .26116 L p .895 .987 .782 r
F P
0 g
s
.45872 .2563 m .47112 .2546 L .472 .25278 L p .936 .965 .741 r
F P
0 g
s
.46334 .24545 m .47271 .25087 L .47324 .24892 L p .985 .903 .619 r
F P
0 g
s
.47324 .24892 m .46487 .23976 L .46334 .24545 L p .985 .903 .619 r
F P
0 g
s
.472 .25278 m .46127 .25101 L .45872 .2563 L p .936 .965 .741 r
F P
0 g
s
.46127 .25101 m .472 .25278 L .47271 .25087 L p .965 .936 .687 r
F P
0 g
s
.47271 .25087 m .46334 .24545 L .46127 .25101 L p .965 .936 .687 r
F P
0 g
s
.45859 .25368 m .46127 .25101 L .46334 .24545 L p .738 .804 .326 r
F P
0 g
s
.46935 .26261 m .45859 .25368 L p .46339 .24359 L 0 0 .276 r
F P
0 g
s
.45327 .26471 m .45859 .25368 L p .45872 .25574 L 0 0 .253 r
F P
0 g
s
.46027 .28137 m .45327 .26471 L p .45872 .25574 L 0 0 .253 r
F P
0 g
s
.4471 .27483 m .45327 .26471 L p .45301 .26723 L .005 0 .245 r
F P
0 g
s
.44976 .29853 m .4471 .27483 L p .45301 .26723 L .005 0 .245 r
F P
0 g
s
.44895 .26909 m .45247 .26546 L p .45133 .26698 L 0 0 0 r
F P
0 g
s
.43299 .29123 m .44895 .26909 L p .45133 .26698 L 0 0 0 r
F P
0 g
s
.44529 .27193 m .44895 .26909 L p .44757 .27073 L 0 0 0 r
F P
0 g
s
.42546 .29706 m .44529 .27193 L p .44757 .27073 L 0 0 0 r
F P
0 g
s
.48269 .25768 m .49077 .2586 L .49077 .2586 L p .442 .829 .987 r
F P
0 g
s
.49077 .2586 m .4829 .25761 L .48269 .25768 L p .442 .829 .987 r
F P
0 g
s
.4829 .25761 m .49077 .2586 L .49077 .2586 L p .609 .869 .991 r
F P
0 g
s
.49077 .2586 m .48312 .25749 L .4829 .25761 L p .609 .869 .991 r
F P
0 g
s
.48312 .25749 m .49077 .2586 L .49077 .2586 L p .703 .868 .96 r
F P
0 g
s
.49077 .2586 m .48333 .25733 L .48312 .25749 L p .703 .868 .96 r
F P
0 g
s
.48333 .25733 m .49077 .2586 L .49078 .2586 L p .76 .853 .92 r
F P
0 g
s
.49078 .2586 m .48354 .25712 L .48333 .25733 L p .76 .853 .92 r
F P
0 g
s
.48354 .25712 m .49078 .2586 L .49078 .2586 L p .798 .835 .88 r
F P
0 g
s
.48431 .25532 m .49078 .25859 L .49078 .25859 L p .908 .698 .608 r
F P
0 g
s
.49078 .25859 m .48433 .25501 L .48431 .25532 L p .908 .698 .608 r
F P
0 g
s
.49078 .2586 m .48373 .25687 L .48354 .25712 L p .798 .835 .88 r
F P
0 g
s
.48373 .25687 m .49078 .2586 L .49078 .2586 L p .826 .816 .84 r
F P
0 g
s
.48425 .25564 m .49078 .25859 L .49078 .25859 L p .896 .729 .667 r
F P
0 g
s
.49078 .25859 m .48431 .25532 L .48425 .25564 L p .896 .729 .667 r
F P
0 g
s
.49078 .2586 m .4839 .25659 L .48373 .25687 L p .826 .816 .84 r
F P
0 g
s
.4839 .25659 m .49078 .2586 L .49078 .2586 L p .848 .797 .801 r
F P
0 g
s
.48417 .25597 m .49078 .25859 L .49078 .25859 L p .882 .754 .717 r
F P
0 g
s
.49078 .25859 m .48425 .25564 L .48417 .25597 L p .882 .754 .717 r
F P
0 g
s
.49078 .2586 m .48405 .25629 L .4839 .25659 L p .848 .797 .801 r
F P
0 g
s
.48405 .25629 m .49078 .2586 L .49078 .25859 L p .866 .776 .76 r
F P
0 g
s
.49078 .25859 m .48417 .25597 L .48405 .25629 L p .866 .776 .76 r
F P
0 g
s
.37826 .25825 m .42178 .25332 L .42201 .25833 L p .639 .44 .597 r
F P
0 g
s
.42201 .25833 m .37864 .2685 L .37826 .25825 L p .639 .44 .597 r
F P
0 g
s
.63739 .28462 m .59293 .28021 L .59026 .29028 L p .588 .445 .654 r
F P
0 g
s
.59293 .28021 m .63739 .28462 L .64002 .26719 L p .589 .433 .638 r
F P
0 g
s
.58656 .3001 m .6263 .31927 L .63277 .30216 L p .584 .454 .669 r
F P
0 g
s
.63277 .30216 m .59026 .29028 L .58656 .3001 L p .584 .454 .669 r
F P
0 g
s
.59026 .29028 m .63277 .30216 L .63739 .28462 L p .588 .445 .654 r
F P
0 g
s
.4406 .53225 m .404 .52439 L .4313 .52716 L p .005 .564 .811 r
F P
0 g
s
.4313 .52716 m .46794 .53509 L .4406 .53225 L p .005 .564 .811 r
F P
0 g
s
.37864 .2685 m .42201 .25833 L .42283 .2629 L p .628 .408 .565 r
F P
0 g
s
.42283 .2629 m .38019 .27785 L .37864 .2685 L p .628 .408 .565 r
F P
0 g
s
.46897 .25775 m .48354 .25712 L .48373 .25687 L p .84 .925 .888 r
F P
0 g
s
.58267 .42992 m .5774 .4734 L .60096 .45805 L p .347 .154 .47 r
F P
0 g
s
.60096 .45805 m .60037 .41809 L .58267 .42992 L p .347 .154 .47 r
F P
0 g
s
.47356 .24698 m .48431 .25532 L .48433 .25501 L p .971 .761 .562 r
F P
0 g
s
.48433 .25501 m .47367 .24511 L .47356 .24698 L p .971 .761 .562 r
F P
0 g
s
.48373 .25687 m .4701 .25627 L .46897 .25775 L p .84 .925 .888 r
F P
0 g
s
.4701 .25627 m .48373 .25687 L .4839 .25659 L p .875 .901 .846 r
F P
0 g
s
.3216 .36953 m .34914 .32731 L .35688 .33632 L p .393 .241 .553 r
F P
0 g
s
.35688 .33632 m .33245 .38288 L .3216 .36953 L p .393 .241 .553 r
F P
0 g
s
.47324 .24892 m .48425 .25564 L .48431 .25532 L p .958 .797 .64 r
F P
0 g
s
.48431 .25532 m .47356 .24698 L .47324 .24892 L p .958 .797 .64 r
F P
0 g
s
.4839 .25659 m .47112 .2546 L .4701 .25627 L p .875 .901 .846 r
F P
0 g
s
.47112 .2546 m .4839 .25659 L .48405 .25629 L p .901 .876 .802 r
F P
0 g
s
.47271 .25087 m .48417 .25597 L .48425 .25564 L p .942 .826 .702 r
F P
0 g
s
.48425 .25564 m .47324 .24892 L .47271 .25087 L p .942 .826 .702 r
F P
0 g
s
.48405 .25629 m .472 .25278 L .47112 .2546 L p .901 .876 .802 r
F P
0 g
s
.472 .25278 m .48405 .25629 L .48417 .25597 L p .923 .852 .755 r
F P
0 g
s
.48417 .25597 m .47271 .25087 L .472 .25278 L p .923 .852 .755 r
F P
0 g
s
.59809 .36306 m .61749 .40242 L .63349 .3833 L p .468 .342 .626 r
F P
0 g
s
.63349 .3833 m .60869 .35018 L .59809 .36306 L p .468 .342 .626 r
F P
0 g
s
.34308 .31576 m .38289 .28606 L .38667 .29289 L p .507 .291 .521 r
F P
0 g
s
.38667 .29289 m .34914 .32731 L .34308 .31576 L p .507 .291 .521 r
F P
0 g
s
.50327 .52065 m .46794 .53509 L .49739 .5304 L p .069 0 0 r
F P
0 g
s
.49739 .5304 m .53032 .51622 L .50327 .52065 L p .069 0 0 r
F P
0 g
s
.32384 .43059 m .33245 .38288 L .34553 .39227 L p .296 .251 .638 r
F P
0 g
s
.34553 .39227 m .34049 .44323 L .32384 .43059 L p .296 .251 .638 r
F P
0 g
s
.55391 .48316 m .53032 .51622 L .55845 .50484 L p .209 0 .159 r
F P
0 g
s
.55845 .50484 m .5774 .4734 L .55391 .48316 L p .209 0 .159 r
F P
0 g
s
.38019 .27785 m .42283 .2629 L .42422 .26689 L p .61 .369 .527 r
F P
0 g
s
.42422 .26689 m .38289 .28606 L .38019 .27785 L p .61 .369 .527 r
F P
0 g
s
.68138 .23362 m .64061 .25039 L .64002 .26719 L p .478 .329 .599 r
F P
0 g
s
.60869 .35018 m .63349 .3833 L .64786 .36129 L p .473 .344 .623 r
F P
0 g
s
.64786 .36129 m .61819 .33544 L .60869 .35018 L p .473 .344 .623 r
F P
0 g
s
.35259 .48648 m .34049 .44323 L .35972 .45038 L p .252 .353 .773 r
F P
0 g
s
.35972 .45038 m .37515 .49547 L .35259 .48648 L p .252 .353 .773 r
F P
0 g
s
.38289 .28606 m .42422 .26689 L .42614 .27019 L p .584 .32 .483 r
F P
0 g
s
.42614 .27019 m .38667 .29289 L .38289 .28606 L p .584 .32 .483 r
F P
0 g
s
.68065 .25878 m .64002 .26719 L .63739 .28462 L p .48 .335 .605 r
F P
0 g
s
.64002 .26719 m .68065 .25878 L .68138 .23362 L p .478 .329 .599 r
F P
0 g
s
.61819 .33544 m .64786 .36129 L .66012 .33705 L p .477 .343 .62 r
F P
0 g
s
.66012 .33705 m .6263 .31927 L .61819 .33544 L p .477 .343 .62 r
F P
0 g
s
.34914 .32731 m .38667 .29289 L .39146 .29817 L p .48 .254 .493 r
F P
0 g
s
.39146 .29817 m .35688 .33632 L .34914 .32731 L p .48 .254 .493 r
F P
0 g
s
.38667 .29289 m .42614 .27019 L .42855 .27271 L p .546 .258 .429 r
F P
0 g
s
.60037 .41809 m .60096 .45805 L .62386 .43743 L p .322 .135 .465 r
F P
0 g
s
.62386 .43743 m .61749 .40242 L .60037 .41809 L p .322 .135 .465 r
F P
0 g
s
.67678 .28496 m .63739 .28462 L .63277 .30216 L p .48 .339 .611 r
F P
0 g
s
.63739 .28462 m .67678 .28496 L .68065 .25878 L p .48 .335 .605 r
F P
0 g
s
.6263 .31927 m .66012 .33705 L .66987 .31133 L p .479 .342 .616 r
F P
0 g
s
.66987 .31133 m .63277 .30216 L .6263 .31927 L p .479 .342 .616 r
F P
0 g
s
.63277 .30216 m .66987 .31133 L .67678 .28496 L p .48 .339 .611 r
F P
0 g
s
.46582 .23412 m .47356 .24698 L .47367 .24511 L p .989 .8 .412 r
F P
0 g
s
.47367 .24511 m .46615 .22868 L .46582 .23412 L p .989 .8 .412 r
F P
0 g
s
.42855 .27271 m .39146 .29817 L .38667 .29289 L p .546 .258 .429 r
F P
0 g
s
.46487 .23976 m .47324 .24892 L .47356 .24698 L p .995 .86 .531 r
F P
0 g
s
.47356 .24698 m .46582 .23412 L .46487 .23976 L p .995 .86 .531 r
F P
0 g
s
.39146 .29817 m .42855 .27271 L .43138 .27439 L p .493 .18 .364 r
F P
0 g
s
.33245 .38288 m .35688 .33632 L .36612 .34252 L p .388 .235 .549 r
F P
0 g
s
.36612 .34252 m .34553 .39227 L .33245 .38288 L p .388 .235 .549 r
F P
0 g
s
.404 .52439 m .37515 .49547 L .40032 .49763 L p .282 .544 .92 r
F P
0 g
s
.40032 .49763 m .4313 .52716 L .404 .52439 L p .282 .544 .92 r
F P
0 g
s
.43138 .27439 m .39713 .30172 L .39146 .29817 L p .493 .18 .364 r
F P
0 g
s
.39713 .30172 m .43138 .27439 L .43455 .27516 L p .419 .082 .285 r
F P
0 g
s
.5774 .4734 m .55845 .50484 L .58681 .48659 L p .08 0 .078 r
F P
0 g
s
.58681 .48659 m .60096 .45805 L .5774 .4734 L p .08 0 .078 r
F P
0 g
s
.35688 .33632 m .39146 .29817 L .39713 .30172 L p .448 .212 .462 r
F P
0 g
s
.43455 .27516 m .40355 .30342 L .39713 .30172 L p .419 .082 .285 r
F P
0 g
s
.40355 .30342 m .43455 .27516 L .438 .275 L p .319 0 .189 r
F P
0 g
s
.39713 .30172 m .36612 .34252 L .35688 .33632 L p .448 .212 .462 r
F P
0 g
s
.46794 .53509 m .4313 .52716 L .46076 .52225 L p .341 .762 .976 r
F P
0 g
s
.46076 .52225 m .49739 .5304 L .46794 .53509 L p .341 .762 .976 r
F P
0 g
s
.61749 .40242 m .62386 .43743 L .64534 .41206 L p .299 .121 .463 r
F P
0 g
s
.64534 .41206 m .63349 .3833 L .61749 .40242 L p .299 .121 .463 r
F P
0 g
s
.34049 .44323 m .34553 .39227 L .36055 .39732 L p .338 .289 .656 r
F P
0 g
s
.36055 .39732 m .35972 .45038 L .34049 .44323 L p .338 .289 .656 r
F P
0 g
s
.53032 .51622 m .49739 .5304 L .52813 .51797 L p 0 0 0 r
F P
0 g
s
.52813 .51797 m .55845 .50484 L .53032 .51622 L p 0 0 0 r
F P
0 g
s
.438 .275 m .41053 .30322 L .40355 .30342 L p .319 0 .189 r
F P
0 g
s
.41053 .30322 m .438 .275 L .44161 .27392 L p .187 0 .075 r
F P
0 g
s
.36612 .34252 m .39713 .30172 L .40355 .30342 L p .408 .164 .429 r
F P
0 g
s
.44161 .27392 m .41791 .30108 L .41053 .30322 L p .187 0 .075 r
F P
0 g
s
.41791 .30108 m .44161 .27392 L .44529 .27193 L p .023 0 0 r
F P
0 g
s
.70949 .21154 m .68138 .23362 L .68065 .25878 L p .269 .159 .54 r
F P
0 g
s
.63349 .3833 m .64534 .41206 L .66468 .38268 L p .28 .112 .466 r
F P
0 g
s
.66468 .38268 m .64786 .36129 L .63349 .3833 L p .28 .112 .466 r
F P
0 g
s
.44529 .27193 m .42546 .29706 L .41791 .30108 L p .023 0 0 r
F P
0 g
s
.34553 .39227 m .36612 .34252 L .37666 .34566 L p .382 .229 .546 r
F P
0 g
s
.37666 .34566 m .36055 .39732 L .34553 .39227 L p .382 .229 .546 r
F P
0 g
s
.37515 .49547 m .35972 .45038 L .3811 .45165 L p .356 .423 .793 r
F P
0 g
s
.3811 .45165 m .40032 .49763 L .37515 .49547 L p .356 .423 .793 r
F P
0 g
s
.40355 .30342 m .37666 .34566 L .36612 .34252 L p .408 .164 .429 r
F P
0 g
s
.44895 .26909 m .43299 .29123 L .42546 .29706 L p 0 0 0 r
F P
0 g
s
.37666 .34566 m .40355 .30342 L .41053 .30322 L p .36 .111 .394 r
F P
0 g
s
.45247 .26546 m .44028 .28375 L .43299 .29123 L p 0 0 0 r
F P
0 g
s
.60096 .45805 m .58681 .48659 L .61449 .46182 L p 0 0 .004 r
F P
0 g
s
.61449 .46182 m .62386 .43743 L .60096 .45805 L p 0 0 .004 r
F P
0 g
s
.70866 .24518 m .68065 .25878 L .67678 .28496 L p .259 .139 .519 r
F P
0 g
s
.68065 .25878 m .70866 .24518 L .70949 .21154 L p .269 .159 .54 r
F P
0 g
s
.64786 .36129 m .66468 .38268 L .68119 .35021 L p .265 .109 .474 r
F P
0 g
s
.68119 .35021 m .66012 .33705 L .64786 .36129 L p .265 .109 .474 r
F P
0 g
s
.46807 .21844 m .46582 .23412 L .46615 .22868 L p 0 0 .011 r
F P
0 g
s
.46615 .22868 m .46877 .20712 L .46807 .21844 L p 0 0 .011 r
F P
0 g
s
.46611 .2302 m .46487 .23976 L .46582 .23412 L p .715 .678 .133 r
F P
0 g
s
.46582 .23412 m .46795 .21927 L p .46611 .2302 L .715 .678 .133 r
F P
0 g
s
.46487 .23976 m .46611 .2302 L .46292 .24206 L p .745 .757 .246 r
F P
0 g
s
.47672 .24283 m .46409 .24213 L p .46611 .2302 L 0 0 .311 r
F P
0 g
s
.46409 .24213 m .46292 .24206 L .46611 .2302 L p 0 0 .311 r
F P
0 g
s
.46795 .21927 m .46807 .21844 L .46611 .2302 L p .715 .678 .133 r
F P
0 g
s
.70355 .28029 m .67678 .28496 L .66987 .31133 L p .255 .123 .501 r
F P
0 g
s
.67678 .28496 m .70355 .28029 L .70866 .24518 L p .259 .139 .519 r
F P
0 g
s
.66012 .33705 m .68119 .35021 L .6943 .31569 L p .257 .113 .485 r
F P
0 g
s
.6943 .31569 m .66987 .31133 L .66012 .33705 L p .257 .113 .485 r
F P
0 g
s
.41053 .30322 m .38821 .34561 L .37666 .34566 L p .36 .111 .394 r
F P
0 g
s
.38821 .34561 m .41053 .30322 L .41791 .30108 L p .306 .055 .359 r
F P
0 g
s
.4313 .52716 m .40032 .49763 L .42747 .49259 L p .437 .613 .924 r
F P
0 g
s
.42747 .49259 m .46076 .52225 L .4313 .52716 L p .437 .613 .924 r
F P
0 g
s
.66987 .31133 m .6943 .31569 L .70355 .28029 L p .255 .123 .501 r
F P
0 g
s
.35972 .45038 m .36055 .39732 L .37714 .39777 L p .377 .321 .668 r
F P
0 g
s
.37714 .39777 m .3811 .45165 L .35972 .45038 L p .377 .321 .668 r
F P
0 g
s
.36055 .39732 m .37666 .34566 L .38821 .34561 L p .377 .224 .543 r
F P
0 g
s
.55845 .50484 m .52813 .51797 L .55926 .49785 L p .522 .913 .791 r
F P
0 g
s
.55926 .49785 m .58681 .48659 L .55845 .50484 L p .522 .913 .791 r
F P
0 g
s
.49739 .5304 m .46076 .52225 L .4916 .50945 L p .545 .83 .998 r
F P
0 g
s
.4916 .50945 m .52813 .51797 L .49739 .5304 L p .545 .83 .998 r
F P
0 g
s
.38821 .34561 m .37714 .39777 L .36055 .39732 L p .377 .224 .543 r
F P
0 g
s
.41791 .30108 m .40049 .3423 L .38821 .34561 L p .306 .055 .359 r
F P
0 g
s
.40049 .3423 m .41791 .30108 L .42546 .29706 L p .245 0 .324 r
F P
0 g
s
.62386 .43743 m .61449 .46182 L .64056 .43115 L p 0 0 0 r
F P
0 g
s
.64056 .43115 m .64534 .41206 L .62386 .43743 L p 0 0 0 r
F P
0 g
s
.42546 .29706 m .41316 .33575 L .40049 .3423 L p .245 0 .324 r
F P
0 g
s
.41316 .33575 m .42546 .29706 L .43299 .29123 L p .181 0 .292 r
F P
0 g
s
.37714 .39777 m .38821 .34561 L .40049 .3423 L p .371 .218 .541 r
F P
0 g
s
.40032 .49763 m .3811 .45165 L .4041 .44676 L p .434 .47 .798 r
F P
0 g
s
.4041 .44676 m .42747 .49259 L .40032 .49763 L p .434 .47 .798 r
F P
0 g
s
.43299 .29123 m .42584 .3261 L .41316 .33575 L p .181 0 .292 r
F P
0 g
s
.42584 .3261 m .43299 .29123 L .44028 .28375 L p .116 0 .267 r
F P
0 g
s
.71863 .18709 m .70949 .21154 L .70866 .24518 L p 0 0 .266 r
F P
0 g
s
.64534 .41206 m .64056 .43115 L .66409 .39547 L p 0 0 0 r
F P
0 g
s
.66409 .39547 m .66468 .38268 L .64534 .41206 L p 0 0 0 r
F P
0 g
s
.44028 .28375 m .43817 .31358 L .42584 .3261 L p .116 0 .267 r
F P
0 g
s
.43817 .31358 m .44028 .28375 L .4471 .27483 L p .056 0 .25 r
F P
0 g
s
.3811 .45165 m .37714 .39777 L .39489 .39346 L p .41 .347 .676 r
F P
0 g
s
.40049 .3423 m .39489 .39346 L .37714 .39777 L p .371 .218 .541 r
F P
0 g
s
.39489 .39346 m .4041 .44676 L .3811 .45165 L p .41 .347 .676 r
F P
0 g
s
.58681 .48659 m .55926 .49785 L .58976 .47041 L p .708 .986 .852 r
F P
0 g
s
.58976 .47041 m .61449 .46182 L .58681 .48659 L p .708 .986 .852 r
F P
0 g
s
.39489 .39346 m .40049 .3423 L .41316 .33575 L p .365 .214 .539 r
F P
0 g
s
.46076 .52225 m .42747 .49259 L .45587 .48019 L p .536 .647 .905 r
F P
0 g
s
.45587 .48019 m .4916 .50945 L .46076 .52225 L p .536 .647 .905 r
F P
0 g
s
.48546 .20261 m .46807 .21844 L .46877 .20712 L p 0 0 .41 r
F P
0 g
s
.46877 .20712 m .48659 .18342 L .48546 .20261 L p 0 0 .41 r
F P
0 g
s
.4471 .27483 m .44976 .29853 L .43817 .31358 L p .056 0 .25 r
F P
0 g
s
.71768 .22794 m .70866 .24518 L .70355 .28029 L p 0 0 .146 r
F P
0 g
s
.70866 .24518 m .71768 .22794 L .71863 .18709 L p 0 0 .266 r
F P
0 g
s
.66468 .38268 m .66409 .39547 L .68422 .35592 L p 0 0 0 r
F P
0 g
s
.68422 .35592 m .68119 .35021 L .66468 .38268 L p 0 0 0 r
F P
0 g
s
.48214 .22262 m .46611 .2302 L .46807 .21844 L p 0 0 .357 r
F P
0 g
s
.46807 .21844 m .48546 .20261 L .48214 .22262 L p 0 0 .357 r
F P
0 g
s
.45327 .26471 m .46027 .28137 L .44976 .29853 L p .005 0 .245 r
F P
0 g
s
.52813 .51797 m .4916 .50945 L .52288 .4888 L p .66 .841 .97 r
F P
0 g
s
.52288 .4888 m .55926 .49785 L .52813 .51797 L p .66 .841 .97 r
F P
0 g
s
.46611 .2302 m .48214 .22262 L .47672 .24283 L p 0 0 .311 r
F P
0 g
s
.45859 .25368 m .46935 .26261 L .46027 .28137 L p 0 0 .253 r
F P
0 g
s
.46292 .24206 m .47672 .24283 L .46935 .26261 L p 0 0 .276 r
F P
0 g
s
.71149 .27067 m .70355 .28029 L .6943 .31569 L p 0 0 .043 r
F P
0 g
s
.70355 .28029 m .71149 .27067 L .71768 .22794 L p 0 0 .146 r
F P
0 g
s
.68119 .35021 m .68422 .35592 L .70021 .31384 L p 0 0 0 r
F P
0 g
s
.70021 .31384 m .6943 .31569 L .68119 .35021 L p 0 0 0 r
F P
0 g
s
.41316 .33575 m .4133 .38438 L .39489 .39346 L p .365 .214 .539 r
F P
0 g
s
.4133 .38438 m .41316 .33575 L .42584 .3261 L p .36 .21 .537 r
F P
0 g
s
.6943 .31569 m .70021 .31384 L .71149 .27067 L p 0 0 .043 r
F P
0 g
s
.4041 .44676 m .39489 .39346 L .4133 .38438 L p .439 .368 .68 r
F P
0 g
s
.42747 .49259 m .4041 .44676 L .42807 .43562 L p .493 .501 .794 r
F P
0 g
s
.42807 .43562 m .45587 .48019 L .42747 .49259 L p .493 .501 .794 r
F P
0 g
s
.61449 .46182 m .58976 .47041 L .61857 .43632 L p .819 .997 .851 r
F P
0 g
s
.61857 .43632 m .64056 .43115 L .61449 .46182 L p .819 .997 .851 r
F P
0 g
s
.4133 .38438 m .42807 .43562 L .4041 .44676 L p .439 .368 .68 r
F P
0 g
s
.42584 .3261 m .43185 .37067 L .4133 .38438 L p .36 .21 .537 r
F P
0 g
s
.43185 .37067 m .42584 .3261 L .43817 .31358 L p .355 .206 .537 r
F P
0 g
s
.4916 .50945 m .45587 .48019 L .48468 .46051 L p .603 .661 .879 r
F P
0 g
s
.48468 .46051 m .52288 .4888 L .4916 .50945 L p .603 .661 .879 r
F P
0 g
s
.55926 .49785 m .52288 .4888 L .55359 .46067 L p .728 .831 .929 r
F P
0 g
s
.55359 .46067 m .58976 .47041 L .55926 .49785 L p .728 .831 .929 r
F P
0 g
s
.43817 .31358 m .44996 .35265 L .43185 .37067 L p .355 .206 .537 r
F P
0 g
s
.44996 .35265 m .43817 .31358 L .44976 .29853 L p .351 .204 .537 r
F P
0 g
s
.42807 .43562 m .4133 .38438 L .43185 .37067 L p .464 .383 .68 r
F P
0 g
s
.70554 .16443 m .71863 .18709 L .71768 .22794 L p .995 .782 .421 r
F P
0 g
s
.64056 .43115 m .61857 .43632 L .64465 .39658 L p .887 .982 .819 r
F P
0 g
s
.64465 .39658 m .66409 .39547 L .64056 .43115 L p .887 .982 .819 r
F P
0 g
s
.51961 .1899 m .48546 .20261 L .48659 .18342 L p .345 .211 .551 r
F P
0 g
s
.48659 .18342 m .52112 .16178 L .51961 .1899 L p .345 .211 .551 r
F P
0 g
s
.44976 .29853 m .46706 .33077 L .44996 .35265 L p .351 .204 .537 r
F P
0 g
s
.46706 .33077 m .44976 .29853 L .46027 .28137 L p .348 .203 .538 r
F P
0 g
s
.45587 .48019 m .42807 .43562 L .45233 .41837 L p .538 .521 .784 r
F P
0 g
s
.45233 .41837 m .48468 .46051 L .45587 .48019 L p .538 .521 .784 r
F P
0 g
s
.43185 .37067 m .45233 .41837 L .42807 .43562 L p .464 .383 .68 r
F P
0 g
s
.51482 .2193 m .48214 .22262 L .48546 .20261 L p .344 .208 .548 r
F P
0 g
s
.48546 .20261 m .51961 .1899 L .51482 .2193 L p .344 .208 .548 r
F P
0 g
s
.46027 .28137 m .48257 .30568 L .46706 .33077 L p .348 .203 .538 r
F P
0 g
s
.48257 .30568 m .46027 .28137 L .46935 .26261 L p .345 .202 .539 r
F P
0 g
s
.70439 .20981 m .71768 .22794 L .71149 .27067 L p .998 .846 .548 r
F P
0 g
s
.71768 .22794 m .70439 .20981 L .70554 .16443 L p .995 .782 .421 r
F P
0 g
s
.66409 .39547 m .64465 .39658 L .66702 .35248 L p .931 .956 .772 r
F P
0 g
s
.66702 .35248 m .68422 .35592 L .66409 .39547 L p .931 .956 .772 r
F P
0 g
s
.50686 .24904 m .47672 .24283 L .48214 .22262 L p .343 .205 .544 r
F P
0 g
s
.48214 .22262 m .51482 .2193 L .50686 .24904 L p .343 .205 .544 r
F P
0 g
s
.46935 .26261 m .49599 .27815 L .48257 .30568 L p .345 .202 .539 r
F P
0 g
s
.49599 .27815 m .46935 .26261 L .47672 .24283 L p .344 .203 .541 r
F P
0 g
s
.45233 .41837 m .43185 .37067 L .44996 .35265 L p .484 .394 .677 r
F P
0 g
s
.47672 .24283 m .50686 .24904 L .49599 .27815 L p .344 .203 .541 r
F P
0 g
s
.58976 .47041 m .55359 .46067 L .58267 .42577 L p .773 .816 .886 r
F P
0 g
s
.58267 .42577 m .61857 .43632 L .58976 .47041 L p .773 .816 .886 r
F P
0 g
s
.69743 .2574 m .71149 .27067 L .70021 .31384 L p .985 .891 .641 r
F P
0 g
s
.71149 .27067 m .69743 .2574 L .70439 .20981 L p .998 .846 .548 r
F P
0 g
s
.68422 .35592 m .66702 .35248 L .68483 .30553 L p .963 .926 .713 r
F P
0 g
s
.68483 .30553 m .70021 .31384 L .68422 .35592 L p .963 .926 .713 r
F P
0 g
s
.52288 .4888 m .48468 .46051 L .51296 .43391 L p .649 .665 .852 r
F P
0 g
s
.51296 .43391 m .55359 .46067 L .52288 .4888 L p .649 .665 .852 r
F P
0 g
s
.70021 .31384 m .68483 .30553 L .69743 .2574 L p .985 .891 .641 r
F P
0 g
s
.44996 .35265 m .4761 .39534 L .45233 .41837 L p .484 .394 .677 r
F P
0 g
s
.4761 .39534 m .44996 .35265 L .46706 .33077 L p .501 .4 .672 r
F P
0 g
s
.48468 .46051 m .45233 .41837 L .4761 .39534 L p .572 .532 .772 r
F P
0 g
s
.4761 .39534 m .51296 .43391 L .48468 .46051 L p .572 .532 .772 r
F P
0 g
s
.67149 .1481 m .70554 .16443 L .70439 .20981 L p .891 .672 .599 r
F P
0 g
s
.61857 .43632 m .58267 .42577 L .60905 .3851 L p .805 .798 .845 r
F P
0 g
s
.60905 .3851 m .64465 .39658 L .61857 .43632 L p .805 .798 .845 r
F P
0 g
s
.56742 .18334 m .51961 .1899 L .52112 .16178 L p .53 .364 .6 r
F P
0 g
s
.52112 .16178 m .56911 .1467 L .56742 .18334 L p .53 .364 .6 r
F P
0 g
s
.46706 .33077 m .4986 .36713 L .4761 .39534 L p .501 .4 .672 r
F P
0 g
s
.4986 .36713 m .46706 .33077 L .48257 .30568 L p .514 .403 .665 r
F P
0 g
s
.55359 .46067 m .51296 .43391 L .53976 .40107 L p .683 .663 .824 r
F P
0 g
s
.53976 .40107 m .58267 .42577 L .55359 .46067 L p .683 .663 .824 r
F P
0 g
s
.56131 .22175 m .51482 .2193 L .51961 .1899 L p .534 .379 .617 r
F P
0 g
s
.51961 .1899 m .56742 .18334 L .56131 .22175 L p .534 .379 .617 r
F P
0 g
s
.48257 .30568 m .51904 .33457 L .4986 .36713 L p .514 .403 .665 r
F P
0 g
s
.51904 .33457 m .48257 .30568 L .49599 .27815 L p .524 .402 .656 r
F P
0 g
s
.51296 .43391 m .4761 .39534 L .4986 .36713 L p .599 .537 .756 r
F P
0 g
s
.67008 .19433 m .70439 .20981 L .69743 .2574 L p .88 .706 .663 r
F P
0 g
s
.70439 .20981 m .67008 .19433 L .67149 .1481 L p .891 .672 .599 r
F P
0 g
s
.64465 .39658 m .60905 .3851 L .63175 .34 L p .829 .778 .804 r
F P
0 g
s
.63175 .34 m .66702 .35248 L .64465 .39658 L p .829 .778 .804 r
F P
0 g
s
.55096 .26064 m .50686 .24904 L .51482 .2193 L p .534 .39 .631 r
F P
0 g
s
.51482 .2193 m .56131 .22175 L .55096 .26064 L p .534 .39 .631 r
F P
0 g
s
.49599 .27815 m .53671 .29867 L .51904 .33457 L p .524 .402 .656 r
F P
0 g
s
.53671 .29867 m .49599 .27815 L .50686 .24904 L p .53 .398 .644 r
F P
0 g
s
.4986 .36713 m .53976 .40107 L .51296 .43391 L p .599 .537 .756 r
F P
0 g
s
.50686 .24904 m .55096 .26064 L .53671 .29867 L p .53 .398 .644 r
F P
0 g
s
.66282 .24287 m .69743 .2574 L .68483 .30553 L p .866 .734 .715 r
F P
0 g
s
.69743 .2574 m .66282 .24287 L .67008 .19433 L p .88 .706 .663 r
F P
0 g
s
.66702 .35248 m .63175 .34 L .64989 .29202 L p .849 .757 .761 r
F P
0 g
s
.64989 .29202 m .68483 .30553 L .66702 .35248 L p .849 .757 .761 r
F P
0 g
s
.68483 .30553 m .64989 .29202 L .66282 .24287 L p .866 .734 .715 r
F P
0 g
s
.62273 .14171 m .67149 .1481 L .67008 .19433 L p .765 .562 .623 r
F P
0 g
s
.58267 .42577 m .53976 .40107 L .56411 .36294 L p .708 .656 .795 r
F P
0 g
s
.56411 .36294 m .60905 .3851 L .58267 .42577 L p .708 .656 .795 r
F P
0 g
s
.62109 .18483 m .56742 .18334 L .56911 .1467 L p .654 .468 .62 r
F P
0 g
s
.56911 .1467 m .62273 .14171 L .62109 .18483 L p .654 .468 .62 r
F P
0 g
s
.53976 .40107 m .4986 .36713 L .51904 .33457 L p .62 .537 .739 r
F P
0 g
s
.67008 .19433 m .62109 .18483 L .62273 .14171 L p .765 .562 .623 r
F P
0 g
s
.51904 .33457 m .56411 .36294 L .53976 .40107 L p .62 .537 .739 r
F P
0 g
s
.61411 .2301 m .56131 .22175 L .56742 .18334 L p .656 .491 .649 r
F P
0 g
s
.56742 .18334 m .62109 .18483 L .61411 .2301 L p .656 .491 .649 r
F P
0 g
s
.56411 .36294 m .51904 .33457 L .53671 .29867 L p .635 .532 .72 r
F P
0 g
s
.62109 .18483 m .67008 .19433 L .66282 .24287 L p .761 .59 .666 r
F P
0 g
s
.60905 .3851 m .56411 .36294 L .58511 .32075 L p .728 .645 .766 r
F P
0 g
s
.58511 .32075 m .63175 .34 L .60905 .3851 L p .728 .645 .766 r
F P
0 g
s
.60198 .27595 m .55096 .26064 L .56131 .22175 L p .653 .509 .675 r
F P
0 g
s
.56131 .22175 m .61411 .2301 L .60198 .27595 L p .653 .509 .675 r
F P
0 g
s
.53671 .29867 m .58511 .32075 L .56411 .36294 L p .635 .532 .72 r
F P
0 g
s
.58511 .32075 m .53671 .29867 L .55096 .26064 L p .646 .523 .699 r
F P
0 g
s
.55096 .26064 m .60198 .27595 L .58511 .32075 L p .646 .523 .699 r
F P
0 g
s
.61411 .2301 m .66282 .24287 L .64989 .29202 L p .754 .613 .702 r
F P
0 g
s
.66282 .24287 m .61411 .2301 L .62109 .18483 L p .761 .59 .666 r
F P
0 g
s
.63175 .34 m .58511 .32075 L .60198 .27595 L p .743 .631 .736 r
F P
0 g
s
.60198 .27595 m .64989 .29202 L .63175 .34 L p .743 .631 .736 r
F P
0 g
s
.64989 .29202 m .60198 .27595 L .61411 .2301 L p .754 .613 .702 r
F P
0 g
s
.25 Mabswid
1 .56252 m
.52895 .71057 L
s
.52895 .71057 m
0 .59155 L
s
0 .59155 m
.43437 .37832 L
s
.43437 .37832 m
1 .56252 L
s
.97142 .23923 m
.43822 0 L
s
.43822 0 m
.43437 .37832 L
s
.43437 .37832 m
1 .56252 L
s
1 .56252 m
.97142 .23923 L
s
.97142 .23923 m
1 .56252 L
s
.97142 .23923 m
.9656 .2418 L
s
gsave
.98305 .23408 -61 -12.65656 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97687 .30095 m
.971 .3034 L
s
gsave
.98861 .29604 -61 -12.50811 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98246 .36409 m
.97653 .36641 L
s
gsave
.9943 .35944 -61 -12.35689 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98817 .42869 m
.9822 .43089 L
s
gsave
1.00011 .42431 -61 -12.20283 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.99401 .49482 m
.98799 .49687 L
s
gsave
1.00606 .49071 -61 -12.04584 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
1 .56252 m
.99393 .56443 L
s
gsave
1.01214 .5587 -61 -11.88584 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.9725 .25146 m
.969 .25299 L
s
.97359 .26375 m
.97008 .26527 L
s
.97468 .27609 m
.97117 .27759 L
s
.97577 .28849 m
.97226 .28998 L
s
.97798 .31346 m
.97445 .31492 L
s
.97909 .32603 m
.97556 .32747 L
s
.98021 .33866 m
.97667 .34009 L
s
.98133 .35134 m
.97778 .35276 L
s
.98359 .37689 m
.98003 .37827 L
s
.98473 .38975 m
.98116 .39112 L
s
.98587 .40267 m
.9823 .40402 L
s
.98702 .41565 m
.98344 .41698 L
s
.98933 .4418 m
.98574 .4431 L
s
.99049 .45496 m
.98689 .45624 L
s
.99166 .46818 m
.98806 .46945 L
s
.99283 .48147 m
.98923 .48272 L
s
.9952 .50823 m
.99158 .50945 L
s
.99639 .52171 m
.99277 .52291 L
s
.99759 .53525 m
.99396 .53643 L
s
.99879 .54885 m
.99516 .55001 L
s
gsave
1.05666 .36908 -61 -12.28022 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
66.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.25 Mabswid
.43822 0 m
.02665 .27748 L
s
.388 .03386 m
.39385 .03637 L
s
gsave
.37631 .02882 -75 -12.5841 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.2946 .09683 m
.30051 .09919 L
s
gsave
.28278 .09212 -75 -12.39237 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.20952 .15419 m
.21548 .15641 L
s
gsave
.19759 .14977 -69 -12.22712 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.13169 .20666 m
.1377 .20875 L
s
gsave
.11967 .20249 -69 -12.08323 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.06023 .25484 m
.06628 .25682 L
s
gsave
.04814 .2509 -69 -11.9568 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.3638 .05017 m
.36732 .05165 L
s
.34019 .06609 m
.34371 .06755 L
s
.31712 .08164 m
.32066 .08308 L
s
.27259 .11167 m
.27615 .11306 L
s
.25109 .12617 m
.25465 .12754 L
s
.23007 .14034 m
.23364 .14169 L
s
.18942 .16774 m
.193 .16905 L
s
.16976 .181 m
.17335 .18229 L
s
.15052 .19397 m
.15412 .19524 L
s
.11326 .21909 m
.11687 .22032 L
s
.09522 .23126 m
.09883 .23247 L
s
.07754 .24317 m
.08117 .24437 L
s
.4128 .01714 m
.41629 .01867 L
s
.04327 .26628 m
.04691 .26745 L
s
gsave
.13794 .12763 -69 -12.22712 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{157.5, 111.75},
  ImageMargins->{{84.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000350000S1000`40l00?003`aOoo0035ool00<Go
o`00aOoo0035ool005[oo`0300oooooo06Soo`00F?oo0`0?J_oo001Hool00`0?ool03`1Zool005Wo
o`803f[oo`00F_oo00<03oooool0J?oo0020ool00`0?ooooo`12ool003ooo`0300oooooo00_oo`<0
3c7oo`0300oooooo047oo`00?Ooo0`0?3?oo00@03ooo00ooo`803booo`0300oooooo047oo`00>?oo
0`0?0_oo00<03ooo00l02_oo0P0?0_oo00@03oooooooo`<03b_oo`0300ooo`0?04;oo`00?_oo0P0?
2Ooo0P0?0ooo00<03oooool00ooo0`0?:Ooo00<03ooo00l0@_oo000oool00`0?ooooo`05ool200l5
ool00`0?ooooo`06ool200lDool300l@ool00`0?ool03`12ool004Koo`0300oooooo00Goo`0300oo
oooo00Soo`803a;oo`0300oooooo05Goo`00A?oo0`0?1ooo00<03oooool02?oo00@03ooo00l03a7o
o`0300oooooo05Coo`00@ooo00<03oooool02?oo00<03oooool03?oo0`0?3Ooo00<03ooo00l0EOoo
0011ool200l;ool00`0?ooooo`0>ool300l<ool200mEool0043oo`803`coo`0300oooooo017oo`80
3f7oo`00?_oo0P0?3_oo00<03oooool04ooo0P0?Gooo000/ool300l>ool00`0?ooooo`0>ool00`0?
ooooo`0Eool300mLool002coo`0300oooooo00coo`<03a3oo`0300oooooo01Soo`803aKoo`0300oo
oooo047oo`00:?oo0`0?0_oo00<03oooool02_oo00<03oooool04Ooo00<03oooool06?oo00@03ooo
00l03a?oo`0300ooo`0?04;oo`00;?oo00<03ooo00l02Ooo0P0?5?oo00<03oooool07?oo0P0?4Ooo
00<03ooo00l0@_oo000]ool200l8ool00`0?ool03`0Dool00`0?ooooo`0Mool300l?ool00`0?ool0
3`12ool003Goo`803aOoo`0300oooooo023oo`<03`goo`0300oooooo047oo`00=?oo0P0?6?oo00<0
3oooool08_oo0`0?Cooo000Cool00`0?ool03`0Mool00`0?ooooo`0Hool00`0?ooooo`0Uool200m=
ool001Coo`0300oooooo01[oo`803a_oo`0300oooooo02Ooo`803d_oo`005?oo00<03oooool06Ooo
0P0?7?oo00<03oooool09ooo00<03ooo00l00P0?B?oo000Cool00`0?ool03`0Hool200lNool00`0?
ooooo`0/ool200lFool300l]ool001koo`0300oooooo00_oo`803b3oo`0300oooooo02coo`0400oo
o`0?00lDool00`0?ooooo`0]ool001goo`0300ooo`0?00_oo`<03b3oo`0300oooooo033oo`803`go
o`<03`?oo`0300oooooo02coo`007Ooo00<03ooo00l02_oo00<03oooool08Ooo00<03oooool0<Ooo
0`0?4?oo00<03ooo00l0;Ooo000Mool00`0?ool03`08ool200lTool00`0?ooooo`0Iool00iNO00l0
3`0500l00kVOooooo`0@ool300l>ool200l]ool001koo`0300oooooo00Koo`0300oooooo02Coo`03
00oooooo01?oo`L03`07YinW[jNOYil03lR_^Il01`0?3_oo0`0?>ooo000Uool200lWool00`0?oooo
o`0?ool068JO00l03`0?QYl03iNOYjnWWjN_UinW[jNOYjnGW`0?^Io8[kVOb:niWlR_^Io8[`<03`oo
o`803cWoo`009?oo00<03ooo00l09ooo00<03oooool03?oo00V6W`0?00l03hJOQIn6WhFO00l02JNO
00`03lRO^Io8[kVOb9niWlR_00oZWmZOjYl200l>ool300lIool00`0?ooooo`0Kool002;oo`803b[o
o`0300oooooo00[oo`0MDil03`0?QYn5WgJOQIn6WhFOMYl03iNOYjnGWjN_UinW[iNOYjnGW`0?^Inh
[kVOb:niWkR_^Il03`02fYl00m^OfYoJW`0200l?ool300lDool300lMool0027oo`803b_oo`0300oo
oooo00Woo`803`0:Dil03hFOQYn5WhJOQIn6WhFO00l2Yil01JN_YinWWjNOYjl00ZNO01003lR_^Io8
WkROb:niWlRO00oZWmZOjYoJWnZOfYl03a7oo`<03`koo`<03`04ool03ooo00lMool000ooo`<03`go
o`803bgoo`0300oooooo00Ooo`0RE8l03e>?Din6W`0?QYn5WhJOQIn6WhFOQYl03iNOYjnWWjN_UinW
[jNOYjnGW`0?^Io8[kVOb:niWlR_^Il03mZOjYl3fYl00nZO00l03`0Cool200lAool200lMool000oo
o`0300oooooo00coo`0300oooooo02goo`0300oooooo00Koo`803`0=DhmSSe>?00n6WhFOQYn5WhJO
QIn6WhFO00l02JNO00l03lRO^Io8[kVOb9niWlR_00oZWmZOjYoJWnZOfYl00P0?00?kKoooool04Ooo
0`0?4?oo00<03oooool06ooo000@ool00`0?ooooo`09ool200l_ool00`0?ooooo`06ool0200?DimD
Se>OE8mCW`0?QIlE00l01LR_^Inh[kVO00l00]ZO00OKWmZOfYoJW`0?o7l03`0Fool300l[ool000oo
o`0300ooo`0?00Soo`803c7oo`0300oooooo00Goo`803`04DhmCWe>?Hhl300l05HFOQYn5WhJOQIn6
WhFO00nW[jNOYjnXWjN_YinW[jRO00ni[lR_^Jo8[`0500l02NZOfYoZWmZOjYl03nZOo6l03`0Hool3
00lYool0013oo`803`Ooo`<03c7oo`0300oooooo00Coo`0406l03`0?Dil300l055>O00n6[hJOQJn6
WhJ_QYn5[jR_00nH[jN_Z:nW[iR_YjnX[jN_00l2^Jl02LV_^Jni[kV_bJni[`0?fjl03`03fYl0100?
o6okO`0?6ooo0P0?9ooo000Hool00`0?ooooo`0bool00`0?ooooo`04ool09P0?06l03`0?HhmCSf>?
Dhl03hJOQIn6WhFOQYn5WhJO00nWWjN_Z9nW[jNOYjnXWjN_Yil03kV_b:ni[lV_^Jo8[kV_bJl03nZ_
fjl200l01NZOfYokKoa_00l07?oo0`0?4ooo00<03oooool03ooo000Fool300ldool00`0?ooooo`03
ool07@0?06l03`0?DimCSe>OE8mCW`0?QZn6WhJ_QYn6[hJOQZl03jN_V:nW[iROYjnH[jN_V9nW[`0?
bJl00kV_00O9[kV_^Jni[`0?fjoJ[`02fjl200l00oa_o7l03`0Oool200l@ool00`0?ool03`0@ool0
01Goo`0300oooooo03Goo`0300oooooo00?oo`0405l03`1O00l3Dhl09f>?Dhl03hJOQIn6WhFOQYn5
WhJO00nXWjN_YinW[jROYjnWWjN_Z9l03kV_b:ni[lR_^Jo8[kV_b:l03mZ_fjoZ[m^_fZl03ob?o6l0
3`0Pool400l=ool00`0?ool03`0@ool001?oo`803cSoo`0300oooooo00?oo`0400l0G`1_Dhl400l0
0hJ_00l03`0700l02ZR_V:nW[jR_YjnH[jN_Z:o9[`0?0[V_0139[kV_^Jni[lV_^Jl03m^_fZoK[mZ_
fjl03of?00olKbCoo`803`_oo`0300ooo`0?013oo`001Ooo00<03oooool02_oo00<03oooool0>?oo
00<03oooool00ooo0P0?00ACS`0?DhmSS`9CS`0:00n5WhJOQZn6WhFOQYn6[hJOYjl600l05ZR_Yjl0
3lV_^Jo8[kV_bJni[lR_^Jl03kV_jZoK[mZ_fioZ[`0?o8olK`0?9?oo00@03ooo00l03`[oo`0300oo
oooo00ooo`000ooo0`0?2_oo0P0?>ooo00<03oooool00ooo00@03`1?00mDS`9CS`0BDimDS`0?QYn6
[hJOQZn6WhJ_QYl03iR_YknH[jR_V:nW_iR_0`0?00>j[`0?^Jl00[V_00C9[kV_^Jl03`;K[`08fZoK
[m^_fjl03of?oIl03bSoo`803a[oo`000ooo00<03ooo00l02Ooo00<03oooool0>ooo00<03oooool0
0_oo00D0G`1?05l03f>?00=CS`0FHhl03hF_QYn5[hJOQJn6WhF_00nW[jR_YjnX[jN_Z:nW[jR_Yjl0
3lVo^Jl400l03LR_^Jl03m^_fZoK[nZ_fjoJ[`0?o8omS`0?02[oo`<03aOoo`001?oo0P0?1ooo0P0?
?_oo00<03oooool00_oo1@0?00eCWe>?Dil03hJ_QYn6[hJOQZn6WhJ_QYl03`02Z:l039R_YknX[jR_
V:nW_jR_00ni[kVo^Zni_`:i[`<03`09fZoK[mZ_fjoJ[m^_00omS`0?02_oo`<03aOoo`001Ooo00<0
3oooool01?oo00<03oooool0?_oo00<03oooool00_oo0P1?00<03e>?Hhl0100?01^6WhFOQYn6[hJO
QIn6WjN_00nW[jR_YjnX[jN_Z:nW[jR_00ni[lVo^Jo9_kV_bKni[lVo^Jl0100?00KJ[m^OjZomSob?
00lYool200l2ool00`0?ooooo`0Eool000[oo`803c_oo`D03`06Z9l03jRO]inXW`0?0P1?00<03e>O
E8l00U>?00=CWhJ_00l00`0?01^6[hJOQZl03jR_V:nW_iR_Z:nH[jNoV:nX[`0?^Knj[kVo^Zni_kZ_
^Knj[`0?^ZoK_m^_fZl00P0?00CK[ofOoHl03bOoo`803`Coo`0300oooooo01Goo`002Ooo00<03ooo
00l0=Ooo0`0?00FVWiNOYYnGWjJO00P03`0603l03e>?00mCSf>?0U>?00H03hF_QYn6[hJOQJl400l0
7JR_YjnX[jN_Z:nW[jR_YjnX[`0?^Jo9_kV_bKni[lVo^Jo9_`0?fkoK[m^ofjoK_m^_00omSob?00l0
9Ooo0P0?1_oo00<03oooool05Ooo0007ool200ldool039JO00l03`0?UYn6W`0?UhnVWiJ?UYnGS`<0
3`07UWl03`0?00l0C`0?04l00P0?0U>?00ACWe>?00n6W`>6[`05QYn6[hJ_QZnH[`0300l049R_YknX
[jR_V:nW_`0?^Kni[kVo^Zni_kV_^Knj[`0?1]^o0`0?00?lWoooool08?oo0`0?2?oo0P0?5_oo0006
ool300laool026BO00l03hJOUIn6SiFOQHl200l01JJ?UXnUSiIoYHl00YEo1@0?00D@C`0?04l03f>?
00803`0?DhmSS`0?QZn6WhJ_QYn6[hJOQZl03jRoZ:nW[jR_00@03`0FYjl03lVo^Jo9_kV_bKni[lVo
^Jo9_`0?fkoK[m^ofjoK_m^_00omWob?00lPool200l<ool00`0?ooooo`02ool300l?ool000Coo`80
3c?oo`803`05I9l03hFOQYn5W`0200l02hJ?00nFSiF?UXl03hEoQ7n4Kh=_HTl00`0?00<0?`0?00l0
0e>?00=DS`0?00l00hJ_00ifWhJ_QZn6[gJO00nH[jRoV:nX_iR_Z;nH[jRo0`0?00Vi_kZ_^Knj[kVo
^Zni_`0?^Kl00]^o00SK[m^ofkl03njOoJl03of_7_oo0P0?3Ooo0P0?1Ooo00<03oooool03_oo0004
ool400l_ool200l00fB?LimTS`0200l03iFOQHn5WhF?00nFS`0?UGnDOhA_Q7mcGg5?D3l`7`0200l0
110o04mCS`0?0e>?00=SSe>?QZl00P0?01:6WhJ_QYn5[hJOYkl03jNoZ:nW_iR_YknX[jNoV:nW_kVo
bKl300l03lVo^Jo9_kV_00oK[m^ofjoK_m^_fkl03of_oIl03`0Mool200l@ool00`0?ooooo`03ool0
0`0?ooooo`0>ool000Coo`0400ooooooool400lYool01Q1o00mTWfB?I9mTS`803`03QIn6ShFO0080
3`0:MHn4S`0?UHn4KhAoLemaGd0o<2l300l01A1?04l03e>?00l00e>?00@03hJ_QZn6W`803`0CQZn6
WhJ_00nX_iR_Z;nH[jRoV:nX_iR_Z;l03kW?^[ni_kZo^Kl00`0?00>i_`0?fkl01M^o00@03nj_oJl0
3a[oo`<03a;oo`0300oooooo00?oo`0300oooooo00koo`001?oo00<03oooool01Ooo0`0?9_oo0P0?
00ITSgBOI8l03fB?00l3QHl03HB?QHl03`0?Pgl03h9_LemaCe0_<1l03c1?00803`0T43mSS`0?HhmC
S`0?DhmSS`0?QZn6WhJ_QYn6[`0?QZn6W`0?Z:nX_jR_YjnX[jRoZ:nW[jR_00nj_lVo^[ni_kZobKnj
_lVo0`0?00WK_m^_fkoK[m^o00om[ofO00l06?oo0P0?5?oo0P0?1?oo0P0?4?oo0004ool00`0?oooo
o`08ool300lRool02P0?47l03fBOI8l03fB?I9meShFO0XF?00AeS`0?MHmdS`<03`03HEm0?c0_008`
G`0A84l03a1?44l03e>?E8mCS`0?Dhl03hJ_MZn6[hN_QZmf[`02QZl200l05JRoV:nX_iR_Z;nH[jRo
V:ni_`0?^Knj_kVo^[ni_kZo^Knj_`0?c;oK_`0200l01m^_fkoK_of_kYom[njO01Koo`803aOoo`03
00oooooo01Coo`001?oo00<03oooool02ooo0`0?7_oo00<03a1o46l00`0?00aTSf>OI8l03hF?Q8md
ShB?MGn3SgAoLgl200l00e9_HFl03`0400l02A1?00l03e>?HhmCSf>?Dhl03`02QZl028JOQZn6[hJ_
QYn6[`0?Ykl200l02:R_YknH[jNoZ:nW_`0?bKl2^Kl02KZobKni_kVo^[o9_`0?flo;_`02fkl300l0
0ofOoJomW`0Eool200lHool200lFool000Coo`0300oooooo00koo`<03a_oo`0800l@Oa1o00mTWfB?
I9mTS`803`0:QImeShB?MHl03gAoLgmTO`0?Hfl200l0141O<5l`Gb1?0P0?00ICWe>?00mCSe>ODhl3
00l2QZl02GJ_QZn6[hJ_V;l03iRoZ;nH[`0200l05JRoV:nX_iR_00nj_kW?^[ni_kZo^Lnj_kVo^[l0
3lboflo<_m_?c;oKc`0300l00of_ooooo`0@ool300lKool00`0?ooooo`0Dool000Coo`0300oooooo
017oo`<03aSoo`0J00l@O`0?00mTSg>?I8l03fB?Lhl03hB?MGn3OgAoLgmcKg9_Hfl03e9OD5l03c1O
<4lPC`803`0FDhmSS`0?HhmCShJ_00n6[hJO00n6WhJ_QYn6[hJO00nH[jRoV:nX_iR_Z;l200l03JR_
00nj_kVo^[o9_kZo^Knj_lVo^[l03mbo00;K_`08floL_m^o00on_nj_oJl03a3oo`803akoo`0300oo
oooo01Coo`001?oo00<03oooool05?oo0`0?5Ooo00T03`1o00l03fBOI8l03fB?I9l00P0?00MeSgB?
M7mcOfAoLgmSK`02DVl01P0?@Em0Gb1?<5mCS`803`=CS`0E00mCS`0?QZmg[hJ_MZl03hN_QZmf[jRo
00nX_iRoZ;nH_jRoV;nX_iRo00<03`0C^[ni_kZo^Knj_kVo^[ni_`0?flo<_m_?c;oKclbo00o^_ojo
00l03ooo0P0?8?oo00<03oooool05?oo0004ool00`0?ooooo`0Gool400lAool200l0515o00mTSf>O
I8mSW`0?HimTS`0?M7mcSf=oLgmSKf9oDUm@Ke5O@5l2<4l02e>?00l03`0?DhmSSe>?Hhn6[`0?MZl0
0hJ_015f[`0?QZn6[`0?Z;nH_jRoV:nX_iRoZ;nH[jRoV;l03kZo00803`03^Knj_lVo00:i_`0500o9
_m^oflo;_`02fkl01M_?00om_nj_00l03Ooo0P0?8_oo0P0?5Ooo0003ool00`0?ooooo`0Lool300l>
ool05B2?00lQS`0?I9mTSfBOI8l03fB?00mdO`0?I7mcOf=_HWmBKf9_@EmAK`02<5l08P0?Hil03`0?
Dhl03e>?HhmCS`0?MZn6[gJ_QZmf[hJ_MZl03iRo00nH_jRoV;nX_iRoZ;nH_jRoV;l03kZo^/nj_kW?
0P0?00nj_kW?^[l03lboflo<_m_?c;oKc`0?o[o^_`0?k[l02_oo0`0?9Ooo00<03oooool00_oo0`0?
3_oo0003ool00`0?ooooo`0Oool300l;ool00`0?88lAO`0200l01g>?I8l03fB?Hhl03f>?00803`07
HfmROe9OHFmAGe5_@4l00P0?00]SSe>?00l03f>?00mSSe>?00mf[`0?00N6[`803`0@Z;nH[jRoV:nX
_iR_Z;nH[jRo00ni_kZo^Lnj_kVo^[l200l01<Vo00oKcmbo0]^o00KKcmbo00o^[ojo00l9ool200lX
ool00`0?ooooo`02ool00`0?ooooo`0>ool000?oo`0300oooooo02;oo`<03`Soo`0300lAOb6O0080
3`09I8mTWfB?I9l03f>OE8l03fAo00803`03HVmBKf>O00803`04E8l03eB?Hhl200l03UB?00mCS`0?
MZn6[gJ_00mg[hJ_MZn6[gN_00l2V;l200l049RoZ;nH_jRoV;nX_`0?^/nZ_kW?^[njcjZo^Lnj_k[?
100?00G<_m_?c;l03lbo00;^_`0300oooooo00Goo`803bWoo`803`Goo`0300oooooo00Ooo`803`Co
o`000ooo00<03oooool09Ooo0`0?1Ooo01T03b2?00laS`0?HimTSf>?00mSWfB?00mTSf>?00mSS`0?
Hhl03f>?00mSS`0?HhmCS`0200l02F>?Dhn6[`0?QZmf[hJ_MZl03`02QZl06gJ_Z;l03jRoV;nX_iRo
00nH[jRoV;nX_iR_00nj_kW?^[nickZo^Lnj_kW?^[l03lc?floK_`0200l01]^o00on_nj_00o^[`Go
o`803bcoo`0300oooooo00;oo`0300ooo`0?00Soo`0300oooooo00?oo`000ooo00<03oooool0:?oo
0`0?0_oo00@03b:?00lRS`803`0CI9mDSf>OI8mSW`0?Hil03f>O00mSWeB?00mDS`0?E8l03e>?Hil0
0P0?01=CSgJo00n6[gJ_Q[mf[hJ_MZl03gJ_QZl03iS?V;nX_iRoV<nH_`0200l04jRoV;l03kZo^Lnj
_k[?^[nickZo^/nj_`0?c<oLclc?bmo<cmc?00D03`?oo`<03bgoo`803`Goo`803`Woo`0300oooooo
00;oo`000ooo00<03oooool0:ooo100?010RSc6?00l03fB?HhmTSf>?00mSSfB?00mTS`0?E8l03`9S
S`0500mSS`0?HhmCS`0200l0;XJ_00n6[`0?QZmf[hJ_MZn6[`0?QZl03jRoV;nX_iRoZ;nH_jRoV;nX
_`0?Z;l03kW?^[ni_kZo^Lnj_kVo^[nic`0?flo<cm_?c<oKclc?00o__nk?00o^cooo0P0?<Ooo00<0
3oooool03Ooo0P0?1?oo0003ool00`0?ooooo`0^ool06@0?8IlRS`0?E8mSWfB?I9mDSf>OE8l03eB?
Hil03f>?00mSWeB?00mDS`0?E8mSSe>?00803`9f[`0:00mf[hJ_MZn6[gJ_QZmf[`0?VKl3V;l01YVo
V;nH_iRoVKnH_`<03`0B^/nZ_kW?^[njcjZo^Ll03mc?c<o;clc?g<o<cl_?00o^cmno0`0?<_oo0P0?
5Ooo0003ool00`0?ooooo`0^ool03P0?8Xl03c:?<Yl03f>?I8mSSfB?Hhl03f>?00l2Hhl0500?DhmS
Se>?Hhl03f>?Dhme[`0?QJmf[hJ_MZl03gJ_QZmf[hJ_MZl200l03JRoV;nX_iRoZ;nH_jRoV;nX_`0?
Z;nZckW?00803`0A^[nickZo^Lnj_`0?c<oKclc?flo<cm_?00o^cnjo00o^_`0eool00`0?ooooo`0C
ool000?oo`0300oooooo02koo`0500lQW`0?<YlcW`0200l046>OI8mSW`0?HimDS`0?E8mSWeB?Hhl0
3f>OE8l03e>?0`0?00af[gJoMZmf_gJ_00mf[hJ_MZl03iRoV<l200l03IRoZ;nH_iS?V;nX_iRo00nZ
ck[?Z/njckZo00803`0>^Lnj_`0?c<o;glc?g<o<cl_Oc<l03nnok/l03cKoo`0300oooooo01?oo`00
0ooo00<03oooool0;_oo00`aSc:?<YlcS`0?@imSS`0?HhmTSf>?I8l3Hhl01UB?HhmSS`0?DhmSS`@0
3`0;MZl03`0?00mf[hJ_00n6[gJ_V;l03`04V;l02@0?V;nX_iRoZ;nH_`0?V;nic`02^/l04ZZo^Lnj
ckW?00ni_`0?flo<cm_?c<oKclc?00o^_nk?00o^ccKoo`0300oooooo01?oo`000ooo00<03oooool0
;_oo01@03c:O<ilbW`0?@jldWfBO00mSWeB?HhmDSf>OE8mSSeB?HimDSgJ_0`0?00Af[fJ_M[l03`9f
[`<03`0;MZnHc`0?V<nH_iS?VKnHciRo00nI_`03V;l02P0?^/nZck[?Z/njcj[?^/nZck[?100?00S<
cl_?c<oLc`0?k/o__`0?=ooo0P0?5?oo0003ool00`0?ooooo`0^ool200l00c:O<Xl03`02@il00`0?
Djl03`0200l00f>?E8mSS`02Hhl400l02fJ_00mf[gF_MZl03gJ_QZmf[hF_MZl00`0?00>H_iS?V;l0
0YRo01BHciRo00nH_jRo00nick[?^LnZckW?^/nicj[?^Ll03kW?c<o;glc?0P0?00KKc`0?k/o^_`0?
k[lgool200lDool000;oo`0300oooooo033oo`0;<Yl03d>_=9m3[`0?E:m4[`0?EJmSW`0700l03GFo
IZme_`0?M[mf[gJoMZl03gJ_M[mf[iS?00803`09V;l03`0?00nH_iS?V;nHciRo00803`0;Z;nZck[?
Z/njcj[?^/nZck[?Z/l03`02c=l01Lc?c=o<glcOc<l0100?>Ooo00<03oooool00_oo0P0?3_oo0002
ool00`0?ooooo`0`ool300l2@il01`0?A9mC[`0?E:mEW`0?009U[`803`0BIJl03fJ_MJmf[`0?MZme
[gJ_MJl03hF_MZnHc`0?V<nH_`0?0iRo0`0?0iRo00Fic`0?^/nZ_kW?00:jc`0@Z[nick[?00o<cmcO
c<o<glc?g=o<c`0?glo^c`0?k/lhool200l6ool00`0?ooooo`0;ool000;oo`0300oooooo033oo`0;
08lcWd>O<im3[`0?E:m4W`0?EJmD[`0400l02VJ_IKmV[`0?IZme_fJ_00mV[gJo0gJ_00bHc`0?V<n8
_iS?R;l03iRoV<nI_iS?V;l300l03J[?Z]l03`0?Z/njcj[?^/nZck[?00o<glc?00?<g`06c<l03lcO
gmoOc`0?>_oo00<03oooool00ooo00<03oooool03?oo0002ool00`0?ooooo`0`ool00`1?00l03`02
@il01@0?A9mC[`0?E:l00P0?00=E[fB_00l00VF_01=e[`0?MJmV[gF_00me[gJ_MJmf[iS?00nHchRo
V<n8_iS?R;l03`03V;l019S?V;l03j[?1P0?00nick[?^Ll03l_Oc<o<glc?bmo<clcO00o^cmo?00l0
>_oo0P0?1_oo00<03oooool02ooo0002ool00`0?ooooo`0aool01`1o00l03d>_A9mD[dB_00803`06
E:l03fF_EJl03fJ_0VF_00T03fJ_MKmV[`0?MZmf_gJ_M[l00P0?01:8_iS?R<nHchRoV<n8c`0?V;nH
ciRo00nZcj[OZ/nZgj[?Z]l300l01;[?00njclc?0lcO00O<clcO00oOgmo?00oOc`0kool00`0?oooo
o`02ool200l>ool000;oo`0300oooooo037oo`803`03@im4We>_00803`04E9mD[eFO00l2IJl02`0?
MJmU[gF_00me[gJ_MJmf[gF_MZl00P0?01NGc`0?V<n8_iS?V;nHchRoV<nH_`0?V;l03iRo^/nZck[?
Z/njcj[?^/nZck[?00<03`0:c=o<cmcOc<o<g`0?g=oOcnk?00llool00`0?ooooo`0Bool000;oo`03
00oooooo037oo`0307l2[`0?00803`0DE:m4WeB_EJmD[`0?IJmE[`0?IZmU_fJ_00mV[gFoIZmf[fJ_
00mf[`>8c`0H00nHchRoV<n8_iS?R;nHciVo00nH_j[OZ/nZgj[?Z]nZcj[OZ/nZgj[?00nmglc_100?
00?<g`0?00l00P0???oo0P0?5?oo0002ool00`0?ooooo`0bool200l01@:ODjl03`0?EIl00UB_00AT
[eF_I:l03`9U[`05MJl03gF_IZme[`0200l088RoQln8_hO?R;n7c`0?V<n8_iS?R;nHchRo00nZc`0?
Z/nicj[?^]nZckW?Z/njgj[?00nlglcO_=o<gkcOc=l300l00moO00ooo`0mool00`0?ooooo`0Bool0
00;oo`0300oooooo033oo`803`0508l2[`:_00lT_`0200l01eF_E:mE[fF_EJmU_fJ_009U[`07IKl0
3`0?00n7cgS?00l01HS?00ZHc`0?V<n8_iS?R<l03hRoZ]nJg`803`0?Z]nZcj[OZ/nZgj[?00nlglc_
_Mo<kkcOc>nmg`0?00;?g`<03cgoo`0300oooooo01;oo`000_oo00<03oooool0;_oo0P0?0ooo00D0
3`:O00lT[b>o00`03`0FN<n7cgRoQln8_`0?R;nGchRoR<n8_iS?00nHchRo00nH_j[OZ/nZgj[?Z]l2
00l01j[?^/nZc`0?Z/o<gkcO00?<g`06_=l03lcOgml03moO0_oo0`0?>_oo00<03oooool04_oo0002
ool00`0?ooooo`0/ool200l5ool05`:O00l03bBo5;l03cJoALl03eK?ElmVc`0?MlmXcgO?00mgcgS?
QlmhcgO?00l01XS?01/03hRo00n8_j[OV]nZgi[OZ]nJgj[OZ/l03j[?00nZclc__Mo<kkgOc>nmg`0?
_Mo?g`0?cml01_oo0`0?=ooo0P0?4ooo00000ooo00ooo`0/ool200l8ool0=P:O8klT_b>o00m5cdFo
00mG_fK?E/l03fO?MlmWcgO?00n7cgS?Qlmh_hO?00n7chRoQln8_hO?R;l03hRoZ]nJcj[OZ/nZgi[?
Z]nZcj[OV/l03j[?c=nlglcO_=o<gkcO00nlgmoO00oNg`[oo`<03cGoo`0300oooooo017oo`0000?o
o`0?ool0:_oo0P0?2ooo01H03bBo5;l03cJoALlfc`0?ElmFcfO?00mWcgO?Ill03gS?QlmhchO?N<l0
3`F8c`0<00n8c`0?00nZgi[OZ]nJgj[OV]nZgi[O0P0?00>lk`0?00l00P0?00>mglc_00l00P0?00??
goooool03?oo0`0?<_oo00<03oooool01?oo00<03oooool02_oo00000ooo00ooo`0Xool200l>ool0
3@0?8klT_`0?A[m5c`0?I/mG_fK?00mgcfNo009gc`0900mh_hO?N<n7cgRo00n8_hS?00803`>Jg`0@
Z]l03j[OZ/nZgj[?Z]nZc`0?Z/nlkkgO_>nmkkc__Ml200l00moO00l03`0Bool300l^ool200l4ool3
00l<ool00003ool03ooo02Koo`803a7oo`0D00lT_`0?ALlf_`0?ElmVceO?Mll03gO?Ilmgc`0?Qlmh
cgO?N<n7c`:8c`0400n8ci[OV^l3V]l04j[O00nZgi[OZ]nJg`0?V]nlkkg__>n]kkc__Nnlk`0?_ml0
3koO01Koo`<03bcoo`0300oooooo00;oo`0300ooo`0?00coo`0000?oo`0?ool09?oo0P0?4ooo01<2
[`0?00m5_dG?AKl03eK?I/mG_`0?IlmgcfO?Mll03hO?N;n7c`0400l3V]l01IWOV]nJgi[OVMl00P0?
00FJc`0?Z/nlkkg_00>lk`06_Nl03`0?_]l03kkO6_oo0`0?:?oo0P0?1Ooo0P0?3?oo00000ooo00oo
o`0Rool200lFool040:_=[l03`0?ALl03eK?ElmVc`0?MlmWcgO?Ill03gS?0P0?00F7ch[_R^nJg`0?
00>Jg`0@V^nJgi[OV]nJki[O00nJgkc__Nnlkkg__>nmk`0?_Nl200l00koOooooo`0Lool300lVool0
0`0?ooooo`04ool00`0?ooooo`0:ool00003ool03ooo023oo`803aWoo`050Zl6c`0?00mVc`0200l0
15K?I/mW_gO?100?00QhchW_R]nIkh[ORNnJg`0?0i[O00>Zgi[OV]l00P0?00>]kkc_00l00`0?00Fm
g`0?_Nl03jo?02?oo`<03b?oo`0300oooooo017oo`0000?oo`0?ool07_oo0P0?7?oo00H2[`KO00l7
g`0?BNl400l03GW_J^mikf[_00n:gh[_R]n:kh[OR^n:g`0?00>Jg`0>V^l03i[OWNn/ojg_[OnMkjco
_Nl03jg_00mncbOoo`@03akoo`803a?oo`0000?oo`0?ool07?oo0P0?8?oo01L6c`0?1]l03dSOF>m8
k`0?JMmikfW_NNmYg`0?R]n9kh[ORNn:ghW_R]l03i[O00803`07[?n]kjco[Nn/ojg_[?l0100?;Ooo
0`0?7?oo00<03oooool04Ooo00000ooo00ooo`0Jool200lSool010KO5]l6g`0?0TS_00M9k`0?JNmi
kf[_NNmYk`0200l00h[_R]n9k`02R^l200l02i[O00l03jco[Nn/oig_[?l03jco00l0<_oo0`0?6Ooo
00<03oooool04Ooo00000ooo00ooo`0Gool300lVool400l00dSOF>m8g`0200l3NNl01FWOVNl03hW_
R]l00P0?00F9khg_W?n=ojco00D03`03SLoooooo03Goo`<03aOoo`0300oooooo013oo`0000?oo`0?
ool05Ooo0P0?:ooo00dFg`0?00l03dS_BNmikf[_NNmZkgW_00n:k`0200l028goS?n=ohcoSOn<ohgo
S?l200l00hgoooooo`0jool300lCool200lBool0000300oooooo01?oo`803c3oo`@03`08NNl03`0?
00mKoec_JomKk`@03`04S?l03`0?00l2ool00`0?ooooo`0mool300lAool00`0?ooooo`0@ool00003
00oooooo017oo`803cKoo`032Ll03`0?00X03`03S?oooooo00;oo`0300oooooo043oo`<03`koo`03
00oooooo00;oo`803`coo`0000<03oooool03ooo0P0?B_oo00<03oooool0@ooo0`0?2_oo0P0?1_oo
00<03oooool02Ooo00000`0?ooooo`0=ool200m<ool00`0?ooooo`16ool300l8ool00`0?ooooo`02
ool200l<ool0000300oooooo00_oo`803dkoo`0300oooooo04Woo`<03`Coo`803`Coo`0300oooooo
00_oo`0000<03oooool02Ooo0P0?D?oo00<03oooool0C?oo0`0?0_oo00<03oooool00_oo0`0?2ooo
00000`0?ooooo`07ool200mBool00`0?ooooo`1?ool300lBool0000300oooooo00Goo`803eCoo`03
00oooooo04koo`<03a?oo`0000<03oooool00ooo0P0?E_oo00<03oooool0Booo0`0?5_oo0000100?
oooooooo0P0?F?oo00<03oooool0B?oo0`0?6Ooo0000100?ool03`0?F_oo00<03oooool0A?oo100?
7?oo000200mLool00`0?ooooo`11ool300lPool000@03e[oo`0300oooooo03koo`<03b?oo`001?oo
1@0?EOoo00<03oooool0>ooo0`0?9_oo0009ool400mAool00`0?ooooo`0hool300lYool000goo`D0
3dcoo`0300oooooo03Coo`@03bcoo`004_oo100?B?oo00<03oooool0<Ooo0`0?<?oo000Fool500m3
ool00`0?ooooo`0^ool300lcool001_oo`@03cooo`0300oooooo02_oo`<03cKoo`007ooo1@0?>_oo
00<03oooool0:?oo0`0?>Ooo000Tool400lfool00`0?ooooo`0Uool300llool002Soo`@03c;oo`03
00oooooo027oo`@03cooo`00;?oo1@0?;Ooo00<03oooool07_oo0`0?@ooo000aool400lYool00`0?
ooooo`0Kool300m6ool003Goo`D03bCoo`0300oooooo01Soo`<03dWoo`00>_oo100?8?oo00<03ooo
ool05Ooo0`0?C?oo000nool500lKool00`0?ooooo`0Aool400m?ool004?oo`@03aOoo`0300oooooo
00koo`<03e?oo`00Aooo1@0?4_oo00<03oooool02ooo0`0?E_oo001<ool400l>ool00`0?ooooo`08
ool300mIool0053oo`@03`[oo`0300oooooo00Goo`<03ecoo`00E?oo1@0?1Ooo00<03oooool00_oo
0`0?Gooo001Iool400l00ooo00l03`0300mRool005goo`803fKoo`00aOoo0000\
\>"],
  ImageRangeCache->{{{0, 195.875}, {138.6875, 0}} -> {0.017655, 0.039185, 
  0.00687, 0.00687}}]
}, Open  ]],

Cell[BoxData[{
    \(\(Clear[Idc]; \)\), 
    \(\(Idc[x_, y_, z_] := 
      \(\(Id /. Ttheta \[Rule] ArcTan[y, \@\(x\^2 + z\^2\)]\) /. 
          Rr \[Rule] \@\(x\^2 + z\^2 + y\^2\)\) /. Pphi \[Rule] atn[z, x]; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Intensity in the $x-z$ Plane"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig16x6 = 
      DensityPlot[
        Evaluate[Idc[x\ a, a, z\ a]], {x, \(-2\), 2.01}, {z, \(-2\), 2.01}, 
        AxesLabel \[Rule] {"\<x in a\>", "\<z in a\>"}, Evaluate[opt1]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.498801 0.239785 0.498801 0.239785 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25902 -0.0125 -7 -12 ]
[.25902 -0.0125 7 0 ]
[.4988 -0.0125 -4 -12 ]
[.4988 -0.0125 4 0 ]
[.73859 -0.0125 -4 -12 ]
[.73859 -0.0125 4 0 ]
[.97837 -0.0125 -4 -12 ]
[.97837 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25902 -14 -6 ]
[-0.0125 .25902 0 6 ]
[-0.0125 .4988 -8 -6 ]
[-0.0125 .4988 0 6 ]
[-0.0125 .73859 -8 -6 ]
[-0.0125 .73859 0 6 ]
[-0.0125 .97837 -8 -6 ]
[-0.0125 .97837 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25902 0 m
.25902 .00625 L
s
gsave
.25902 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.4988 0 m
.4988 .00625 L
s
gsave
.4988 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.73859 0 m
.73859 .00625 L
s
gsave
.73859 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97837 0 m
.97837 .00625 L
s
gsave
.97837 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06719 0 m
.06719 .00375 L
s
.11514 0 m
.11514 .00375 L
s
.1631 0 m
.1631 .00375 L
s
.21106 0 m
.21106 .00375 L
s
.30697 0 m
.30697 .00375 L
s
.35493 0 m
.35493 .00375 L
s
.40289 0 m
.40289 .00375 L
s
.45084 0 m
.45084 .00375 L
s
.54676 0 m
.54676 .00375 L
s
.59472 0 m
.59472 .00375 L
s
.64267 0 m
.64267 .00375 L
s
.69063 0 m
.69063 .00375 L
s
.78654 0 m
.78654 .00375 L
s
.8345 0 m
.8345 .00375 L
s
.88246 0 m
.88246 .00375 L
s
.93041 0 m
.93041 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25902 m
.00625 .25902 L
s
gsave
-0.0125 .25902 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .4988 m
.00625 .4988 L
s
gsave
-0.0125 .4988 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .73859 m
.00625 .73859 L
s
gsave
-0.0125 .73859 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .97837 m
.00625 .97837 L
s
gsave
-0.0125 .97837 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06719 m
.00375 .06719 L
s
0 .11514 m
.00375 .11514 L
s
0 .1631 m
.00375 .1631 L
s
0 .21106 m
.00375 .21106 L
s
0 .30697 m
.00375 .30697 L
s
0 .35493 m
.00375 .35493 L
s
0 .40289 m
.00375 .40289 L
s
0 .45084 m
.00375 .45084 L
s
0 .54676 m
.00375 .54676 L
s
0 .59472 m
.00375 .59472 L
s
0 .64267 m
.00375 .64267 L
s
0 .69063 m
.00375 .69063 L
s
0 .78654 m
.00375 .78654 L
s
0 .8345 m
.00375 .8345 L
s
0 .88246 m
.00375 .88246 L
s
0 .93041 m
.00375 .93041 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25902 .99375 m
.25902 1 L
s
.4988 .99375 m
.4988 1 L
s
.73859 .99375 m
.73859 1 L
s
.97837 .99375 m
.97837 1 L
s
.125 Mabswid
.06719 .99625 m
.06719 1 L
s
.11514 .99625 m
.11514 1 L
s
.1631 .99625 m
.1631 1 L
s
.21106 .99625 m
.21106 1 L
s
.30697 .99625 m
.30697 1 L
s
.35493 .99625 m
.35493 1 L
s
.40289 .99625 m
.40289 1 L
s
.45084 .99625 m
.45084 1 L
s
.54676 .99625 m
.54676 1 L
s
.59472 .99625 m
.59472 1 L
s
.64267 .99625 m
.64267 1 L
s
.69063 .99625 m
.69063 1 L
s
.78654 .99625 m
.78654 1 L
s
.8345 .99625 m
.8345 1 L
s
.88246 .99625 m
.88246 1 L
s
.93041 .99625 m
.93041 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25902 m
1 .25902 L
s
.99375 .4988 m
1 .4988 L
s
.99375 .73859 m
1 .73859 L
s
.99375 .97837 m
1 .97837 L
s
.125 Mabswid
.99625 .06719 m
1 .06719 L
s
.99625 .11514 m
1 .11514 L
s
.99625 .1631 m
1 .1631 L
s
.99625 .21106 m
1 .21106 L
s
.99625 .30697 m
1 .30697 L
s
.99625 .35493 m
1 .35493 L
s
.99625 .40289 m
1 .40289 L
s
.99625 .45084 m
1 .45084 L
s
.99625 .54676 m
1 .54676 L
s
.99625 .59472 m
1 .59472 L
s
.99625 .64267 m
1 .64267 L
s
.99625 .69063 m
1 .69063 L
s
.99625 .78654 m
1 .78654 L
s
.99625 .8345 m
1 .8345 L
s
.99625 .88246 m
1 .88246 L
s
.99625 .93041 m
1 .93041 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
68.500000 13.000000 moveto
(in) show
76.687500 13.000000 moveto
(a) show
80.187500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0203030404050606070808090A0B0B0C0D0D0E0E0E0E0F0E
0E0E0E0D0D0C0B0B0A090808070606050404030302
030304050506070708090A0B0C0D0D0E0F10101111111111
111110100F0E0D0C0C0B0A09080707060505040303
03040505060708090A0B0C0D0E0F10111213131414151515
141413131211100F0E0C0B0A090808070605050403
040505060708090A0B0C0D0F101113141516171818191919
1818171615141211100F0D0C0B0A09080706050504
0405060708090A0B0D0E101113141618191B1C1D1D1E1E1E
1D1D1C1A1917161413110F0E0D0B0A090807060504
05060708090A0C0D0F10121416181A1C1E20212324242424
232221201E1C1A18161412100E0D0B0A0908070605
060708090A0C0D0F111315171A1C1F212426282A2B2C2C2C
2B2A282624211F1C19171512100F0D0B0A09080706
0607090A0B0D0F111315181B1E2124282B2E313334353635
3432302E2B2724211E1B181513110F0D0B0A080706
07080A0B0D0F111316191C1F23272B2F33373B3E40414141
3F3D3A37332F2B27231F1B181513100E0C0B090807
08090B0C0E101315191C2024292E33383E43474B4D4F504F
4D4A46423D38332D2824201C181512100E0C0A0908
080A0C0D101215181C20252A30363C434A50565A5E606160
5E5A554F49423C352F2924201B1815120F0D0B0A08
090B0D0F1114171B1F242A30373F474F5860676D72757674
716D665F574F463E373029241F1B1714110E0C0B09
0A0C0E1013161A1E232930374049535E68727B83898C8D8C
88827A71675C52483F362F28221E191612100D0B0A
0B0D0F1114181C21272E363F4954616D7A87929BA2A7A8A6
A29A9185796C5F53483E352D26211C1814110E0C0A
0B0D1013161A1F242B333C4753616F7F8E9DAAB5BEC3C4C2
BDB4A99B8C7D6E5F52463B322A241E1A1612100D0B
0C0E1114181C21282F38434F5E6D7F91A3B4C3D0D8DEDFDD
D8CEC2B2A18F7D6C5C4E42372E27211C1714110E0C
0D0F1215191E242B333E4A58687A8EA3B7CADAE7EFF4F5F3
EEE6D9C8B5A08C786656483C322A231D1915110F0C
0D1013161B20262E3743506072879DB4CADEEEF8FDFFFFFF
FDF7ECDCC8B19A84705E4E41362D251F1A16120F0D
0E1013171C2128313B4756677B92AAC3DAEEFAFFFEFAF8FA
FEFFF9ECD8C0A88F79655445393027211B1713100D
0E1114181D232A333E4B5A6D839BB5D0E7F8FFFCEEDFD9E1
F0FCFFF7E5CDB399806B59493C3229221C1714100E
0E1114181D242B34404D5E7289A2BED8EFFDFEEED0AEA0B2
D4F1FFFCEDD6BBA086705C4C3E332A231D1814110E
0E1115191E242C35414F60758CA7C3DEF4FFFADFAE715078
B5E3FBFFF2DBC0A48A725E4D40342B231D1814110E
0F1115191E242C36415061768DA8C4DFF5FFF8D9A050005A
A7DEFAFFF3DDC1A58B735F4E40342B241D1814110E
0E1115191E242C35414F60748CA6C2DDF3FFFAE1B2785A7E
B8E4FCFEF1DBBFA389725E4D3F342B231D1814110E
0E1114181D232B343F4D5E7188A2BDD8EEFDFEF0D4B5A7B8
D7F2FFFCECD5BA9F866F5C4C3E332A231D1814110E
0E1114181D222A323D4A5A6D829AB4CEE6F7FFFCF1E3DEE4
F2FDFFF6E3CCB198806A58493C3129221C1714100E
0E1013171C2128303A4655667A91A9C2D9ECF9FFFFFBFAFC
FFFFF8EAD6BFA68E78645345392F27211B1713100D
0D1013161A20262E37424F5F71859BB2C8DCECF7FCFFFFFE
FCF6EADAC6B099836F5D4E41362D251F1A16120F0D
0D0F1215191E242B333D495767798CA1B5C8D8E5EDF2F3F1
ECE3D6C6B39F8A776555483C322A231D1815110F0C
0C0E1114171C21272F38424F5C6C7D8FA0B1C0CDD6DBDDDB
D5CCBFB09F8D7B6A5B4D41372E27201B1713100E0C
0B0D1012161A1F242B333C46525F6E7D8C9AA8B3BBC0C1BF
BAB1A6998A7B6C5E51453B322A231E1915120F0D0B
0B0C0F1114181C21272D353E48535F6C78848F99A0A4A5A3
9F988E83776A5E52473D342D26201B1714110E0C0A
0A0C0E101316191E23282F373F48525C66707980868A8B89
8680786F655B51473E362E28221D191512100D0B0A
090B0C0F1114171B1F242930363E464E565E656B70727372
6F6A645D554D453D362F29231E1A1713110E0C0B09
080A0B0D0F1215181B2024292F353B42484E54595C5E5F5E
5C58534E48413B342E29241F1B1714120F0D0B0A08
08090A0C0E101215181C2024282D32373C4145494C4D4E4D
4C4945413C37322D28231F1B181512100E0C0A0908
0708090B0D0E101315181B1F22262A2E3236393C3E40403F
3E3C3936322E2A26221E1B181512100E0C0B090807
0607080A0B0D0F111315181B1E2124272A2D303233343434
33312F2D2A2723201D1A171512100E0D0B0A080706
060708090A0B0D0F10121517191C1E21232527292A2B2B2B
2A29272523201E1B19171412100E0D0B0A09070606
05060708090A0B0D0E10121416181A1C1D1F212223232423
2322211F1D1B1917151312100E0D0B0A0908070605
0405060708090A0B0C0E0F1112141617191A1B1C1D1D1D1D
1D1C1B1A1817151412110F0E0C0B0A090807060504
040505060708090A0B0C0D0E101112141516171718181818
1817171615131211100E0D0C0B0A09080706050404
0304050506070808090A0B0C0D0E10111112131414141414
1414131211100F0E0D0C0B0A090807070605040403
030304050506070708090A0B0B0C0D0E0F0F101011111111
1110100F0F0E0D0C0B0B0A09080706060504040303
0203030404050606070808090A0A0B0C0C0D0D0E0E0E0E0E
0E0E0D0D0C0C0B0A0A090808070606050404030302
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{110.25, 110.25},
  ImageMargins->{{107.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002:0000RQ000`40l00?003`R_oo002:ool008[o
o`00R_oo002:ool008[oo`00R_oo002:ool008[oo`004_oo0`0?5?oo0`0?4ooo00<03oooool05?oo
0`0?5?oo0`0?6_oo000Bool00`0?ooooo`0Eool00`0?ooooo`0Aool00`0?ool03`0Fool00`0?oooo
o`0Cool00`0?ooooo`0Jool000goo`<03`?oo`0300oooooo00ooo`<03`;oo`0300oooooo017oo`03
00ooo`0?01Koo`0300oooooo01Coo`0300oooooo01Woo`004_oo00<03ooo00l05Ooo00<03oooool0
4Ooo00<03ooo00l05_oo00<03oooool04ooo00<03ooo00l06_oo000Cool200lDool200lDool00`0?
ooooo`0Dool200lFool200lJool008[oo`00R_oo001fool00`0?ool03`03ool01@0?ool03ooo00l0
0ooo00<03ooo00l00ooo001gool00`0?ooooo`02ool01@0?ool03ooo00l00ooo0P0?1?oo0008ool3
00m/ool00`0?ooooo`02ool01@0?ool03ooo00l01?oo00<03oooool00_oo0008ool00`0?ooooo`04
oomS00l4ool00`0?ool03`03ool0100?ool03`0?1?oo0P0?1?oo0003ool300l3ool00`0?ooooo`03
ool00`0?ool03`0Fool00`0?ooooo`0Eool00`0?ooooo`0Dool00`0?ooooo`0Eool00`0?ool03`0H
ool000Soo`0300ooo`0?00Coo`0300ooo`0?00803`0U40l03a0?00l@3`0?40l03a0?00l@7`4?40l0
3a0O0@l@7`4?41l13a0O4@l@7`4?41lA3a0O4@l@7a4?41lA3a0O4@lA7a4?41l00Q4O00DA3a0O4AlA
7a4?00<A7`064@l@7a4O4AlA3a0O0Q4O028A3a0O4@l@7a4?41lA3a0O4@l@7a4?41l13a0O0@l@7`4?
41l13a0O0@l@3`0?41l13a0?00l@3`0?40l03a0?00l@3`803`03ool03`0?00[oo`0300oooooo00_o
o`002Ooo0P0?1?oo02X03ooo01l13`0?0@l07`4?01l13`0O0@l07`4?01l13a0O0@l07`4?41l13a0O
0@l@7`4?41l17a4O0@lA7`4O4Al13a4O0AlA7`4O4Al17a4O0Al34Al01@4O4AlA7a4O0Al00a4O02/1
7a4O4AlA7`4O4Al17a4O0AlA7`4O4Al13a4O0AlA7`4?41l13a4O0@l@7`4?41l13`0O0@l@7`4?01l1
3`0O0@l07`4?01l13`0O0@l03`4?01l13`02ool00`0?ooooo`0Fool000ooo`0400ooo`0?40l300l0
7A0?00l@7`0?40l03a0O0@l@7`0?41l13a0O0@l@7`4?41lA3a0O0@l@7a4?41lA3a0O4Al@7a4?41l0
0a4O00<@7a4O4Al04A4O024@7a4O4AlA7a0O4Al@7a4?41lA3a0O4@l@7a4?41l13a0O0@l@7`4?41l0
3a0O0@l@7`0?41l03a0?00l@7`0?40l00`0?00@@3oooool03aSoo`003ooo01`03ooo01l03`0O0@l0
7`4?01l13a0O0@l07`4?41l13a0O0@l@7`4?41l17a0O0@l@7`4O4Al17`<A7`050AlA7a4O4Al17`0K
4Al08@4O4AlA7a4O0AlA7`4O4Al17a0O0AlA7`4?41l17a0O0@l@7`4?41l13`0O0@l@7`4?01l13`0O
0@l07`4?01l03`02ool00`0?ooooo`0Fool000ooo`0M00ooo`0?40l03a0?00l@3`4?40l03a0O0@l@
3`4?41l13a0O4@l@7`4?41lA3a0O4@l@7a4?4AlA3`034Al00a4?4AlA7`024Al05B4O4AlA7a4O8AlA
7b4O4AlQ7a4O8AlA7b4O4AlQ7a4O8AlA7b4O4AlQ7`034Al00b4O4AlA7`044Al0714?41lA7a0O4@l@
7a4?41l13a0O4@l@7`4?41l13a0O0@l@3`0?41l13a0?00l@3`0?40l03a0?0_oo00<03oooool05_oo
000?ool06P0?ool07`4?01l13`0O0@l07`4?01l13a0O0@l07`4?41l13a0O0AlA7`4?4Al17a4O0Al3
4Al01@4O4AlA7a4O0Al0114O018A;a8O4AlA7a4_4QlA7a8O4BlB7a4_4QlA;a8O4AlB7a4_4Ql24Al0
0a4_4QlA7`044Al0804O4AlA7a4O0AlA7`4O4Al13a4O0AlA7`4?41l13a0O0@l@7`4?41l13`0O0@l0
7`4?01l13`0O0@l07`4?ool200lHool000ooo`0L00ooo`0?40l03a0?00l@3`0?41l03a0?00l@7`4?
41l13a0O0@l@7a4?41l13a0O4@l@7a4?41l34Al00a0O4AlA7`054Al01B4O4AlA7a4O8Al00a4O00DQ
7a4O8AlA7b4O00<A7`058AlA7a4O4AlQ7`074Al07A0O4AlA7a4?41lA3a0O0@l@7a4?41l13a0O0@l@
7`4?41l03a0O0@l@3`0?41l03a0?00l@3`0?40l00_oo00<03oooool05_oo000?ool0600?ool07`4?
01l13a0O0@l07`4?41l13a0O0@l@7`4?41l17a4O0Al@7`4O4Al17`PA7`0Q4BlB7a4_4AlA;a8O8BlB
7a4_4QlQ;a8O8BlB7b4_4QlQ;a8O8BlB7b4_4QlQ;a8O8BlB7b4_4QlA;a8O4BlA7a4_00XA7`0E0AlA
7`4O4Al17a0O0Al@7`4?41l13a0O0@l07`4?41l13`0O0@l07`4?00;oo`0300oooooo01Koo`003ooo
01T03ooo00l@3`4?40l03a0?0@l@3`0?41l13a0O0@l@7`4?41lA3a0O4@l@7a4?4AlA3`034Al00a4?
4AlA7`024Al08B4O4AlQ7a4O8AlA7b4O4QlQ7a8O8BlB7b4O4QlQ;a8O8BlB7b4_4QlQ7a8O8BlB7b4O
4AlQ7a8O8AlA7b4O4AlQ7`064Al0614?41lA3a4O4@l@7a4?41l13a0O4@l@7`4?41l13a0O0@l@3`0?
40l13a0?00l@3`;oo`0300oooooo01Koo`003ooo01H03ooo01l13`0O0@l07`4?41l13`0O0@l@7`4?
41l17a4O0@lA7`4O4Al17`DA7`0Y4QlA7a8O4BlB7a4_4QlA;a8O8BlB7b4_4RlR;a8O8RlB;b8_4RlR
;a8_8RlB;b8_4RlR;a8_8RlB;b8_4QlR;a8O8RlB7b4_4QlQ;a8O4BlB7`024Al0114_4AlA7`4O0a4O
01@17a4O0AlA7`4?41l17a4O0@l@7`4?41l13`0O0@l07`4?01l13ooo0P0?6?oo000?ool0500?ool0
3a0?00l@7`4?40l03a0O0@l@7`4?41l13a0O4@l@7`4?41l24Al00a4?41lA7`024Al0:B4O4AlA7a4O
8AlA7b4_4QlQ;a8O8BlB7b4_8QlQ;b8O8BlR7b4_8QlQ;b8_8BlR7b4_8QlQ;b8O8BlR7b4_4QlQ;a8O
8BlB7b4O4AlQ;a4O8Al01a4O01D@7a4O4AlA3a0O4@l@7`4?41l13a0O0@l@7`0?41l13a0?00l@7`0?
40l00_oo00<03oooool05_oo000?ool0400?ool@7`4?01l13a0O0@l@7`4?41l13a0O0AlA7`4O214O
00`A;a8O4BlB7a4_4QlQ;a8O8BlB;b8_4Rl38Rl00a8_8RlR;`028Rl01R8o8blR;b8_8SlS;`8R;`03
8SlR;b8_00@R;`0>4RlR;b8_8RlB;b4_4RlQ;a8O8BlB7b4_4AlA;`HA7`0A0AlA7a4O4Al17a0O0Al@
7`4?41l13a0O0@l07`4?41l13`02ool00`0?ooooo`0Fool000ooo`0E00ooo`0?40l13a0?0@l@7`4?
41l13a0O0@l@7a4?41lA3a0O4@lA7a4?00@A7`0=8AlA7b4O4QlQ7a8O8BlB7b4_8QlQ;b8O8Bl00R8_
00<R7b8_8Rl00R8_00Db;b8_8RlR;c8_00<R;`03<RlR;b8_00@R;`0>8QlQ;b8O8BlR7b4_8QlQ;a8O
8AlA7b4O4AlQ7`8A7`0D4@lA7a4O4AlA3a0O4@l@7`4?41lA3a0O0@l@7`4?41l13a0?00l@3`;oo`03
00oooooo01Koo`003ooo01803ooo01l13a0O0@l@7`4?4Al13a0O0AlA7`4O4Al17a4O0Al44Al0214_
4QlA;a8O4BlB7b8_4Ql38Rl00a8_8RlR;`028Rl06B8o8blb?b<_<SlS;c<o8blb?b<o<clS;c8o8clc
?b<_<SlS;c8o8blR?b<_8SlR;b8o008R;`0;4RlR;a8_8RlB7b4_4QlQ;a8O4BlB7`054Al03`4O4Al1
7a4O0@l@7`4O4Al13a0O0@l@7`4?01l13`02ool00`0?ooooo`0Fool000ooo`0@00ooo`4?40l03a0O
0@l@7`4?41l13a0O4@l@7a4?41l74Al02B4O4AlQ;a8O8BlB7b4_4QlQ;`038Rl06B4_8RlR;b8_<RlR
;c8o8blb?b<_<SlS;c8o<blb?b<_<SlS;c8o8blb?b<_<SlS;c8_00<R;`0=8BlR;b8_8QlQ;b8O8BlB
7b4O4AlQ7a4O8Al00a4O018@7a4O4AlA3a0O4@l@7`4?41l13a0O0@l@7`0?41l13a0?ool200lHool0
00ooo`0=00oooa0O0@l@7`4?41l13a0O0AlA7`4O41l01a4O00PA;a8O4BlB7b4_4RlR;a8_128_00PR
?b<_<SlS;c8o8clc?b<o13<o00HcCc<o<clc?c=?=3l2<cl00c=?<clc?`04<cl01b<o<clS?c8o8blR
?b<_00DR;`074QlQ;a8O8BlB7a4_4Ql02A4O00T17a0O0Al@7`4?41l13a0O0@l00_oo00<03oooool0
5_oo000?ool04@0?ool03a0O0@l@3a4?41l13a0O4@l@7a4?41lA3a4O4@l0114O00PQ7a4O8BlB7b4_
8QlR;b8O128_00Tb;b8_<SlS;c8o<blb?c<_<Sl00c<o00E3?c<o<clc?d<o00<c?`0=@clc?c<o<blb
?c<_<Slc;c8o<blb;b<_<Rl00R8_00XR7b4_8QlQ;a8O8AlB7b4_4AlQ7`HA7`0<4@l@7a4?41l13a0O
0@l@7`4?40l03a0O0_oo00<03oooool05_oo000?ool03P0?ool07`4?41l13a0O0AlA7`4?4Al17a4O
0Al44Al04Q4_4QlA;a8O8BlB;b8_4RlR;b<_8RlS;b8o8blc?b<_<clS?`8c?`0G<dld?d=?=3m4CcA?
A4ldCdA?=4m4CcA?A4ldCdA?=4m4CcA?A4ld?c=?=3lcC`02<cl01R<o<clS;c8o8blR?`@R;`074QlQ
;a8_8BlB7a4_4Ql01A4O00/17a4O0AlA7`4?41l13a0O0@l07`4?00;oo`0300oooooo01Koo`003ooo
00`03ooo0@l@7`4?41l13a0O4@l@7`4?41l74Al0224O4AlQ;a8O8BlR7b8_8Ql28Rl01c8o8Rlb?b<_
<Slc;c8o00<c?`0E@cld?d=?=3m3Cd@o@dm4?d=?A4m3Cd@o@dm4?d=?A3m3Cd@o@dld?d<o00<c?`05
<Slc?c8o8blb;`038Rl02B4_8RlQ;a8O8BlA7b4_4AlQ7`034Al03A0O4AlA7a4?41lA3a0O0@l@7`4?
41l13a0O00;oo`0300oooooo01Koo`003ooo00`03ooo41l13a0O0AlA7`4O4Al17a4O0Al44Al03Q4_
4QlA;a8O8BlB;b8_4RlR;b<_8RlS;c8o8cl4<cl014=?=3m3CcA?0TA?01U4GdE?E5m5CeAOAEmEGdEO
E5m5GeEOAEmDGdEOE5m5CdAOADm4CcA?A4ldCdA?=3lcC`02<cl01R<o<SlS;c8o8RlR?`8R;`074RlQ
;a8_8BlB7a4_4Ql01A4O00X17a4O0AlA7`4?41l17a0O0@ooo`803aSoo`003ooo00d03ooo0@l@7`4?
41lA3a0O4@l@7a4?4AlA3`044Al03R4O4AlQ;a8O8BlR7b8_8Qlb;b8_<SlS;c8o<bl4<cl00d<oA3m3
C`03A4l04EA?ADmDGdE?E5mECeAOEDmDGeE?E5m5CeAOEDmDGdE?E4l00TA?00E4?d=?A3m3?c@o008c
?`03<Slc;c8_00<R;`098BlR;b8_8QlQ;a8O8BlA7b4O008A7`0<4@lA7a4O4AlA3a0O4@l@7`4?41l1
3a0O0_oo00<03oooool05_oo0008ool300l4ool02P0?ool@7`4?4Al13a4O0AlA7`4O1A4O01<B7a4_
4QlA;a8_8RlB;b8_8blR;b<_<SlS?c<o=3lcCc@oA4ld?`02A4l015AOADmEGdEO0UEO00mEKeIOIVmF
GfE_EVmVKeIOIFmFKfI_EUmUKeIOEFl00UEO00A5GeEOADm4G`94C`0C=3m3Cc@o<clS?c<o8blb?b8_
8SlS;b8_4RlQ;a8_8BlB7a4_4Ql01A4O00L17a4O0AlA7`4?41l13`02ool00`0?ooooo`0Fool000Wo
o`0300oooooo00?oo`0<00ooo`4?41lA3a0O4@l@7a4O41lA3a0O0a4O00dQ7a4O8BlB7b4_8QlR;b8O
<RlR;c8o8blb?`03<cl02D=?=3m3CdA?@dm4CeAOADmDG`03EEl03FEOEUmUKeIOIFmVGfE_EUmUKeIO
IFmFGfEO00=EG`0=E5mECeAOA4m3CdA?@dld?d<o<clb?c<_<Sl00b8_00Tb;b8_8RlB7b4_4AlQ;a4O
8Al00a4O00T@7a4O41l13a0O4@l@7`4?41l00_oo00<03oooool05_oo0003ool300l3ool00`0?oooo
o`03ool0200?ool@7`4?41l17a4O0Al54Al0318O4BlB7a4_4RlR;a8_8RlS;b8_8blb?`8c?`03=3lc
CcA?0094C`0@A5m5CeEOAEmEKeIOIVmFGfIoIVmfOfM_MWmWOgMoIgl3Mgl01VMoMWmWOgMoIfmfO`9V
K`0KEUmUKeIOEEm5GeAOADm4CcA?@dld?c=?8clc?b<_<SlS;b8o8blR;a8_8BlB;b4_4QlA;a8O00DA
7`060Al@7`4O41l13ooo0P0?6?oo0009ool00`0?ooooo`03ool02@0?oolA3a0O4@l@7a4?4AlA3`04
4Al08B4O4AlQ;a8O8BlR7b8_8Qlb;b8_<SlS;c8o<bm3?c<o@dm4?eA?A4mDCeE?E5mEGfEOIUmUKfI_
MVmWKgIoMfmfO`02Mgl02GM_MgmgKgMoIfmfOgM_MWmWK`02IVl02fE_EUmUGeEOE5mECeA?A4m3Cd@o
@cl00S<o00Hc;c8_8blb?b8_<Rl28Rl01Q8O8BlA7b4_4AlQ7`8A7`084@l@7a4?41lA3a0O4@l@7`;o
o`0300oooooo01Koo`002?oo0P0?1Ooo00H03ooo41l17a4O0Al34Al05P4O4AlB7a4O4QlA;a8O8RlB
;b8_8blR;b<_8SlS?c<o=3lcCcA?A4m5CdAO0UEO00=5GfE_EUl00VI_00IgOfMoMhmhOhR?N8l2R8l0
1XRORHn8WhV?R9n9S`>8S`06N8n8SgQoMhmWOgMo0VI_00mFGfE_AEmEGdE?A5ldCdA?=3lc?b<o<clS
?c8o8bl00b8_00lB;b4_4QlA;a8O4AlB7a4O0AlA7`4O4Al13a0O0Al00_oo00<03oooool05_oo000?
ool0200?ool13a0O4@l@7a4?41l34Al0224O4AlQ;a4O8BlB7b4_8Ql28Rl02c8o8blb?c<o@clc?d=?
A3mDGdA?E5l00UEO00YFGfE_IVmVKfM_MWmgOhMoN7n7S`>8S`05V8n8SiROR8nHS`03R8l01XN?R7mg
OgMoMWmgK`9VK`0?IFmEGeAOEDmDCdA?@dm4?d<o<clb?c<_<SlR;c8o00<R;`058BlB7b4_4AlQ;`04
4Al01Q4?41lA3a0O0@l@7`;oo`0300oooooo01Koo`003ooo00P03ooo4Al13a4O0AlA7`4O114O00DA
;a8O8BlB7b4_00<R;`0<8SlS;c8o8clc?c@o<dldCdA?ADmDGdEO0UEO019UKeIOIWmWKgMoIgmgSgQo
R8mhShROR8n8WhV?R9n9ShRORHl3R8l01WQoQhmhOgN?IfmfO`9VK`0:EUmUKeEOEEm5CdAO=4m4Cc<o
<dl2<cl00b<o8SlS;`048Rl0124_4QlA;a8O1A4O00D17a0O0AlA7`4?00;oo`0300oooooo01Koo`00
3ooo00H03ooo4@l@7a4?41l54Al01R4O4AlQ7a8O8BlR7`8R;`0:<RlS;c8o<bm3?c<o@dm4?eA?ADl2
EEl01fE_IUmUKfM_MWmgOhMo00:8S`0?RHnHWiVOVInJWjV_ZYnZ[jZOZJnZWjV_VYnY[iZO00:IW`0A
V9n9ShR?R7n7OgMoMWmWKfE_IUmEGeE?E4m4Cd=?A3m3?`02<cl033<_<SlR;c8_8QlR;b8O8BlB7b4O
4AlQ7`@A7`054@l@7a4?41ooo`0200lHool000ooo`0600oooa4O0AlA7`4O1A4O01/B7a4O4QlA;a8_
8RlB;b8_8blR?b<o<cld?c<o=4m4CdE?A5m5GeEOEVmVKeIOIWmWKgMoN7l00XR?01^IWhV?VJnJWjV_
VYnZ[iZ_ZZnJ[jZ_VZnY[iZOZJnJWiVORHnHWgR?R8mgOgN?IfmfOeIOIFl00UEO01=5CdAO=4m4Cc<o
<dld?c<o8blR?b<_8RlB;b8_4RlQ;a8O4BlB7`054Al00`4O41l17`02ool00`0?ooooo`0Fool000oo
o`0800ooo`4?41lA7a0O4Al@7`<A7`058AlA7b4_4QlQ;`038Rl01S8o8blc?c<o@dld?`94C`0=E5mE
GfE_EUmfOfM_MWmhOhN?R8nHWiVOZIl00ZZ_00Z[[kZo^knk_kboblnl_l_?_;o;_`>k_`0E^[n[[jZ_
ZZnYWiVOV8n8ShMoMgmfOfM_IFmVGeAOEDmDCdA?@dld?d=?008c?`0:8blb?b8_8RlR7b4_4QlQ;a4O
8Al34Al01A0O4Al@7`4?41l00_oo00<03oooool05_oo000?ool0100?oolA7`4O114O00dA;a8O4AlB
7a4_4RlQ;a8_8RlS;b8_8blb?`02<cl04C@o@dm5CdAOAEmEGeI_IVmWKgIoIgn7SgQoR9n9SiV_VYl0
0ZZ_00nk_j^_^lnl_l_?_;o;ckboblnl_k_?_;nk_j^_^[l00ZZ_00ZIWiV_RHn8WgQoMhmWKgIoEUmU
K`9EG`05A4m4Gc@o@dld?`02<cl02c8o8blR?b<_8RlB;b4_4RlQ;a8O4Bl01Q4O00@17oooool03aSo
o`003ooo00H03ooo4@l@7a4?41l34Al09B4O4AlQ;a8O8BlR7b8_8Qlb;b8_<clc;d<o<cm4Cd@oE5mE
CfE_EUmfKfM_QhmhOhN?RHnHWiZOZJnk[kZo_;o;_lc?g<oMcmcO00?Mg`06kMoMgmgOgLoLgmg?0/c?
017;_k^o^[n[[jVOVYnHWhV?QgmgOgIoIfmUGeIOE5m5Cd=?0094C`06<cm3?c<_<SlS;c8_0R8_00HR
7b4_4AlQ;a4O8Al24Al0114?41lA3a0O0_oo00<03oooool05_oo000?ool01P0?oolA7`4O4Al17`<A
7`054QlA;a8O8BlB7`038Rl01R<_8SlS?c<o=3lcC`94C`0GADmEGeIOIVmWKfIoN7n7SgQoV9n9SjZ_
VYnj_j^_blnl_lcOcLoMglg?gMoNg`05gMl05Lg?gMo=clc?_;nkcj^_^[nJWiV_RHnHWgQoMhmWKgIo
EUmEKdEOEEldC`02A4l01S=?=3lc?b<o8SlS;`<R;`054QlA;a8O4AlB7`034Al0104O4Al17ooo0P0?
6?oo000?ool0100?oolA3a0O1A4O00XQ7a4O8BlB7b4_8Qlb;b8_<SlS;`8c?`04@dld?eA?A4l2EEl0
4GI_IVmgOgMoV8n8SiROVYnY[k^_^[o<_l_?gMoLgmkOkNl00nk_00Gnknk_o_o^kok_00?^k`0<kNoN
gmcOgLo;clbo^[n[[jVOVInHShR?0WMo0VI_0UEO00UDCdA?E4ld?d=?<clb?b<_<Sl00R8_00HR7b4_
4QlQ;a4O8Al44Al01A4?41oooooo00l06?oo000?ool0100?oolA7`4O114O00DA;a8O4BlB7b4_00<R
;`038SlS?c8o008c?`0C=4m4CdE?A5mFGeE_IVmVOgQoMhn9ShRORHnY[iZO^kn[_lc?_<l00]gO00[]
kmkOk_o^kokokno^ono_k_o_k`?^k`0>g]o]klgOgMnlclc?Zknk_iZOVJn9ShROMgmgS`9VK`07EEmE
KdE?A5m5Cd=?=4l00S<o00<b?b<_8Rl00R8_00DB;b4_4QlA;a8O00DA7`040Aoooooo00lHool000oo
o`0500oooa4?4AlA3`034Al03A8O8AlA7b4_4QlQ;b8_<RlR;c8o<bm3?c<o0094C`06E5mECfE_IUmf
OgM_0XR?00NYWiVOZInk[kZoc;o;c`02gMl2k^l01?o_o_ookoko1_oo02Kokokoooonono_kNo^kmgO
gLo;clbo^[n[[jVOVIn7ShQoMWmgKfE_EUmDGeE?E5m4?d=?<cm3?c<_<SlR;c8_8QlQ;b8O8BlB7b4O
0Q4O00@A3a4O4@lA7`;oo`0300oooooo01Koo`003ooo02P03ooo4Al17a4O0AlA;a8O4BlB7a4_4RlR
;a8_8RlS;b8o8clc?c@o<dldCdA?AEmEGeIOIFmWOgMoN8n8SiZOVJnJWkZoZjo<ckc?gMoNg`;^k`04
o_o_koookol7ool01^ooooo_kokog^o^k`;Mg`04_<o<cj^_^[l2VIl07WR?R8mWKgIoEUmVKdE?E5m5
GdA?=4lcCc@o<clS;b8o8blR;a8_8BlB7a4_4QlA7a8O4Al17a4O0Aooo`803aSoo`003ooo00@03ooo
4@l@7`<A7`068AlA7b4_4QlQ;b8O0R8_00Hb;b8_<clc;d=?=3l2A4l2EEl2IVl018MoMgnHWhV?0jZ_
00Bl_l_?gMoLg`;^k`03ononoooo00?oo`06knonono_o_o_koko1Ooo00cnono_kNo^kmcOcLo;_k^o
ZZnZWiROR8l2Mgl01FE_IVmEGeEOE5l00TA?00Hd?d<o<clb?b8_<Rl28Rl01Q8O8BlA7b4_4AlQ7`8A
7`054@l@7oooool03`0Hool000ooo`0400oooa4O0Al44Al01A4_4QlQ;a8_8Bl00R8_00XS;b8o<clc
?c@o@dm5CdAOEEmEK`9VK`04N7mgShVOV9l3ZZl01<_?_;oMgmgO0^k_00?nonooool01?oo00G_ooko
koooonoo00Goo`08koooomk_k^o=gmgO_;nkc`:Z[`04RHnHWgQoMgl2IVl3EEl014AOA4m3Cc@o0S<o
00<b?b<_8Rl00R8_00<B7a4_4Ql01A4O00@17oooool03aSoo`003ooo00<03ooo4Al0114O00XQ7a8O
8AlB7b4_8Qlb;b8_<SlS;`8c?`0E@dm4?eA?ADmUGeIOMVmWKhN?R7nYWiVO^[n[[kZoc<oLcmkOkNoo
koko00;oo`04onooonk_k^l2gMl02Mg?g=oMgngOk^onknk_ooook`02ool01?kokno]gmkO0/c?01>j
_j^_VInIWhN?N7mfKfM_IEmEGfEOADmDCd@o@dlc;c<o8blb?`028Rl01b8O8BlB7b4O4AlQ7a4?00<A
7`;oo`0300oooooo01Koo`003ooo00<03ooo4Al00a4O00HA;a8O8BlB7a4_4Rl38Rl06B<_<Slc?c<o
=4m4CdE?A5mFGeE_IfmVOgR?R8nIWiV_Zknk_j^_c=o=cnk_g]onono_00?oo`09koo^knk_gNoNgmgO
cMoMkmkO00?^k`0<koooooooooo_kokog]oMklg?c<n[[kZo0YVO00mhOhN?IfmVOeIOEFmFGdAOADm3
Cc@o<clS?b8o8bl00b8_00LB;b4_4QlA;a8O4Al17`024Al2ool00`0?ooooo`0Fool000ooo`0400oo
oa4?41l34Al01R4O4AlQ;a8O8BlR7`8R;`0<<SlS;c<o<cm3Cd@oE5m5CfE_EUmfOfM_0XR?00>Y[iZO
bkl00[^o00K=cmcOk^o^koo_o_l2ool2k^l2c<l02jZ_^ZnIWjV_Zjnj_lc?g=o=cok_k^l00_oo00Kn
ooook^o^kmcOcLl2^kl03JVOVIn8ShQoMWmWKfE_EUmUKdE?E5ld?d=?008c?`0:8blb?b8_8RlR7b4_
4AlQ;a4O8Al24Al00a4?41ooo`0200lHool000ooo`0400oooa4O0Al24Al02a4_4AlQ;a8O8BlB;b8_
8blR;b<_<Sl00S<o01DdCdA?AEmDGeIOIFmWOgMoR8n8WiZOZJnk_k_?_;oMglgOk_o^koookol00_oo
0^k_00g<glg?Z[n[[iV_VYnj_j^_g=o=cmcOk^o^o`02ool01^ooooo^knk_cLoLg`:k_`0=VYnI[hR?
R8mWKgIoEUmUKeIOE5m5CdA?=4l00S<o00<b?b<_8Sl00R8_00@B;b4_4QlA;`@A7`040Aoooooo00lH
ool000Woo`0300oooooo00?oo`0300oooa4O00@A7`0K8AlB7b4_4QlR;b8O<RlR;c8o8bm3?c<oA4m4
?eAOEDmUKeIOMWmgOiR?R8nY[jZOblnl_l^o00;Mg`06knonkoooooookoko0]gO00JZ[kZ_MfmfOeE?
E5l2Mgl01j^_^[nk[ngOg]onooo_00;oo`0Oo^o^kmgOgLo;_k^oZJnJWiR?R8mfOgM_IFmVGfE_ADmD
Gd@o@dlc?d<o<blb?b8_<RlR7b4_4QlQ7a4O8Al0114O0_oo00<03oooool05_oo0008ool00`0?ool0
3`04ool00`0?oolA7`034Al01Q4_4QlQ;a8O8BlB;`8R;`0H8SlS?c<o<clcCcA?A4m5CeEOEVmVKfMo
Mgn9ShROVZnZ[kboblnl_mgOg]o^ono_0ooo017_kmg_g]nZ_j^_MWmWOeEOADmgOgQo^kn[[kZog]oM
knoo00?oo`0Ckno^omgOgMnl_k_?VZnZ[hR?R9mWOgMoEUmUKeIOEEm5CdA?=4l00S<o00<b?b<_8Rl0
0R8_00DB;b4_4QlA;a8O00@A7`;oo`0300oooooo01Koo`002?oo00<03ooo00l01?oo00@03ooo4Al@
7`<A7`058AlB7b4_4QlQ;`038Rl02S8o<blc?c<o@dm4CeAOADmUKfIO0WMo00^HShR?ZZnZWl_?_;o;
cmgOkMo^koko00;oo`08knonomg?g=nIWjV_ADmDG`803`05EEmUGjZ_ZJnZW`02gMl01_koknoooooo
o^o^k`;Mg`04blnk_jV_ZYl2R8l02GIoMfmUKeIOIFmECeAOA3m3C`02<cl02R<_<SlR;b8_8QlQ;a4O
8BlA7b4O0Q4O00DA3a0Oooooo`0?01Soo`002?oo00<03ooo00l01?oo00<03ooo4Al00a4O01<A;a8O
8BlB7b4_4RlR;b<_8RlS;c8o=3lcCcA?A4m5GeEOEVmUK`02Mgl01hV?R9nZ[jZ__;o;ckbo00;Mg`0<
k_o_koooooononoogMo=giV_VYmEGdEO0P0?00=UKeIOZZl00ZZ_00?Mgmg_kol00ooo01k_knkogMoM
gkboblnJ[jV_RHn8WfMoMgmFKfI_EUmDGdEOA4ldCc=?<clb?b<_8SlS;b8_4RlQ;a8O4Bl44Al0104O
ool03`0?6?oo0009ool00`0?ooooo`03ool00`0?oolA7`044Al04R4O4QlQ;a8O8RlR7c8_8Rlb?b<_
@clc?dA?A3mDGeE?IFmVG`9gO`07V8n9SjV_ZZo;ckbobll00]gO00c_kok_ooooono_o_oMcmcOVYnY
WeE?E5l200l01EEOIEnZWjV_ZYl00]gO00Knooo_ooooook_k^l2gMl06l^o^knY[jZOV8n8SgIoMfmU
KfIOIFm5CeAOA3m3Cc<o@clc;c8o8Rlb;b8O8BlB7b4O4AlQ7`044Al2ool00`0?ooooo`0Fool000oo
o`0300oooa4O00<A7`064BlB7b4_4QlQ;a8_0R8_01@R?b<o<clc?c=?=4m4CdE?EEmFKfI_IgmgOhV?
R9nJ[jZ__;o;ckbo0]gO00?^ono_ool00_oo017_kmg_g]nj_j^_MgmhOeE_EUmgSgQo^kn[_k^og]o]
knoo00?oo`08k^o^omgOgMnl_k_?VYnZ[`:8S`09IgmgOeIOIFmFGeEOADm4CcA?008c?`03<SlS;b8_
008R;`054RlQ;a8O4BlB7`044Al2ool00`0?ooooo`0Fool000ooo`0400oooa4?41l34Al01B4O4QlQ
;a8O8Bl00b8_01<b?c<_<clc?d=?A4mDGdE?IFmVGgIoMfnHShR?ZJnZWl^o^ko;c`02gMl02^k_o^oo
ooooononomgOkMnZ[kZo0WMo00eEGfE_N7n7Sk^o^[nk[ngOgMonooo_o_ooo`02k^l01]cOgMo;_k^o
ZJnJW`:8S`09MWmgKfE_EUmUKdE?E5m4?d=?008c?`0:8blb?b8_8RlR7b4_4AlQ;a4O8Al24Al01A4?
41oooooo00l06?oo000?ool0100?oolA7`4O0Q4O00HA;a4O8BlB7b4_4Rl38Rl032<_<Slc?c<o=4m4
CdEOE5mFGfE_IgmgO`:8S`07VYnY[k^o^lnl_mgOcMl00^k_00Coonooooooo`;^k`04g=o=ck^oZjl2
ZZl01k^oZkoLglgOgMo^knko00;oo`06koooonk_k^o=cmcO0[^o00fJWiV_R8n8SfM_MWmFGfE_EUmD
GdE?A4ldC`02<cl00c8o8blR?`028Rl0118_8BlB7a4_114O00@17oooool03aSoo`003ooo00<03ooo
4Al0114O01@Q7a8O8AlB7b4_8Qlb;b8_<SlS;d<o<cm3Cd@oE5mECfE_EUmfOgM_0XR?00NY[iZO^knk
_l^ogLoLg`02k^l2ool04Oo_ooo^knk_cLoLck^_^[nZWjV_^jnk_lg?g=oMcok_k^l00ooo00Gokng_
k^oLglg?00:k_`0=ZJnJWhN?R8mfOfM_IEmFGfE_ADmDGd@o@dl00S<o00XS;c8o8Rlb;b8O8BlB7b4O
4AlQ7`@A7`03ool03`0?01Soo`003ooo00<03ooo4Al00a4O00HA;a8O8BlB7a4_4Rl38Rl03R<_<SlS
?c<o=4m4CdE?A5mFGeE_IfmVOgR?R8l2VIl02J^_^kn[[lcOcLo]kmkOo_o_k`03ool01Nook^o^kmg_
g]l00]gO00GMkmkOk^o_knko00Coo`04knonomkOgNl2c<l04j^_Z[nIWiVON7n7SfM_IWmFGeE_EUm4
GdE?@dld?c<o8clR?b<_00<R;`074RlQ;a8O4BlB7a4O0Al00Q4O0_oo00<03oooool05_oo000?ool0
100?oolA3a0O0a4O00HQ7a4O8BlB7b4_8Ql28Rl03S8o8blc?c<o@dm4?eAOADmUGeEOMWmWKhN?R7l2
VIl02KZoZjnj_lc?g<oNgng_knono`02ool01_o_o_o^knk_gMo]g`;Mg`03g]o]gnk_00;^k`08o_oo
ooooooononk_kNoMg`;<c`08^[n[[iROVIn7SgQoMVmVK`9EG`05IEm4CeAO=3m3C`02<cl02R<_<SlR
;b8_4QlQ;a4O8BlA7b4O0Q4O00DA3a0Oooooo`0?01Soo`003ooo00@03ooo4Al17`@A7`054BlB7b4_
4RlQ;`028Rl022<_8Slc?c<o=3m3CdE?A4l2EEl2IVl017MoMhn9SiRO0jZ_00S;ckbogMo=gnk_g^on
onoo1Ooo00G_ookokoooonoo00Goo`0<koonomk_k^o=gmcO_;nkciZ_ZZn9ShRO0WMo00UFKfI_EEmE
GdEOA5m4Cd=?=3l00S<o00<b?b<_8Rl00R8_00<B7a4_4Ql01A4O00@17oooool03aSoo`003ooo00D0
3ooo4AlA7a4?00<A7`054QlQ7a4O8BlR7`028Rl0238o8blb?c<_@dld?eA?A4l2EEl2IVl02hMoMgnH
WhV?ZZnZWjZ_^ko;cmg?g=l00^k_00?_kokoool00ooo00Gokokoononooo_00Koo`0Ao_ookng_k]oL
gmg?bknk_jV_ZYnHWhV?QgmgOfI_IUmDG`02EEl03TA?E4lc?d=?<blb?b8_<RlR7b8_8QlQ;a8O8Al2
4Al01A4?4AlA3a4Oool00P0?6?oo000?ool0800?oolA7`4O4Al17a4_4QlA;a8O4BlB7b8_4RlR;b<_
8SlS?c<o=3lcCcA?A4m5GeEOEUmUKfMoMgmhShR?VYl2VIl01:ZoZjo<ckc?0]gO00K^kmk_o_o_kooo
kol7ool03>ooooo_kokog^o^klgOgMnl_l_?ZjnZ_`:IW`0MN8n8SfM_MWmFGfE_ADmDGdEOA4ldCc=?
=3lc?b<_8SlS;b8_4RlQ;a8O4BlB7a4O4QlA7`4O4Al17`02ool00`0?ooooo`0Fool000ooo`0400oo
oa4?41l34Al06B4O4AlQ;a4O8BlB7b8_8Qlb;b8_<Slc;d<o<cm4Cd@oE5mECfE_EUmfOgM_Qhn8OjVO
00:IW`06Zjnj_lbobloMgmcO0^k_00C_kokoooono`Goo`0>o_ooookoonononk_kNo^gmcOgMo;ckbo
^ZnZ[`:IW`0AQhn8OgIoIfmUKeIOE5m5CeAOA4m3Cc<o@clc;c8o8Rlb;`028Rl0118O8BlA7b4_114O
00DA3a0Oooooo`0?01Soo`003ooo00@03ooo4Al17`@A7`054BlB7a4_4QlQ;`038Rl00b8o8clb?`02
<cl05cA?A4m5CdAOEUmEGfI_IWmhOgMoRHn8WhV?ZJnJWkZoZko<ckc?g=o=gng_g]l00^k_00C^onk_
k_o_k`G^k`0<g]oMklgOg=nl_l_?Zjnj_iZOVJn9ShR?0WMo0VI_0UEO00E5CdAOADm3CcA?008c?`03
<SlS;b8_008R;`054RlQ;a8O4BlB7`054Al0104Oooooo`0?6?oo000?ool01@0?oolA3a4O4@l0114O
00HQ7a4O8BlB7b4_8Ql28Rl02S8o<blc?c<o@dm4?eA?ADmUGeEO0VI_0127OgMoV8n8SiR?VYnY[j^_
^[o<_l_?gLoLgmkOkNo^g`;^k`03o^o^kok_00;^k`0?k]o]knk_kMoNgmcOgLo;ckbo^[n[[jV_VYnH
ShR?009gO`9VK`9EG`05E4m4CeA?=3m3C`02<cl02R<_<SlR;b8_8QlQ;a8O8BlA7b4O0Q4O00@A3a4O
4@l@7`;oo`0300oooooo01Koo`003ooo00H03ooo4Al17a4O0Al34Al01A8O4BlB7b4_4Ql00b8_00HS
;b8o8clc?c@o<dl2A4l05DE?EEmFGfE_IfmVOgQoQhmhOhRORHnY[iZOZ[n[[k_?_;o<clg?gMo=c`06
gMl00mcOcLoLg`02c<l06Kbo^ln[[jZoVYnI[hV?R9mhOgN?IfmVOeIOEFm5CeEO=4m4CcA?<dld?c<o
8clR?b<_00<R;`034QlA;a8O00DA7`040AlA7`4Oool200lHool000ooo`0400oooa4?41l74Al07b4O
4AlQ;a8O8BlR;c8o8Rlb?c<o@dlc?d=?A4mDGdE?IFmEGgIoIfn7OgMoQhn9SiROVInY[j^_^Znk_l^o
00;<c`04cLoLgmg?g=l2gMl01Mg?g=o=cmcOcLl00/c?01o;_k^o^ZnZ[jV_VYnHShR?QgmgOgI_IVmU
KeIOE5m5Cd=?A3m3Cc<o@clc;c8o8Rlb?b8O8BlR7b4_4QlQ7`034Al01A0O4AlA7a4?41l00_oo00<0
3oooool05_oo000?ool0100?oolA7`4O114O00dA;a4O4AlB7a4_4RlQ;a8_8RlS;b8_8blb?`02<cl0
3c@o@dm5CdA?AEmEGeI_IVmWKgIoIfn7SgQoR9n9S`02VIl2ZZl02[ZoZjnk_k^o^lnl_k_?_;nkckbo
0k^o00B[[jZoVZnZ[`:IW`0?RHn8SgQoMhmWKgIoEUmUKdEOEEm4CdAO=3m3Cc@o008c?`03<SlS;b8o
008R;`064RlQ;a8O4BlB7a4_1Q4O00@17oooool03aSoo`003ooo00H03ooo4@l@7a4?41l34Al0324O
4AlQ7a8O8BlR7b8_8Qlb;b8_<SlS;`8c?`0?@dld?eA?A4mEGeE?IFmVGgIoIfmfOgMoQhn8SiR?00:I
W`04ZYnY[j^_^[l3^kl01/^o_;o;_k^obknk[`:k_`04^[n[[jV_ZYl2VIl02YR?R8n7OgMoMVmVKfE_
EUmDGeE?0TA?0153Cc@o@dlc;c<o8blb?b8_<RlR7b8_4QlQ;a4O8AlA7b4O008A7`044@l@7a4?41l2
ool00`0?ooooo`0Fool000ooo`0600oooa4O0AlA7`4O1A4O01TB7a4O4QlA;a8_8RlB;b8_8blR?b<_
<cld?c<o=3m4CdE?A5m5GeEOEVmVKeIOIWmWK`02Mgl018R?N8nHWhV?0YVO00^Y[iZOZJnJ[jZ_VYnY
[iZOZJnJWiV_00:IW`04RHn8WgR?R8l2Mgl02VM_IWmFGfE_AEmEGdE?A5ldCdA?0S<o00dd?c<o8blR
?b<_8RlB;b4_4RlQ;a8O4BlB7`054Al00`4O41l17`02ool00`0?ooooo`0Fool000ooo`0800ooo`4?
41lA3a0O4Al@7`<A7`068AlA7b4_4QlQ;b8O0R8_014b;b8_<SlS;d<o<cm3Cc@oE4m4CeEOEDmUKfIO
IFmWKgI_009gO`04R7n7ShR?V9l3VIl04:V_VYnY[jZOZJnJWjV_VInY[iZOV9nIWiRORHn7ShQo0WMo
00IfKfI_IFmFGeAOEEl2A4l00d=?A3lc?`02<cl013<_<SlR;c8_0R8_00HB7b4_4AlQ;a4O8Al24Al0
1a4?41lA3a0O0@l@7ooo00803aSoo`003ooo00P03ooo4Al13a4O0AlA7`4O114O00DA;a8O8BlB7b4_
00<R;`0<8SlS;c8o8clc?c@o<dldCdA?ADm4GdEO0UEO00YUKeIOIVmVKgIoIfmgSgQoQhmhO`B8S`03
R9n9ShR?00B8S`06N7n7SgMoMgmWKgIo0VI_00mFGeE_AEmEGdA?A5ldCdA?<clcCb<o<clS?b8o8bl0
0b8_00DB;b4_4QlA;a8O00DA7`050Al@7`4O4Al13`02ool00`0?ooooo`0Fool000Soo`<03`Coo`06
00oooa4?41lA3a0O0Q4O00<A3a4O4Al00Q4O00HQ7a4O8BlB7b4_8Ql28Rl03c8_8Rlc?c<_@clc?d=?
A3mDCdA?EEmECeAOEUmUK`02IVl027M_MWmgOhMoN7n7ShQoQhl3R8l039R?R8n8ShQoQhn8ShN?N7n7
OgMoMWmWK`9VK`0?IFmFGeAOEDmDCdA?@dm4?d<o<clb?c<_<SlS;c8_008R;`068QlQ;a8O8BlA7b4O
0Q4O00PA3a4O4@lA7a4?41lA3a0O0_oo00<03oooool05_oo0009ool00`0?ooooo`03ool02P0?ool@
7`4?4Al13a4O0AlA7`4O0a4O00HB7a4_4QlQ;a8O8Bl38Rl02R8o8blb?b<o<cld?c<o=3m4CdE?0TA?
01]DGdEOEEmEGfE_EUmVKeI_IWmWKgMoIfmgOfMoMgmWOgMoIgmgOfM_MWmWKfIoEVmVKeIOIFl00UEO
00e5CeEOA4m4CcA?A4ld?c=?8clc?b<_8SlS;`038Rl01A8_8RlB7a4_4Ql01A4O00L17a4O0AlA7`4?
41l13`02ool00`0?ooooo`0Fool000Woo`0300oooooo00?oo`0800ooo`4?41lA3a0O4@l@7`LA7`05
8AlA7b4_4QlQ;`038Rl02C8o8Rlb?c<_@clc?d=?=3mDC`02A4l01TE?E5mEGeEOEUmUK`=VK`0=MVmW
KgIoIfmfOgM_MWmWKgIoIfmfOfM_MVl00VI_00=VGfE_EUl00UEO00IDGdE?A4m4Cd=?A3l2<cl01C8o
<clb?b<_<Sl00R8_00HR7b4_4QlQ;a8O8Al64Al01a4?41lA3a0O0@l@7ooo00803aSoo`002Ooo00<0
3oooool00ooo00P03ooo41l13a0O0AlA7`4O1A4O00`B7a4_4QlA;a8_8RlB;b8_8blR;b<_<Sl3<cl0
33=?=4m4CdA?A5m5CeEOADmEKeEOIFmFG`9VK`0?MWmWKgIoIgmgOfMoMgmWOgMoIgmfOfMoMWmWKfIo
009VK`06EUmUKeEOEEm5CeAO0TA?00Xd?d=?=3lcCb<o<clS;c8o8blR?`8R;`074RlQ;a8_8BlB7a4_
4Ql01A4O00D17a0O0Al@7`4?00;oo`0300oooooo01Koo`002?oo0P0?1Ooo01H03ooo0@l@7`4?41lA
3a0O4@l@7a4?4AlA3b4O4AlQ7a4O8AlB7b4_4QlQ;`<R;`09<RlS;c<o<bm3?c<o@dld?d=?00=4C`04
E4mECeAOEDl2EEl04fEOEUmUGfIOIFmFGfE_IUmUKeIOIEmFGfEOEEmDGeEOE5m5CeA?0094C`03A3m3
Cc@o008c?`05<Slc;c8o8blb;`028Rl02R8O8BlR7b4_4QlQ7a4O8AlA7b4O0Q4O00PA3a0O4@l@7`4?
41l13a0O0_oo00<03oooool05_oo000?ool02P0?ool@7`4?4Al13a4O0AlA7`4O1A4O00dB7a4_4QlA
;a8_8RlB;b8_8blR;b<_8SlS?`02<cl013=?=3m3Cc@o0TA?0314GdE?E5m5GeEOAEmEKeIOIFmFGfE_
EUmVKeIOIFmFGfE_EUmEKeIOEEm5GeEOAEmEGdE?A5ldCdA?=3m3Cc@o<clS?c<o8blb?b8_8SlS;b8_
4RlQ;a8_8BlB7a4_4Ql54Al01`4O4Al17a4O0@l@7`4?00;oo`0300oooooo01Koo`003ooo00`03ooo
0@l@7`4?41l13a0O4@l@7a4?41l54Al01b4O4AlQ;a4O8BlB7b4_00<R;`05<RlR;c8o8blb?`03<cl0
1D<o=3m3Cd@o@dl00dA?00eDCdE?E5m5CeAOEDmDGdE?E5m5CeAOADmDC`03A4l01D=?A4m3Cc@o@cl0
0c<o00@b?c<_<SlS;`<R;`088QlQ;b8O8BlB7b4_4AlQ7`@A7`0:4@l@7a4?41l13a0O0@l@7`4?41l2
ool00`0?ooooo`0Fool000ooo`0<00oooa0O0@l@7`4O4Al13a4O0AlA7`4O114O00hA;a8O4BlB7b4_
4RlR;a8_8RlS;b8_8blR?b<o13<o01LcCc@o@dldCdA?=4m4GdA?E5m5CeAOADmDGdE?E5m5GeAOADmD
GdE?E5m5CdAO0094C`06=4m4CcA?@dld?c=?0S<o00HS?c8o8blb?b8_8Sl28Rl01a8_8BlB;b4_4QlA
;a8O00DA7`0:0AlA7`4O4Al13a0O0Al@7`4?ool200lHool000ooo`0>00ooo`4?41l13a0O4@l@7a4?
41lA3a4O4@l@7`8A7`0:4@lQ7a4O8AlA7b4O4QlQ;a8O8Bl38Rl0238_8Rlb?b<_<Slc;c8o<bl2<cl0
5D<o=3m3?d@o@dm4?d=?A3m3Cd@o@dm4?d=?A3m3Cd@o@dld?d<o<cm3?`03<cl01C8o<blb?b<_<Rl0
128_00XR7b4_8QlQ;a8O8AlA7b4O4AlQ7`8A7`0<4@l@7a4?41lA3a0O4@l@7`4?41l13a0O0_oo00<0
3oooool05_oo000?ool03P0?ool07`4?41l13a0O0@lA7`4?4Al17a4O0Al44Al0214_4QlA;a8O4BlB
;b8_4Rl38Rl0:2<_8SlS;c8o8blc?b<o<clS?c=?=3m3Cc@o@dld?dA?=3m4CcA?A4ldCdA?=4m4Cc@o
A4ld?dA?=3lcCc@o<clS?c<o8clc?b<_<SlS;b8o0R8_00TB;b8_4QlQ;a8_8BlB7a4_4Ql01A4O00/1
7a4O0AlA7`4?41l13a0O0@l07`4?00;oo`0300oooooo01Koo`003ooo01003ooo0@l@3`0?41l13a0O
4@l@7`4?41lA3a0O4@l@7`<A7`098AlA7b4O4AlQ;a4O8BlB7b4_00<R;`0=<RlR;b8_8Rlb;b<_<SlS
;c8o<clb?c<o<Sl02c<o00Tb?c<o<Slc;c8o<blb?b<_<Rl00b8_00/Q;b8_8BlR7b4_4QlQ;a8O8AlA
7b4O00@A7`0>4@l@7a4O41l13a0O4@l@7`4?41l03a0O0@l@3`;oo`0300oooooo01Koo`003ooo00d0
3ooo41l13a0O0@l@7`4?41l17a4O0Al@7`074Al0214_4QlA;a8O8BlB;b8_4Rl48Rl0228o8blb?b<_
<SlS;c<o8cl8<cl00c=?<clc?`04<cl02R<o<clc?c<o8clb?b<_<SlS;b8o0R8_00/B;b8_4RlR;a8O
8BlB7b4_4QlA;a8O00DA7`0=0AlA7a4O4Al17a0O0Al@7`4?41l13a0O0@l00_oo00<03oooool05_oo
000?ool04@0?ool03a0O0@l@3`4?41l13a0O4@l@7`4?41lA3a4O4@l00a4O00hA3b4O4AlQ7a4O8AlA
7b4_4QlQ;b8O8RlR7b4_0b8_01Tb;b8_<RlS;c8_8blb?b<_<Slc;c8o8blb?c<_<SlS;c8o8blb?b<_
<RlR;c8_8Rlb;`028Rl03R8O8BlR7b4_4QlQ;a8O8BlB7b4O4AlQ7a4O8Al24Al04A4?41lA3a4O4@l@
7a4?41l13a0O0@l@7`4?40l03a0Oool00P0?6?oo000?ool04P0?ool07`4?41l13a0O0@lA7`4?41l1
7a4O0@lA7`4O4Al17`DA7`0;4QlA;a8O4BlB7b4_4QlR;a8_8RlB;`048Rl05R8o8blR?b<_8SlS;c8o
8blb?b<_<clS;c8o8blb?b<_<SlS;c8o8blR?b<_1B8_00/B;b8_4RlR;a8O8BlB7b4_4QlA;a8O00DA
7`0?0AlA7`4O4Al13a0O0AlA7`4?01l13a0O0@l07`4?00;oo`0300oooooo01Koo`003ooo01@03ooo
00l@3`0?41l13a0O0@l@7`4?41l13a0O0@l@7a4?41lA3a0O1a4O00dQ7a4O8BlB7b4_4QlQ;a8O8BlR
7b4_8QlQ;`0C8Rl03B4_8RlQ;b8O8BlR7b4_4QlQ7a4O8AlA7b4O00HA7`0B4@l@7a4O41l13a0O4@l@
7`4?41l13a0O0@l@7`0?41l03a0?0_oo00<03oooool05_oo000?ool04@0?ool@7`4?01l13a0O0@l@
7`4?41l13a0O0AlA7`4O41l00Q4O00<17a4O4Al00Q4O010A;a8O4BlB7a4_4QlQ;a8O8BlB;b8_4RlR
;a8_8RlB;`@R;`068SlR;b8_8RlR?b<_0R8_00<R?b8_8Rl0128_00hB;b8_4RlR;a8O8BlB7b4_4QlA
;a8O4BlA7a4_1Q4O01417a4O4AlA7`4O41l17a0O0@l@7`4?41l13`0O0@l@7`4?00;oo`0300oooooo
01Koo`003ooo01H03ooo00l@3`4?40l03a0O0@l@3`4?41l13a0O4@l@7`4?41lA3a0O4@l@7`8A7`03
4@lA7a4O008A7`0Y8AlA7b4O4QlQ7a4O8BlB7b4_8QlQ;a8O8BlR7b4_8QlQ;b8O8BlR7b4_8QlQ;b8O
8BlR7b4_8QlQ;b8O8BlB7b4O4QlQ;a8O8AlA7b4O4AlQ7`064Al0514?41lA3a0O4@l@7a4?41l13a0O
0@l@7`4?40l03a0O0@l@3`0?40l2ool00`0?ooooo`0Fool000ooo`0F00ooo`0O0@l07`4?01l13a0O
0@l07`4?41l13a0O0AlA7`4?4Al17a4O0Al54Al0:A8O4AlB7a4_4QlA;a8O4BlB7b4_4QlQ;a8O8RlB
7b8_4RlR;a8_8RlB;b8_4RlR;a8_8RlB;b8_4RlR;a8O8BlB7b8_4QlA;a8O8BlB7a4_4Ql01A4O01P1
7a4O4AlA7`4O4Al17a4O0@l@7`4O4Al13a0O0@l@7`4?01l13`0O0@l07`4?ool200lHool000ooo`0H
00ooo`0?40l03a0O00l@3`0?41l13a0O00l@7`4?41l13a0O0@l@7a4?41lA3a0O0Q4O00<A3a0O4Al0
1Q4O01dQ7a4O8AlA7b4O4AlQ;a8O8AlA7b4_4QlQ;a4O8BlB7b4_4AlQ;a8O8AlA7b4_4QlQ7a4O8AlA
7b4O00LA7`0I41lA7a0O4@l@7a4?41l13a0O4@l@7`4?41l13a0O0@l@7`0?41l03a0?00l@3`0?40l0
0_oo00<03oooool05_oo000?ool0600?ool07`4?01l13a0O0@l07`4?41l13a0O0@l@7`4?41l17a4O
0Al@7`4O4Al17`PA7`0Q4BlA7a4_4AlA;a8O8BlB7a4_4QlQ;a8O8BlB7b4_4QlQ;a8O8BlB7b4_4QlQ
;a8O4BlB7b4_4QlA;a8O4BlA7a4_00HA7`0I0AlA7a4O4Al17a4O0AlA7`4O41l17a0O0@l@7`4?41l1
3`0O0@l@7`4?01l13`0O0@l00_oo00<03oooool05_oo000?ool07P0?ool03a0?00l@3`0?40l13a0?
00l@7`4?40l13a0O0@l@7`4?41l13a0O4@l@7a4?41lA3a4O4@l@7`8A7`034@lA7a4O00HA7`0A8AlA
7b4O4AlQ7a4O8AlA7b4O4AlQ7a4O8AlA7b4O4AlQ7`064Al0814?4AlA7a4O4@l@7a4?41lA3a0O4@l@
7`4?41lA3a0O0@l@7`4?41l13a0?00l@7`4?40l03a0?00l@3`0?40l2ool00`0?ooooo`0Fool000oo
o`0N00ooo`0O0@l07`4?01l13`0O0@l07`4?41l13`0O0@l@7`4?41l13a4O0@l@7`4O4Al17a4O0AlA
7`4O0a4O00<17a4O4Al00a4O014B7a4O4AlA;a8O4AlB7a4_4QlA7a8O4BlB7a4O4QlA;a8O008A7`03
4BlB7a4O00@A7`0P0AlA7a4O4Al17a4O0AlA7`4?4Al17a4O0@l@7`4?41l13`0O0@l@7`4?01l13`0O
0@l07`4?01l13`0O0@ooo`803aSoo`003ooo00@03ooo00l@3`<03`0M40l03a0O00l@3`0?41l13a0O
00l@7`4?41l13a0O0@l@7a4?41l13a0O4@l@7a4?41lA7a0O4@l@7`034Al01A0O4AlA7a4O41l02a4O
00D@7a4O4AlA7a0O00<A7`0M41lA7a0O4@l@7a4?41l13a0O4@l@7`4?41l13a0O0@l@7`0?41l13a0?
00l@7`0?40l03a0?00l@3`0300l0110?ooooo`0?6?oo0008ool300l4ool0800?ool07`0?01l13`0O
0@l07`4?41l13`0O0@l@7`4?41l13a0O0@l@7`4O41l13a0O0AlA7`4O41l17a4O0Al34Al00`4O4AlA
7`0I4Al08@4O4AlA7a4O0AlA7`4O4Al17a0O0AlA7`4?41l17a0O0@l@7`4?41l13`0O0@l@7`4?01l1
3`0O0@l07`4?01l03`02ool00`0?ooooo`0Fool000Soo`0300oooooo00Coo`0R00ooo`0?40l03a0?
00l@3`4?40l03a0?0@l@3`0?41l13a0?0@l@7`4?41lA3a0O0@l@7a4?41lA3a0O4@lA7a4?41l24Al0
1A4?4AlA7a4O4@l03a4O00DA3a4O4AlA7a4?00<A7`0P4@l@7a4?41lA3a0O4@l@7a4?41lA3a0O0@l@
7`4?41l13a0?00l@7`4?40l03a0?00l@3`0?40l03a0?00l@3`;oo`0300oooooo01Koo`002Ooo00<0
3oooool00ooo02X03ooo01l13`0?0@l07`4?01l13`0O0@l07`4?01l13a0O0@l07`4?41l13a0O0@l@
7`4?41l17a4O0@l@7`4O4Al13a4O0AlA7`4O4Al17a4O0Al34Al01@4O4AlA7a4O0Al00a4O02/17a4O
4AlA7`4O4Al17a4O0AlA7`4O4Al13a4O0AlA7`4?41l13a4O0@l@7`4?41l13`0O0@l@7`4?01l13`0O
0@l07`4?01l13`0O0@l03`4?01l13`02ool00`0?ooooo`0Fool000Soo`0300ooo`0?00Coo`0400oo
o`0?40l300l09A0?00l@3`0?40l03a0O00l@3`0?41l13a0O00l@7`4?41l13a0O0@l@7a4?41l13a0O
4@l@7a4?41lA3a0O4@l@7a4O41lA3a0O008A7`064@l@7a4O4AlA3a0O0Q4O02HA3a0O4Al@7a4?41lA
7a0O4@l@7a4?41l13a0O4@l@7`4?41l13a0O0@l@7`4?41l13a0O00l@7`4?40l03a0O00l@3`0?40l0
3a0?0`0?00@@3ooo00l03aSoo`002Ooo0P0?1?oo00<03ooo00l05_oo00<03oooool05Ooo00<03ooo
ool05?oo00<03oooool05Ooo00<03ooo00l06?oo000?oomS00lHool008[oo`00R_oo002:ool008[o
o`00R_oo0006ool200l4ool01@0?ool03ooo00l00ooo00<03ooo00l0Looo0006ool00`0?ooooo`03
ool01@0?ool03ooo00l00ooo0P0?M?oo0007ool00`0?ooooo`02ool01@0?ool03ooo00l01?oo00<0
3oooool0L_oo0006ool200l4ool0100?ool03`0?1?oo0P0?M?oo002:ool000coo`0300oooooo07_o
o`00R_oo002:ool008[oo`00R_oo002:ool008[oo`00R_oo002:ool008[oo`00\
\>"],
  ImageRangeCache->{{{0, 136.8125}, {136.8125, 0}} -> {-2.727326, -2.85482, 
  0.053123, 0.053123}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Intensity in the $x-y$ Plane"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig16x7 = 
      DensityPlot[
        Evaluate[Idc[x\ a, y\ a, a]], {x, \(-2\), 2.01}, {y, \(-2\), 2.01}, 
        AxesLabel \[Rule] {"\<x in a\>", "\<y in a\>"}, Evaluate[opt1]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.498801 0.239785 0.498801 0.239785 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25902 -0.0125 -7 -12 ]
[.25902 -0.0125 7 0 ]
[.4988 -0.0125 -4 -12 ]
[.4988 -0.0125 4 0 ]
[.73859 -0.0125 -4 -12 ]
[.73859 -0.0125 4 0 ]
[.97837 -0.0125 -4 -12 ]
[.97837 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25902 -14 -6 ]
[-0.0125 .25902 0 6 ]
[-0.0125 .4988 -8 -6 ]
[-0.0125 .4988 0 6 ]
[-0.0125 .73859 -8 -6 ]
[-0.0125 .73859 0 6 ]
[-0.0125 .97837 -8 -6 ]
[-0.0125 .97837 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25902 0 m
.25902 .00625 L
s
gsave
.25902 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.4988 0 m
.4988 .00625 L
s
gsave
.4988 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.73859 0 m
.73859 .00625 L
s
gsave
.73859 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97837 0 m
.97837 .00625 L
s
gsave
.97837 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06719 0 m
.06719 .00375 L
s
.11514 0 m
.11514 .00375 L
s
.1631 0 m
.1631 .00375 L
s
.21106 0 m
.21106 .00375 L
s
.30697 0 m
.30697 .00375 L
s
.35493 0 m
.35493 .00375 L
s
.40289 0 m
.40289 .00375 L
s
.45084 0 m
.45084 .00375 L
s
.54676 0 m
.54676 .00375 L
s
.59472 0 m
.59472 .00375 L
s
.64267 0 m
.64267 .00375 L
s
.69063 0 m
.69063 .00375 L
s
.78654 0 m
.78654 .00375 L
s
.8345 0 m
.8345 .00375 L
s
.88246 0 m
.88246 .00375 L
s
.93041 0 m
.93041 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25902 m
.00625 .25902 L
s
gsave
-0.0125 .25902 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .4988 m
.00625 .4988 L
s
gsave
-0.0125 .4988 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .73859 m
.00625 .73859 L
s
gsave
-0.0125 .73859 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .97837 m
.00625 .97837 L
s
gsave
-0.0125 .97837 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06719 m
.00375 .06719 L
s
0 .11514 m
.00375 .11514 L
s
0 .1631 m
.00375 .1631 L
s
0 .21106 m
.00375 .21106 L
s
0 .30697 m
.00375 .30697 L
s
0 .35493 m
.00375 .35493 L
s
0 .40289 m
.00375 .40289 L
s
0 .45084 m
.00375 .45084 L
s
0 .54676 m
.00375 .54676 L
s
0 .59472 m
.00375 .59472 L
s
0 .64267 m
.00375 .64267 L
s
0 .69063 m
.00375 .69063 L
s
0 .78654 m
.00375 .78654 L
s
0 .8345 m
.00375 .8345 L
s
0 .88246 m
.00375 .88246 L
s
0 .93041 m
.00375 .93041 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25902 .99375 m
.25902 1 L
s
.4988 .99375 m
.4988 1 L
s
.73859 .99375 m
.73859 1 L
s
.97837 .99375 m
.97837 1 L
s
.125 Mabswid
.06719 .99625 m
.06719 1 L
s
.11514 .99625 m
.11514 1 L
s
.1631 .99625 m
.1631 1 L
s
.21106 .99625 m
.21106 1 L
s
.30697 .99625 m
.30697 1 L
s
.35493 .99625 m
.35493 1 L
s
.40289 .99625 m
.40289 1 L
s
.45084 .99625 m
.45084 1 L
s
.54676 .99625 m
.54676 1 L
s
.59472 .99625 m
.59472 1 L
s
.64267 .99625 m
.64267 1 L
s
.69063 .99625 m
.69063 1 L
s
.78654 .99625 m
.78654 1 L
s
.8345 .99625 m
.8345 1 L
s
.88246 .99625 m
.88246 1 L
s
.93041 .99625 m
.93041 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25902 m
1 .25902 L
s
.99375 .4988 m
1 .4988 L
s
.99375 .73859 m
1 .73859 L
s
.99375 .97837 m
1 .97837 L
s
.125 Mabswid
.99625 .06719 m
1 .06719 L
s
.99625 .11514 m
1 .11514 L
s
.99625 .1631 m
1 .1631 L
s
.99625 .21106 m
1 .21106 L
s
.99625 .30697 m
1 .30697 L
s
.99625 .35493 m
1 .35493 L
s
.99625 .40289 m
1 .40289 L
s
.99625 .45084 m
1 .45084 L
s
.99625 .54676 m
1 .54676 L
s
.99625 .59472 m
1 .59472 L
s
.99625 .64267 m
1 .64267 L
s
.99625 .69063 m
1 .69063 L
s
.99625 .78654 m
1 .78654 L
s
.99625 .8345 m
1 .8345 L
s
.99625 .88246 m
1 .88246 L
s
.99625 .93041 m
1 .93041 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000010101020202030303040404040404040505050505
050504040404040404030303020202010100000000
000001010202020303040405050506060606060607070707
070606060606060505050404030302020201010000
010101020203030404050606070708080808090909090909
090909080808070707060605040403030202010100
01010203030404050606070809090A0A0B0B0B0C0C0C0C0C
0C0C0B0B0B0A0A0908080706060504040302020101
02020303040505060708090A0B0C0C0D0E0E0F0F0F0F0F0F
0F0F0F0E0E0D0C0B0B0A0908070605050403030201
0203030405060708090A0B0C0D0E0F101112131314141414
1413131211100F0E0D0C0B0A090706060504030302
03030405060708090A0C0D0F101213141617181819191919
1918181716141311100E0D0C0A0908070605040302
030405060708090B0C0E1011131517191B1C1E1F20202020
201F1E1C1B19171513110F0E0C0A09080706050403
0404050608090A0C0E101215171A1C1F2123252728282928
28262523211E1C19171412100E0C0A090806050404
04050607090A0C0E101215181B1E2225282B2E3032333332
31302E2B2825211E1B181512100E0C0A0807060504
050607080A0B0D0F1215181C2024282C3135383B3E3F3F3F
3D3B3834302C28231F1B1815120F0D0B0908070504
050607090A0C0F1114171B20242A2F353A4045494C4E4F4E
4C49443F3A342E29241F1B1714110E0C0A09070605
050708090B0D1013161A1E242930373E454D53595E606160
5D59534C453D362F29231E1916120F0D0B09080605
0607080A0C0E1114181C21272E363F48515B646C72757675
716B635A50473E352E27211C1714110E0C0A080706
0607090A0C0F1215191E242B333C47525E6A7680888D8F8D
877F75695D51453B322A231E1915110F0C0A090706
0608090B0D0F12161B20262E37424E5C6B7A8895A0A7A9A6
9F948778695A4D41362D261F1A16120F0D0B090706
0708090B0D1013171B2128303B47556576889AABB8C0C3C0
B7A9988674635345392F27201B16130F0D0B090806
0708090B0D1013171C2229323D4A596B7F95AABDCDD8DBD7
CCBBA8927D6958483B3128211B1613100D0B090807
0708090B0D1013171C2229323E4C5C70869DB5CCDEEAEEE9
DCC9B39B836D5A4A3C3128211B1613100D0B090807
07080A0B0D1013171B2129323E4C5D7189A2BCD4E8F6FAF5
E7D2B99F866F5B4A3C3128211B1613100D0B090807
07080A0B0D1013161B2128313D4B5D7189A3BED7EDFAFFF9
EBD5BBA0866F5B4A3C3027201B16120F0D0B090807
0708090B0D1013161B2128313C4A5C7088A2BDD7EDFBFFFA
EBD5BB9F856E5A493B3027201A16120F0D0B090807
0708090B0D1013161B2028313C4A5B7088A2BDD7ECFAFFF9
EAD4BA9F856D59483A2F27201A16120F0D0B090807
0708090B0D1013161B2128313C4A5C7088A2BED7EDFBFFFA
EBD5BB9F856E5A493B3027201A16120F0D0B090807
07080A0B0D1013171B2128323D4B5D7189A3BED7ECFAFFF9
EAD5BBA0866F5B4A3C3027201B16120F0D0B090807
07080A0B0D1013171C2129323E4C5D7189A2BCD4E8F5F9F4
E6D1B99F866F5B4A3C3128211B1613100D0B090807
0708090B0D1013171C2229323E4C5C6F859DB4CADDE8ECE7
DBC8B29A836D5A4A3C3128211B1613100D0B090807
0708090B0D1013171C2229323D4A596B7E93A8BCCBD5D8D4
CABAA6917C6957483B3128211B1613100D0B090807
0608090B0D1013171B2128303A465464758798A8B5BDC0BD
B4A7978573625245392F27201B16120F0D0B090806
0608090B0D0F12161A20262E37414D5B697886939DA4A6A3
9C92857668594C40362D251F1A16120F0D0B090706
0607090A0C0F1215191E242B333C46515D68747E858A8C8A
857D73675B50453B322A231D1915110F0C0A090706
0607080A0C0E1114181C21272E353E47505962696F737473
6F6961584F463D352D26201B1714100E0C0A080706
050708090B0D1012161A1E23292F363D444B52575B5E5F5E
5B57514A433C352E28231E1915120F0D0B09080605
050607090A0C0E1114171B1F24292E34393F43474A4C4D4C
4A47433E39332E28231F1B1713110E0C0A09070605
05060708090B0D0F1215181B1F23272C3034373A3C3E3E3D
3C3A37332F2B27231F1B1714120F0D0B0908070504
04050607080A0C0E101215181B1E2124272A2D2F30313231
302F2D2A2724211D1A171412100D0C0A0807060504
0404050608090A0C0E10121417191C1E2022242627272827
27252422201E1B19161412100E0C0A090706050403
030405060708090A0C0E0F11131517191A1C1D1E1F1F1F1F
1F1E1D1C1A18171513110F0D0C0A09080605050403
03030405060708090A0B0D0E101113141516171818191919
1818171615141211100E0D0B0A0908060605040302
0203030405060607080A0B0C0D0E0F101112121313131313
1313121211100F0E0D0C0B09080706050504030302
01020303040505060708090A0A0B0C0D0D0E0E0F0F0F0F0F
0F0F0E0E0D0D0C0B0A090908070605040403020201
0101020203040405060607080809090A0A0B0B0B0B0C0C0C
0B0B0B0B0A0A090908080706050504040302020101
000101020203030404050506060707080808080909090909
090908080808070706060505040403030202010100
000001010102020303040404050505060606060606060606
060606060606050505040404030302020101010000
000000000101010202030303030404040404040404040404
040404040404040403030302020201010100000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{110.125, 110.125},
  ImageMargins->{{107.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002:0000RQ000`40l00?003`R_oo002:ool008[o
o`00R_oo002:ool008[oo`00R_oo002:ool008[oo`004_oo0`0?5?oo0`0?4ooo00<03oooool05?oo
0`0?5?oo0`0?6_oo000Bool00`0?ooooo`0Eool00`0?ooooo`0Aool00`0?ool03`0Fool00`0?oooo
o`0Cool00`0?ooooo`0Jool000goo`<03`?oo`0300oooooo00ooo`<03`;oo`0300oooooo017oo`03
00ooo`0?01Koo`0300oooooo01Coo`0300oooooo01Woo`004_oo00<03ooo00l05Ooo00<03oooool0
4Ooo00<03ooo00l05_oo00<03oooool04ooo00<03ooo00l06_oo000Cool200lDool200lDool00`0?
ooooo`0Dool200lFool200lJool008[oo`00R_oo002:ool007Koo`0300ooo`0?00?oo`0500ooo`0?
ool03`03ool00`0?ool03`03ool000Soo`<03fcoo`0300oooooo00;oo`0500ooo`0?ool03`03ool2
00l4ool000Soo`0300oooooo00Coof<03`Goo`0300oooooo00;oo`0500ooo`0?ool03`04ool00`0?
ooooo`02ool000?oo`<03`?oo`0300oooooo00?oo`0300ooo`0?01Koo`0300oooooo01Goo`0300oo
oooo01Coo`0300oooooo01Goo`0300ooo`0?00Coo`0300ooo`0?00?oo`0400ooo`0?00l4ool200l4
ool000Soo`0300ooo`0?00Coo`0300ooo`0?00H03`0540l03`0?00l@3`0300l0?A0?00l03`0?40l0
3a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`4?40l03a0?0@l@3`0?40l1
3a0?00l@3`4?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00<03`0540l0
3`0?00l@3`0:00l00ooo00l03`0Hool000Woo`803`Coo`0300ooo`0?00P03`050@l03`0?00l13`02
00l0>P0O0@l03`4?01l13`0?0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?
01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0?0@l07`4?
0P0?00H07`4?00l03`0O0@l300l00`4?00l03`0600l2ool00`0?ooooo`08ool00`0?ooooo`0;ool0
00ooo`0300ooo`0?00`03`0540l03`0?00l@3`0300l0<A0?00l03`0?40l03a0?00l@3`0?40l03a0?
00l@3`0?40l03a0?00l@3`0?41l03a0?00l@7`0?40l03a0O00l@3`0?40l03a0?00l@3`0?40l03a0?
00l@3`0?40l03a0?00<03`0540l03`0?00l@3`0300l00a0?00l03`0:00l2ool00`0?ooooo`0Fool0
00ooo`0300ooo`0?00D03`0601l03`0?00l07`4?0P0?04807`4?01l03`0O0@l07`4?01l13a0O0@l0
7`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?41l13a0O0@l@7`4?41l13a0O0@l@7`4?41l13`0O0@l@
7`4?01l13a0O0@l07`4?41l13`0O0@l@7`4?01l13`0O0@l07`4?01l03`0O0@l200l01@0O0@l03`0?
01l01`0?0_oo00<03oooool05_oo000?ool00`0?ool03`0600l01A0?00l03`0?40l00`0?044@3`0?
40l03a0?00l@3`0?40l03a0?0@l@3`0?41l13a0?00l@7`4?40l03a0O0@l@3`0?41l13a0?0@l@7`4?
40l13a0O0@l@3`0?41l13a0?00l@7`4?40l03a0O0@l@3`0?40l13a0?00l@3`4?40l03a0?00l@3`0?
40l03a0?00<03`0540l03`0?00l@3`0600l2ool00`0?ooooo`0Fool000ooo`0400ooo`0?0@l300l0
D@4?00l03`0O0@l03`4?01l13`0?0@l07`4?01l13`0O0@l@7`4?01l13a0O0@l07`4?41l13a0O0@l@
7`4?41l13a4O0@l@7`4?4Al13a0O0@lA7`4?41l13a4O0@l@7`4?4Al13a0O0@l@7`4?41l13a0O0@l0
7`4?41l13`0O0@l@7`4?01l13`0O0@l07`4?01l13`0O0@l03`4?01l13`0300l00`4?00l03`0200l0
0ooo00l03`0Hool000ooo`0300ooo`0?00P03`1940l03`0?00l@3`0?40l03a0?00l@7`0?40l03a0O
0@l@7`0?41l13a0O0@l@7`4?41l13a0O0@l@7`4?41l13a0O0@l@7`4?41l13a0O0@l@7`4?41l13a0O
0@l@7`4?41l13a0O0@l@7`4?41l13a0O00l@7`4?40l03a0O0@l@3`0?40l03a0?00l@3`0?40l00`0?
00<@3`0?00l01P0?0_oo00<03oooool05_oo000?ool01@0?ool03`0?01l00`0?05807`4?01l03`0O
0@l07`4?01l13a0O0@l07`4?41l13a0O0@l@7`4?41l17a0O0@l@7`4O4Al13a0O0AlA7`4O41l17a4O
0AlA7`4O4Al17a4O0AlA7`4O4Al17a4O0AlA7`4O4Al17a0O0AlA7`4?41l17a4O0@l@7`4?41l13a0O
0@l@7`4?01l13a0O0@l07`4?01l13`0O0@l07`0?01l13`803`0401l03`0?00l2ool00`0?ooooo`0F
ool000ooo`0300ooo`0?00803`1E40l03`0?00l@3`0?40l03a0?00l@3`0?40l03a0O0@l@3`0?41l1
3a0O0@l@7`4?41lA3a0O0@l@7a4?41lA3a0O4@l@7a4?41lA3a0O4@l@7a4?41lA3a0O4@l@7a4?41lA
3a0O4@l@7a4?41lA3a0O4@l@7`4?41lA3a0O0@l@7`4?41l13a0?0@l@7`4?40l03a0O0@l@3`0?40l0
3a0?00l@3`0?40l00`0?00<@3`0?00l00_oo00<03oooool05_oo000?ool0100?ool07`4?0P0?0200
7`4?00l13`0O0@l07`4?01l13`0O0@l07`4?41l13a0O0@lA7`4?41l17a4O0AlA7`4O4Al17a4O0AlA
7`4O0a4O00D17a4O4AlA7`4O00<A7`050AlA7a4O4Al17`034Al08`4O4AlA7a4O0AlA7`4O4Al17a4O
0AlA7`4?4Al17a4O0@l@7`4?41l13`0O0@l@7`4?01l13`0O0@l07`4?00l13`0O0@l00`0?00@13ooo
00l03aSoo`003ooo00@03ooo00l@3`<03`0M40l03`0?00l@3`0?41l03a0?00l@7`4?41l03a0O0@l@
7`4?41l13a0O4@l@7a4?41lA3a0O4@l@7`024Al00a4?41lA7`024Al01A0O4AlA7a4O41l00a4O00D@
7a4O4AlA7a0O00<A7`0M41lA7a4O4@l@7a4O41lA3a0O4@l@7`4?41lA3a0O0@l@7`4?41l13a0O00l@
7`0?40l03a0O00l@3`0300l00a0?00l03`0200l2ool00`0?ooooo`0Fool000ooo`0L00ooo`0?00l0
7`4?01l03`0O0@l@7`4?01l13a0O0@l@7`4?41l13a0O0AlA7`4O41l17a4O0Al<4Al03Q4_4QlA7a4O
4BlB7a4_4AlA;a8O4BlA7a4_4Ql24Al01A4_4QlA7a4O4Bl01Q4O01/17a4O4AlA7`4O4Al17a4O0@l@
7`4O41l13a0O0@l@7`4?01l13a0O0@l07`4?01l03`0O0@l00P0?0_oo00<03oooool05_oo000?ool0
0`0?ool03`0200l06A0?00l@3`0?40l03a0?0@l@3`0?41l13a0O0@l@7`4?41lA3a0O4@l@7a4?4AlA
3a0O008A7`034@lA7a4O00HA7`0=8AlA7a4O4AlQ7a4O8AlA7b4O4AlQ7a4O8Al00a4O00<Q7a4O4Al0
114O01hA3a4O4AlA7a4?41lA3a0O4@l@7a4?41l13a0O4@l@7`4?40l03a0O0@l@3`0?40l03a0?00l@
3`0?40l200l2ool00`0?ooooo`0Fool000ooo`0J00ooo`0O0@l03`4?01l13`0O0@l07`4?41l13`0O
0@l@7`4?41l17a4O0AlA7`4O4Al17`DA7`0Q4QlA7a4O4BlB7a4_4QlA;a8O8BlB7a4_4QlQ;a8O8BlB
7b4_4QlQ;a8O8BlB7a4_4QlQ;a8O4BlB7b4_4QlA;a8O008A7`044BlA7a4O0Al34Al05`4O4Al17a4O
0@l@7`4O4Al13a0O0@l@7`4?01l13`0O0@l07`4?00l13`0O0@l00_oo00<03oooool05_oo000?ool0
100?ool03a0?0`0?014@3`0?41l13a0?00l@7`4?41l13a0O0@l@7a4?41lA3a0O00<A7`0541lA7a4O
4AlQ7`034Al07B4O4AlQ;a8O8AlA7b4_4QlQ;a8O8BlB7b4_4QlQ;a8O8BlB7b4_4QlQ;a4O8BlB7b4O
4AlQ;a4O8Al01a4O01D@7a4O41lA3a0O4@l@7`4?41l13a0O0@l@7`0?41l13a0?00l@7`0?40l00`0?
00@@3ooo00l03aSoo`003ooo01@03ooo01l03`0O0@l@7`4?01l13a0O0@l@7`4?41l13a0O0AlA7`4O
214O00`A;a8O4BlB7a4_4QlQ;a8O8BlB;b8_4Rl38Rl01A8_8RlR;b8_4Rl00b8_00DB;b8_8RlR;a8_
00<R;`0;4RlQ;a8_8RlB7b4_4QlQ;a8O4BlB7`054Al05@4O4Al17a4O0Al@7`4O41l13a0O0@l@7`4?
01l13a0O0@l07`4?01l03`02ool00`0?ooooo`0Fool000ooo`0F00ooo`0?40l03a0?00l@3`4?40l1
3a0O0@l@7`4?41l13a0O4@l@7a4?41l24Al00a4?4AlA7`024Al03B4O4AlQ;a8O8AlB7b4_4QlQ;b8O
8BlR7b4_008R;`068QlQ;b8_8RlR7b4_0R8_018R7b4_8RlR;b8O8BlR7b4_8QlQ;b8O8BlB7b4O4AlQ
7a4O8Al64Al0514?41lA3a0O0@l@7a4?41l13a0O0@l@7`4?40l03a0?00l@3`0?40l2ool00`0?oooo
o`0Fool000ooo`0B00ooo`0O0@l07`4?01l13a0O0@l@7`4?41l13a0O0AlA7`4O0a4O00d17a4O4QlA
7a8O4BlB7b4_4QlQ;a8_8RlB7`038Rl08a8_8RlS;b8_8blR?b<_<SlS;b8o8blb?b<_8SlS;c8o8blR
?b<_8SlS;b8o8blR;a8_8RlB;b8_4QlR;a8O8BlB7a4_4Ql01A4O01<17a4O4AlA7`4O41l17a4O0@l@
7`4?41l13`0O0@l07`4?01l13`02ool00`0?ooooo`0Fool000ooo`0D00ooo`0?40l03a0?00l@3`0?
41l13a0O0@l@7`4?41lA3a0O4@l@7`DA7`0;8AlA7b4O4AlQ;a8O8BlR7b4_8QlQ;`078Rl03C8_8Rlb
?b<_<RlR;c8o8blb;b8_<SlR;c8_00LR;`098BlR;b4_4QlQ;a8O8BlB7b4O00<A7`0E41lA7a4O4@l@
7a4?41l13a0O0@l@7`4?41l03a0O00l@3`0?40l03a0?00;oo`0300oooooo01Koo`003ooo01003ooo
01l13`0O0@l@7`4?41l13a0O0@l@7`4O4Al17`LA7`064QlA;a8O8BlB7b4_1B8_00XR?b8_8SlS;c8o
8blc?b<o<clS?`/c?`0:8clc?b<o<clS;c8o8blb?b8_8Sl28Rl02Q8_8RlB;b8_4QlQ;a8O4BlA7a4_
1Q4O00h17a0O0Al@7`4?41l13a0O0@l07`4?01l13ooo0P0?6?oo000?ool04P0?ool03a0?0@l@3`0?
41l13a0?4@l@7`4?41lA3a0O4@l@7`8A7`0;4@lQ7a4O8AlA7b4O4QlQ;a8O8BlR7`048Rl02S8_8blb
;c<_<Slc;c8o<blc?c<_1c<o00`c;c8o<blc?c<_<Slc;c8o8blb;b8_<Rl48Rl01R8O8BlR7b4_4QlQ
7`HA7`0@4@l@7a4?41l13a0O0@l@7`4?40l03a0O0@l@3`0?40l2ool00`0?ooooo`0Fool000Soo`<0
3`Coo`0J00ooo`0O0@l@7`4?01l13a0O0@l@7`4O4Al13a4O0AlA7`4O4AlB7a4O4QlA;a8O8BlB7`@R
;`0_8SlS;c8o8blb?b<o<clS?c=?=3lcCc@o@dld?dA?=3m4CcA?A4ldCdA?=4m4Cc@o@dld?d=?=3lc
Cc@o<clS?c<o8clc?b<_8SlS;b8_4RlR;a8_8RlB7a4_4QlA;`024Al04A8O4Al17a4O0AlA7`4?41l1
3a0O0@l07`4?01l13`0O0@l00_oo00<03oooool05_oo0009ool00`0?ooooo`03ool0400?ool03a0?
00l@7`4?41l13a0O0@l@7a4?41l13a0O1A4O00LQ7a4O8BlA7b4_4QlQ;`038Rl01C8_8Rlb?b<_<Sl0
0c<o01=3?c<o@dld?d=?A3m3Cd@o@dm4?d=?A3m3Cd@o@dld?d=?=3m3C`03<cl01S8o<blb?c<_<SlS
;`<R;`068QlQ;b8O8BlB7b4O1Q4O00hA3a0O4@l@7`4?41l13a0O0@l@7`0?41l03a0?0_oo00<03ooo
ool05_oo0003ool300l3ool00`0?ooooo`03ool03P0?ool@7`4?01l13a0O0@l@7`4O4Al13a0O0Al6
4Al01A4_4QlQ;a8O8Bl00b8_00@R?b<_<SlS?`@c?`0E@dld?dA?=4m4GdA?E5m5CeAOADmEGdE?E5m5
GeEOADmDGdE?E5m5CdAO0094C`0D=4m4Cc@o@dlc?c=?8clc?b<_<SlS;b8_4RlR;a8_8RlB7a4_4QlA
;`@A7`0>0AlA7`4O4Al13a0O0Al@7`4?01l13a0O0@ooo`803aSoo`002Ooo00<03oooool00ooo0140
3ooo00l@3`4?40l13a0O0@l@7a4?41l13a0O4@lA7a4?008A7`078AlA7b4O4AlQ;a8O8Bl00b8_00Db
?b<_<clc;c8o008c?`0E=3m3?d@o@dm4CeA?A4mDCdE?E5mECeAOEDmDGeE?E5m5CeAOA4mDCdE?0094
C`04@dm4?d<o=3l2<cl01C8o<blb?b<_<Rl00R8_00PR7b4_8QlQ;a8O8AlA7b4O114O00`A3a0O4@l@
7`4?41l13a0O0@l@3`0?40l2ool00`0?ooooo`0Fool000Soo`803`Goo`0>00ooo`0O0@l@7`4?01l1
3a4O0@l@7`4O4Al17`DA7`0E4QlA7a8O4BlB;b8_4RlR;b<_8RlS;c8o8clc?b<o<dld?d=?=3m4CcA?
0094C`0?A5m5CeAOADmDGdEOEEm5CeAOAEmDGdE?A5m5CdAO0094C`0<=4m4Cc@o<dld?c<o8clc?b<_
<SlR;b8o0R8_00LB7b4_4QlQ;a8O4BlB7`054Al02`4O41l17a4O0@l07`4?41l13`0O0@l00_oo00<0
3oooool05_oo000?ool0400?ool03a0?00l@7`4?41l13a0O0@l@7a4?41lA3a0O0a4O00DQ7a4O8BlB
7b4_00<R;`09<SlR;c8o<bm3?c<o@cld?d=?0094C`03ADmDGeEO009EG`0=IEmFGfE_EUmUKfIOIFmF
GfE_EUmUKeEOIEl00UEO00=ECeAOADl00TA?00Q3Cd@o<clc?c8o<clb?b<_0R8_00LQ;b8O8BlB7b4_
4AlQ7`034Al03A0O4Al@7`4?41l13a0O0@l@7`0?41l03a0?00;oo`0300oooooo01Koo`003ooo00d0
3ooo41l13a0O0@l@7`4?41l17a4O0Al@7`044Al0318O4AlB7a4_4RlQ;a8_8RlS;b8_8blb?`8c?`09
=3lcCc@oA4ldCdAOA4mDGdE?009EG`0?EFmFGfE_EVmVKeIOIFmFKfI_EUmUKeIOEFmFGeE_009EG`0>
ADmDGdA?A4ld?d=?=3lcCb<o<clS;c8o8RlR?`8R;`064QlQ;a8O8BlB7a4_1Q4O00T17a0O0Al@7`4?
01l13a0O0@l00_oo00<03oooool05_oo000?ool03P0?ool03a0O0@l@3`4?41l13a0O4@l@7a4?41l3
4Al07B4O4AlQ;a8O8BlR7b8_8Qlb;b8_<Slc;d<o<cm3Cd@o@dm4CeA?EDmDGeEOIFmVGfE_IVmfOgM_
MWl00WMo01=gKgMoMgmgOfM_MWmVKgI_IfmUKfIOIEmFGeAOEDmDCdA?@dm4?`02<cl0138o<blb;b<_
0R8_00LQ;b8O8AlA7b4_4AlQ7`024Al03A4?41lA3a0O0@l@7`4?41l13a0?00l@7ooo00803aSoo`00
3ooo00h03ooo01l13a0O0@l@7`4?4Al13a4O0AlA7`4O0a4O00DB7a4_4QlQ;a8O00<R;`0E8blR?b<o
<cld?c=?=4m4CcA?A5m5CeEOAEmEKeIOIVmFKfIoIfmgOfM_00=gO`0QIgmgOgMoMgmWKfIoIfmVOeI_
IVmFGeE_ADmEGdE?A4ld?dA?=3lc?b<o<clS;b8o4RlR;a8_8RlB7a4_4QlA7a8O00<A7`0;0AlA7`4O
4Al13a0O0@l@7`4?01l13`02ool00`0?ooooo`0Fool000ooo`0=00ooo`4?40l03a0O0@l@7a4?41lA
3a0O4@l0114O00XQ7a4O8BlB7b4_8Qlb;b8_<SlS;`8c?`03@dld?eA?0094C`06EDmDGeIOIFmVKgI_
0WMo00=hOhN?R8l00XR?00FHShR?V9n8SiR?00:8S`0;N7n7SgQoMgmgKgI_IVmUKeIOE5mEC`02A4l0
1T=?=3lc?c<o<SlS;`8R;`078BlR;b4_4QlQ;a4O8Al0114O00XA3a0O4@l@7`4?41l03a0O0@l@3`;o
o`0300oooooo01Koo`003ooo00`03ooo41l13a0O0@l@7`4?41l17a4O0Al44Al01A4_4QlA;a8O8Bl0
0b8_00<R?b<o<Sl00S<o00/dCd=?A4m4GdE?EEm5GfE_EVmVOfM_009gO`0:QhmhOhR?R8nHWhV?V9n9
SiRORHl2R8l00hN?N7n7S`02Mgl01VI_IWmFGfE_AEmEG`94C`06=3m3Cc<o<clS;c8o0R8_00LB;b8_
4QlQ;a8O4BlB7`054Al02@4O41l17a0O0@l@7`4?41l13`02ool00`0?ooooo`0Fool000ooo`0=00oo
o`0?41l13a0O4@l@7a4?41lA3a4O4@l0114O01LQ7a4O8BlB7b4_8Rlb;b8_<Slc;d<o<cm3CdA?E5m5
CeAOEUmUKfM_MVmgOhMo00:8S`0?VHnHWiZOZInZWjZ_ZYnZ[jZOZJnJWjVOVHnHWiV?00:8S`9gO`0=
MVmVKfEOEUmDGeE?A4m4?d<o<clb?c<_<Rl00R8_00HR7b4_8QlQ;a8O8Al24Al0314?4AlA3a4O4@l@
7a4?41l13a0?00l@7`;oo`0300oooooo01Koo`003ooo02P03ooo01l13a0O0@l@7`4?4Al13a4O0AlA
7`4O4AlB7a4O4QlA;a8_8RlB;b8_8blR?b<o<cld?c=?=4m4CdEOEEm5CeE_EUmVOfM_MhmhO`:8S`0Q
VIn9WjV_VYnZ[iZ_ZZnJ[jZ_VZnY[iZOVIn9WiVON8n8SgQoMgmWKfIoEUmEKdE?E5ldCdA?=3lcCb<o
<clS;b8o008R;`0D4QlQ;a8O4BlB7a4O4QlA7`4O4Al17a4O0@l@7`4?41l13`0O0@ooo`803aSoo`00
3ooo00`03ooo0@l@7`4?41l13a0O4@l@7a4?41l34Al01R4O4AlQ;a8O8BlR7`8R;`06<RlR;c8o<bm3
Cc@o0TA?0eEO00AVKfE_MgmgO`:8S`:IW`:Z[`0=^knj_k^obknk_l_?^ko;_k^_^[nZ[jV_ZZl00YVO
00R7ShR?MWmgKfE_IVmEGeE?0TA?00m3Cc@o<Slc?c8o8RlQ;b8_8BlB7b4_4AlQ;a4O8Al00Q4O00XA
3a0O4@l@7`4?41l13a0O0@l@3`;oo`0300oooooo01Koo`003ooo00`03ooo41l13a0O0@l@7`4?41l1
7a4O0Al44Al01A4_4QlQ;a8O8Bl00R8_00PS;b8o<clc?c@o@dm5CdAO0eEO0VI_0WMo0XR?00BI[iVO
ZZnZ[`:k_`08^lnl_l_?_;nkckbo^kn[_`>Z[`:IW`06N8n8SgMoMgmFKfI_0UEO00m4CdAO=3m3Cb<o
<clS;c8o4RlR;a8_8RlB7a4_4Ql01A4O00T17a0O0Al@7`4?41l13a0O0@l00_oo00<03oooool05_oo
000?ool03@0?ool13a0O0@l@7a4?41lA3a0O4@lA7a4?00@A7`048AlA7b4_8Ql28Rl04C8o8blc?c<o
@dld?eA?A4mUGeEOIEmVKgI_N7n7SiV?V9l00ZZ_0[^o00S<cmc?gLoLgmg?g=oMcmcO0/c?0k^o016Y
[jZ_V9n9ShMoMgmfKfI_IEmEGeA?A4m3Cc@o<clc;c8_008R;`068QlQ;b8O8BlB7b4O0Q4O00`A3a4O
4@lA7a4?41lA3a0O0@l@7`4?41l2ool00`0?ooooo`0Fool000ooo`0D00ooo`0O0@l@7`4?41l13a4O
0@lA7`4O4Al17a4O4QlA7a8O4BlB;`<R;`0A8blb?b<o<cldCdA?ADm4GeIOEFmFGfIoIfn7SgQoVIn9
W`02ZZl02[_?_;o<clc?gMo=gmgOcMoLglgO0/c?0k^o00jJ[jZ_RHnIWgQoMhmWKfI_EUmEKdE?A5ld
?d=?0S<o01LS;b8o8RlR;a8O8BlB;a4_4QlA;a8O4Al17a4O0AlA7`4?41l13a0O0@l07`4?00;oo`03
00oooooo01Koo`003ooo00`03ooo0@l@7`4?41l13a0O4@l@7a4?41l34Al01R4O4AlQ;a8O8BlR7`8R
;`0=<SlR;c<o<cm3Cd@oE5m5CfE_EEmUKfM_MWl00XR?00BIWjVO^jnj_`;<c`;Mg`06k]o]knk_k^oN
gng_0]gO01k<_l_?c<nj_j^_ZInIWhN?N7mfOfI_IFmEGeA?A4m3Cc@o<Slc?c8o8blQ;b8_8BlB7b4_
4AlQ;a4O8Al24Al02a4?41lA3a0O0@l@7`4?41l13a0Oool00P0?6?oo000?ool0300?ool@7`4?41l1
3a0O0@l@7`4O4Al17`@A7`054BlB7b4_4RlQ;`028Rl03B<_<Slc?c<o=4m3CdE?E5mFGfE_EUmfOfM_
00:8S`04VJnJWkZoZkl2c<l01=g_gMo^kmk_0nk_01SNkmgOgMo<ckc?c<n[[kZoVInI[gR?R8mWKgIo
EUmUKdE?A5ldCd=?8clc?b<_<Sl28Rl01A8_8RlB7a4_4Ql01A4O00T17a0O0Al@7`4?41l13a0O0@l0
0_oo00<03oooool05_oo000?ool03@0?ool13a0O0@l@7a4?41lA3a0O4@lA7a4?00@A7`048AlA7b4_
4Ql28Rl0<c8o8blc?c<o@dm4?eAOADmUKeIOIFmgKgIoR8nHSiZOZJnk_l^ocLoLgmkOkNo_kokoonon
onk_o_oNgng_c<oLclg?^[nk_jV_VYn7ShR?MWmWKfEOEEmDGdE?@dm4?c<o<blb;`028Rl01R8O8BlR
7b4_4QlQ7`8A7`0<4@lA7a4?4AlA3a0O4@l@7`4?41l13a0O0_oo00<03oooool05_oo000?ool0900?
ool07`4?41l13a0O0AlA7`4?4Al17a4O0AlA7a8O4AlB7a4_4RlR;a8_8RlS;c8o8clc?cA?A4m5CeAO
EUmUKeIOMWmWO`:8S`0QZJnJWk^o^ko<glg?k^oNgnkoknooono_k_o_knk_g]o<glg?c=n[_k^oVYnY
[gR?R8mWKgMoEUmEKdE?E5ld?d=?008c?`0G8blR?b8_8RlB7b4_4RlA;a8O4BlB7a4O0AlA7`4O4Al1
3a0O0@l@7`4?01l13`02ool00`0?ooooo`0Fool000ooo`0<00ooo`4?41l13a0O0@l@7a4?41lA3a0O
0a4O00HQ7a4O8BlA7b4_8Ql28Rl03C8_8Rlc?c<_@dm4?eAOADmUKeIOIFmWKgIo00:8S`06VYnY[k^o
^ko=cmcO0^k_00__kokoooooono_o_o^kng_cLoLglg?00:k_`0GZInIWhR?R7mfOfM_IFmFGeA?A4m3
Cc@o<Slc?c8o8RlQ;b8_8BlB7b4_4AlQ;`044Al02a4?41lA3a0O0@l@7`4?41l13a0Oool00P0?6?oo
000?ool0300?ool@7`4?41l13a4O0@l@7`4O4Al17`@A7`054BlB7b4_4QlQ;`028Rl05B<_8Slc?c<o
=3m3CdE?E5mFGfE_EUmgOfM_R9n8SjV_VYnkckbogMo=c`02k^l00oookoooo`02ool01^o_k^o^kmcO
cLoLg`:k_`0GVYnI[hR?R8mWKgIoEUmUKdE?A5ldCd=?8clc?b<_<SlB;b8_4RlR;a8O4BlB7`054Al0
2@4O41l17a0O0@l@7`4?41l13`02ool00`0?ooooo`0Fool000Woo`0300oooooo00?oo`0=00ooo`4?
41l13a0O4@l@7a4?41lA3a4O4@l0114O00@Q7a4O8BlB7`8R;`0=<SlS;c8o<cm3Cc@oE4m4CfE_EUmU
GgM_MWl00XR?00ZJWjV_^ko;_mg?g=o^gnk_onono`;oo`07onononkOkNo=cmcOcLl00[^o00nY[iZO
Qhn8OgIoIfmUGeEOE4m5Cd=?=3lc?c<_<Rl00R8_00HR7b4_8QlQ;a8O8Al24Al0314?4AlA3a4O4@l@
7a4?41l13a0O0@l@7`;oo`0300oooooo01Koo`002?oo00<03ooo00l01?oo02@03ooo01l13a0O0@l@
7`4?4Al13a4O0AlA7`4O4AlB7a4O4QlA;a8_8RlB;b8_8blb?b<o<cld?dA?ADm4GeIOIFmFGgIoIfl2
R8l02ZV_VYnk_k^og=o=gnk_g^ooonoo0ooo00K_onk_g^oLglg?g=l2^kl049ZOZJmhShR?IfmfOeIO
EFm5CdAO=3m3Cb<o<clS;b8o0R8_01<B7b4_4QlA;a8O4AlB7a4O0AlA7`4O4Al13a0O0@l@7`4?01l1
3`02ool00`0?ooooo`0Fool000Soo`0300ooo`0?00Coo`0<00ooo`4?41l13a0O0@l@7a4?41lA3a0O
0a4O00HQ7a4O8BlA7b4_8Ql28Rl03C8_8Rlc?c<_@dld?eAOADmUKeEOIFmWKgIo00:8S`06VYnY[k^o
^ko=cmcO0^k_00_okokoooooono_o_o^kng_cLoLglg?00:k_`0GZInIWhN?R7mfOfM_IFmEGeA?A4m3
Cc@o<Slc?c8o8RlQ;b8_8BlB7b4_4AlQ;`044Al02Q4?41lA3a0O0@l@7`4?41l13a0O0_oo00<03ooo
ool05_oo0008ool00`0?ool03`04ool0300?ool@7`4?41l13a0O0@l@7`4O4Al17`@A7`054BlB7b4_
4QlQ;`028Rl03B<_8Slc?c<o=3m3CdE?E5mFGeE_EUmfOfM_00:8S`06ZJnJWk_?_;oMglg?0^k_00?o
onooool00_oo00K_knk_g^oLglg?g=l2^kl05iZOVJn8ShR?IfmfOeIOEFm5CdAO=3m3Cb<o<clS;c8o
4RlR;a8_8BlB7a4_4Ql01A4O00X17a0O0Al@7`4?41l13a0O0@ooo`803aSoo`002Ooo00<03oooool0
0ooo00d03ooo0@l@7`4?41lA3a0O4@l@7a4?4AlA3`044Al04b4O4AlQ;a8O8BlR;c8o8blb?c<o@dld
?eA?A4mUKeIOIEmgKgIo00:8S`0:VYnY[k^obkoMcmcOk]o]koo_o_l2ool01oo_o_o^gng_cLoLglg?
00:k_`0?ZJnJWhN?R7mfOfM_IEmEGeA?A4m3?c@o<clc;c8_008R;`068QlQ;b8O8BlB7b4O0Q4O00`A
3a4O4@lA7a4?41lA3a0O0@l@7`4?41l2ool00`0?ooooo`0Fool000ooo`0T00ooo`0O0@l@7`4?41l1
3a4O0@lA7`4O4Al17a4O4QlA7a8O4BlB;b8_4RlR;b<_<SlS?c<o=3m4CdE?A5mFGfE_EUmfOfM_0XR?
00ZY[iZO^knl_mcOcMo^kmk_ooo_o`?oo`06koo^kmk_g=o=cmcO0[^o012JWjV_N8n8SfM_MWmFGeE_
ADm4Gc@o@dlS?c<o8blR?`8R;`0C4QlQ;a8O4BlB7a4O4QlA7`4O4Al17a4O0@l@7`4?41l13`0O0@l0
0_oo00<03oooool05_oo000?ool0300?ool13a0O0@l@7`4?41lA3a0O4@l@7`<A7`068AlA7b4_4AlQ
;b8O0R8_00db;b8_<clc;d=?=3mDGdE?IFmEGfE_IfmfO`02R8l01YZOZJnk_k^ocLoLg`;^k`0;onon
ooooooo_kokok^o]klg?g=o=c`02^kl05jVOVIn7ShQoMWmWKfE_EEmDCdA?@dld?c8o<clb?b8_8BlR
;b4_4QlQ;a4O8Bl0114O00XA3a0O4@l@7`4?41l13a0O0@l@7`;oo`0300oooooo01Koo`003ooo00`0
3ooo41l13a0O0@lA7`4?41l17a4O0Al44Al01A4_4QlQ;a8O8Bl00R8_01DS;b8o<clc?c@o@dm5CeAO
EUmUKeIOMgmWKhROR8nY[iZO^lnl_mgOcLl00^k_00?oonooool00_oo00K_knk_g^oLglg?g=l2^kl0
5iZOVJn8ShR?IfmfOeIOIFm5CdAO=4m3Cb<o<clS;c8o4RlR;a8_8RlB7a4_4Ql01A4O00T17a0O0Al@
7`4?41l13a0O0@l00_oo00<03oooool05_oo000?ool03@0?ool13a0O0@l@7a4?41lA3a0O4@lA7a4?
00@A7`048AlA7b4_4Ql28Rl06C8o8blc?c<o@dld?eA?ADmUKeIOIFmgKgIoR8nHSjZOZJnk_l^ogLoL
gnkOkNookoko00;oo`07onononkOkNo=cmcOcLl00[^o00nY[iZOQhn8SgIoIfmUGeEOE5m5Cd=?A3lc
?c<_<Rl00R8_00HR7b4_8QlQ;a8O8Al24Al03A4?4AlA3a4O4@l@7a4?41l13a0O0@l@7ooo00803aSo
o`003ooo02@03ooo01l13a0O0@l@7`4O4Al13a4O0AlA7`4O4AlB7a4O4QlA;a8_8RlB;b8_8blb?b<o
<cldCdA?ADmDGeIOIFmFGgIoIgl2R8l08JV_VYnk_k^oc=o=cnk_g]o^ono_ooo_knkokno]kmkOc=o=
clcOZknk_iZOZJmhShR?IfmgOeIOEFm5CeAO=3m3C`02<cl05b<_8SlR;b8_4QlQ;a8_4BlB7a4_4QlA
7`4O4Al17a4O0@l@7`4?41l13`0O0@l00_oo00<03oooool05_oo000?ool0300?ool13a0O0@l@7`4?
41lA3a0O4@l@7`<A7`068AlA7b4_4QlQ;b8O0R8_00db?b8_<clc?d=?A3mDGdE?IFmFGfE_IfmfO`02
R8l0;YZOZJnk_k^ocLoLgnkOkNo_kok_onononk_o^oNgng_c<oLclc?^knk[jVOVIn8ShQoMWmWKfE_
EUmDCdA?@dld?c8o<clb?b<_8BlR;b4_4QlQ;a4O8BlA7b4O0Q4O00XA3a0O4@l@7`4?41l13a0O0@l@
7`;oo`0300oooooo01Koo`003ooo00`03ooo41l13a0O0@l@7`4?41l17a4O0Al44Al01A4_4QlQ;a8_
8Bl00R8_00dS;c8o<clc?cA?@dm5CeAOEUmUKeIOMWmWK`02R8l01YV_VYnj_j^oc<nlc`;Mg`06k^oN
gnk_k^o]kmkO0]gO01G<ckc?c<n[[kZoVInI[gR?R8mWKgIoEUmUKdE?A5ldCd=?8clc?b<_<Sl00R8_
00DB;b8_4QlA;a8O00DA7`090Al@7`4O41l13a0O0@l@7`4?00;oo`0300oooooo01Koo`003ooo00d0
3ooo0@l@7`4?41lA3a0O4@l@7a4?4AlA3`044Al0124O4AlQ;b8O0R8_01<b?b<_<clc?d=?A3mDGdE?
IFmFGfEOMfmfOhQoQhnIWjVOZjnj_`02c<l2gMl03NkOkNo^gng_k]o]kmg?g=o<_l_?c;nj[j^_00:I
W`0=Qhn8OgIoIfmUGeEOE5m5Cd=?A3lc?c<_<Rl00R8_00HR7b4_8QlQ;a8O8Al24Al03A4?4AlA3a4O
4@l@7a4?41l13a0O0@l@7ooo00803aSoo`003ooo01@03ooo01l13a0O0@l@7`4?4Al13a4O0AlA7`4O
4AlB7a4O4QlA;a8_0b8_01lS;c8o8clc?cA?A4m5CdAOEUmEKeIOIWmWKhN?N7nHWhVOZZnJ[k^o_;o<
ckc?g=o=cmgOcLo<glg?c<nlc`03^kl03YZ_ZZn9SiRON7mgSfM_IVmEGeE_ADm4Gc@o@dl2<cl05b<_
8SlR;b8_4QlQ;a8_4BlB7a4_4QlA7`4O4Al17a4O0@l@7`4?41l13`0O0@l00_oo00<03oooool05_oo
000?ool0300?ool13a0O0@l@7`4?41lA3a0O4@l@7`<A7`068AlA7b4_4QlQ;b8O0R8_014b?b8_<clc
?d=?A3mDGdE?IEmEGfEOIVmfKgMoQhn9SiRO00:Z[`:k_`;<c`06cLoLgmg?g=o=cmcO0/c?00^k_kZo
^knY[jZOV9n9ShN?MgmfKfI_009EG`0AE4m4Cd=?=3lb?c<o<SlS;b4_8RlQ;a8O8BlA7b4_4AlQ7`02
4Al02Q4?41lA3a0O0@l@7`4?41l13a0O0_oo00<03oooool05_oo000?ool0300?ool@7`4?41l13a0O
0@l@7`4O4Al17`@A7`054BlB7b4_4QlQ;`028Rl022<_8Slc?c<o=3m3CdE?A4l3EEl016I_EVmgOgMo
0XR?0YVO00BZ[iZ_^[n[_`:k_`09^lnl_k^o^knj_j^oZZnJ[jZ_00:IW`06N8n8SfMoMgmFKfI_0UEO
00m4CdAO=3m3Cb<o<clS;c8o4RlR;a8_8RlB7a4_4Ql01A4O00T17a0O0Al@7`4?41l13a0O0@l00_oo
00<03oooool05_oo000?ool03@0?ool03a0O0@l@7a4?41lA3a0O4@lA7a4?00@A7`048AlA7b4_4Ql2
8Rl02c8o8blb?c<_@dld?eA?A4mEGeE?EEl00VI_00IgKgIoR8n8SiV?VIl2ZZl00j^_^[nk_`02^kl0
4/^o^knk_j^_^[nZWjZ_ZYnHWiVOR8n8OgIoMfmUKfIOE5mEC`94C`05@clc?c<o<blb;`028Rl01R8O
8BlR7b4_4QlQ7`8A7`0<4@lA7a4?4AlA3a0O4@l@7`4?41l03a0O0_oo00<03oooool05_oo000?ool0
>`0?ool07`4?41l13a0O0@lA7`4?4Al17a4O0AlA7a8O4AlB7a4_4QlR;a8_8RlS;b8o8clc?c@o<dld
CdA?ADmEGdE?EFmFGfI_IfmgOgQoR8mhSiRORInI[iZOZJnJ[jZ_VZnY[iZOVInJWiRORHnIWgR?R8l0
0WMo00iVKfIoEUmEKdE?E5ldCdA?=3lcCb<o<clS;b8o0R8_01@B7b4_4QlA;a8O4AlB7a4O0AlA7`4O
4Al13a0O0@l@7`4?01l13ooo0P0?6?oo000?ool0300?ool13a0?0@l@7`4?41lA3a0O4@l@7`DA7`0C
8BlA7b4_4QlR;b8O<RlR;c8o<bm3?c<o@dm4?eAOADmDGeIOIEl00VI_0WMo0XR?00Z9SiROVInYWiZO
ZJnZWjV_VYnY[`:IW`07RHnHWhV?Qhn8OgIoMgl00VI_00IUGeEOE5m5Cd=?A3l2<cl02c8o<blR;b8_
8BlR;b4_4QlQ;a4O8Bl0114O00XA3a0O4@l@7`4?41l03a0O0@l@3`;oo`0300oooooo01Koo`003ooo
00`03ooo41l13a0O0@l@7`4?41l17a4O0Al44Al01A4_4QlA;a8O8Bl00b8_00<R?b<o<Sl00S<o00Td
Cd=?A4m4GdE?EEm5GfE_EUl00VI_0WMo00>7SgQoR8l00hR?00>8WhV?R8l00hR?00^7SgQoMhmWOgMo
IVmVOeIOIFm5GeAO0094C`06=3m3Cc<o<clS;c8o0R8_00LB;b8_4QlQ;a8O4BlB7`054Al02@4O41l1
7a0O0@l@7`4?41l13`02ool00`0?ooooo`0Fool000ooo`0=00ooo`0?41l13a0?4@l@7`4?41lA3a0O
4@l0114O00HQ7a4O8BlB7b4_8Ql28Rl01S8o<blc?c<o@dm4?`94C`05E4mECeAOEUmUK`02IVl01WM_
MWmhOhN?R7n7S`>8S`0:V8n8ShR?R7n7SgMoQhmhOgIoMfl2IVl026EOEEmDGeE?E4m4Cd=?=3l2<cl0
2c8o8blb;b8_8BlR7b4_4QlQ;a4O8Al00Q4O00`A3a4O4@l@7`4?41lA3a0O0@l@3`0?41l2ool00`0?
ooooo`0Fool000ooo`0>00ooo`0O0@l@7`4?41l13a4O0@lA7`4O4Al17`<A7`054QlA;a8O8BlB7`03
8Rl00b<_8SlS?`02<cl0=3=?=4m4Cc@oA5m5CeEOADmEKeIOIVmFKfIoIfmgOfM_MgmWOgMoIgmgOfMo
MgmWKfIoIfmVKeIOIVmFGeEOADmEGdE?A4ld?d=?=3lc?b<_<clS;b8o4RlR;a8_8RlB7a4_4QlA7a8O
0a4O00/17a4O0AlA7`4?41l13a0O0@l07`4?00;oo`0300oooooo01Koo`003ooo00l03ooo0@l@3`0?
41l13a0O4@l@7a4?41lA3a4O4@l0114O00XQ;a4O8BlB7b4_8Rlb?b8_<Slc;`8c?`0Y@dm4?d=?A4mD
CeE?E5mEGfEOIUmUKfI_MVmWKgIoMfmfOgMoMWmgKgIoIfmfOfI_MVmVKfE_EUmUGeEOE5m5CeA?A4m3
Cc@o@clc?c8o8blb;`028Rl01R8O8BlR7b4_4QlQ7`<A7`0>41lA7a4O4@l@7a4?41l13a0O00l@7`4?
40ooo`803aSoo`003ooo00d03ooo41l13a0O0@l@7`4?41l17a4O0Al@7`064Al01A8O4BlB;b4_4Rl0
0b8_00<S;c8o<cl00S<o00@cCc@oA4ld?`94C`03E5m5CeEO00=EG`0:EFmFGfE_EUmUKeI_IFmFGeE_
EUl2EEl01EE_AEmEGdE?A5l00TA?00Xd?d=?=3lc?b<o<clS;c8o8RlR?`8R;`064QlQ;a8O4BlB7a4_
1Q4O00T17a0O0Al@7`4?01l13a0O0@l00_oo00<03oooool05_oo0008ool300l4ool0900?ool03a0?
0@l@3`4?41l13a0O4@l@7a4?41lA3a4O4@lQ7a4O8AlB7b4_8QlR;b8O<RlR;c8o8blb?c<_@clc?d<o
A3m3C`94C`04ADmDGeE?E5l2EEl02UIOIEmVGfE_EUmUKfIOIFmFGfEO0eEO00ADGeE?E5m5C`94C`07
@dld?d<o<clb?c<_<Rl00b8_00TQ;b8O8BlB7b4O4AlQ7a4O8Al00Q4O00`A3a0O4@l@7`4?41l13a0O
0@l@3`0?40l2ool00`0?ooooo`0Fool000Woo`0300oooooo00?oo`0>00ooo`0O0@l@7`4?41l13a4O
0@lA7`4O4Al17`DA7`054QlA;a8O8BlB;`038Rl02B<_<SlS?c<o=3lc?c@o@dldC`02A4l0:TAOADmE
GdEOEFmFGfE_EUmUKeIOIVmFGfE_EUmUKeIOEFmFGeEOAEmEGdE?E5ldCdA?=3m4Cc<o<dlS?c<o8blR
?b<_8RlB;b8_4QlQ;a8O4BlB7`DA7`0;0AlA7`4O4Al13a0O0@l@7`4?01l13`02ool00`0?ooooo`0F
ool000Woo`0300oooooo00?oo`0@00ooo`0?40l03a0O0@l@7`4?41l13a0O4@l@7a4?41l34Al03b4O
4AlQ;a8O8BlR7b8_8Qlb;b8_<SlS;c8o<blb?`03<cl00d=?A3m3C`03A4l03EA?A4mDGdE?E5m5CeAO
ADmDGdA?E5m4CeA?00=4C`04@dm4?d=?=3l2<cl00c8o<blb;`038Rl01B4_8RlQ;a8O8Al00a4O018Q
7a4O4AlA3a0O4@l@7`4?41l13a0O0@l@7`0?41l03a0?ool200lHool000Woo`0300oooooo00?oo`0@
00oooa0O0@l07`4?41l13a0O0AlA7`4?41l17a4O0Al44Al01A4_4QlQ;a8O8Bl00b8_00HR?b<_<SlS
?c<o8cl2<cl013=?=3m4CcA?0TA?00m4GdA?A5m5CeAOADmDGdEOE5m5CdAOADm4GdA?A5l00TA?00@d
Cd=?=3m3C`8c?`048clc?b<_8Sl28Rl01a8_8RlB;b8_4QlA;a8O00DA7`0=0AlA7`4O4Al13a0O0Al@
7`4?01l13a0O0@l00_oo00<03oooool05_oo0008ool200l5ool04@0?ool03a0?0@l@3`4?41l13a0O
4@l@7`4?41lA3a4O4@l0114O014Q7a4O8BlB7b4_8QlR;b8O<RlR;c8_8blb;c<_<Slc;c8o00<c?`0A
@cld?d=?=3m3Cd@o@dm4?d=?A3m3Cc@o@dld?d=?=3m3?`03<cl01C8o<blb?b<_<Rl00b8_00TQ;b8_
8BlB7b4O4AlQ7a4O8Al00Q4O010A3a4O4@lA7a4?41lA3a0O0@l@7`4?41l13a0?00l@3`;oo`0300oo
oooo01Koo`003ooo01/03ooo01l13a0O0@l07`4?41l13a0O0@lA7`4?4Al17a4O0AlA7a8O4AlB7a4_
4QlQ;a8O8Bl0128_01`S;b8o8blb?b<o<clS?c<o=3lcCc@o<dld?dA?=3m4CcA?A4ld?d=?=4m4Cc@o
<dld?d=?=3lcC`8c?`0?8clc?b<_<clS;b8o8blR;a8_8RlB;b8_4QlA;a8O00<A7`0A4QlA7`4O4Al1
7a4O0@l@7`4?41l13`0O0@l07`4?01l13`02ool00`0?ooooo`0Fool000ooo`0D00ooo`0?40l03a0O
0@l@3`0?41l13a0O0@l@7`4?41lA3a4O4@l@7`<A7`098AlA7b4_4QlQ;b8O8BlR7b4_00<R;`0=<RlR
;c8o8blb?c<_<Slc;c8o<clb?c<_<Sl00S<o00hc;c8o<clb?c<_<Slc?c8o8blb?b<_<SlR;c8_0b8_
00DQ;b8O8BlB7b4O00LA7`0A41lA7a0O4@l@7a4?41l13a0O00l@7`4?40l03a0O00l@3`02ool00`0?
ooooo`0Fool000ooo`0@00ooo`0O0@l07`4?41l13a0O0@l@7`4?41l17a4O0Al74Al01Q8O4BlB7b4_
4QlQ;`LR;`088SlS;c8o8blb?b<o<clS?`<c?`058clc?c<o<clS?`03<cl02R<o<clS?c<o8blb?b<_
<SlR;b8o0R8_00XB;b8_4RlQ;a8O4BlB7a4_4AlA;`HA7`0>0Al@7`4O41l13a0O0@l@7`4?01l13`0O
0@ooo`803aSoo`003ooo01D03ooo00l@3`0?40l03a0?0@l@3`4?41l13a0O4@l@7`4?41lA3a4O4@l0
114O00dQ7a4O8BlB7b4_4QlQ;b8O8BlR7b8_8QlQ;`038Rl04C8_8Rlb;b<_<RlR;c8_8blb;b8_<RlS
;c8_8Rlb;b8_<Rl00b8_00dQ;b8_8RlR7b4_8QlQ;a8O8AlA7b4O4AlQ7`024Al0514?41lA7a4O4@l@
7a4?41l13a0O0@l@7`4?40l03a0?00l@3`0?40l2ool00`0?ooooo`0Fool000ooo`0B00ooo`0O0@l0
7`4?01l13a0O0@l@7`4?41l13a0O0AlA7`4O0a4O01417a4O4QlA7a8O4BlB7b4_4QlQ;a8_8RlB7b8_
4RlR;a8_00@R;`0>8SlS;b8o8blR?b<_<SlS;b8o8blR?b<_8SlS;`8R;`0>8SlR;b8_4RlR;a8_8RlB
7b4_4QlQ;a8O4BlB7`DA7`0C0AlA7a4O4Al17a0O0AlA7`4?01l13a0O0@l07`4?01l13`0O0@l00_oo
00<03oooool05_oo000?ool0600?ool03a0?00l@3`0?40l03a0O0@l@7`0?41l13a0O0@l@7`4?41lA
3a4O4@l@7`<A7`0A8AlA7b4O4AlQ7a4O8BlB7b4_4QlQ;a8O8BlR7b4_8QlQ;`028Rl01R8O8BlR;b8_
8QlQ;`8R;`0>8QlQ;b8_8BlR7b4_8QlQ;a8O8BlA7b4_4QlQ7`LA7`0E41lA7a0O4@l@7a4?41l13a0O
0@l@7`4?40l03a0O00l@3`0?40l03a0?00;oo`0300oooooo01Koo`003ooo01@03ooo01l03`0O0@l@
7`4?01l13a0O0@l@7`4?41l13a0O0AlA7`4O214O010A;a8O4BlB7a4_4QlQ;a8O8BlB;b8_4RlR;a8_
8RlB;`<R;`054RlR;b8_8RlB;`038Rl03a8_8RlB;b8_4RlQ;a8_8BlB7b4_4QlQ;a8O4BlB7`054Al0
5@4O4Al17a4O0Al@7`4O41l13a0O0@l@7`4?01l13a0O0@l07`4?01l03`02ool00`0?ooooo`0Fool0
00ooo`0J00ooo`0?40l03a0?00l@3`4?40l03a0O0@l@3`4?41l13a0O4@l@7`4?41lA3a4O4@l@7`8A
7`034@lA7a4O008A7`0Q8AlA7b4O4AlQ7a4O8AlB7b4O4QlQ;a8O8AlB7b4_4QlQ;a8O8BlB7b4O4QlQ
;a8O8AlA7b4O4QlQ7a4O8AlA7b4O00HA7`0F4@l@7a4?41lA3a0O4@l@7`4?41l13a0O0@l@3`0?41l1
3a0?00l@3`0?40l200l00ooo00l03`0Hool000ooo`0J00ooo`0O0@l03`4?01l13`0O0@l07`4?41l1
3`0O0@l@7`4?41l17a4O0@lA7`4O4Al17`DA7`0Q4QlA7a4O4BlB7a4_4QlA;a8O8BlB7a4_4QlQ;a8O
8BlB7b4_4QlQ;a8O8BlB7a4_4QlQ;a8O4BlB7a4_4QlA;a8O00DA7`0K0AlA7a4O4Al17a4O0AlA7`4?
41l17a4O0@l@7`4?41l13`0O0@l07`4?01l13`0?0@l07`4?00;oo`0300oooooo01Koo`003ooo00@0
3ooo00l@3`<03`0E40l03a0?00l@3`0?41l13a0?00l@7`4?41l13a0O0@l@7a4?41lA3a0O008A7`03
4@l@7a4O008A7`0341lA7a4O00DA7`058AlA7a4O4AlQ7`034Al01B4O4AlA7a4O8Al01a4O01d@7a4O
4AlA7a0O4Al@7a4?41lA3a0O0@l@7`4?41l13a0O00l@7`4?40l03a0O00l@3`0?40l03a0?00<03`04
40oooooo00lHool000ooo`0L00ooo`0?00l07`4?01l03`0O0@l@7`4?01l13a0O0@l07`4?41l13a0O
0AlA7`4O41l17a4O0Al<4Al01Q4_4AlA7a4O4BlB7`8A7`064BlB7a4O4AlA;a8O0Q4O00DA;a4O4AlA
7a4_00HA7`0K0AlA7a4O4Al17a4O0AlA7`4?41l13a0O0@l@7`4?41l13`0O0@l@7`4?01l13`0O00l0
7`4?00803`;oo`0300oooooo01Koo`003ooo00<03ooo00l00P0?024@3`0?40l03a0?00l@3`0?40l0
3a0?0@l@3`0?41l13a0O0@l@7`4?41lA3a0O0@l@7a4?41lA3a0O4@lA7a4?41l00Q4O00DA3a0O4AlA
7a4?00<A7`054@lA7a4O4AlA3`034Al08Q4?41lA7a4O4@l@7a4?4AlA3a0O4@l@7a4?41lA3a0O0@l@
7a4?41l13a0?0@l@7`4?40l03a0?00l@3`0?40l03a0?0`0?00<@3`0?00l00_oo00<03oooool05_oo
000?ool0100?ool03`4?0P0?02007`4?00l13`0O0@l07`4?01l13`0O0@l07`4?41l13a0O0@lA7`4?
41l17a4O0@lA7`4O4Al17a4O0AlA7`4O0a4O00D17a4O4AlA7`4O00<A7`050AlA7a4O4Al17`034Al0
8`4O4AlA7a4O0AlA7`4O4Al17a4O0AlA7`4?41l13a4O0@l@7`4?41l13`0O0@l@7`4?01l13`0O0@l0
7`4?00l13`0O0@l00`0?00@13ooo00l03aSoo`003ooo00<03ooo00l0100?054@3`0?00l03a0?00l@
3`0?40l03a0O00l@3`0?41l13a0O00l@7`4?41l13a0O0@l@7`4?41l13a0O4@l@7`4?41lA3a0O0@l@
7a4?41lA3a0O4@l@7a4?41lA3a0O0@l@7a4?41l13a0O4@l@7`4?41lA3a0O0@l@7`4?41l13a0O0@l@
7`4?40l03a0O00l@3`0?41l03a0?00l@3`0?40l00`0?00<@3`0?00l00P0?0_oo00<03oooool05_oo
000?ool01@0?ool03`0?01l00`0?05807`4?01l03`0O0@l07`4?01l13a0O0@l07`4?41l13a0O0@l@
7`4?41l17a0O0@l@7`4O4Al13a0O0AlA7`4O41l17a4O0Al@7`4O4Al17a4O0AlA7`4O41l17a4O0Al@
7`4O4Al17a0O0AlA7`4?41l17a0O0@l@7`4?41l13a0O0@l@7`4?01l13a0O0@l07`4?01l13`0O0@l0
7`0?01l13`803`0401l03`0?00l2ool00`0?ooooo`0Fool000ooo`0300ooo`0?00803`0540l03`0?
00l@3`0300l0BA0?00l@3`0?40l03a0?00l@3`0?40l13a0?00l@7`4?40l13a0O0@l@3`4?41l13a0O
0@l@7`4?41lA3a0O0@l@7a4?41l13a0O4@l@7`4?41lA3a0O0@l@7`4?41l13a0O0@l@7`4?40l13a0O
0@l@3`0?41l13a0?00l@3`4?40l03a0?00l@3`0?40l03a0?00<03`0540l03`0?00l@3`0200l2ool0
0`0?ooooo`0Fool000ooo`0300ooo`0?00@03`1A0@l03`0?01l13`0?0@l07`4?00l13`0O0@l07`4?
01l13`0O0@l07`4?41l13`0O0@l@7`4?41l13a0O0@l@7`4?41l13a0O0@lA7`4?41l13a4O0@l@7`4?
4Al13a0O0@lA7`4?41l13a0O0@l@7`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?01l13`0O0@l07`4?
01l13`0?0@l07`4?00<03`030@l03`0?00803`03ool03`0?01Soo`003ooo00<03ooo00l0300?03d@
3`0?00l03a0?00l@3`0?40l03a0?00l@3`0?41l03a0?00l@7`4?40l03a0O0@l@3`0?41l13a0?00l@
7`4?40l03a0O0@l@3`0?41l13a0?00l@7`4?40l03a0O0@l@3`0?41l03a0?00l@7`0?40l03a0?00l@
3`0300l01A0?00l03`0?40l0300?0_oo00<03oooool05_oo0008ool300l4ool00`0?ool03`0500l0
1P0O00l03`0?01l13`803`1201l13`0O00l07`4?01l13`0O0@l07`4?01l13a0O0@l07`4?41l13`0O
0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l@7`4?01l13a0O
0@l07`4?41l13`0O0@l07`4?01l13`0O00l07`4?0P0?00D07`4?00l03`0O00L03`;oo`0300oooooo
01Koo`002?oo00<03oooool01?oo00<03ooo00l01P0?00D@3`0?00l03a0?00<03`1140l03a0?00l@
3`0?40l03a0?00l@3`4?40l03a0?0@l@3`0?41l13a0?00l@7`4?40l03a0O0@l@3`0?41l13a0?00l@
7`4?40l03a0O0@l@3`0?41l13a0?00l@7`4?40l03a0?0@l@3`0?40l03a0?00l@3`0?40l03a0?00l@
3`0300l01A0?00l03`0?40l01P0?0_oo00<03oooool05_oo0009ool00`0?ooooo`03ool00`0?ool0
3`0800l01@4?00l03`0?0@l00P0?03X07`4?00l13`0O0@l03`4?01l13`0?0@l07`4?01l13`0O0@l0
7`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l0
7`4?01l13`0O0@l03`4?01l13`803`0301l13`0?00803`050@l03`0?00l13`0800l2ool00`0?oooo
o`0Fool000Soo`0300ooo`0?00Coo`0300ooo`0?01003`0540l03`0?00l@3`0300l0:A0?00l@3`0?
40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?
40l03a0?00l@3`0?40l00`0?00D@3`0?00l03a0?00<03`0340l03`0?00h03`03ool03`0?01Soo`00
2Ooo0P0?1?oo00<03ooo00l05_oo00<03oooool05Ooo00<03oooool05?oo00<03oooool05Ooo00<0
3ooo00l06?oo000?oomS00lHool008[oo`00R_oo002:ool000Koo`0300oooooo087oo`001ooo00<0
3oooool0P?oo0007ool00`0?ooooo`02ool01@0?ool03ooo00l00ooo00<03ooo00l0Looo0006ool0
0`0?ool03`03ool01@0?ool03ooo00l00ooo0P0?M?oo0006ool00`0?ool03`03ool01@0?ool03ooo
00l01?oo00<03oooool0L_oo0006ool00`0?ool03`03ool0100?ool03`0?1?oo0P0?M?oo002:ool0
00coo`0300oooooo07_oo`00R_oo002:ool008[oo`00R_oo002:ool008[oo`00R_oo002:ool008[o
o`00\
\>"],
  ImageRangeCache->{{{0, 136.625}, {136.625, 0}} -> {-2.728424, -2.856153, 
  0.053221, 0.053221}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Near-Field Solution", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(a = 50\ nano; \)\)], "Input"],

Cell[BoxData[
    \(\(sol = 
      Solve[{x\^2 + y\^2 == a\^2\ \((1 - u\^2)\)\ \((1 + v\^2)\), 
          z == a\ u\ v}, {u, v}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(uu = sol\[LeftDoubleBracket]4, 1, 2\[RightDoubleBracket]; \n
    vv = sol\[LeftDoubleBracket]4, 2, 2\[RightDoubleBracket]; \)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Electric Field", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(clear[Eax]; \)\), 
    \(\(Eax[x_, y_, z_] = 
      \(k\ z - \(1\/\[Pi]\) 
              \((2\ k\ a\ u\ 
                  \((1 + v\ ArcTan[v] + 1\/\(3\ \((u\^2 + v\^2)\)\) + 
                      \(x\^2 - y\^2\)\/\(3\ a\^2\ \((u\^2 + v\^2)\)\ 
                          \((1 + v\^2)\)\^2\))\))\) /. {u \[Rule] uu, 
            v \[Rule] vv}\) /. case; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Eay]; \)\), 
    \(\(Eay[x_, y_, z_] = 
      \(\(-\(\(4\ k\ x\ y\ u\)\/\(3\ \[Pi]\ a\ \((u\^2 + v\^2)\)\ 
                  \((1 + v\^2)\)\^2\)\)\) /. {u \[Rule] uu, v \[Rule] vv}
            \) /. case; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Eaz]; \)\), 
    \(\(Eaz[x_, y_, z_] = 
      \(\(4\ k\ x\ v\)\/\(3\ \[Pi]\ \((u\^2 + v\^2)\)\ \((1 + v\^2)\)\) /. {
            u \[Rule] uu, v \[Rule] vv}\) /. case; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Ea]; \)\), 
    \(\(Ea[x_, y_, z_] = {Eax[x, y, z], Eay[x, y, z], Eaz[x, y, z]}; \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Electric Field in the $x-y$ Plane"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Fig16x8 = 
      Table[DensityPlot[
          Evaluate[Abs[Eax[x\ a, y\ a, \(10\^jj\ a\)\/1000]\^2]], {x, \(-2\), 
            2}, {y, \(-2\), 2}, 
          AxesLabel \[Rule] {"\<x in a\>", "\<y in a\>"}, 
          PlotLabel \[Rule] jj, Evaluate[opt1], 
          DisplayFunction \[Rule] Identity], {jj, 1, 3, 1}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{Fig16x8\[LeftDoubleBracket]1\[RightDoubleBracket], 
          Fig16x8\[LeftDoubleBracket]2\[RightDoubleBracket], 
          Fig16x8\[LeftDoubleBracket]3\[RightDoubleBracket]}]]; \)\)], "Input",\

  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.31746 0.00744 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.02381 0.00744 0.321429 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25962 -0.0125 -7 -12 ]
[.25962 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.74038 -0.0125 -4 -12 ]
[.74038 -0.0125 4 0 ]
[.98077 -0.0125 -4 -12 ]
[.98077 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25962 -14 -6 ]
[-0.0125 .25962 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .74038 -8 -6 ]
[-0.0125 .74038 0 6 ]
[-0.0125 .98077 -8 -6 ]
[-0.0125 .98077 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000001090706060606
060709010000000000000000000000000000000000
00000000000000000000000000000000200F0D0C0C0C0C0C
0C0C0D0F2000000000000000000000000000000000
000000000000000000000000000001281713121212121212
121212131728010000000000000000000000000000
00000000000000000000000000013D1F1918171717171717
17171718191F3D0100000000000000000000000000
00000000000000000000000000822A201D1C1B1B1B1B1B1B
1B1B1B1C1D202A8200000000000000000000000000
0000000000000000000000000C412922201F1F1E1E1E1E1E
1E1E1F1F202229410C000000000000000000000000
000000000000000000000000AA3729252322212121212121
2121212223252937AA000000000000000000000000
00000000000000000000000265352A272524242424242424
2424242425272A3565020000000000000000000000
00000000000000000000001254342B282626252525252525
2525252626282B3454120000000000000000000000
00000000000000000000008F4E342C292727262626262626
2626262727292C344E8F0000000000000000000000
0000000000000000000000FF4D342C292827272726262626
2627272728292C344DFF0000000000000000000000
00000000000000000000008F4E342C292727262626262626
2626262727292C344E8F0000000000000000000000
00000000000000000000001254342B282626252525252525
2525252626282B3454120000000000000000000000
00000000000000000000000265352A272524242424242424
2424242425272A3565020000000000000000000000
000000000000000000000000AA3729252322212121212121
2121212223252937AA000000000000000000000000
0000000000000000000000000C412922201F1F1E1E1E1E1E
1E1E1F1F202229410C000000000000000000000000
00000000000000000000000000822A201D1C1B1B1B1B1B1B
1B1B1B1C1D202A8200000000000000000000000000
00000000000000000000000000013D1F1918171717171717
17171718191F3D0100000000000000000000000000
000000000000000000000000000001281713121212121212
121212131728010000000000000000000000000000
00000000000000000000000000000000200F0D0C0C0C0C0C
0C0C0D0F2000000000000000000000000000000000
000000000000000000000000000000000001090706060606
060709010000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744 0.64881 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25962 -0.0125 -7 -12 ]
[.25962 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.74038 -0.0125 -4 -12 ]
[.74038 -0.0125 4 0 ]
[.98077 -0.0125 -4 -12 ]
[.98077 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25962 -14 -6 ]
[-0.0125 .25962 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .74038 -8 -6 ]
[-0.0125 .74038 0 6 ]
[-0.0125 .98077 -8 -6 ]
[-0.0125 .98077 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000001010101
010000000000000000000000000000000000000000
000000000000000000000000000000000101020202020202
020202010100000000000000000000000000000000
00000000000000000000000000000102030507090A0A0A0A
0A0907050302010000000000000000000000000000
000000000000000000000000010203070D151B1D1E1E1E1E
1E1D1B150D07030201000000000000000000000000
00000000000000000000000102050C1C2F37383838383838
383838372F1C0C0502010000000000000000000000
00000000000000000000010205102C4E5655535353535353
53535355564E2C1005020100000000000000000000
0000000000000000000002050F336A75716E6C6C6C6C6C6C
6C6C6C6E71756A330F050200000000000000000000
00000000000000000001030B2A78958E8784828282828282
82828284878E95782A0B0301000000000000000000
00000000000000000102061863B0ACA19A97959595959595
959595979AA1ACB063180602010000000000000000
000000000000000001030B32A9CCBCB0A9A6A5A4A4A4A4A4
A4A4A5A6A9B0BCCCA9320B03010000000000000000
00000000000000000104125AD8DAC7BBB5B2B1B1B0B1B1B1
B0B1B1B2B5BBC7DAD85A1204010000000000000000
000000000000000002061A83F1E3CFC4BEBBBAB9B9B9B9B9
B9B9BABBBEC4CFE3F1831A06020000000000000000
0000000000000000020722A1FCE8D4C9C3C0BFBFBFBFBFBF
BFBFBFC0C3C9D4E8FCA12207020000000000000000
0000000000000001020824ABFFE9D5CBC5C2C1C0C0C0C0C0
C0C0C1C2C5CBD5E9FFAB2408020100000000000000
0000000000000000020722A1FCE8D4C9C3C0BFBFBFBFBFBF
BFBFBFC0C3C9D4E8FCA12207020000000000000000
000000000000000002061A83F1E3CFC4BEBBBAB9B9B9B9B9
B9B9BABBBEC4CFE3F1831A06020000000000000000
00000000000000000104125AD8DAC7BBB5B2B1B1B0B1B1B1
B0B1B1B2B5BBC7DAD85A1204010000000000000000
000000000000000001030B32A9CCBCB0A9A6A5A4A4A4A4A4
A4A4A5A6A9B0BCCCA9320B03010000000000000000
00000000000000000102061863B0ACA19A97959595959595
959595979AA1ACB063180602010000000000000000
00000000000000000001030B2A78958E8784828282828282
82828284878E95782A0B0301000000000000000000
0000000000000000000002050F336A75716E6C6C6C6C6C6C
6C6C6C6E71756A330F050200000000000000000000
00000000000000000000010205102C4E5655535353535353
53535355564E2C1005020100000000000000000000
00000000000000000000000102050C1C2F37383838383838
383838372F1C0C0502010000000000000000000000
000000000000000000000000010203070D151B1D1E1E1E1E
1E1D1B150D07030201000000000000000000000000
00000000000000000000000000000102030507090A0A0A0A
0A0907050302010000000000000000000000000000
000000000000000000000000000000000101020202020202
020202010100000000000000000000000000000000
000000000000000000000000000000000000000001010101
010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744 0.97619 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25962 -0.0125 -7 -12 ]
[.25962 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.74038 -0.0125 -4 -12 ]
[.74038 -0.0125 4 0 ]
[.98077 -0.0125 -4 -12 ]
[.98077 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25962 -14 -6 ]
[-0.0125 .25962 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .74038 -8 -6 ]
[-0.0125 .74038 0 6 ]
[-0.0125 .98077 -8 -6 ]
[-0.0125 .98077 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000001010102020203030304040405050505050605
050505050404040303030202020101010000000000
000000000101010202030304040505060606070707070707
070707060606050504040303020201010100000000
0000000101020202030404050506070708080909090A0A0A
090909080807070605050404030202020101000000
000001010202030304050506070809090A0B0C0C0C0D0D0D
0C0C0C0B0A09090807060505040303020201010000
000101020203040405060708090A0B0C0D0E0F1010101010
10100F0E0D0C0B0A09080706050404030202010100
01010202030404050608090A0C0D0E101112131415151515
1514131211100E0D0C0A0908060504040302020101
0102020304050607080A0B0D0F1012141617191A1A1B1B1B
1A1A1917161412100F0D0B0A080706050403020201
01020304050607080A0C0E10121517191C1E1F2122222322
22211F1E1C19171512100E0C0A0807060504030201
020303040607090A0C0F1114171A1D20232528292B2C2C2C
2B29282523201D1A1714110F0C0A09070604030302
0203040507080A0D0F1215191C2024282C2F323436373737
3634322F2C2824201C1915120F0D0A080705040302
03040506080A0C0F12161A1E23282D31363A3E4043444444
43403E3A36312D28231E1A16120F0C0A0806050403
030506080A0C0F12161A1F252B31373D42474C4F52535453
524F4C47423D37312B251F1A16120F0C0A08060503
040507090B0E11151A1F252C333A424950565B6063656565
63605B565049423A332C251F1A15110E0B09070504
0506080A0D1014191E252C343D464F575F676D7276787978
76726D675F574F463D342C251E1914100D0A080605
0507090B0E12171C232B333D47525C66707980868A8D8D8D
8A86807970665C52473D332B231C17120E0B090705
06080A0D10151A2028313B46525E6A76818B939A9FA2A3A2
9F9A938B81766A5E52463B3128201A15100D0A0806
06080B0E12171D242D37424F5D6B7986929DA6AEB3B6B7B6
B3AEA69D9286796B5D4F42372D241D17120E0B0806
07090C0F14192028323D4A5867778695A2AEB9C1C6CACBCA
C6C1B9AEA295867767584A3D32282019140F0C0907
070A0D10151B222B36425160718292A2B1BEC9D2D8DBDDDB
D8D2C9BEB1A2928271605142362B221B15100D0A07
080A0D11161D242E39475667798B9DAEBDCBD7E0E6EAEBEA
E6E0D7CBBDAE9D8B79675647392E241D16110D0A08
080A0E12171E26303C4A5B6C7F92A5B7C7D5E1EAF1F5F6F5
F1EAE1D5C7B7A5927F6C5B4A3C30261E17120E0A08
080B0E12181F27313E4D5D6F8396AABCCDDBE7F1F8FCFDFC
F8F1E7DBCDBCAA96836F5D4D3E31271F18120E0B08
080B0E12181F27323F4D5E718498ABBECEDDE9F3FAFEFFFE
FAF3E9DDCEBEAB9884715E4D3F32271F18120E0B08
080B0E12181F27313E4D5D6F8396AABCCDDBE7F1F8FCFDFC
F8F1E7DBCDBCAA96836F5D4D3E31271F18120E0B08
080A0E12171E26303C4A5B6C7F92A5B7C7D5E1EAF1F5F6F5
F1EAE1D5C7B7A5927F6C5B4A3C30261E17120E0A08
080A0D11161D242E39475667798B9DAEBDCBD7E0E6EAEBEA
E6E0D7CBBDAE9D8B79675647392E241D16110D0A08
070A0D10151B222B36425160718292A2B1BEC9D2D8DBDDDB
D8D2C9BEB1A2928271605142362B221B15100D0A07
07090C0F14192028323D4A5867778695A2AEB9C1C6CACBCA
C6C1B9AEA295867767584A3D32282019140F0C0907
06080B0E12171D242D37424F5D6B7986929DA6AEB3B6B7B6
B3AEA69D9286796B5D4F42372D241D17120E0B0806
06080A0D10151A2028313B46525E6A76818B939A9FA2A3A2
9F9A938B81766A5E52463B3128201A15100D0A0806
0507090B0E12171C232B333D47525C66707980868A8D8D8D
8A86807970665C52473D332B231C17120E0B090705
0506080A0D1014191E252C343D464F575F676D7276787978
76726D675F574F463D342C251E1914100D0A080605
040507090B0E11151A1F252C333A424950565B6063656565
63605B565049423A332C251F1A15110E0B09070504
030506080A0C0F12161A1F252B31373D42474C4F52535453
524F4C47423D37312B251F1A16120F0C0A08060503
03040506080A0C0F12161A1E23282D31363A3E4043444444
43403E3A36312D28231E1A16120F0C0A0806050403
0203040507080A0D0F1215191C2024282C2F323436373737
3634322F2C2824201C1915120F0D0A080705040302
020303040607090A0C0F1114171A1D20232528292B2C2C2C
2B29282523201D1A1714110F0C0A09070604030302
01020304050607080A0C0E10121517191C1E1F2122222322
22211F1E1C19171512100E0C0A0807060504030201
0102020304050607080A0B0D0F1012141617191A1A1B1B1B
1A1A1917161412100F0D0B0A080706050403020201
01010202030404050608090A0C0D0E101112131415151515
1514131211100E0D0C0A0908060504040302020101
000101020203040405060708090A0B0C0D0E0F1010101010
10100F0E0D0C0B0A09080706050404030202010100
000001010202030304050506070809090A0B0C0C0C0D0D0D
0C0C0C0B0A09090807060505040303020201010000
0000000101020202030404050506070708080909090A0A0A
090909080807070605050404030202020101000000
000000000101010202030304040505060606070707070707
070707060606050504040303020201010100000000
000000000001010102020203030304040405050505050605
050505050404040303030202020101010000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{320.75, 100.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006A0000OQ000`40l00?003`ooooT_oo003ooonB
ool00?oooi;oo`00ooooT_oo003ooonBool00?oooi;oo`00ooooT_oo003ooonBool00?oooi;oo`00
ooooT_oo003ooonBool00?oooi;oo`00ooooT_oo000Kool300l@ool300l?ool00`0?ooooo`0?ool3
00l@ool300lfool300l@ool300l?ool00`0?ooooo`0?ool300lAool300leool300l@ool300l?ool0
0`0?ooooo`0@ool300l@ool300lRool001_oo`0300oooooo017oo`0300oooooo00goo`0300ooo`0?
017oo`0300oooooo00ooo`0300oooooo03Koo`0300oooooo017oo`0300oooooo00goo`0300ooo`0?
017oo`0300oooooo013oo`0300oooooo03Goo`0300oooooo017oo`0300oooooo00goo`0300ooo`0?
01;oo`0300oooooo00ooo`0300oooooo02;oo`005_oo0`0?0ooo00<03oooool02_oo0`0?0ooo00<0
3oooool03Ooo00<03ooo00l04Ooo00<03oooool04?oo00<03oooool0<?oo0`0?0ooo00<03oooool0
2ooo0`0?0_oo00<03oooool03Ooo00<03ooo00l04Ooo00<03oooool04Ooo00<03oooool0<?oo0`0?
0_oo00<03oooool02ooo0`0?0_oo00<03oooool03Ooo00<03ooo00l04_oo00<03oooool04?oo00<0
3oooool08Ooo000Kool00`0?ool03`0Aool00`0?ooooo`0=ool00`0?ool03`0Aool00`0?ooooo`0?
ool00`0?ool03`0fool00`0?ool03`0Aool00`0?ooooo`0=ool00`0?ool03`0Aool00`0?ooooo`0@
ool00`0?ool03`0eool00`0?ool03`0Aool00`0?ooooo`0=ool00`0?ool03`0Bool00`0?ooooo`0?
ool00`0?ool03`0Rool001coo`803a3oo`803a3oo`0300oooooo00ooo`803a;oo`803cOoo`803a3o
o`803a3oo`0300oooooo00ooo`803a?oo`803cKoo`803a3oo`803a3oo`0300oooooo013oo`803a;o
o`803b;oo`00ooooT_oo003ooonBool006goo`0300ooo`0?00?oo`0500ooo`0?ool03`03ool00`0?
ool03`1bool00`0?ool03`03ool01@0?ool03ooo00l00ooo00<03ooo00l0L_oo00<03ooo00l00ooo
00H03oooool03ooo00l3ool00`0?ool03`0<ool0017oo`<03e[oo`0300oooooo00;oo`0500ooo`0?
ool03`03ool200lGool300mJool00`0?ooooo`02ool01@0?ool03ooo00l00ooo0P0?6?oo0`0?FOoo
00<03oooool00_oo00H03oooool03ooo00l3ool200l=ool0017oo`0300oooooo00Cooe403`Goo`03
00oooooo00;oo`0500ooo`0?ool03`04ool00`0?ooooo`0Eool00`0?ooooo`04oomB00l4ool00`0?
ooooo`02ool01@0?ool03ooo00l01?oo00<03oooool05_oo00<03oooool01?ooD@0?1?oo00<03ooo
ool00_oo00H03oooool03ooo00l4ool00`0?ooooo`0;ool000goo`<03`;oo`0300oooooo00?oo`03
00ooo`0?01;oo`0300oooooo013oo`0300oooooo017oo`0300oooooo013oo`803`Coo`0300ooo`0?
00?oo`0400ooo`0?00l4ool200lCool300l2ool00`0?ooooo`03ool00`0?ool03`0Bool00`0?oooo
o`0@ool00`0?ooooo`0Aool00`0?ooooo`0@ool00`0?ool03`03ool00`0?ool03`03ool0100?ool0
3`0?1?oo0P0?4ooo0`0?0ooo00<03oooool00ooo0P0?4_oo00<03oooool04Ooo00<03oooool04?oo
00<03oooool04?oo00<03ooo00l00ooo00<03ooo00l00ooo00<03oooool00P0?1?oo0P0?3Ooo000A
ool00`0?ool03`04oom?00l00ooo00ooo`0Zool00`0?ool03`04oomB00l[ool00`0?ool03`04ool0
0`0?ool03`0900l01P0O00l03`0?01l13`803`0Z01l13`0O00l07`4?01l13`0O0@l07`4?01l13a0O
0@l07`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?01l13`0O0@l07`0?01l13`0O00l07`4?0P0?00D0
7`0?00l03`0O00`03b7oo`004_oo0P0?1?oo00<03ooo00l0C00?00?oo`0?ool02Ooo00<03oooool0
7ooo0P0?1?oo00<03ooo00l0C@0?00?oo`0?ool02?oo00<03oooool08?oo0P0?1?oo00<03ooo00l0
2P0?00D@3`0?00l03a0?00<03`0Y40l03a0?00l@3`0?40l03a0?00l@3`4?40l03a0?0@l@3`0?41l1
3a0?00l@3`4?40l03a0?0@l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0300l01A0?00l03`0?40l0
2@0?00?oo`0?ool02?oo00<03oooool05Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0aool00`0?
ool03`1=00l00ooo00ooo`0aool00`0?ool03`0800l0=@4?00l03`0O0@l03`4?01l13`0?0@l07`4?
01l13`0O0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l@7`4?
01l13`0O0@l07`4?00l13`0O0@l00P0?00<07`4?00l00P0?00<13`0?00l01@0?00?oo`0?ool08?oo
000Hool00`0?ool03`1<00l00ooo00ooo`0aool00`0?ool03`1=00l00ooo00ooo`0aool00`0?ool0
3`0<00l0;A0?00l03`0?40l03a0?00l@3`0?41l03a0?00l@7`4?40l03a0O0@l@7`0?41l13a0O00l@
7`4?41l03a0O0@l@7`0?41l13a0?00l@7`0?40l03a0?00l@3`0300l00a0?00l03`0=00l00ooo00oo
o`0Pool001Soo`0300ooo`0?04`03`03ool03ooo037ooe803c;oo`0300ooo`0?00D03`0601l03`0?
00l07`4?0P0?03807`4?01l13`0O0@l@7`4?01l13a0O0@l@7`4?41l13a0O0Al@7`4?41l17a4O0@l@
7`4O4Al13a0O0Al@7`4?41l13a0O0@l@7`4?41l13`0O0@l@7`4?01l13`0O00l07`4?0P0?00D07`4?
00l03`0O00H03`03ool03ooo023oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<Ooo00<03ooo00l0
C@0?00?oo`0?ool0<Ooo00<03ooo00l00P0?00D@3`0?00l03a0?00<03`0i40l03a0?00l@3`0?40l1
3a0?0@l@7`4?41lA3a0O0@l@7a4?41lA3a0O4@l@7a4?41lA3a4O4@l@7a4?41lA3a0O4@l@7a4?41lA
3a0O0@l@7a4?41l13a0?00l@7`4?40l03a0?00l@3`0?40l03a0?00<03`0340l03`0?00<03`03ool0
3ooo023oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<Ooo00<03ooo00l0C@0?00?oo`0?ool0<Ooo
00<03ooo00l0100?03d13`0?00l07`4?00l13`0O0@l07`4?01l13`0O0@l07`4?41l13a0O0@lA7`4?
41l17a4O0AlA7`4O4Al17a4O0AlA7`4O4Al17a4O0AlA7`4O4Al13a0O0@lA7`4?41l13a0O0@l07`4?
01l13`0O0@l07`4?01l13`0200l00`0O0@l03`0600l00ooo00ooo`0Pool001Soo`0300ooo`0?04`0
3`03ool03ooo037ooe803c;oo`0300ooo`0?00@03`0I40l03`0?00l@3`0?40l03a0?00l@7`4?41l0
3a0O0@l@7a4?41l13a0O4@l@7a4?41l00a4O00D@7a4O4AlA7a0O00<A7`0541lA7a4O4Al@7`024Al0
4Q4?41lA3a0O0@l@7a4?41l13a0O00l@7`4?40l03a0?00l@3`<03`0340l03`0?00D03`03ool03ooo
023oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<Ooo00<03ooo00l0C@0?00?oo`0?ool0<Ooo00D0
3ooo00l03`0O00<03`0D01l13`0O00l07`4?01l13`0O0@l@7`4?41l13a0O0@l@7`4O4Al17`<A7`03
0AlA7a4O014A7`0C0AlA7`4O4Al13a0O0Al@7`4?41l13a0O0@l07`4?01l13`0O0@l00P0?00D07`4?
00l03`0O00803`03ool03ooo023oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<Ooo00<03ooo00l0
C@0?00?oo`0?ool0<Ooo00<03ooo00l00P0?01D@3`0?00l03a0?00l@3`0?40l03a0O0@l@7`4?41l1
3a0O4@l@7a4?41l00Q4O00<A3a4O4Al00Q4O00dQ7a4O8AlA7b4O4AlQ7a4O8AlA7b4O4AlQ7`034Al0
1B4O4AlA7a4?41l00Q4O018A3a0O4@l@7`4?41l13a0O0@l@3`0?40l03a0?00l@3`0?40l300l0110?
00ooo`0?8Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0aool00`0?ool03`1=00l00ooo00ooo`0a
ool0100?ool03`4?0P0?01@07`4?00l13`0O0@l07`4?01l13a0O0@l@7`4?4Al13a4O0AlA7`4O1A4O
014B7a4O4AlA;a8O4BlB7a4_4QlA;a8O4BlB7a4_4QlA;a8O00DA7`0C0AlA7`4O4Al17a0O0AlA7`4?
41l13a0O0@l07`4?01l13`0O0@l00P0?00<07`4?00l00P0?00?oo`0?ool08?oo000Hool00`0?ool0
3`1<00l00ooo00ooo`0aoomB00lbool0100?ool03a0?0`0?014@3`0?40l03a0?00l@7`4?41l13a0O
0@l@7a4?41lA7a0O00<A7`0I8AlA7b4_4AlQ7a4O8BlB7b4_4QlQ;a8O8BlR7b4_4QlQ;a8O8BlB7b4_
4AlQ;a4O8Al00a4O014@7a4O4AlA3a0O4@l@7`4?41l13a0O0@l@3`0?41l03a0?00<03`0640l03`0?
00ooo`0?8Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0aool00`0?ool03`1=00l00ooo00ooo`0a
ool0500?ool03`0?01l13`0O0@l07`4?41l13a0O0@l@7`4?41l17a4O0Al44Al0214_4QlQ;a8O8BlB
;b8_4Rl88Rl00b8o8RlR;`048Rl02Q8_8RlR;b8_4QlQ;a8O8BlB7a4_1Q4O00h13a0O0@l@7`4?41l1
3a0O0@l07`4?01l03`0O0P0?00?oo`0?ool08?oo000Hool00`0?ool03`1<00l00ooo00ooo`0aool0
0`0?ool03`1=00l00ooo00ooo`0aool00`0?ool03`0200l0410?00l@3`4?40l03a0O0@l@3`4?41l1
3a0O4@lA7a4?114O00TQ7a4O8BlB7b4_8QlR;b8O8Bl03R8_00XR7b4_8QlQ;a8O8AlA7b4O4AlQ7`8A
7`0>4@l@7a4?41l13a0O0@l@7`4?40l03a0?00l@3`<03`0440l03ooo00lQool001Soo`0300ooo`0?
04`03`03ool03ooo037oo`0300ooo`0?04d03`03ool03ooo037oo`0B00ooo`0O0@l03`4?01l13a0O
0@l07`4?4Al13a0O0AlA7`4O0a4O00DB7a4_4QlR;a8O00DR;`0C8blR;b<_8SlS;c<o8blb?b<o<clS
;c8o8blc?b<_8SlS;b8_8bl00b8_00LB;b8_4QlR;a8O4BlB7`034Al03@4O4Al13a0O0@lA7`4?01l1
3`0O0@l07`4?00803`0301ooo`0?027oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<OooDP0?<_oo
00@03ooo00l@3`<03`0:40l03a0O0@l@7`4?41l13a0O4@l54Al01Q8O8AlB7b4_8QlQ;`<R;`0A<RlR
;c8o8blb?b<_<SlS;c8o<blb?b<_<SlS;c8o8blb;`038Rl02B4_8RlQ;b8O8BlB7b4_4AlQ7`034Al0
3A0O4@l@7`4?41l13a0O0@l@3`0?40l03a0?00<03`03ool03ooo023oo`006?oo00<03ooo00l0C00?
00?oo`0?ool0<Ooo00<03ooo00l09@0?00D07`0?00l03`0O02<03`03ool03ooo037oo`0>00ooo`0?
00l07`4?01l13a0O0@l@7`4?41l17`DA7`054QlA;a8O8RlB;`038Rl01B<_8SlS?c<o8cl013<o00Tc
Cc@o<dld?c=?=3lcCc<o<dl01S<o00/S;b8o8blR;a8_8RlB;b4_4QlA;a8O00DA7`0>0@l@7`4?41l1
3`0O0@l07`0?01l13`0?ool03b7oo`004Ooo0`0?1?oo00<03ooo00l0C00?00?oo`0?ool0:_oo0`0?
1?oo00<03ooo00l07P0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l00a0?00l03`0L00l0
0ooo00ooo`0Zool300l4ool03P0?ool03a0?00l@3`0?41l13a0O4@l@7a4?41l34Al01B4O4AlQ;a8O
8Bl00R8_00dS;c8_<blc?c<_@clc?d=?=3m3Cd@o@dm4?`07A4l01T@o@dm4?d=?=3m3?`8c?`0:<blb
?c<_<SlS;c8_8QlR;a8O8Bl54Al03Q0O4@l@7`4?41l13a0?00l@3`0?40l03ooo00lQool001;oo`03
00oooooo00?oo`0300ooo`0?04`03`03ool03ooo02_oo`0300oooooo00?oo`0300ooo`0?01`03`05
0@l03`0?01l13`0200l01P0O0@l03`0?01l13`803`0301l13`0?00803`030@l03`0?01X03`03ool0
3ooo02_oo`0300oooooo00?oo`0J00ooo`0O0@l07`4?01l13a0O0@l@7`4O4Al17a4O4QlA7a8O4BlB
7b8_4RlR;b<_<SlS;`<c?`09=3lcCc@o@dld?dA?=4m4CcA?00M4C`06=4m4CcA?@dld?c=?0S<o00@S
;c<o8blb?`8R;`0F4RlR;a8O4BlB7a4O0AlA7`4O4Al13a0O0@l@7`4?01l13`0O0@l07ooo00lQool0
00goo`<03`;oo`0300oooooo00?oodl03`03ool03ooo02Koo`<03`;oo`0300oooooo00?ooal03`0E
40l03a0O0@l@7`4?41l13a0O4@l@7`4?41lA3a0O0@l@7`0?41l03a0?01h03bKoo`<03`?oo`0300oo
oooo00?oo`0<00ooo`0?40l03a0O0@l@7a4?41lA3a0O0a4O00DQ7a4O8BlB7b4_008R;`038blb?c<o
008c?`0=@dm4?dA?A3mDCdA?E5m5CeAOEEmDGeE?E5l00UEO00IECeAOEEmDGdE?E5l2A4l02T@o@dm4
?d<o<clb?c<o<SlR;c8_0R8_00<B7b4O4Al00Q4O00T@7a4O41l13a0O0@l@7`4?40l01@0?8Ooo000B
ool00`0?ooooo`03ool00`0?ool03`1<00l00ooo00ooo`0[ool00`0?ooooo`03ool00`0?ool03`0I
00l06P0O0@l07`0?01l13a0O0@l@7`4O4Al13a0O0AlA7`4?41l17a0O0@l@7`4?01l03`0O0@lJ00l0
0ooo00ooo`0[ool00`0?ooooo`03ool0300?ool07`4?01l13a0O0@l@7`4O4Al17`<A7`094QlA;a8_
8BlB;b8_8blb?b<_008c?`03<dld?d=?00=4C`04A5m5CeEOAEl7EEl044EOEEm5GeAOADm4GdE?A4ld
?d=?=3lcCb<o<clS?b8o0b8_00<Q;a8O4Bl0114O00`17a4O0@l@7`4?41l13`0O0@l07ooo00lQool0
017oo`803`Goo`0300ooo`0?01d03`0A40lA3a0O0@l@3`0?41l13a0?00l@7`4?40l13a0O0@l@3`0N
00l00ooo00ooo`0Zool200l5ool00`0?ool03`0F00l01Q0?00l@3`4?40lA3`8A7`0I8BlR7b4_8QlQ
;b8O8RlR7b4_8QlR;b8O8BlR7b4_4QlQ7a4?4Al13a0?00l@3`0?40l05P0?00?oo`0?ool0:_oo0P0?
1Ooo00X03ooo00l@3`4?40l13a0O4@l@7`DA7`078BlB7b4_8Rlb;b8_<Sl00S<o00Ld?d<oA4mDCdE?
E5mEC`02EEl01FEOIUmUKfIOIFl00VI_01YVGfI_IVmVKfIOIFmEGfE_EEmUGeE?E4m5Cd=?A4m3Cc@o
<clc;c8o8Rlb;b8_8BlB7b4O0a4O00`@7a4?41l13a0O0@l@3`4?40l03ooo00lQool001Soo`0300oo
o`0?01h03`0?41l13a0O0@l07`4?41l13`0O0@l@7`4?01l13a4O01l03`03ool03ooo037oo`0300oo
o`0?01@03`0Q0@l03`0?01l13a0O0@lA7`4O4BlB7b4_4RlR;a8_8RlB;b8_4RlR;a8_8RlB;b8_4RlR
;a8O4Al17a0O0@l07`4?01P03`03ool03ooo037oo`0:00ooo`0O0@l07`4?01l13a4O0@l44Al0214_
4QlR;a8_8RlS;b8_8bl2<cl03T=?=3m4CdE?A5m5CeEOEUmEGeIOIFmFKfI_EVl3IVl01eI_IVmFKfI_
EUmEKeIO00=EG`0@ADm4GcA?A4ld?d=?<clb?b<o8RlS;b8_4QlR;a8O4Bl24Al0304O4Al17a4O0@l0
7`4?01l13`0Oool03b7oo`006?oo00<03ooo00l06`0?014Q;a4O4AlA3a0O4@l@7a4?41lA3a0O4@l@
7a4?41lA3a0O00<A7`038BlR;`0?01X03`03ool03ooo037ooaL03`0Q40l03a0O4@l@7b8O8Blc;c8o
<cm3Cc<o@clc?d=?<cm3?c<o@dlc?d<o<cm3Cc<o@clc?d<o<blb?b8O8BlA3a0O01X03c;oo`0<00oo
o`0?40l03a0O0@l@7a4O41lA7a0O0Q4O00<B7b4_8Rl00R8_00Db?c<_<cld?d=?0094C`05ADmUGeEO
IFmFG`02IVl00gIoIfmfO`03Mgl02HMoMgmgOgMoMWmgOgIoIfmfO`02IVl025IOIEmEGeAOADmDCdA?
@dl2<cl023<_<SlR;b4_8RlQ;a8O8Al24Al02a4?41lA3a0O0@l@3`0?41l03ooo00l08Ooo000Hool0
0`0?ool03`0H00l01P0O8blb?a8O4BlB7`8A7`054BlA7a4O4AlA;`034Al02a4_4AlA7a4O4BlB7a4O
4QlA;b<_<Sl06@0?00?oo`0?ool0<Ooo00<03ooo00l04@0?00X07`4?00l13`0O4Alc?b<_E5m5G`EE
G`05AEmEGeEOEEm5G`03EEl01DEOEEmEGeEOAEl015EO00UDGdEO<clS;a4O0@l@7`0?01l04`0?00?o
o`0?ool0<Ooo00P03ooo41l13a0O0Al@7`4O114O00LA;a8O8RlR;b8o8clb?`02<cl00cA?A5m4C`02
EEl06FE_IVmVKfMoMWmgOgN?N7n8SgR?R9n9SiRORHn8WhV?V9n8ShROR8n7SgQoMhmhOgIo009VK`07
EUmUKdEOEEm5CdA?=3l00S<o00Lb?b8_8SlB;b8_4QlA;`024Al02P4O41l17a0O0@l@7`4?41ooo`0?
8Ooo000Hool00`0?ool03`0I00l01C8_8RlQ;a4O8Al00a4O00DQ7a4O4AlA7b4O00<A7`0:8AlA7a4O
4AlQ7a4O8BlB7c8_8RlI00l00ooo00ooo`0aool00`0?ool03`0B00l02A0?00l@3`4?4Alc;c8oADmD
G`03EEl01EAOEEmEGeE?E5l00UEO00IECeAOEEmEGeE?E5l2EEl02UE?EEmEGeEOADmDGc<_<SlA3a0?
0`0?00<@3`0?00l0400?00?oo`0?ool0<Ooo00X03ooo00l@7`4?41lA3a0O4@l@7`8A7`034QlQ7b8O
008R;`0:<Slc;c<o<cm3CdA?E4mECeAOEUl2IVl01GIoMfmgOgMoQhl00hR?00FHShR?V8n9SiR?00>8
S`06QhmhOhN?Mgn7OgM_0VI_00MUGeIOEEmECeA?A3m3C`02<cl023<_8RlR;b4_8QlQ;a8O8Al24Al0
2A4?41lA3a0O0@l@3`0?ool03`0Qool001Soo`0300ooo`0?01L03`0M=4m4Ca8_8RlB7b4_4QlA;a8O
8BlB7a4_4QlQ;a8O4BlB7b4_4QlA;a8O8BlB7a4_4QlQ;a8_8RldC`0H00l00ooo00ooo`0aool00`0?
ool03`0B00l0:04?01lA7a4O<cmVOfM_MgmWOgIoIgmfOfM_IWmWKgIoIfmVOfM_MWmWKfIoIfmfOfM_
IWmWKgIoIfmfOfMoMgmWOfIoIflc?`4O4Al13`0O4`0?00?oo`0?ool0<Ooo01/03ooo01l13a0O0@l@
7`4O4Al17a4_4QlR;a8O8RlS;c8o8clc?c@o@dm4CeEOAEmVKeIOIWl00WMo01IhOhN?RHn8ShV?VInJ
WjV_VYnY[iZOZZnJWjV_VYnY[iVOV9n9WhR?RHn7S`9gO`0AIfmVOeIOIVm5GdAOADm3Cc@o<clS;c8o
4RlR;a8O8RlB7`034Al0204O41l13a0O0@l07ooo00lQool001Soo`0300ooo`0?01L03`0M@dm4?b8_
8QlQ;a4O8BlB7b4O4AlQ;a8O8AlA7b4_4QlQ7a4O8BlB7b4O4AlQ;a8O8BlB7b8_8Qm3C`0H00l00ooo
00ooo`0aoolE00l01a0O00l@7a4O<cmVKgI_009gO`0FIfmfOfM_MWmWKgI_IVmfOfM_MVmVKgIoIfmf
KfI_MWmWKgI_IVmfOfM_MWl2Mgl00fI_MVlc?`024Al00a0?00l03`0D00lbool0200?ool13a0O0@l@
7`4?41l34Al05b4O4QlQ;b8O<RlR;c<o<bm3Cc@oA4mECeAOEUmUKfI_MWmgOhN?N7nHShR?V9l00iVO
00NY[iZOZJnJWjV_VYnYW`02VIl04XV?V9n8ShR?N7mfOgMoMVmVKfE_EUmDGdA?E4ld?d=?<blb;`8R
;`0?8QlQ;a8O8AlA7a0O4Al@7`4?41l13a0O0@ooo`0?027oo`006?oo00<03ooo00l05@0?00AhShR?
8blb?`8R;`0E4RlQ;a8_8RlB7b4_4RlR;a8O8BlB;b8_4QlQ;a8_8RlB7b4_4RlR;a8_00<R;`038bn7
SgR?01H03`03ool03ooo037oo`0300ooo`0?01403`0:01l17a4O8blb?gMoVIn9WhRORHl3R8l04GR?
R8mhOhN?N8n8SgQoQhmhShR?N7n7SgR?R8mhOhN?N8l00XR?00Z8WhV?VIn9WgN?8blb?`4O41l13a80
3`03ool03ooo037oo`0l00oooa0O0@l@7`4O4Al17a4_4AlQ;a8O8RlB;b8_8clb?c@o<dldCdA?AEmU
KeIOIWmWKgMoN8n8ShVOV9nJWiV_VZnZ_j^_^[n[[k^oZknk_j^o^kn[[kZoZjnZ[iZ_VJnJWiRON8n8
SgQoMgmWKfIoEUmEGdEO0TA?00PcCb<o<SlS;b8_4RlR;a8O1A4O00H13a0O0@l@7ooo00lQool001So
o`0300ooo`0?01@03`054@m3Cd@o<SlS;`038Rl04R8O8BlR;b8_8QlQ;b8O8RlR7b4_8QlR;b8O8BlR
7b8_8QlQ;`8R;`088QlR;b8_<Sm4?d=?4@l@7a@03`03ool03ooo037oo`0300ooo`0?00h03`0940l0
3`0?0@lQ7a8OIVmVGkZ_00:Z[`0FVYnYWiVOVInISiROVHnHWiV?V9nISiROVHnHWiV?V9nISiROVHnH
WiV?V9l2VIl02YZOZInZ[jZ_ZjmUKfIO8BlB7a0?0`0?00<@3`0?00l0300?00?oo`0?ool0<Ooo00L0
3ooo0@l@7`4?41lA3`024Al03B4O4QlQ;b8O8BlR;c<o<bm3Cd@oE5m5CfEO009VK`9gO`0<R8nHWiV?
ZJnJWkZ_ZZnj_k^obknl_l_?0/c?00K<_l_?c<o;ckbobkl2^kl01jZ_^ZnJWiROVHn7ShR?009gO`09
MVmEGfEOADmDCd@o<clc;c8_008R;`0=8QlQ;a4O8AlA3a4O4@l@7`4?40l13ooo00l08Ooo000Hool0
0`0?ool03`0D00l01A4O=4m4Cb<_<Sl0128_014B;b8_8RlR;a8_8RlB;b8_4RlR;a8_8RlB;b8_4RlR
;a8_00DR;`058bm4CcA?4Al17`0D00l00ooo00ooo`0aool00`0?ool03`0?00l0;P0O0@l@7a8O4BmF
KfI_ZjnZ_j^_ZJnJWiVOVYnIWhVOVIn9WiVORInIWhVOVIn9WiVORInIWhVOVIn9WiVORInIWiZOZJnJ
WjZoZjnZ_eI_IVlB7b4_0@l07`4?400?00?oo`0?ool0<Ooo00H03ooo01l13a4O0Al34Al01Q8O8BlB
7b8_4RlR?`8c?`07=3m3CdE?E5mFGfI_Ifl00WMo00b8ShVOVInJWjV_ZjnZ_j^o^lnl_lc?_;l3c<l0
1Kc?c<nlclc?_;l00[^o00NZ_j^_ZJn9WiVON8n8S`02Mgl01VI_EFmFGeAOADm3C`8c?`0@8blR?b8_
8RlB7a4_4QlA7`4O4Al13a4O0@l07ooo00lQool001Soo`0300ooo`0?01@03`04ZZm3?c<o<Sl78Rl0
1B4_8RlR;b8_8Bl00b8_00DQ;b8_8RlR;b4_00LR;`03<Slc?d<o00:Z[a@03`03ool03ooo037ooa<0
3`0740lA3c<o<cnY[jZ_c<l00[^o01ZZ[kZoZZnY[jZOZJnJWjV_ZYnY[iZOZJnZWjV_VYnY[jZOZJnJ
WjV_ZYnY[jZ_ZJnZ[kZo0[^o00S<cjZ_ZZlb?c<o41l03a0?4P0?<_oo00`03ooo0@l@7a4?41lA3a0O
4AlQ7a8O8Bl28Rl06B<_@clc?dA?A3mDGeE?IFmWKgIoR7n7ShV?ZJnJWkZoZjo;_k^oblo<cmc?gLoL
gmg?00?Mg`06gLoLgmg?g=o<_l_?0[^o016[[jV_VYnHWhV?Qhn8OgIoEUmUKeE?E5m4?d<o<clb?b<_
008R;`038BlA7b4O008A7`074@l@7a4?41l13ooo00l08Ooo000Hool00`0?ool03`0D00l01jZ_=3lc
Cb<_<SlS;b8o01DR;`068SlS;b8o8blcCc@o0ZZ_500?00?oo`0?ool0<Ooo00<03ooo00l03@0?00D0
7`0?01l03a0O008c?`:Z[`05c<nk_k^oZ[n[[`03ZZl04IZ_ZZnJWjV_VZnZ[iZOZJnJ[jZ_VYnY[iZ_
ZZnJ[jV_VZl00ZZ_00FZ_j^_^knk_lc?00:Z[`8c?`040Al07`0?01l?00l00ooo00ooo`0aool01@0?
ool@7`4?41l00a4O00@A;a8O8RlB7`8R;`03<Slc?c=?0094C`0CAEmEGeI_MgmWKhN?N8nHWiZOZJn[
[kZo^knkclc?g=o=cmcOcMl01MgO01S=gmcOcLo<ckc?^lnl_kZoVYnY[hVOV9mhOhN?IgmVKeIOEEm5
GdA?<clcCb<o<Sl28Rl00a8_4BlB7`034Al01P4?41l13a0Oool03b7oo`006?oo00<03ooo00l0500?
00YVGd<o<clb?b<_<RlR;c8_8Rlb;`<R;`05<RlR;b8_8Rlb;`038Rl03C8_8RlR;b8_<RlR;c8_8Rlb
;b8_<Slc?d<o009VKa@03`03ool03ooo037oo`0300ooo`0?00h03`0;40l03a0?4AmUGeEOg=oMcmcO
c;o;c`02^kl05[^_^[n[[kZ_ZZnj_j^_^ZnZ[kZoZjnj[jZ_^[n[[kZ_ZZnj_j^_^Znk[kZo0[^o00c<
_l_?gLoLgmg?IEmFGb4O00l@3`0?40l>00l00ooo00ooo`0aool04`0?ool13a0O0@l@7a4?4AlB7b4O
8QlQ;b8_<Rlc;d=?=3mDCdA?009EG`0=MVmgOgMoR8nHSiVO^ZnZ[l^o^ko<clbog=l00]gO01KNgng_
k]o^knkOkNo^gng_g]o]gmg?g=o<_lc?^knj[jZ_ZInIWiR?R8n7O`9VK`07EEmUGdA?@dld?c8o<bl0
0R8_00<Q;a4O8Al00Q4O00LA3a0O0@l@7`4?ool03`0Qool001Soo`0300ooo`0?01803`0:01l13fI_
<clcCb<_<SlS;b8o8bl28Rl01R8o8blR;b8_8SlS;`8R;`068SlS;b8_8RlR?b<_0R8_00HR?b<_8RlS
;b8o8bl2<cl2IVlD00l00ooo00ooo`0aoolB00l02P0O0@lA7eIOEFo=gmgOcMo<ckc?0[^o01Jj_j^o
^[n[[jZoZjnj_j^_Z[n[[kZoZjnZ_j^_Z[n[[jZoZjnj_j^_^[n[_`:k_`0:c<nlcmgOcLoMgeIOEFlA
7`0O0@lB00lbool01P0?ool@7`4O4Al17`8A7`044BlB7b8_4Rl28Rl04C<o=3m3CdE?A5mFGeEOIVmg
SgQoR8n9SiV_ZjnZ_k^o^ll00/c?01_=cmg_g]o]kmkOk^oNknk_g^o^kmkOkNoMgmcOcMo<ckc?^ln[
[jZoVYnI[hV?R8mgOfI_Ifl00UEO00Y4Gc@o@dlS?c<o8blR;a8_4BlB7`<A7`060AlA7`4?41ooo`0?
8Ooo000Hool00`0?ool03`0B00l24Al035EO<clc?c8o8blb?b<_<RlR;c8_8Rlb;`<R;`05<RlR;b8_
8Rlb;`038Rl02C8_8Rlb;b8_<RlR;c8o8blb?`02<cl00eEOE5lA7`0C00l00ooo00ooo`0aool00`0?
ool03`0?00l03P4?40lB7hN?N7onknk_kNo<cmc?_;o;ck^obkl3^kl01KZo^knk_k^_^[l00[^o00Jk
[kZo^knk_k^_^[l3^kl01/^o_;o;clc?g<oMg`;^k`05Qhn8Ob4_0@l@3`0@00l00ooo00ooo`0aool0
1`0?ool13a0O4@lA7a4?008A7`0K8BlR7b4_8Rlb;c<_@dld?eAOADmUGeEOMWmhOhN?RHnHWiZO^[nk
[l_?_;oLglg?gMo^gng_00;^k`0Rknononk_o_o_kok_k^o]kmgOkMo=cmcO_;nj_k^_ZJnJWiRORHn7
SfM_MVmEGfE_ADm3Cc@o<Slc;c8_8RlQ;a8O8Al24Al01a4?41lA3a0O0@ooo`0?027oo`004ooo00<0
3oooool00_oo00<03ooo00l04P0?00>HWhV?E5l00S<o028S;c8o8blb?b<_8SlS;b8o8blR?b<_8SlS
;b8o8blR?b<_8SlS;b8o8blR?b<_<SlS;b8o8blb?b<_<dlc?eEOADnHWa<03`03ool03ooo02coo`03
00oooooo00;oo`0300ooo`0?00d03`0<01l13a0O0@lR;iZOZJo_oooog^oLglg?0/c?01K;ckbo^lnl
_k_?_;nkckbo^lnl_k_?_;nkckbo^lnl_k_?_;nkckboblnl_`;<c`03g=o=cng_00;oo`07VYnY[b8_
41l13`0O0@l03P0?00?oo`0?ool0:ooo00<03oooool00ooo00D03ooo41l17a0O00<A7`0@8BlB7b8_
4RlR?b<_<cldCd=?AEmDGeIOIFmWOhR?N8l2VIl00jZ_^knkc`02c<l00lgOgMoNk`02k^l01?kokooo
onoo0ooo00G_kokokno]kmkO00;Mg`03c<nk_k_?00:Z[`0:RInIWgR?MWmWKfE_EUmDGcA?@dl2<cl0
1R<_8SlR;b4_4QlA;`8A7`060Al@7`4?41ooo`0?8Ooo000Bool00`0?ool03`03ool00`0?ool03`0B
00l09hV?V9m5Cd<o<clb?b<_<RlS;c8_8blb;b8_<RlR;c8_8Rlb;b8_<RlR;c8_8Rlb;b8_<RlR;c8_
8Rlb;b<_<RlS;c8o<cm3?eE?E5n9S`0C00l00ooo00ooo`0[ool00`0?ool03`03ool00`0?ool03`0>
00l0<A0?0@l@7b8_ZInJWoooono]klg?g=o<_l_?_;o;ck^obknk_l^o^ko;_k^obknk_l^o^ko;_k^o
bknk_l^o^ko;_kboblo<_l_?cLoLgmkOo_ookjV_VYlR;`4?41l03a0?00h03`03ool03ooo02[oo`03
00ooo`0?00Coo`0600ooo`4?41lA3a0O0Q4O01<B7b4O8RlR;b<_<Rlc?d=?A3mDGeE?IFmFGgIoR7n7
SiV?V9nZ[`02^kl01Mc?c<oMgmg?kNl00^k_00o_kokoonooooo_o_ookokoknonknkOkNoMcmcOc<l0
0[^o0ZZ_01ZIWiV?QhmgKgIoEUmUKeE?@dm4?c8o<clb;b<_8BlB7b4_4AlQ7a4O41lA3a0O0@ooo`0?
8Ooo000Bool00`0?ool03`03oolE00l2ool085EO<clc?b<o<clS;b8o8blR?b<_8SlS;b8o8blR?b<_
8SlS;b8o8blR?b<_8SlS;b8o8blR?b<_<SlS;b8o8cl2<cl00eAOADooo`0C00l00ooo00ooo`0[ool0
0`0?ool03`03ool?00l01P4?00l03a0O0@lR;`:Z[`;oo`0Pg]oLglg?c<nlcl_?_;o;ckbo^lnl_k_?
_;nkckbo^lnl_k_?_;nkckbo^lnl_k_?_;o;ckboc<nlcmcOcLo^k`;oo`05ZjnZ[b8_41l13`0300l0
0`4?00l03`0<00l[ool00`0?ool03`04ool02P0?ool@7`4O4Al17a4O4QlQ;a8O0R8_01<R?b<_<cld
CdA?ADmDGeIOIVmWKhR?N8nIWhVOZZnl_k^oc<o<g`02gMl01MkOk_o_koooknl00ooo00O_ooookooo
ono_k^oNk`02gMl00lcO_;nk_`02ZZl2VIl03gR?MWmWOfI_EUmDGcA?A4lS?c<o8blR?a8_4BlB7`03
4Al0104O4Al13a0O0P0?8Ooo000Bool00`0?ool03`03ool00`0?ool03`0B00l2ool084E?<clc?c8o
<blb?b<_<RlR;c8o8Rlb;b8_<RlR;c8_8Rlb;b8_<RlR;c8_8Rlb;b8_<SlR;c8_8Rlb?b<_<Sl2<cl0
0dE?E5ooo`0C00l00ooo00ooo`0[ool00`0?ool03`03ool00`0?ool03`0?00l00`4?41lR;`02ZZl2
ool00ng_cLoLg`02c<l05[boblnk_l_?^ko;_k^obknk_l^o^ko;_k^obknk_l^o^ko;_k^oblnl_l_?
0/c?00?=cmcOk]l00_oo0ZZ_00<R;`4?41l0400?00?oo`0?ool0:_oo00<03ooo00l01?oo00L03ooo
0@l@7a4?4AlA3`024Al03b4_8QlQ;b8_<Slc?d=?A3mDGdE?IFmFGgIoR7n7S`02VIl00jZ_bknk_`02
c<l2gMl01Ng_k^onkoo_o_l01Ooo00Gnooo_o^oNgng_00;Mg`03c<o;_k^o00:Z[`0:V9nIWhN?Ifmf
OeIOIFm5Cd=?A3l2<cl01C8_8RlR;a8O8Bl00Q4O00LA3a0O4@l@7`4?ool03`0Qool001?oo`0300oo
oooo00;oo`0300ooo`0?01803`03V9n9SeAO008c?`0R8blb?b<_<SlS;b8o8blR?b<_8SlS;b8o8blR
?b<_8SlS;b8o8blR?b<_8SlS;c8o8blR?b<_<SlS;c=?<cmEGdE?V9lC00l00ooo00ooo`0/ool00`0?
ooooo`02ool00`0?ool03`0=00l0300O0@l@7`4?8RnJWjV_koooomk_g=o=c`;<c`0Fblnl_k_?_;nk
ckbo^lnl_k_?_;nkckbo^lnl_k_?_;nkckbo^lnl_l_?_;l2c<l00mcOcLo]k`02ool01iZOZJlR;a0O
0@l07`4?00h03`03ool03ooo02_oo`0300oooooo00?oo`0500oooa0O0Al@7`034Al0424_4QlR;a8_
8SlS;c<o=4m3CdEOE5mFGfE_Ign8SgR?0YVO00>Z[k^o^ll00/c?00?=gmgOg^l00^k_00Cnonooooo_
o`?oo`05knonono_kNoNg`02gMl00lc?^knkc`02ZZl02XVOVImhSgIoIfmUKeIOE5ldCd=?0S<o00HS
;b8o8RlQ;a8O4Bl24Al01P4O41l13a0Oool03b7oo`006?oo00<03ooo00l04P0?0Q4O029ECd<o<clb
?b<_<RlR;c8_8Rlb;b8_<RlR;c8_8Rlb;b8_<RlR;c8_8Rlb;b8_<RlR;c8_8Rlb;b8_<RlR;c8o<cm3
?`9EG`034Al03`0?01403`03ool03ooo037oo`0300ooo`0?00h03`0640l03a0O4Qn7ShQo0^k_00O]
glc?g<nl_l_?^ko;_`04^kl01[^_^[nk_k^o^jnj_`:k_`05^jnj_k^o^knk[`02^kl03l^o_;o;clc?
g<oNgok_k^n7ShQo8Bl03a0O00l@3`0>00l00ooo00ooo`0aool01P0?ool13a0O0@l@7`8A7`034QlQ
7b8O008R;`0M<Rlc;d=?=3mDCdA?IFmFGgI_N7n7ShV?V9nZWkZo^jo;clbog=o=cngOk]o]knk_o^o^
kokoknonk`03k^l09>g_gMo]glg?g=o<_kZo^jnY[jZOV9n9ShN?IVmfOeIOIEm4Cd=?=3lb?c<_<RlR
;b4_4AlQ;a4O8AlA7a0O0@l@7`4?ool03b7oo`006?oo00<03ooo00l04P0?00<A7a8OEEl00S<o01dS
;c<o8blR?b<_8SlS;b8o8blR;b<_8SlS;b8_8blR?b<_8RlS;b8o8blR;b<_8SlS;b8o8blR?b<_008c
?`9EG`034Al03`0?01403`03ool03ooo037ooa803`0@01l13b8_N7n8Sno_k^oNglcOcLo;ckbo^lnl
_k^oZkl3^kl01J^o^knk_k^oZkl00k^o00>[_k^o^kl00[^o00jkckboblnl_lcOcLoMknk_k_mhShR?
4Ql07`4?4P0?<_oo02@03ooo41l17a4O0AlA7a8O8BlB7b8_4RlR?b<_<cld?dA?ADm4GeIOIFmWKhN?
N7nIWhV?ZZn[_k^o_;o<clg?g=oNgnk_g^l2k^l08^koknonono_k_o_knk_g^oMkmkOg=o=clc?Zknk
_iZOZZn9SiVON7mVOfM_IFmFGdAO=3m4Cb<o<clS;b8o4RlA;a8O0a4O00H17a4O0@l@7ooo00lQool0
01Soo`0300ooo`0?01<03`0940mVKc<o<clb?b<_<SlR;c8_00<R;`05<RlR;b8_8Rlb;`038Rl01C8_
8RlR;b8_<Rl00b8_00Db;b8_<SlR;c8o008c?`03IVmUK`0?01<03`03ool03ooo037oo`0300ooo`0?
01003`0940lA7fE_EEoLgmg?g=nl_l_?00:k_`0FZjnj_jZ_^[n[[kZ_ZZnj_j^_^ZnZ[kZoZjnj[jZ_
^[n[[kZ_ZZnj_j^_^[l2^kl02[bobloMgmcOcLmUGeEO4Al03a0?400?00?oo`0?ool0<Ooo00L03ooo
0@l@7a4?41lA3`024Al00b4_8QlQ;`028Rl00c<_@clc?`02A4l2EEl00fI_Mgn7O`02R8l00iVO^ZnZ
[`02^kl04L_?c<oLgmgOkMoNgng_k]o]knk_kNo^gng_g]oMglg?g=l00/c?00Rk_kZ_ZZnYWiVOV8n8
SgMo0VI_0UEO00Y4Cd<o<clb?c<_<RlR;b4_4AlQ7`8A7`074@l@7a4?41l13ooo00l08Ooo000Hool0
0`0?ool03`0D00l02VI_=3lc?b<_<SlS;c8o8RlR?b<_0R8_00HR?b<_8RlR;b8o8bl28Rl01R8o8blR
;b8_8SlS;`8R;`068SlS;c8o8blcCc@o0VI_00<07`0?00l04@0?00?oo`0?ool0<Ooo00<03ooo00l0
3@0?00`07`0?01l13a4_EUmUKlgOg=oMglc?_<l3^kl05J^_^[n[[kZoZjnZ_j^_^[n[[jZoZjnj_j^_
Z[n[[kZoZjnZ_j^_^kn[[`02^kl02lc?_<oMglgOgMmFGeE_4Al07`4?01l03`0?00?oo`0?ool0<Ooo
00D03ooo41l13a0O00<A7`0>4BlB7b8_4RlR?b<_<cld?c=?ADm4GeEOEFmVK`9gO`07R9n9SiV_ZjnZ
_kbo^kl00/c?00o=gmgOgMo]kmkOk^oNknk_g^o^kmkOkNoNgmgOcLl00/c?00Rk_j^_Z[nJWiV_R8n8
WgQo0VI_00aEKeEOA5ld?c=?8clc?b8_8SlB;b4_4Ql34Al01P4?41l13a0Oool03b7oo`006?oo00<0
3ooo00l0500?00JZ[d<o<clb?b<_<Rl68Rl01B8O8RlR;b8_8Ql00b8_00DR7b8_8RlR;b8O00@R;`05
<RlR;c8o<cm3?`02ZZlD00l00ooo00ooo`0aool00`0?ool03`0>00l0110?00l@3a4?0S<o00>Z[jZO
c<l00[^o01J[[kZ_ZZnZ[jZOZJnZWjV_VYnY[jZOZJnJWjV_ZYnY[iZOZJnZWjV_ZYnY[`:Z[`05Zjnj
[k^o^ko<c`02ZZl01c<o<bl@7`0?40l03a0?00h03`03ool03ooo037oo`0700ooo`4?41l13a0O4@l0
0Q4O00<Q7b8O8Bl00R8_01Pc;d<o<cm3CdA?E5mECfE_MfmfOgQoQhnISjV_VYnj[jZ_bknk_l_?c<oL
cmg?g=l3gMl06]cOgMoLgmg?g<o<_lc?^ko;_jZ_ZJnJWiROVHn7SgQoMWmVGfE_EDmDGdA?@clc?c8o
<bl28Rl0324_4AlQ7a4?4AlA3a0O0@l@3`4?ool03b7oo`006?oo00<03ooo00l0500?00RZ[c@o<dlS
;c8o8blR?b<_1B8_00DB;b8_8RlR;a8_00<R;`034RlR;b8_00<R;`078blR;b<_8SlS;c=?=3l00ZZ_
500?00?oo`0?ool0<Ooo4P0?00D07`4?4AlS?c<o00:Z[`05c<nk_kboZ[n[[`03ZZl04IZOZZnJ[jZ_
VYnY[iZ_ZZnJWjV_VZnZ[iZOZJnJ[jZ_VZl00ZZ_00NZ_j^_^knl_lc?VZnZ[`02<cl00`4?01l13`0B
00lbool01P0?ool07`4O4Al17`8A7`044BlB7b4_4Rl28Rl0638o=3lc?cA?A4m5GeEOEUmfOfMoR8mh
OiROVYnY[j^_Z[nl_k^o_<o<glg?gMo=c`?Mg`0JcMoMglgOgMo=clc?_<nk_kboZ[nJWjV_RHnHWgR?
R8mWKfE_EVmEGdEOA4ld?c<o8blb?`8R;`0<4QlA;a8O4Al17a4O0AlA7`4?01ooo`0?8Ooo000Hool0
0`0?ool03`0D00l0114?@dm4?c8o0b8_014Q;b8_8RlR7b4_8RlQ;b8O8BlR;b4_8QlQ;b8_8BlR7b4_
008R;`038QlQ;b8_008R;`05<Sm4Cd=?4@l@7`0D00l00ooo00ooo`0aool00`0?ool03`0@00l02a0?
00lQ;a8OIFmVKkZoZZnj[iVOZJl00iVO012HWiV?V9nISiROVHnHWiV?V9nISiROVHnHWiV?V9nIS`BI
W`0;ZJnZ[kZ_ZZmUKfIO8BlA7a0O00l@3`0@00l00ooo00ooo`0aool0200?ool13a0O0@l@7a4?41l2
4Al0318O8BlR;b8_8blb?c<o@dld?eA?A4mEG`9VK`9gO`07R7nHWiV?ZJnJWkZ_ZZl00[^o00G;_lbo
blo<_l_?00;<c`0=c;o;clboblnk[kZoZZnj[iZOV9nIShR?R7l00WMo00mVKeEOIEm4CeAO=3lb?c<o
<SlS;b4_8RlQ;a4O8Al00Q4O00LA3a0O0@l@7`4?ool03`0Qool001Soo`0300ooo`0?01D03`04N8n8
Sb<_<Sl28Rl05A8_8BlB;b8_4QlQ;a8_8RlB7b4_4RlR;a8O8BlB;b8_4QlQ;a8_8RlB;`038Rl00b<_
QhmhS`0F00l00ooo00ooo`0aool00`0?ool03`0A00l02P0O0AlA7b<_<SmgOiVORIn8WhV?0hR?015h
ShR?N7n7SgR?R8mhOhN?N8n8SgQoQhmhShR?N7n7SgR?00:8S`0:R9n9SiVORImgSb<_<Sl17a0O0@lB
00l00ooo00ooo`0aool0?00?ool@7`4?41l17a4O0AlA;a4O8BlB7b8_4RlR;b<o<Sld?c=?=4m4CdEO
IFmFGfIoIfmgOgR?R8n9WiROVYnI[iZ_Z[n[[kZoZjnk_j^o^kn[_k^oZjnj_j^_ZZnJ[iV_VYnHWgR?
R8mhOgMoIfmVOeIOEEm5G`94C`08<dlS?c8o8blR;a8_8RlB7`DA7`060@l@7`4?41ooo`0?8Ooo000H
ool00`0?ool03`0E00l08HN?R7lb?b<_8BlR;b4_8QlQ;b8O8BlB7b4_8QlQ;a8O8BlR7b4_4QlQ;b8O
8BlB7b4_8QlQ;b8O8BlR;c8oN7n7S`0F00l00ooo00ooo`0aool00`0?ool03`0B00l02A0O4@lb?b<_
QgnISiRORHnHS`02R8l04XQoQhn8OhN?N7n7ShQoQhmhOhN?R7n7SgQoQhn8OhN?N7n7S`:8S`0:RHnH
SiV?V9mgOc8o8bl@7a4?40lB00l00ooo00ooo`0aool01`0?ool03a0O0@l@7a4?008A7`0m8AlA7b4_
8QlQ;b8_<Slc;d<o<cm4Cd@oE5mFGfE_IfmfKgMoR8n8OiROVHnYWiVOZJnZ[kZ_Zjnj_k^_^[nk[kZo
^jnj_j^_^ZnZWjV_VInYWiV?R8n8OhMoMgmfKfM_IFmECeAOA3m3Cc<o<Slc;c8_8RlQ;b8O8Al00Q4O
00TA3a0O4@l@7`4?40l03ooo00l08Ooo000Hool00`0?ool03`0G00l07CA?A4lB;b8_4QlQ;a8O4BlB
7b4_4QlA;a8O8BlB7a4_4QlQ;a8O4BlB7b4_4QlA;a8O8BlB;b8_=4l0600?00?oo`0?ool0<Ooo5@0?
02P13`0O4AlA7c<oIWmWKgMoIgmfOfMoMWmWKfIoIfmfOfM_IWmWKgIoIfmVOfM_MWmWKfIoIfmfOfM_
MWmWOgMoIgmVOfM_<cl17a4O0@l07aD03c;oo`0K00ooo`0O0@l@7`4?41l17a4O0AlA;a8O8RlB7b8_
8blb?b<o<cld?d=?A4mEGdEOIVmFGfIo009gO`0FN7n7ShV?R8n9SiVOVYnY[iZOZJnJWjZ_VYnY[iZO
ZJnIWiRORIn8ShV?Qhl2Mgl04FM_IWmFGfI_AEm4GdE?@dld?c<o8blb?a8_8RlB7b8_4Ql00a4O00P1
7a0O0@l@7`4?01ooo`0?8Ooo000Hool00`0?ool03`0G00l07D=?A3lR;b8O8BlA7b4_4QlQ7a4O8BlB
7b4O4AlQ;a8O8AlA7b4_4QlQ7a4O8BlB7b4_4QlR;b8O@dl0600?00?oo`0?ool0<Ooo00<03ooo00l0
4P0?00L@7`0?41lA7c<oIVmfK`02Mgl05VM_MWmWKgIoIfmfKfI_MWmWKgI_IVmfOfM_MVmVKgIoIfmf
KfI_MWmWKgIo0WMo00=VKgI_<cl00Q4O00<@3`0?00l04P0?00?oo`0?ool0<Ooo00P03ooo0@l@7`4?
41l13a0O0a4O01LQ7a8O8BlR7c8_8Rlc?c<_@dld?dA?EDmDGeIOIFmVKgIoMgn7SgQoV8n8SiRO00>I
W`07ZJnJWjV_VYnY[iZOZIl00YVO01:9SiROR8n8SgQoMWmgOgI_IVmUKeIOE5m4CeA?=3m3Cc<_<Rl2
8Rl03b8O8BlB7b4O4Al@7a4O41l13a0O0@l@7`4?ool03`0Qool001Soo`0300ooo`0?01P03`0601lS
;c8o4QlA;a8O0Q4O00DA;a4O4AlA7a4_00<A7`0;4BlA7a4O4AlA;a8O4AlB7a4_8blb?`0I00l00ooo
00ooo`0aool00`0?ool03`0A00l02P0O0@l03`4?01lA7c<o8bmDGdEO1EEO00E5GeEOEEmEGdEO00=E
G`05AEmEGeEOEEm5G`04EEl02EAOAElc?b<_4Al13a0O00l07`0C00l00ooo00ooo`0aool0200?ool@
7`4?41l17a0O0Al44Al01a4_4QlR;b8_8SlS?c8o008c?`03=4m4GdA?009EG`0IIFmVKfI_IgmfOgMo
MhmhOhR?N8n8WhV?V9n9ShRORHnHWhR?R9n8ShN?N7mgSgQoMWl00VI_00MFGfE_AEmEGdE?A4ld?`02
<cl01c8o8RlR?a8_8RlB7a4_008A7`0:0Al@7`4O41l13a0O0@l@7ooo00lQool001Soo`0300ooo`0?
01/03`0B8RlA3a4O4@lA7a4?41lA3a0O4@l@7a4?41lA3a0O4@l@7a4?0Q4O00<R;b8O00l06P0?00?o
o`0?ool0<Ooo00<03ooo00l04P0?00X@3`0?00l03a0?4@l@7b8O8Blc;`8c?`0I@clc?d<o=3m3?c<o
@cld?d<o<cm3?c@o@clc?d<o=3m3?c<_<clR7b4_4@l@7`4?40l05P0?00?oo`0?ool0<Ooo00X03ooo
00l@7`4?41l13a0O4@l@7`<A7`0>8AlB7b8_8Qlb;b8_<SlS;d<oA3m3CdA?E4mEC`9EG`08IFmVGfI_
IVmfKgM_MWmgK`AgO`0:QgmgOgMoMfmfOfM_MWmVKgI_IUl2EEl01EAOEDm4CdA?@dl00S<o00PS;c8o
8RlR;b8O8BlB7b4O0Q4O00/A3a4O0@l@7`4?41l13a0?00ooo`0?027oo`006?oo00<03ooo00l06`0?
01@R;a4O0AlA7`4O4Al17a4O0AlA7`4O4Al17a4O0AlA7`4O4Al17a4O0R8_6`0?00?oo`0?ool0<Ooo
5`0?02D13`0?0@lA7`4O8RlB7c<o8clcCc@o<dld?c=?=3lcCc@o<dld?c=?=3lcCc@o<dld?c=?=3lc
?b<o8RlB7a4O0Al07`0?01l13`0F00lbool02P0?ool07`4?41l13a0O0AlA7`4O0a4O00LB7b4_4RlR
;b<_8SlS?`02<cl04T=?=4m4CdA?EEmFGeEOEUmUKfM_IVmWKgMoIgmgOfMoMgmhO`EgO`03IfmVOfM_
009VK`0OIFmFGeEOADmEGdE?A4ld?c<o=3lc?b<_8SlB;b8_4QlQ;a8O4Al17a4O0AlA7`4?41l13a0O
0@l07ooo00l08Ooo000Bool300l3ool00`0?ool03`0N00l03`4?41l03a0O0@l@3`0?41l13a0?00l@
7`4?41l13`0O00l00ooo00ooo`0[ool300l3ool00`0?ool03`0H00l07A0?00l@7a4?41lA7b4_4QlQ
;b8O8BlR7b4_8RlQ;b8O8BlR;b4_8QlQ;b8O8AlA3a0O00l@7`0?40l0600?00?oo`0?ool0:_oo0`0?
1?oo00`03ooo00l@3`0?41l13a0O4@l@7a4?41l34Al01b4_4QlR;b8O<RlR;c8o00<c?`06@dm4?eA?
A4mDGdE?0UEO00MUKeIOIFmVKfE_IVmUK`03IVl01FE_IVmUKeIOIEl00UEO00I5CeA?A4m4Cd@o@dl2
<cl022<_<SlR;b8_8QlQ;a8O8Al44Al02`4?41l13a0O0@l@3`0?40l03ooo00l08Ooo000Cool00`0?
ooooo`02ool00`0?ool03`0L00l04@0O00l@7`4?41l13a0O0@l07`4?41l13`0O0@l@7`4?41l07`0?
00?oo`0?ool0;?oo00<03oooool00_oo00<03ooo00l05@0?00`07`4?01l03a0O0@lA7`4O4BlB;b8_
4Rl38Rl04Q8_8RlR;b8_4RlR;a8_8RlB7b4_4QlA7`4O41l13`0O00l07aL03`03ool03ooo02_oo`03
00oooooo00?oo`0<00ooo`0O0@l07`4?41l13a0O0AlA7`4O0Q4O00<A;a8O8Bl00b8_00XR?b<o<clc
?d=?=3m4CdE?A5m5G`9EG`04EFmFGfI_EUl7IVl01UI_IVmFKfE_EUmEK`9EG`06ADm4GdA?A4ld?d=?
0S<o00PS;b8o8blR;a8O8BlB7a4_114O00X17a0O0Al@7`4?01l13`0Oool03b7oo`004ooo00<03ooo
ool00_oo00<03ooo00l0C00?00?oo`0?ool0;?oo00<03oooool00_oo00<03ooo00l06P0?01T@3`0?
40l13a0?0@l@7`4?41lA3a0O0@l@7a4?41l13a0O4@l@7`4?40l03a0?00l@3`0J00l00ooo00ooo`0[
ool00`0?ooooo`03ool03@0?ool03a0?0@l@3`0?41l13a0O4@l@7a4?008A7`0G8AlB7b4_8QlR;b8O
<Rlc;c8o<blb?c<o@dld?d=?A4mDCdA?E5mECeAOEDmDG`02EEl03UE?E5mEGeEOEDmDGdE?E5m4CeA?
A4m3Cc@o@cl2<cl02S<_<SlR;c8_8QlQ;b8O8AlB7b4O0Q4O00dA3a0O4@l@7`4?41l03a0?0@l@3`0?
ool03`0Qool001?oo`0300oooooo00;oodl03`03ool03ooo02coo`0300oooooo00;ooa/03`0I0@l0
3`0?01l13`0O0@l07`4?4Al13a0O0AlA7`4?41l17a4O0@l@7`4?41l13`0O0@l00`0?00<13`0?00l0
600?;?oo00<03oooool00ooo01<03ooo01l13`0O0@l07`4?4Al13a4O0AlA7`4O4AlB7a4_4QlQ;`02
8Rl04B<_<SlS;c<o8clcCcA?A4ldCdA?ADm4CdE?EEm5GeEOAEl00eEO00i5GeEOAEmEGdE?E5m5CdA?
ADm4CcA?A4ld?c=?0S<o00PS;b8o8blR;a8_8BlB7a4_114O00X17a0O0Al@7`4?01l13`0O0@l07`80
3b7oo`004_oo0P0?1?oo00<03ooo00l0C00?00?oo`0?ool0:ooo0P0?1?oo00<03ooo00l0800?00D@
3`0?00l03a0?00<03`0540l03`0?00l@3`0P00l00ooo00ooo`0Zool200l5ool03P0?ool03a0?00l@
7`0?40l13a0O0@l@7a4?41l34Al01B4_4AlQ;a8O8Bl00b8_00<b?b<_<Sl00c<o00E3Cc<o@dm4?d=?
00M4C`0=@dm4Cd=?=3m3Cc<o@dlc?c8o<clb?b<_<Rl00R8_00@R7b4_4QlQ;`DA7`0941lA3a0O0@l@
7`0?41l03a0?00<03`03ool03ooo023oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<Ooo00<03ooo
00l09@0?00D07`0?00l03`0O02<03`03ool03ooo037oo`0>00ooo`0?00l07`4?01l13a0O0@l@7`4?
41l17`DA7`054QlA;a8O8RlB;`038Rl01B<_8SlS?c<o8cl013<o00TcCc@o<dld?c=?=3lcCc<o<dl0
1S<o00/S;b8o8blR;a8_8RlB;b4_4QlA;a8O00DA7`0>0@l@7`4?41l13`0O0@l07`0?01l13`0?ool0
3b7oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<Ooo00<03ooo00l08P0?00D@3`0?00l03a0?02H0
3`03ool03ooo037oo`0Q00ooo`0?40l03a0?00l@3`4?40l13a0O0@l@7a4?4AlA3b4O4AlQ7a4O8BlR
7b4_8QlQ;b8_<SlS;c8o<blc?c<_00@c?`09@clc?d<o<cm3?c<o@clc?d<o008c?`06<blb?c<_<SlS
;c8_0R8_00HR7b4_4QlQ;a4O8Al24Al04A4?41lA3a0O0@l@7`4?41l13a0?00l@3`0?40l03ooo00l0
8Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0aoomB00lbool04P0?ool07`4?00l13`0O0@l@7`4?
01l13a4O0@l@7`4O4Al17`<A7`054QlA;a8O8RlB7`058Rl04b<_8RlS;b8o8blc?b<_<SlS?c<o8blb
?b<_<clS;b8o8blR;b<_00<R;`074RlR;a8O8RlB7a4_4Ql00a4O00d17a4O0@l@7`4?4Al13`0O0@l0
7`4?01l13`0200l00`0Oool03`0Qool001Soo`0300ooo`0?04`03`03ool03ooo037oo`0300ooo`0?
04d03`03ool03ooo037oo`0400ooo`0?40l300l02Q0?00l@7`4?41l13a0O0@l@7a4?1A4O00HB7b4O
4QlQ;b8O8Bl38Rl04C8_8Rlb?b<_<SlS;c8o8blb?c<_<SlS;c8o8blb?b<_<Rl00b8_00TQ;b8_8BlR
7b4_4QlQ;a4O8Al00a4O00d@7a4?41l13a0O0@l@7`4?40l03a0?00l@3`0300l00ooo00ooo`0Pool0
01Soo`0300ooo`0?04`03`03ool03ooo037oo`0300ooo`0?04d03`03ool03ooo037oo`0D00ooo`0?
00l07`4?01l13`0O0@l@7`4?41l13a0O0@l@7`4O4Al17`@A7`084BlB7b4_4QlQ;a8_8RlB;`PR;`03
8SlR;b8_00@R;`0:4RlR;b8_8RlB7b4_4QlQ;a8O4Bl64Al03P4?41l13a0O0@l@7`4?41l13`0O0@l0
7`0?01l200l00ooo00ooo`0Pool001Soo`0300ooo`0?04`03`03ool03ooo037ooe803c;oo`0300oo
o`0?00803`0A40l03a0?00l@3`0?40l13a0?0@l@7`4?41lA3a0O4@l@7`024Al07Q4?4AlA7b4O4AlQ
7a4O8BlB7b4_8QlQ;a8O8BlR7b4_4QlQ;b8O8BlB7b4_4QlQ;a8O8AlA7b4O4AlQ7`8A7`0B4@lA7a4?
4AlA3a0O4@l@7`4?40l13a0O0@l@3`0?40l03a0?0`0?00@@3`0?ool03b7oo`006?oo00<03ooo00l0
C00?00?oo`0?ool0<Ooo00<03ooo00l0C@0?00?oo`0?ool0<Ooo00@03ooo00l13`803`0@01l13`0O
0@l07`4?41l13`0O0@l@7`4?41l17a4O0Al34Al06`4O4AlB7a4O4QlA;a8O8BlB7b4_4QlR;a8O8BlB
;b8_4QlQ;a8O8RlB7b4_4QlQ;a8O4BlB7`054Al04`4O4Al17a4O0@l@7`4?41l13`0O0@l@7`4?01l1
3`0?0@l07`4?00<03`03ool03ooo023oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<Ooo00<03ooo
00l0C@0?00?oo`0?ool0<Ooo00<03ooo00l0100?01D@3`0?00l03a0?00l@3`0?40l03a0O0@l@7`4?
41lA3a0O4Al@7a4?41l01a4O00TQ7a4O8AlA7b4O4AlQ7a4O8Al00a4O00DQ7a4O4AlA7a0O008A7`0B
4@l@7a4O41l13a0O0@l@7`4?40l03a0O00l@3`0?40l03a0?1`0?00?oo`0?ool08?oo000Hool00`0?
ool03`1<00l00ooo00ooo`0aool00`0?ool03`1=00l00ooo00ooo`0aool01P0?ool03`0?01l13`80
3`0@01l13`0O0@l07`4?41l13`0O0@l@7`4?41l17a4O0Al84Al03Q4_4QlA;a4O4BlB7a4_4QlA;a8O
4BlB7a4_4Ql24Al00a4_4AlA7`044Al04`4O4Al17a4O0@l@7`4O41l13`0O0@l@7`4?01l13`0O00l0
7`4?00803`0501l03`0?ool03`0Qool001Soo`0300ooo`0?04`03`03ool03ooo037ooe803c;oo`03
00ooo`0?00803`0L40l03`0?00l@3`0?40l03a0?00l@3`4?40l03a0O0@l@7a4?41l13a0O4@l@7a4?
41lA3a4O4@l34Al01A4?4AlA7a4O4@l00a4O01XA3a4O4AlA7a4?41lA3a0O4@l@7a4?41l13a0O0@l@
7`4?40l03a0?0@l@3`0?40l03a0?0`0?00<@3`0?00l00`0?00?oo`0?ool08?oo000Hool00`0?ool0
3`1<00l00ooo00ooo`0aool00`0?ool03`1=00l00ooo00ooo`0aool0100?ool03`4?0`0?01L13`0?
00l07`4?01l13`0O0@l07`4?01l13a0O0@l@7`4?4Al13a4O0AlA7`4O00<A7`050AlA7a4O4Al17`03
4Al01@4O4AlA7a4O0Al00a4O01L17a4O0AlA7`4?4Al17a4O0@l@7`4?41l13`0O0@l07`4?01l13`0O
0@l07`4?00<03`060@l03`0?00ooo`0?8Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0aool00`0?
ool03`1=00l00ooo00ooo`0aool00`0?ool03`0800l0=A0?00l03`0?40l03a0O00l@3`0?41l13a0O
0@l@7`4?41l13a0O0@l@7a4?41lA3a0O4@l@7a4?41lA7a0O4@l@7a4?41lA3a0O4@l@7`4?41l13a0O
0@l@7`4?41l13a0?00l@7`0?40l00`0?00D@3`0?00l03a0?00L03`03ool03ooo023oo`006?oo00<0
3ooo00l0C00?00?oo`0?ool0<Ooo00<03ooo00l0C@0?00?oo`0?ool0<Ooo00<03ooo00l01@0?00H0
7`0?00l03`0O0@l200l0<P0O0@l07`4?01l13a0O0@l07`4?41l13a0O0@l@7`4?41l17a0O0@l@7`4O
4Al13a0O0AlA7`4?41l17a0O0@l@7`4?41l13a0O0@l@7`4?01l13a0O0@l07`4?01l03`0O0@l200l0
1@0O0@l03`0?01l01P0?00?oo`0?ool08?oo000Hool00`0?ool03`1<00l00ooo00ooo`0aoomB00lb
ool00`0?ool03`0600l0>A0?00l03`0?40l03a0?00l@3`0?40l03a0?00l@3`4?40l13a0O0@l@7`4?
41l13a0O4@l@7`4?41lA3a0O0@l@7a4?41l13a0O4@l@7`4?41l13a0O0@l@3`4?41l13a0?00l@3`0?
40l03a0?00l@3`0300l01A0?00l03`0?40l01@0?00?oo`0?ool08?oo000Bool300l3ool00`0?ool0
3`1<00l00ooo00ooo`0[ool300l3ool00`0?ool03`1=00l00ooo00ooo`0Zool300l4ool00`0?ool0
3`0800l0=@4?00l03`0O0@l03`4?01l13`0?0@l07`4?01l13`0O0@l@7`4?01l13a0O0@l07`4?41l1
3`0O0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l@7`4?01l13`0O0@l07`4?00l13`0O0@l00P0?00<0
7`4?00l00P0?00<13`0?00l01@0?00?oo`0?ool08?oo000Bool00`0?ooooo`03ool00`0?ool03`1<
00l00ooo00ooo`0[ool00`0?ooooo`03ool00`0?ool03`1=00l00ooo00ooo`0Zool00`0?ooooo`04
ool00`0?ool03`0<00l0;A0?00l03`0?40l03a0?00l@3`0?41l03a0?00l@7`4?40l03a0O0@l@7`0?
41l13a0O00l@7`4?41l03a0O0@l@7`0?41l13a0?00l@7`0?40l03a0?00l@3`0300l00a0?00l03`0=
00l00ooo00ooo`0Pool001?oo`0300oooooo00;oo`0300ooo`0?04`03`03ool03ooo02coo`0300oo
oooo00;oo`0300ooo`0?04d03`03ool03ooo02_oo`0300oooooo00?oo`0300ooo`0?00T03`0601l0
3`0?00l07`4?0P0?02X07`4?01l03`0O0@l07`4?01l13`0O0@l07`4?41l13`0O0@l@7`4?01l13a0O
0@l07`4?41l13`0O0@l07`4?01l13`0O00l07`4?01l03`0O0@l200l01@0O00l03`0?01l02P0?00?o
o`0?ool08?oo000Bool00`0?ool03`03ool200m>ool00`0?ooooo`0Zool00`0?ool03`03ool200m>
ool200l[ool00`0?ool03`04ool00`0?ooooo`1<ool200lQool001?oo`803`?ooe403bgoo`803`?o
oe803bcoo`803`Cooe403b7oo`00ooooT_oo003ooonBool00?oooi;oo`004?oo00<03oooool0P?oo
00<03oooool0P?oo00<03oooool0N?oo000Aool00`0?ooooo`0[ool300mBool00`0?ooooo`0[ool3
00mBool00`0?ooooo`0[ool200m:ool0017oo`0300oooooo00;oo`0500ooo`0?ool03`03ool00`0?
ool03`0Oool00`0?ooooo`1Aool00`0?ooooo`02ool01@0?ool03ooo00l00ooo00<03ooo00l07_oo
00<03oooool0D_oo00<03oooool00_oo00D03ooo00ooo`0?00?oo`0300ooo`0?023oo`0300oooooo
04Ooo`004?oo00<03ooo00l00ooo00D03ooo00ooo`0?00?oo`803b3oo`0300oooooo053oo`0300oo
o`0?00?oo`0500ooo`0?ool03`03ool200lPool00`0?ooooo`1@ool00`0?ool03`03ool01@0?ool0
3ooo00l00ooo0P0?8?oo00<03oooool0B?oo000@ool00`0?ool03`03ool01@0?ool03ooo00l01?oo
00<03oooool07_oo00<03oooool0D?oo00<03ooo00l00ooo00D03ooo00ooo`0?00Coo`0300oooooo
01goo`0300ooo`0?057oo`0300ooo`0?00?oo`0500ooo`0?ool03`04ool00`0?ooooo`0Oool00`0?
ooooo`17ool0013oo`0300ooo`0?00?oo`0400ooo`0?00l4ool200lOool200mBool00`0?ool03`03
ool0100?ool03`0?1?oo0P0?8?oo0P0?DOoo00<03ooo00l00ooo00@03ooo00l03`Coo`803aooo`80
3d[oo`00ooooT_oo000Fool00`0?ooooo`20ool00`0?ooooo`20ool00`0?ooooo`1bool00?oooi;o
o`00ooooT_oo003ooonBool00?oooi;oo`00ooooT_oo003ooonBool00?oooi;oo`00ooooT_oo003o
oonBool00?oooi;oo`00ooooT_oo003ooonBool00001\
\>"],
  ImageRangeCache->{{{0, 399.9375}, {124.3125, 0}} -> {-2.079997, -2.069722, 
  0.01297, 0.01297}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tbl1 = 
      TableForm[{N[Abs[Eax[0, 0, a\/100]]\^2], N[Abs[Eax[0, 0, a\/10]]\^2], 
          N[Abs[Eax[0, 0, a\ 1\/1]]\^2]}, 
        TableHeadings \[Rule] {{"\<a/100\>", "\<a/10\>", "\<a\>"}}]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("a/100"\), "0.277809968586673461`"},
          {\("a/10"\), "0.223888045508901445`"},
          {\("a"\), "0.0232585074536240377`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {0.27780996858667346, 0.22388804550890145, 0.02325850745362404}, 
        TableHeadings -> {{"a/100", "a/10", "a"}}]]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Fig16x9 = 
      Table[DensityPlot[
          Evaluate[Abs[Eay[x\ a, y\ a, \(10\^jj\ a\)\/1000]\^2]], {x, \(-2\), 
            2}, {y, \(-2\), 2}, 
          AxesLabel \[Rule] {"\<x in a\>", "\<y in a\>"}, 
          PlotLabel \[Rule] jj, Evaluate[opt1], 
          DisplayFunction \[Rule] Identity], {jj, 1, 3, 1}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{Fig16x9\[LeftDoubleBracket]1\[RightDoubleBracket], 
          Fig16x9\[LeftDoubleBracket]2\[RightDoubleBracket], 
          Fig16x9\[LeftDoubleBracket]3\[RightDoubleBracket]}]]; \)\)], "Input",\

  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.31746 0.00744 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.02381 0.00744 0.321429 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25962 -0.0125 -7 -12 ]
[.25962 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.74038 -0.0125 -4 -12 ]
[.74038 -0.0125 4 0 ]
[.98077 -0.0125 -4 -12 ]
[.98077 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25962 -14 -6 ]
[-0.0125 .25962 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .74038 -8 -6 ]
[-0.0125 .74038 0 6 ]
[-0.0125 .98077 -8 -6 ]
[-0.0125 .98077 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000002050005
020000000000000000000000000000000000000000
00000000000000000000000000000000000E79200A020002
0A20790E0000000000000000000000000000000000
00000000000000000000000000000002FF3A170A04000000
040A173AFF02000000000000000000000000000000
000000000000000000000000000005A330160B0502000000
02050B1630A3050000000000000000000000000000
0000000000000000000000000002A32E150B060301000000
0103060B152EA30200000000000000000000000000
00000000000000000000000000FF30150B06030100000000
000103060B1530FF00000000000000000000000000
0000000000000000000000000E3A160B0603020100000000
00010203060B163A0E000000000000000000000000
00000000000000000000000079170B060302010000000000
0000010203060B1779000000000000000000000000
000000000000000000000000200A05030101000000000000
000000010103050A20000000000000000000000000
0000000000000000000000020A0402010000000000000000
00000000000102040A020000000000000000000000
000000000000000000000005020000000000000000000000
000000000000000002050000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000005020000000000000000000000
000000000000000002050000000000000000000000
0000000000000000000000020A0402010000000000000000
00000000000102040A020000000000000000000000
000000000000000000000000200A05030101000000000000
000000010103050A20000000000000000000000000
00000000000000000000000079170B060302010000000000
0000010203060B1779000000000000000000000000
0000000000000000000000000E3A160B0603020100000000
00010203060B163A0E000000000000000000000000
00000000000000000000000000FF30150B06030100000000
000103060B1530FF00000000000000000000000000
0000000000000000000000000002A32E150B060301000000
0103060B152EA30200000000000000000000000000
000000000000000000000000000005A330160B0502000000
02050B1630A3050000000000000000000000000000
00000000000000000000000000000002FF3A170A04000000
040A173AFF02000000000000000000000000000000
00000000000000000000000000000000000E79200A020002
0A20790E0000000000000000000000000000000000
000000000000000000000000000000000000000002050005
020000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744 0.64881 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25962 -0.0125 -7 -12 ]
[.25962 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.74038 -0.0125 -4 -12 ]
[.74038 -0.0125 4 0 ]
[.98077 -0.0125 -4 -12 ]
[.98077 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25962 -14 -6 ]
[-0.0125 .25962 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .74038 -8 -6 ]
[-0.0125 .74038 0 6 ]
[-0.0125 .98077 -8 -6 ]
[-0.0125 .98077 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000010203040403010001
030404030201000000000000000000000000000000
000000000000000000000000000102050A131D1F14060006
141F1D130A05020100000000000000000000000000
000000000000000000000000010309183B6C755025090009
2550756C3B18090301000000000000000000000000
000000000000000000000001030A2471CDBB783F1A060006
1A3F78BBCD71240A03010000000000000000000000
00000000000000000000000209248BFFD8894E2810040004
10284E89D8FF8B2409020000000000000000000000
0000000000000000000001051871FFDF905731190A020002
0A19315790DFFF7118050100000000000000000000
00000000000000000000020A3BCDD8905A361F1006010001
06101F365A90D8CD3B0A0200000000000000000000
0000000000000000000003136CBB89573621130A04010001
040A1321365789BB6C130300000000000000000000
00000000000000000000041D75784E311F130B0502000000
02050B131F314E78751D0400000000000000000000
00000000000000000000041F503F2819100A050301000000
0103050A1019283F501F0400000000000000000000
000000000000000000000314251A100A0604020100000000
00010204060A101A25140300000000000000000000
000000000000000000000106090604020101000000000000
000000010102040609060100000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000106090604020101000000000000
000000010102040609060100000000000000000000
000000000000000000000314251A100A0604020100000000
00010204060A101A25140300000000000000000000
00000000000000000000041F503F2819100A050301000000
0103050A1019283F501F0400000000000000000000
00000000000000000000041D75784E311F130B0502000000
02050B131F314E78751D0400000000000000000000
0000000000000000000003136CBB89573621130A04010001
040A1321365789BB6C130300000000000000000000
00000000000000000000020A3BCDD8905A361F1006010001
06101F365A90D8CD3B0A0200000000000000000000
0000000000000000000001051871FFDF905731190A020002
0A19315790DFFF7118050100000000000000000000
00000000000000000000000209248BFFD8894E2810040004
10284E89D8FF8B2409020000000000000000000000
000000000000000000000001030A2471CDBB783F1A060006
1A3F78BBCD71240A03010000000000000000000000
000000000000000000000000010309183B6C755025090009
2550756C3B18090301000000000000000000000000
000000000000000000000000000102050A131D1F14060006
141F1D130A05020100000000000000000000000000
000000000000000000000000000000010203040403010001
030404030201000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744 0.97619 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25962 -0.0125 -7 -12 ]
[.25962 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.74038 -0.0125 -4 -12 ]
[.74038 -0.0125 4 0 ]
[.98077 -0.0125 -4 -12 ]
[.98077 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25962 -14 -6 ]
[-0.0125 .25962 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .74038 -8 -6 ]
[-0.0125 .74038 0 6 ]
[-0.0125 .98077 -8 -6 ]
[-0.0125 .98077 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
010102020303040505060607070606050403020100000000
000102030405060607070606050504030302020101
010202030405050607080909090909080705040201000000
010204050708090909090908070605050403020201
02020304050607080A0B0C0D0E0D0D0C0A08050301000000
010305080A0C0D0D0E0D0C0B0A0807060504030202
020304050608090B0D0F1112131313110F0C080502000000
0205080C0F1113131312110F0D0B09080605040302
03040506080A0C0F111417191B1B1B1915110C0703000000
03070C1115191B1B1B191714110F0C0A0806050403
030506080A0D1013171B1F22252626231F19120B05010001
050B12191F23262625221F1B1713100D0A08060503
040507090C1014181E23292E323535322C241A1007020002
07101A242C323535322E29231E1814100C09070504
0506080B0F13181F262E363D434748453D3225170B020002
0B1725323D454847433D362E261F18130F0B080605
05070A0D11171E262F3A4550595F605C5344321F0F040004
0F1F3244535C605F5950453A2F261E17110D0A0705
06080B0F141B232E3A485665717A7D796D5A432A14050005
142A435A6D797D7A716556483A2E231B140F0B0806
06090C11171F29364556697C8D999E9A8B7355351A060006
1A3555738B9A9E998D7C69564536291F17110C0906
07090D1219222E3D50657C94A9B9C0BBAA8D68411F080008
1F41688DAABBC0B9A9947C65503D2E2219120D0907
07090E131B25324359718DA9C3D6DFD9C5A4794C24090009
244C79A4C5D9DFD6C3A98D71594332251B130E0907
06090D131B2635475F7A99B9D6ECF5F0D9B48553280A000A
285385B4D9F0F5ECD6B9997A5F4735261B130D0906
06090D131B263548607D9EC0DFF5FFF9E1BA8956290A000A
295689BAE1F9FFF5DFC09E7D604835261B130D0906
05080C11192332455C799ABBD9F0F9F2DAB48452270A000A
275284B4DAF2F9F0D9BB9A795C45322319110C0805
04070A0F151F2C3D536D8BAAC5D9E1DAC4A1754923090009
234975A1C4DAE1D9C5AA8B6D533D2C1F150F0A0704
0305080C11192432445A738DA4B4BAB4A183603B1C070007
1C3B6083A1B4BAB4A48D735A44322419110C080503
020405080C121A2532435568798589847560452B14050005
142B4560758489857968554332251A120C08050402
01020305070B10171F2A35414C535652493B2B1A0C030003
0C1A2B3B495256534C41352A1F17100B0705030201
000101020305070B0F141A1F24282927231C140C06010001
060C141C23272928241F1A140F0B07050302010100
000000000001020204050608090A0A0A0907050301000000
01030507090A0A0A09080605040202010000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000001020204050608090A0A0A0907050301000000
01030507090A0A0A09080605040202010000000000
000101020305070B0F141A1F24282927231C140C06010001
060C141C23272928241F1A140F0B07050302010100
01020305070B10171F2A35414C535652493B2B1A0C030003
0C1A2B3B495256534C41352A1F17100B0705030201
020405080C121A2532435568798589847560452B14050005
142B4560758489857968554332251A120C08050402
0305080C11192432445A738DA4B4BAB4A183603B1C070007
1C3B6083A1B4BAB4A48D735A44322419110C080503
04070A0F151F2C3D536D8BAAC5D9E1DAC4A1754923090009
234975A1C4DAE1D9C5AA8B6D533D2C1F150F0A0704
05080C11192332455C799ABBD9F0F9F2DAB48452270A000A
275284B4DAF2F9F0D9BB9A795C45322319110C0805
06090D131B263548607D9EC0DFF5FFF9E1BA8956290A000A
295689BAE1F9FFF5DFC09E7D604835261B130D0906
06090D131B2635475F7A99B9D6ECF5F0D9B48553280A000A
285385B4D9F0F5ECD6B9997A5F4735261B130D0906
07090E131B25324359718DA9C3D6DFD9C5A4794C24090009
244C79A4C5D9DFD6C3A98D71594332251B130E0907
07090D1219222E3D50657C94A9B9C0BBAA8D68411F080008
1F41688DAABBC0B9A9947C65503D2E2219120D0907
06090C11171F29364556697C8D999E9A8B7355351A060006
1A3555738B9A9E998D7C69564536291F17110C0906
06080B0F141B232E3A485665717A7D796D5A432A14050005
142A435A6D797D7A716556483A2E231B140F0B0806
05070A0D11171E262F3A4550595F605C5344321F0F040004
0F1F3244535C605F5950453A2F261E17110D0A0705
0506080B0F13181F262E363D434748453D3225170B020002
0B1725323D454847433D362E261F18130F0B080605
040507090C1014181E23292E323535322C241A1007020002
07101A242C323535322E29231E1814100C09070504
030506080A0D1013171B1F22252626231F19120B05010001
050B12191F23262625221F1B1713100D0A08060503
03040506080A0C0F111417191B1B1B1915110C0703000000
03070C1115191B1B1B191714110F0C0A0806050403
020304050608090B0D0F1112131313110F0C080502000000
0205080C0F1113131312110F0D0B09080605040302
02020304050607080A0B0C0D0E0D0D0C0A08050301000000
010305080A0C0D0D0E0D0C0B0A0807060504030202
010202030405050607080909090909080705040201000000
010204050708090909090908070605050403020201
010102020303040505060607070606050403020100000000
000102030405060607070606050504030302020101
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{320.75, 100.25},
  ImageMargins->{{43.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006A0000OQ000`40l00?003`ooooT_oo003ooonB
ool00?oooi;oo`00ooooT_oo003ooonBool00?oooi;oo`00ooooT_oo003ooonBool00?oooi;oo`00
ooooT_oo003ooonBool00?oooi;oo`00ooooT_oo000Kool300l@ool300l?ool00`0?ooooo`0?ool3
00l@ool300lfool300l@ool300l?ool00`0?ooooo`0?ool300lAool300leool300l@ool300l?ool0
0`0?ooooo`0@ool300l@ool300lRool001_oo`0300oooooo017oo`0300oooooo00goo`0300ooo`0?
017oo`0300oooooo00ooo`0300oooooo03Koo`0300oooooo017oo`0300oooooo00goo`0300ooo`0?
017oo`0300oooooo013oo`0300oooooo03Goo`0300oooooo017oo`0300oooooo00goo`0300ooo`0?
01;oo`0300oooooo00ooo`0300oooooo02;oo`005_oo0`0?0ooo00<03oooool02_oo0`0?0ooo00<0
3oooool03Ooo00<03ooo00l04Ooo00<03oooool04?oo00<03oooool0<?oo0`0?0ooo00<03oooool0
2ooo0`0?0_oo00<03oooool03Ooo00<03ooo00l04Ooo00<03oooool04Ooo00<03oooool0<?oo0`0?
0_oo00<03oooool02ooo0`0?0_oo00<03oooool03Ooo00<03ooo00l04_oo00<03oooool04?oo00<0
3oooool08Ooo000Kool00`0?ool03`0Aool00`0?ooooo`0=ool00`0?ool03`0Aool00`0?ooooo`0?
ool00`0?ool03`0fool00`0?ool03`0Aool00`0?ooooo`0=ool00`0?ool03`0Aool00`0?ooooo`0@
ool00`0?ool03`0eool00`0?ool03`0Aool00`0?ooooo`0=ool00`0?ool03`0Bool00`0?ooooo`0?
ool00`0?ool03`0Rool001coo`803a3oo`803a3oo`0300oooooo00ooo`803a;oo`803cOoo`803a3o
o`803a3oo`0300oooooo00ooo`803a?oo`803cKoo`803a3oo`803a3oo`0300oooooo013oo`803a;o
o`803b;oo`00ooooT_oo003ooonBool006goo`0300ooo`0?00?oo`0500ooo`0?ool03`03ool00`0?
ool03`1bool00`0?ool03`03ool01@0?ool03ooo00l00ooo00<03ooo00l0L_oo00<03ooo00l00ooo
00H03oooool03ooo00l3ool00`0?ool03`0<ool0017oo`<03e[oo`0300oooooo00;oo`0500ooo`0?
ool03`03ool200lGool300mJool00`0?ooooo`02ool01@0?ool03ooo00l00ooo0P0?6?oo0`0?FOoo
00<03oooool00_oo00H03oooool03ooo00l3ool200l=ool0017oo`0300oooooo00Cooe403`Goo`03
00oooooo00;oo`0500ooo`0?ool03`04ool00`0?ooooo`0Eool00`0?ooooo`04oomB00l4ool00`0?
ooooo`02ool01@0?ool03ooo00l01?oo00<03oooool05_oo00<03oooool01?ooD@0?1?oo00<03ooo
ool00_oo00H03oooool03ooo00l4ool00`0?ooooo`0;ool000goo`<03`;oo`0300oooooo00?oo`03
00ooo`0?01;oo`0300oooooo013oo`0300oooooo017oo`0300oooooo013oo`803`Coo`0300ooo`0?
00?oo`0400ooo`0?00l4ool200lCool300l2ool00`0?ooooo`03ool00`0?ool03`0Bool00`0?oooo
o`0@ool00`0?ooooo`0Aool00`0?ooooo`0@ool00`0?ool03`03ool00`0?ool03`03ool0100?ool0
3`0?1?oo0P0?4ooo0`0?0ooo00<03oooool00ooo0P0?4_oo00<03oooool04Ooo00<03oooool04?oo
00<03oooool04?oo00<03ooo00l00ooo00<03ooo00l00ooo00<03oooool00P0?1?oo0P0?3Ooo000A
ool00`0?ool03`04oom?00l00ooo00ooo`0Zool00`0?ool03`04oomB00l[ool00`0?ool03`04ool0
1P0?ool03`0?01l13`803`0J01l13`0O00l07`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?41l13`0O
0@l07`0?01l13`h03`0J01l13`0O0@l07`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l0
7`0?01l13`803`0301l03`0?00803b7oo`004_oo0P0?1?oo00<03ooo00l0C00?00?oo`0?ool02Ooo
00<03oooool07ooo0P0?1?oo00<03ooo00l0C@0?00?oo`0?ool02?oo00<03oooool08?oo0P0?1?oo
00<03ooo00l00P0?01d@3`0?00l03a0?00l@3`0?40l03a0?0@l@3`0?41l13a0?0@l@7`4?40l03a0?
0@l@3`0?40l03a0?00/03`0M40l03`0?00l@3`0?40l13a0?00l@7`4?40l13a0O0@l@3`0?40l13a0?
00l@3`0?40l03a0?00l@3`0300l0110?00ooo`0?2Ooo00<03oooool05Ooo000Hool00`0?ool03`1<
00l00ooo00ooo`0aool00`0?ool03`1=00l00ooo00ooo`0aool0100?ool03`4?0P0?01h07`4?01l1
3`0O0@l07`4?01l13a0O0@l@7`4?4Al13a0O0@lA7`4?41l13a0O0@l07`4?01l13`0O0@l700l08@4?
00l03`0O0@l07`4?01l13a0O0@l@7`4?4Al13a0O0@lA7`4?41l13a0O0@l07`4?01l13`0O0@l03`4?
01l13`0300l00ooo00ooo`0Pool001Soo`0300ooo`0?04`03`03ool03ooo037oo`0300ooo`0?04d0
3`03ool03ooo037oo`0400ooo`0?40l300l07A0?00l@3`0?40l03a0O0@l@7`0?41l13a0O0@l@7`4?
41l13a0O0@l@7`4?41l13a0?00l@3`0?40l02`0?01T@3`0?41l13a0O0@l@7`4?41l13a0O0@l@7`4?
41l13a0O00l@7`4?40l03a0O00l@3`0300l01Q0?00l03`0?ool03b7oo`006?oo00<03ooo00l0C00?
00?oo`0?ool0<OooDP0?<_oo01@03ooo00l03`0O0@l07`4?01l13a0O0@l@7`4?41l13a0O0AlA7`4O
0a4O00h17a4O4AlA7`4O4Al17a4O0@l@7`4?01l03`0O1`0?00P07`4?41l13a0O0@lA7`4O0a4O01X1
7a4O4AlA7`4O4Al17a4O0@l@7`4?41l13a0O0@l@7`4?01l13`0O00l07`4?00ooo`0?8Ooo000Hool0
0`0?ool03`1<00l00ooo00ooo`0aool00`0?ool03`1=00l00ooo00ooo`0aool04@0?ool03a0?00l@
3`0?40l13a0?0@l@7`4?41lA3a4O4@l0114O00DQ7a4O4AlA7b4O00DA7`0741lA3a0O00l@3`0?40l0
1`0?00D@3`4?41lA3a0O00<A7`058AlA7a4O4AlQ7`064Al04A4?41lA3a0O0@l@7`0?41l13a0?00l@
3`0?40l03ooo00l08Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0aool00`0?ool03`1=00l00ooo
00ooo`0aool04P0?ool07`4?00l13`0O0@l@7`4?41l13a4O0@lA7`4O4Al17`@A7`054BlB7a4O4AlA
;`024Al01`4O4Al17a4O0@l07`4?00L03`070@l03`4?41l13a4O0Al0114O00<A;a8O4Al00Q4O014B
7a4O4AlA7`4O4Al13a4O0@lA7`4?01l13`0O0@l07`4?00803`0301ooo`0?027oo`006?oo00<03ooo
00l0C00?00?oo`0?ool0<OooDP0?<_oo00h03ooo00l@3`0?41l03a0?0@l@7`4?41lA3a0O1A4O00/Q
7a4O8BlB7b4_8QlQ;a8O8BlB7b4O00<A7`0341l13a0O00L03`0540l03a0O4@l@7`034Al02b4_4QlQ
;a8O8BlR7b4_4QlQ;a4O8Bl01A4O00T@7a4?41l13a0O00l@7`0?40l00`0?00?oo`0?ool08?oo000H
ool00`0?ool03`1<00l00ooo00ooo`0aool00`0?ool03`1=00l00ooo00ooo`0aool03P0?ool07`4?
01l13a0O0@l@7`4?4Al13a4O0Al34Al03Q8O4BlB7a4_4QlR;a8O8BlB;b8_4QlQ;a8O4Bl24Al01@4O
41l13`0O0@l01P0?00@07`4?4Al17`8A7`0=4BlB7b4_4RlR;a8O8BlB;b4_4QlA;a8O4Bl0114O00h1
7a4O0Al@7`4?01l13a0O0@l07`4?01ooo`0?8Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0aool0
0`0?ool03`1=00l00ooo00ooo`0aool03@0?ool03a0?0@l@3`0?41l13a0O4@lA7a4?008A7`068BlB
7b4_8QlR;b8O0R8_00<b;b8_<Rl00b8_00TQ;b8_8BlB7b4O4@l@7`4?40l00`0?00D@3`0?40l13a0O
008A7`034QlQ;b8_008R;`05<RlR;c8_8Rlb;`028Rl01R8O8BlR7b4_4QlQ7`8A7`0=4@l@7a4?41l1
3a0O00l@3`4?40l03ooo00l08Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0aool00`0?ool03`1=
00l00ooo00ooo`0aool04`0?ool07`4?01l13`0O0@lA7`4?4Al17a4O0AlA;a8O8BlB7b4_00<R;`0;
8SlS;b8o8blR?b<_8RlB;b8_4QlQ;`024Al00`4O01l13`0500l03`4?01l13a4O4QlQ;a8O8RlS;b8_
8blR?b<_8SlS;`038Rl01Q8_8BlB7b4_4AlA;`8A7`0<0Al@7`4O41l13`0O0@l07`4?01ooo`0?8Ooo
000Hool00`0?ool03`1<00l00ooo00ooo`0aoomB00lbool0300?ool03a0?00l@7`4?41lA3a0O4Al@
7`8A7`034QlQ;b8_008R;`05<SlR;c8o<clb?`03<cl02c8o<clb?b<_<RlR;b4_4Al@7`0?41l01@0?
00D@7`0?4AlB7b4_008R;`038blb?c<o008c?`0=@clc?c<o<blb?b8_<SlR;b4_8RlQ;a8O8Al00Q4O
00/A3a0O0@l@7`4?40l03a0?00ooo`0?027oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<Ooo00<0
3ooo00l0C@0?00?oo`0?ool0<Ooo00P03ooo41l13`0O0@l@7`4O114O00HQ;a8O8RlS;b8o8cl2<cl0
2c=?=4m4CdA?A5m5CdAOA4m4GcA?A4l00S<o00DS;b4_4Ql@7`4O00<03`070@l03`4O41lB7b8o8Rl0
0S<o0TA?00E4GdE?A5m4CdAO0094C`06=3lcCc@o<clS;b8o0R8_00<B7b4_4Ql00Q4O00T@7`4O41l1
3`0O0@l@7ooo00l08Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0aool00`0?ool03`1=00l00ooo
00ooo`0aool02@0?ool03a0O0@l@7`4?41lA3`034Al02Q8O8AlR;c8_8Rlb?c<_@clc?d=?0dA?00eD
CdA?A4m4Cd=?A3lc?c<_<RlA7b4_4@l@7`0300l02Q0?00l@7a4?8AlR;c8_<blc?d@o0TA?00=DCdA?
E4l00TA?00a4?d=?<cm3?c<_<RlR;b4_8RlQ;a8O8Al24Al02A4?41l13a0O0@l@3`0?ool03`0Qool0
01Soo`0300ooo`0?04`03`03ool03ooo037oo`0300ooo`0?04d03`03ool03ooo037oo`0800ooo`0O
0@l@7`4?41l17`8A7`0E4BlB7b8_4RlR?b<o<cld?c=?ADm4CdE?EFmFGfI_EUmUKeIOIFm5GeEO0094
C`068clR;b8_4Al17`0O0P0?00D13`0O4AlA7a8_008c?`94C`0:EEmFGfE_EUmUKeI_IVmFGeEOAEl2
A4l023=?8clc?b<_8SlB;b8_4Ql34Al0204O41l13a0O0@l07ooo00lQool001Soo`0300ooo`0?04`0
3`03ool03ooo037ooe803c;oo`0800ooo`0?41l03a0O0@l@7`8A7`094QlQ7b8_8BlR;c8o<cm3Cc@o
0094C`07E5mEGfEOIUmUKeIOIFl00UEO00IECdA?A4lc?b8O8Bl24Al300l01a0?00l@7a4O8Rlc?c8o
0094C`0:EDmUKeEOIFmFGfE_IUmUGdE?E5l2A4l023@o<Slc?c8_8RlQ;b8_8Bl34Al0210O0@l@7`0?
41l03ooo00lQool001Soo`0300ooo`0?04`03`03ool03ooo037oo`0300ooo`0?04d03`03ool03ooo
037oo`0600oooa0O0@l@7`4O0Q4O01lA;a8O8RlB7b8o8Rlc?c@o@dm5CdAOEEmEKfI_MgmWKgN?N7n7
SgMoMhmWKgIoEUmEKdA?<SlS;a4_4Ql@7`0200l01@4?41lA7a4_8bl00TA?00YEKeIOMWmgOgN?N7n7
SgMoMhmWO`9VK`0;EFmEGdAO=3m3Cb<o<clR;b8o4RlA;`044Al01P4?41l13a0Oool03b7oo`004Ooo
0`0?1?oo00<03ooo00l0C00?00?oo`0?ool0:_oo0`0?1?oo00<03ooo00l06P0?00T@3`0?00l03a0?
00l@3`0?40l01`0?00D@3`0?40l03a0?00<03`0340l03`0?01P03`03ool03ooo02[oo`<03`Coo`0:
00ooo`0?41l13a0O4@lA7a8O8Al28Rl00b<_<Rlc?`02A4l01fEOEEmfKfI_Qgn8SiR?00FIW`05V8n8
SgIoMfmEG`02<cl00a8O8Bl03`0200l01A0?00lQ;a8O@cl00UEO00=gKgIoR8l00YVO00ZYWiVOVInI
WiR?Mgn7OfI_MVmEG`94C`07@clc?c8o8blQ;a4O8Bl00Q4O00LA3a0O0@l@3`0?ool03`0Qool001;o
o`0300oooooo00?oo`0300ooo`0?04`03`03ool03ooo02_oo`0300oooooo00?oo`0300ooo`0?01/0
3`0:01l13`0?0@l07`4?01l13`0?0@l300l02@4?00l13`0O0@l07`4?01l13`0L00l00ooo00ooo`0[
ool00`0?ooooo`03ool01P0?ool07`4?4Al17`8A7`098BlB7b8_8Rlb?b<_<dm5CdA?009EG`05IfmV
KgQoR9n9S`02VIl03IV_VYnIWhV?R9mWOgMoEElcCc@o8RlB7`0O00803`050@l07a8O8Rlc?`02EEl0
1gMoIgn8WiZOVInJWiV_00:IW`0?RHmgSgQoIVmWKeEOADm4Cc@o<dlS;c8o4RlA;a8O00<A7`060@lA
7`4?01ooo`0?8Ooo000=ool300l2ool00`0?ooooo`03oolV00l01A0?00l03`0?40l0900?00?oo`0?
ool09_oo0`0?0_oo00<03oooool00ooo6`0?00d@3`0?41l13a0O4AlQ;b8O8BlR;a4O0@l@3`0200l0
3P4?40lA7b8_8QlQ;b8O4Al13a0O00l@7`0?40lJ00lVool300l3ool00`0?ooooo`03ool02P0?ool1
3a0O0@l@7a4?4AlB7b4_0R8_00Dc;c8o=3mDGeE?009VK`05QgmgOiROZZnY[`05^kl2ZZl01IR?R8mV
Kd@o@dl00R8_00d13`0?00l@7`4?8BlR;d=?IVmfKhR?V9nZ[`02^kl04l^o^knj_k^oZZn9SiROMgn7
SfI_E5mECd=?=3lb?c<_8RlB7b4_008A7`054@l@7`4?41l13`0200lQool001;oo`0300oooooo00?o
o`0300ooo`0?02403`040@l03`4?01l200l00`4?01l13`0R00l00ooo00ooo`0[ool00`0?ooooo`03
ool00`0?ool03`0I00l0300O0@lA7`4?4BlB;b8_4RlR;a8O41l13`803`0341l13a4_008R;`074RlR
;a8O4Al13`0O0@l00P0?00<07`0?00l05@0?00?oo`0?ool0:ooo00<03oooool00ooo00D03ooo41l1
3a0O00<A7`098BlB7b8_8Rlc?b<oA4m5GeAO009VK`03N7mgShVO00:Z[`:k_`03^lnk_k^o00:Z[`05
RHn8WfM_A4ldC`028Rl0210O00l03`4?41lB;b8_A4l2IVl00hRORHnZ[`02^kl05;bo^ln[_k^oZZnI
WhVOMhmhOfI_AEmDGcA?A4lS?c<o8RlQ;a8O4Bl24Al01P4?41l13a0Oool03b7oo`004Ooo0P0?1Ooo
00<03ooo00l0700?00LA3a0OMgmgOb8O41lA3`0500l01`4?41lR;b8_Mgl@7a4O01d03`03ool03ooo
02[oo`803`Goo`0300ooo`0?01H03`0?40lA3a0O4QlQ7c@o@dmWKgIoMgmDGeE?<RlA3a0O00803`0@
4@l@7b8_E5mECgMoMfmfKc@o@dlB7b4O4@l@7`0?40lF00l00ooo00ooo`0Zool200l5ool01P0?ool1
3a0O0@l@7`8A7`0O4QlQ;b8_<Rlc;c<oA4mUGeEOMWmgKiR?RHnZ[kboblo=cmcOgMoLgmg?blo<_jV_
VYn7OdE?E5lR;c8_4@l00P0?00D@7a4?8RlR;eAO009gO`0:VYnY[lbog=oMcngOgMoLglg?bkl2ZZl0
1HV?V8mgKfEOEEl00TA?00hc?c<_<RlR7b4_4AlQ7a4O41l13a0?0@ooo`0?8Ooo000Hool00`0?ool0
3`0L00l0214O0AmgSgQo8Rl13a0O0@l300l00`4?4Al13`028Rl00gMo0AlA7`0M00l00ooo00ooo`0a
ool00`0?ool03`0D00l04@4?00l13a0O0@lQ;a8O@dld?gIoIgmgOdEOEElS;a0O0@l00P0?00D@7`4?
8Rm5CeEO009gO`07Ifm3Cc@o8BlB7a0O0@l0600?00?oo`0?ool0<Ooo02@03ooo01l13a4O0AlA7a8O
8RlB7b8o8blc?b<oA4mFGeE_IfmfOhV?R9nJ[k_?_;oMglg?gNo=gmgO_;o;ciZ_ZZmgOeAOADl28Rl0
3Q0O00l03`4?41lS;b8_ADmgSgQoZZnJWl_?cMl2gMl01=g_cLoMgkbo0ZZ_00N8WhV?MWmFGeE_=4m4
C`02<cl00b<_8BlB;`034Al01P4?4Al13`0Oool03b7oo`006?oo00<03ooo00l06`0?00Oooc<o@dlB
7b4O4@l@3`0700l01Q0?0@l@7a4O@dld?`;ooa/03`03ool03ooo037ooaL03`0740l03a0O8Rlb;gM_
MWl00/c?00Rk_gMoMgm3Cd@o8Bl13a0?0P0?00D13a0?4Qm3Cd@o009gO`08^ko<clc?MfmfOb8_<RlA
3aT03c;oo`0<00ooo`4?41l13a0O4@lQ7b8O8BlR;c8_0S<o00=4CfE_IUl00WMo0YVO00>k_lg?g=l0
0^k_00g_knk_k^oLgmg?^[n[[hN?EDmDGb8_<Sl13`0200l02Q0O0@lb;b8_EEn8OhN?Zjnj_mg?0^k_
00Onono_kNo^kmcO^jnj_`02VIl00gMoIFmVG`02A4l01D<o<clb;a8O8Bl00Q4O00LA3a0O0@l@7`4?
ool03`0Qool001Soo`0300ooo`0?01L03`0;0@l07iZ_ZJlS?a4_4QlA7`4O01l13`0600l0300O0@l@
7`4?41lB7b4_8clc?iZ_ZJl13aP03`03ool03ooo037oo`0300ooo`0?01803`070@l03`4?41lS;hRO
R8l00_oo00[MglgOR9m5GeEO8blR?a4O01l13`803`0:01l13a4O8blb?dE?E5n8SmgOcMl2ool01hRO
R8lR?`4O41l03`0O01<03`03ool03ooo037oo`0500oooa0O0@l@7`034Al03R4_4RlR?b<_<dld?dAO
EUmUKgQoQhnJWiV__;l2gMl01nkoknooono_o_oNgmg_00:k_`06R8mEGeEO<SlS;a4O0P0?00D17a4O
8blb?eEO00:8S`:k_`03gNo_koko00;oo`0Jkno^omkO^lnl_iV_VYn7SeIOIFm5CdAO<clcCb<_8RlB
7a4_4QlA7`4?41l13a0Oool03b7oo`006?oo00<03ooo00l05`0?00/@3`4?ZJnZWc<o4QlQ7a4?41l1
3a0?00L03`0;40l03a0?4@lQ7a4O<clc;jV_ZYl@3`0H00l00ooo00ooo`0aool00`0?ool03`0B00l0
1a0?00l@7`4?<Rn8SiR?00;oo`0:gLoLghR?E5mECc8o8blA7`0?40l300l02A0?4@lb;b8_E5m5CiR?
gLoLg`02ool01HR?V8lR;a0O4@l05@0?00?oo`0?ool0<Ooo01H03ooo00l@7`4?41lA3a4O4QlQ;b8_
<Rlc?d<oA4mUKeIOQgmgOjVOVYo;_`;Mg`0:knonkoooo_o_kngOgMnk_k^_V8l2EEl00b<_<RlA3`02
00l01A0O4@lb?b<_IEl00XR?00Fk[k^ogMonono_00;oo`0<o_o_kngO^ko;_iZOZImgOfE_EUmDCdA?
0S<o00`b;b8O8BlA7b4O4@l@7`4?40l03ooo00lQool001Soo`0300ooo`0?01H03`0:01nJWjZ_8clc
?a8O4Al13`0O0@l:00l02P0O0@l@7`4?4AlB7a4_8clc?iZO600?00?oo`0?ool0<Ooo00<03ooo00l0
4P0?00D13`0O4QlQ;fM_00;oo`;Mg`0:R9n9SeEO8clc?a8O8Bl13`0O0@l200l01@0O0@lA7a8O8Bl0
0S<o00=EGhRORHl00]gO0_oo00EgOa8O4Bl13`0O01<03`03ool03ooo037oo`0600ooo`0O0@l@7`4O
0Q4O010Q;a8O8RlS;c<o8cm4CeIOIFmgOgN?VYnIWk^ogMo=g`;^k`0=o_o_knk_cMoMgj^_^kmhSeEO
AElR?b<_41l00P0?01413a0O8blR?dEOR8mhSk^oZjoMgno_k^o_kokokno^klgO00:k_`:IW`03MhmF
GfE_0094C`8c?`038RlQ;a8O00<A7`060@l@7`4?01ooo`0?8Ooo000Hool00`0?ool03`0G00l02JV_
VYlb?c<_8AlA3a0O0@l@3`0;00l02A0?00l@7`4?8AlA7c8o<bnY[`0H00l00ooo00ooo`0aoolE00l0
1A0O00lQ;a4OMWl00_oo0]gO00Z9SiROEElc?c<_8BlB7a0O00l@3`<03`0940lA3b4_4Qlb?c<oEEn9
SiRO00;Mg`;oo`04MflQ;a8O40lF00lbool02P0?ool03a0O0@l@7a4?4AlB7b4_0R8_0S<o00=4CfE_
EEl00WMo0YVO00>k_mg?g=l00^k_00g_kok_k^oLgmg?^[n[[hN?EDmDGb8_<Sl13`0200l03Q0O0@lb
;b8_E5n8OhN?Zjnj_mg?o^o^kokoknl2k^l00mcO^knk_`02VIl00gMoIFmEG`02A4l01C8o<clR;a8O
8Bl00Q4O00LA3a0O0@l@7`0?ool03`0Qool001Soo`0300ooo`0?01D03`;oo`0:8clc?a8O4Bl17`0O
0@l07`0?01l;00l0200O0@l@7`4O41lB7a4_8cl2oolF00l00ooo00ooo`0aool00`0?ool03`0A00l0
3@0O0AlA7c@o@do<cmgOcMnHWhV?IFmFGc=?008R;`8A7`030@l03`0?00@03`0B01lA7a4O4RlR;c@o
IFmFGiRORHoMglgOc=ld?d=?0@l@7`4?4P0?00?oo`0?ool0<Ooo00H03ooo01l13a0O0Al24Al07a4_
4QlR;a8_<SlS?dA?AEmEGfM_MWn8ShROZZo;ckbogMo=gmg_cMoMgkboblnJWjV_MgmDGdE?8SlR;a0O
00803`0A0Al@7b8_8Sm5CgMoIgnY[iZOblo=gmgOg]oMklgOgMnlc`02ZZl038RORHmfOdEOEEldCdA?
8blb?b8_4BlB7`<A7`060@l@7`4?01ooo`0?8Ooo000Hool00`0?ool03`0D00l02Q4?@cld?b4O4Ql@
7a4?41l03a0?3`0?00T@3`0?41l13a0O4@lQ7c@o@cl00Q4O500?00?oo`0?ool0<Ooo00<03ooo00l0
4P0?00DQ7a4OMWmWKk^o00:8S`0:EEmUGc<o@clR7b4O4Al@7`4?40l700l02A0O4@lA7a4O8Rlc?d<o
EEmUG`02R8l00k^oMVmVK`024Al00a0?00l03`0@00l00ooo00ooo`0aool0200?ool03a0?0@l@7`4?
41l24Al01A8O8BlR;c8_<cl00TA?01IUGeEOMWmgKiR?ZYnY[j^_^[nk_kZoZjnYWiZOQhn8OfE_=3m3
Cb8O8Bl13`803`0<40l13b4_8Qm3CfIOIFn8OhN?VYnj_j^_0[^o00Rj_j^_ZJn8SiR?MfmfOeEO0TA?
0S<o0R8_00`Q;a4O4AlA3a0O0@l@3`4?40l03ooo00lQool001Soo`0300ooo`0?01@03`0<4Ald?c=?
4QlA;`4?4Al13`0?0@l07`4?2`0?00/13`0?0@l07`4?41l13a4O4Qm3Cc@o008A7a@03`03ool03ooo
037oo`0300ooo`0?01803`074AlA;fM_MWnk_hR?RHl00UEO00XcCc@o8RlA7a4_0AlA7`4?00l13`<0
3`090@l07`4?41lB7a4O4RlcCc@o009EG`08R8n9Sk^oIfmVOa8O4Al13a803`03ool03ooo037oo`08
00ooo`0O0@l07`4?41l17`8A7`058BlB7b8_8Rlc?`02A4l05UIOEFmWOgMoRHnY[iZ_^kn[[k^oZjnk
_iZOVJmhShR?EUm3Cc@o8RlB7`0O0P0?01H13`0O4RlR;c@oIFmFKhR?N7nI[j^_^kn[_k^oZjnk_iZO
R9n9SgMoIgmEK`94C`058clc?b<_8RlB7`034Al0204O41l13`0O0@l07ooo00lQool001Soo`0300oo
o`0?01@03`08MglQ;a8O41lA3a0O0@l@3a<03`0940l03a0O0@l@7a4O8BmgOhMo01@03`03ool03ooo
037ooaD03`038BlR7gIo009gO`0:ADmDGc<o<clR7b4_4Al@7`4?40l900l01a0O00l@7a4?4AlR7b4_
008c?`08ADmDGgMoMgmgKb4_8Ql@3a@03c;oo`0:00ooo`0?40l03a0O00l@7a4?41l24Al01A8O8BlR
;c8o<cl00TA?0UEO00mVKgMoQgn8ShN?R8n7ShQoMgmgKfE_IUm4Cb<_<Sl00Q4O0`0?00D@7`0?8AlA
7c8o0094C`05IUmUKgM_Qhn8O`02R8l01HN?R8mgOfI_MVl00UEO00=4Cc8o<cl00R8_00TQ;a8O4AlA
3a0O0@l@7`0?40l00`0?00?oo`0?ool08?oo000Hool00`0?ool03`0D00l02WN?4QlQ;`4O41l13a0O
00l07`4?3P0?00X07`4?00l03`0O0@l@7`4O4BlB7`9gOa@03`03ool03ooo037oo`0300ooo`0?0140
3`0401lB;b8_Igl2Mgl035EOADlc?c<o8RlB;a4_0AlA7`4?01l13`H03`0801l13a0O0Al@7a8O8RlB
;`8c?`03EEm5CgN?009gO`034RlR;`4?01803`03ool03ooo037oo`0:00ooo`0?0@l07`4?41l13a4O
0Al24Al00b4_4RlR?`02<cl2A4l2EEl00fM_MgmgO`03R8l037R?R8mgOgMoEUmUKdA?<SlS;a4_4Ql@
7`803`050@l@7a4O4BlS?`02A4l016E_EVmgOgR?0hR?00=hShR?N7l00VI_0UEO00M4Cc<o<clS;b8o
4QlQ;`024Al02P4O41l13a0O0@l07`4?00ooo`0?8Ooo000Hool00`0?ool03`0D00l01R8O41lA3a0?
0@l@3`<03`0340l03`0?00d03`0940l03`0?00l@3`0?40l13a0O008R;a@03`03ool03ooo037oo`03
00ooo`0?01803`098BlR;eAOEDm3Cb8_<SlB7b4_008A7`060@l@3`0?40l03a0?1`0?00D@3`0?40l1
3a0O008A7`0:4QlQ;b8_<Sm4?eAOEDlR;b8O40lB00l00ooo00ooo`0aool00`0?ool03`0200l0210?
00l@3`4?40lA3a0O4@l24Al0128_8Qlb?b<_0S<o00E3CdE?E5mECeAO009EG`0:EDmDCdA?@dld?c8o
8QlQ;a4?41l300l03A0?00l@7a4?8Blc;c8o=3m3CdA?EEmECfEO009EG`0:EDmDGd@oA4lc?d<o8blR
;b8O8Al24Al01Q4?41l13a0O0@l@3`<03`0440l03ooo00lQool001Soo`0300ooo`0?01@03`088Rl1
3a0O0@l07`4?01l13a<03`070@l03`4?01l13a4O0@l00R8_500?00?oo`0?ool0<Ooo500?00X07a8_
8Rm5GeEO=4lR?b<_8BlB7`<A7`030@l07`4?00T03`050@l07`4?01l13`024Al01b4_4QlR?b<_A4m5
CeEO008R;`030@l03`0?01803c;oo`0?00ooo`0?0@l03`4?01l13a0O0@lA7`4O4Al17a4_008R;`0F
8blb?c@o<cldCeAOADmEGdEOEEm5GeEOADm4Gc@o@dlS;b4_4QlA7`4O01l200l02`4?01l17a4O4Qlb
?b<_@dld?dAOAEl01EEO00=5CdA?=4l00S<o00Db?b8_8RlB7a4_008A7`070@l07`4?01l13`0O0@l0
0`0?00?oo`0?ool08?oo000Hool00`0?ool03`0C00l01A0?4@l@3`0?40l06`0?00D@3`0?40l13a0O
01@03`03ool03ooo037oo`0300ooo`0?01803`8A7`09<RlR;b4_4Al@7a4?41l13a0?00l03`0:40l0
3a0?0@l@3a4?41lA7a0O4Ql28Rl00b4O4Al03`0B00l00ooo00ooo`0aool00`0?ool03`0400l02A0?
00l03`0?40l03a0O0@l@7`034Al02B4_4QlR;b8_<RlR;c8o8blb;`038Rl01b4_8QlA7a4?41l03a0O
00D03`0=40l03a0O4AlQ7b8O8BlR;c8_8Rlb?b<_<Rl00R8_00hR7b4_4QlQ;a4O41lA7a0O0@l@7`0?
41l03a0?1`0?00?oo`0?ool08?oo000Cool00`0?ooooo`02ool00`0?ool03`0B00l00a0O0@l07`0S
00l00`0O00l03`0A00l00ooo00ooo`0/ool00`0?ooooo`02ool00`0?ool03`0A00l02P0O0@l@7`4?
41l13`0O0@l07`4?0P0?00<07`0?00l04@0?00T07`4?01l13`0O0Al@7`4?01l04`0?00?oo`0?ool0
:ooo00<03oooool00ooo00<03ooo00l02@0?01T07`4?00l13`0O0@l@7`4?01l13a0O0@l@7`4O4Al1
3a0O0Al@7`4?41l13`0O00l07`0700l05P0O0@l@7`4?41l13a0O0@l@7`4O4Al13a0O0Al@7`4?01l1
3a0O0@l07`4?0P0?00<07`0?00l0200?00?oo`0?ool08?oo000Bool00`0?ool03`03ool00`0?ool0
3`0C00l00a0?00l03`0R00l00`4?00l03`0A00l00ooo00ooo`0[ool00`0?ool03`03ool00`0?ool0
3`0B00l02A0?00l@7`4?40l03a0?00l@3`0C00l03A0?00l03`0?40l03a0?0@l@7a4?41l13a0?0180
3`03ool03ooo02[oo`0300ooo`0?00Coo`0300ooo`0?00X03`0I40l03a0?00l@3`0?41l13a0O4@l@
7`4?41lA3a0O0@l@7a4?41l13a0?00l@3`0?40l01`0?01D@3`0?40l13a0?4@l@7`4?41lA3a0O0@l@
7`4?41l13a0?00l@3`0?40l00`0?00<@3`0?00l01`0?00?oo`0?ool08?oo000Bool00`0?ool03`03
oom?00l00ooo00ooo`0[ool00`0?ool03`03oomB00l[ool00`0?ool03`04ool00`0?ool03`1>00lQ
ool001;oo`0300ooo`0?00?oo`0300ooo`0?04`03`03ool03ooo02_oo`0300ooo`0?00?oo`0300oo
o`0?04d03`03ool03ooo02[oo`0300ooo`0?00Coo`0300ooo`0?04`03`03ool03ooo023oo`004ooo
00<03oooool00_oo00<03ooo00l04P0?00<@7`4?01l08`0?00<07`0?00l04@0?00?oo`0?ool0;?oo
00<03oooool00_oo00<03ooo00l04@0?00X07`4?41l13a0O0@l07`4?01l13`803`0301l03`0?0140
3`0901l13`0O0@l07`4O41l13`0O01<03`03ool03ooo02_oo`0300oooooo00?oo`0300ooo`0?00T0
3`0I01l13`0?0@l07`4?41l13`0O0@l@7`4?41l17a4O0@l@7`4O41l13a0O0@l07`0?01l01`0?01H0
7`4?41l13a0O0@l@7`4?41l17a4O0@l@7`4O41l13`0O0@l@7`4?01l13`803`0301l03`0?00P03`03
ool03ooo023oo`006?oo00<03ooo00l0500?00<13a0?00l00P0?00<@3`0?00l05@0?00L@3`0?00l0
3a0?4@l@7`0D00l00ooo00ooo`0aool00`0?ool03`0B00l01B4O4Alb;b8_8Bl00Q4O00H13a0O00l@
7`0?40l;00l02A0?00l03`0?40l03a0O0@l@7`024Al01Q8O<RlR;b4O4Al@3a803`03ool03ooo037o
o`0300ooo`0?00803`0A40l03`0?00l@3`0?40l13a0?4@lA7a4?8AlA7b4_4QlQ;`028Rl03R<_<RlS
;c8_8blb;b8_8BlR7b4O4@l@7`4?40l300l04A0?00l@7`4?41lA7b4O8QlQ;b8_<RlS;c8_8blb?b<_
<Rl00R8_00hB7b4_4AlA7a4?41lA3a0O0@l@3`0?40l03a0?1@0?00?oo`0?ool08?oo000Hool00`0?
ool03`0B00l01P0O0@lA7`4?01l13a/03`050@l07`4?41l17`0D00l00ooo00ooo`0aoolE00l01A8O
4BlS;b8_4Ql00a4O00L13`0O0@l07`0?01l13`0;00l01`4?00l13`0O0@lA7`4?008A7`068RlS;b8o
4QlA7`4?500?<_oo00@03ooo00l13`<03`070@l03`4?01l13a0O0@l00a4O00`B7a4_4QlR;a8_8SlS
;c8o8blR?b<_8Sl28Rl01a8_8RlB7a4O0Al@7`4?00D03`0>0@l@7`4O4BlB7b8_4QlR;b<_8SlS;b8o
8blb?`@R;`0;4QlA;a4O4Al13a4O0@l@7`4?01l13`0300l01P4?00l03`0?ool03b7oo`006?oo00<0
3ooo00l0500?00@R;a0O0@l@3a/03`0540lA3a0O8QlQ;`0D00l00ooo00ooo`0aool00`0?ool03`0B
00l03b8_8QmDGeE?@dlS;c8_4QlQ;a4O41lA3a0O00l@3`0;00l03a0?00l@7a4O41lB7b4_8blb;d@o
E5m5Cb4_8Rl@3`0B00l00ooo00ooo`0aool0100?ool03a0?0`0?00D@3`0?41l13a0O008A7`0:4QlQ
;b8_<SlS;d<o<cm3CdE?E5l3EEl02eAOEEmDGdA?@dld?c8o4QlQ;a4?41l01@0?00T@7a4?8BlS;c8o
=3m3CdA?E5l00eEO00EDGeEOE5m4?d=?008c?`0>8blQ;b8_8BlB7a0O4Al@7`4?41l03a0O00l@3`<0
3`03ool03ooo023oo`006?oo00<03ooo00l0500?00TR;`4O4Al13`0O0@l07`0?01l04`0?00P07`4?
01l13a0O0AlR;a8_500?00?oo`0?ool0<Ooo00<03ooo00l04@0?00X07b8_8Rm5GeAO=4lb?b<_8BlB
7`8A7`0541l13a0O00l07`0700l01P0O0@l07`4?01l17`8A7`0:8BlB7c8o8bm4CdEOEElB;b8_0@lB
00l00ooo00ooo`0aool0300?ool03`0?01l13`0O0@l@7`4?4Al17`8A7`0:8BlB;b8_8blb?c<o<dm4
CeAOADl3EEl034EOEEm5CeAO=3m3Cb<o8BlB7a4O0Al07`803`0;0@l07`4O4AlB;c8o8bm3Cc@oE5m5
G`03EEl034EOEEm5CdA?=4lcCc@o<SlB;b8_4QlQ;`8A7`080Al@7`4?01l13`0O00l07`803`03ool0
3ooo023oo`006?oo00<03ooo00l0500?00YgOb4O4Al@7a4?40l03a0?00l@3`l03`0940l03a0?00l@
3`0?41lB7b4O009gOa@03`03ool03ooo037oo`0300ooo`0?01803`098BlR7gMoMfn7OeE?E5lc;c8o
008R;`064Al@7a4?40l13a0?1`0?00D@3`0?41lA3b4O008R;`0:<blb?eE?E5mgOgIoMglQ;b8O40lB
00l00ooo00ooo`0aool02P0?ool03a0?00l@3`0?41lA3a0O0Q4O00DB7b4_8Rlc?c<_0094C`9EG`0A
MVmgOgMoR7n7ShR?Qhn8OgIoMgmUKeIOE4lc;c8o4AlQ7`0300l01A0?00lQ7a4O<Sl00TA?00IFGfE_
Mgn7ShQoV8l2R8l018QoQgmVKfI_0UEO01=4Cc<o<blb;b8_8BlB7b4O4@l@7`4?41l03a0?00l@3`0?
ool03`0Qool001Soo`0300ooo`0?01@03`08MglB7a4_0AlA7`4?01l13`<03`030@l03`0?00`03`0:
01l13`0?0@l07`4O8BlB7gN?N7lD00l00ooo00ooo`0aoolD00l00`0O4RlR;`03Mgl015AOAElc?b<o
0R8_00DA7`4?4Al13`0O00P03`030@l07`4O008A7`8R;`0:<clS?eAOAEmgOfMoMglB;b8_0@lD00lb
ool03`0?ool07`4?01l13`0O0@lA7`4O4AlB7b8_4QlR?`02<cl05SA?A4mEGeEOIVmgSgQoR8mhShR?
N8n8SfMoMgmFKfI_A4lb?b<_4AlB7`0O0P0?00/13`0O4QlA7b<_A4m5CfI_EUmgOgR?00>8S`05N8n8
SgMoIWmWK`02EEl01dA?<clc?b<_8SlB7b8_008A7`0:0Al@7`4?01l13`0O00l07ooo00lQool001So
o`0300ooo`0?01@03`084Am3Cc@o8AlA7a0O0@l@3`<03`0340l03`0?00d03`0940l03a0O0@lQ7c<o
@dlA3a0O01@03`03ool03ooo037oo`0300ooo`0?01803`8A7`03MVmVKk^o00:8S`9EG`03<cm3?b8_
008A7`0341lA3a0?00L03`0741l13b4O4AlR;c<o@cl00UEO0XR?00Fk_gIoIflQ7a4O01<03`03ool0
3ooo037oo`0800ooo`0?40l03a0O0@l@7`8A7`054QlQ;b8_8Rlc?`02A4l05VE_EEmfOgM_V9nJWjV_
Zjnj_k^o^[n[[jV_VYn7ShQoIFld?d=?8QlQ;`4?0P0?00`@7`4?8BlR7d=?EUmUKhQoQhnJWkZoZjl2
^kl02;ZoZjnY[hR?V8mgKgIoEEl2A4l2<cl00c8_8RlQ;`024Al0114?41l13a0?0`0?00?oo`0?ool0
8?oo000Hool00`0?ool03`0E00l2ool02R<o<clB7a4_0Al07`4?01l03`0O2`0?00P07`4?41l17a0O
4QlA;b<o0_oo5P0?00?oo`0?ool0<Ooo00<03ooo00l04@0?00d07`4O4Ald?d=?c<oMglgOV9n9SfE_
EUlcC`028Rl24Al00`4?00l03`0400l04P0O4AlA7a8_8Rld?fE_EUnHWhV?gMo=glcO=3m3C`4?41l1
3a803`03ool03ooo037oo`0600ooo`0O0@l@7`4O0Q4O01lA;a8O8RlB;c8o8cm4CdEOEEmWKgIoR8n8
WjZ_blnl_mgOcMoMklgOgMnl_l_?VYnY[gMoE5m5Cb8o8Rl@7`0200l04@4O41lR;b8oADmgOfMoZJnJ
Wl_?cMoMgmkOgNo=gmgO_<l00ZZ_00b8WhV?MWm5GeEO=4m4Cb<_<SlR;a4_4Ql34Al01P4?41l13`0O
ool03b7oo`006?oo00<03ooo00l05@0?0_oo00Tc?c<_8AlA7a0O0@l@3`0?40l03@0?00L@3`0?41lA
3b4O4Alc?`02oolF00l00ooo00ooo`0aool00`0?ool03`0B00l04A0O4@m3Cc@og<oMcmcORHnHSeEO
IElc?b4_8RlA7a4?40l01P0?01813a4O4AlR;b8O@cmEGfEORHnHSmg?g=o<cd=?=3l@7`4?40lB00l0
0ooo00ooo`0aool01`0?ool03a0O0@l@7a4?008A7`0A8AlR;b8_8blb?d@oEEmECgI_IfnHShR?ZZo<
_l_?gLoLg`02gMl02mg?blnl_jV_VYmfOdA?E4lR;c8_4@l00P0?00D@7a4?8RlR;eA?009gO`0:VYnY
WkbogMoMcngOgMoLgmg?bll2ZZl05HR?V8mWKeEOEDm3Cd@o<SlS;b4_4AlQ7a4?4AlA3a0O0@l@3`0?
ool03`0Qool001Soo`0300ooo`0?01H03`0:01nJWjZ_8clc?a8O4Al13`0O0@l:00l02P0O0@l@7`4?
4AlB7a4_8clc?iZO600?00?oo`0?ool0<Ooo5@0?00D13`0O4QlQ;fM_00;oo`;Mg`0:R9n9SeEO8clc
?a8O8Bl13`0O0@l200l01@0O0@lA7a8O8Bl00S<o00=EGhRORHl00]gO0_oo00EgOa8O4Bl13`0O01D0
3c;oo`0600ooo`0O0@l@7`4O0Q4O010Q;a8O8RlS;c<o8cm4CeIOIFmgOgN?VYnIWk^ogMo=g`;^k`0=
o_o_knk_cMoMgj^_^kmhSeEOAElR?b<_41l00P0?01413a0O8blR?dEOR8mhSk^oZjoMgno_k^o_koko
kno^klgO00:k_`:IW`03MhmFGfE_0094C`8c?`038RlQ;a8O00<A7`060@l@7`4?01ooo`0?8Ooo000H
ool00`0?ool03`0G00l02JV_VYlb?c<_8AlA3a0O0@l@3`0;00l02A0?00l@7`4?8AlA7c8o<bnY[`0H
00l00ooo00ooo`0aool00`0?ool03`0B00l01A0O00lQ;a4OMWl00_oo0]gO00Z9SiROEElc?c<_8BlB
7a0O00l@3`<03`0940lA3b4_4Qlb?c<oEEn9SiRO00;Mg`;oo`04MflQ;a8O40lD00l00ooo00ooo`0a
ool02P0?ool03a0O0@l@7a4?4AlB7b4_0R8_0S<o00=4CfE_EEl00WMo0YVO00>k_mg?g=l00^k_00g_
kok_k^oLgmg?^[n[[hN?EDmDGb8_<Sl13`0200l03Q0O0@lb;b8_E5n8OhN?Zjnj_mg?o^o^kokoknl2
k^l00mcO^knk_`02VIl00gMoIFmEG`02A4l01C8o<clR;a8O8Bl00Q4O00LA3a0O0@l@7`0?ool03`0Q
ool001Soo`0300ooo`0?01L03`0;0@l07iZ_ZJlS?a4_4QlA7`4O01l13`0600l0300O0@l@7`4?41lB
7b4_8clc?iZ_ZJl13aP03`03ool03ooo037oo`0300ooo`0?01803`070@l03`4?41lS;hROR8l00_oo
00[MglgOR9m5GeEO8blR?a4O01l13`803`0:01l13a4O8blb?dE?E5n8SmgOcMl2ool01hROR8lR?`4O
41l03`0O01<03`03ool03ooo037oo`0500oooa0O0@l@7`034Al03R4_4RlR?b<_<dld?dAOEUmUKgQo
QhnJWiV__;l2gMl01nkoknooono_o_oNgmg_00:k_`06R8mEGeEO<SlS;a4O0P0?00D17a4O8blb?eEO
00:8S`:k_`03gNo_koko00;oo`0Jkno^omkO^lnl_iV_VYn7SeIOIFm5CdAO<clcCb<_8RlB7a4_4QlA
7`4?41l13a0Oool03b7oo`006?oo00<03ooo00l06@0?00T@3`0?oold?d<o4AlQ;`4?40l01`0?00H@
3a4?41lB7d<o=3l2ool00a0?00l03`0H00l00ooo00ooo`0aool00`0?ool03`0B00l01A0?00l@3`0?
41l00R8_00aWKgIoc<o<ck^oQgmgOd=?A3lQ;`0?41l300l0110O4Qm3Cd@o0WMo00Fk_lc?c<mWKgIo
008R;`030@l@3`0?01D03`03ool03ooo037oo`0C00ooo`0?41l13a0O4@lA7a8O8BlR;c8_<cm3?dA?
IFmFGhMoMgl00YVO00Fj_mg?g=o^gng_00?^k`05g=oMckZoZjn7S`02EEl00b<_<RlA3`0200l02Q0O
4@lb?b<_E5n8OhR?Zjnj_mg?0^k_00Gnknk_k^o^gmcO00:k_`:IW`05MgmUKeIOE4m4C`02<cl0338_
8QlQ;a4O8AlA3a0O0@l@3`0?ool03b7oo`006?oo00<03ooo00l06P0?00T07ooo@dld?a4_4QlA7`4?
01l01@0?00L07`4?41l17b4_=3lcC`02ool00`0?01l03`0H00l00ooo00ooo`0aoolG00l02P4?00l1
3b8o8bmgOfM_c<o=ck^o0WMo00DdCdA?4Ql07`4?00803`0B01l13b8_=4m4CgQoMgnk_lc?cLmgOfM_
8SlS;a4O0@l07`4?5P0?<_oo00`03ooo01l13a4O0AlA7a8O8RlB7b8o8bl2<cl01DAOEVmVKgQoMhl0
0YVO00f[_mcOcLo^kmk_k_o_knk_cMoMgj^_^kmhS`02EEl00c8o8bl@7`0200l03P4?41lS;c8oAEn8
SgR?^kn[[mgOkno^kno_k_l2k^l00lg?^knk_`02VIl02WN?EVmVKdE?A5ld?c<o8blQ;a8_0a4O00H1
3a4O0@l07ooo00lQool001;oo`<03`?oo`0300ooo`0?01`03`8A7`06Mgn7Ob8_41l13a0?0`0?00P@
3a4?41lR7b4_MglA7a4?7@0?00?oo`0?ool0:ooo0`0?0ooo00<03ooo00l05`0?00h13a0O4AlQ;c@o
@dmVKgMoMfmDGeE?8Rl13a0O0P0?00h13a0O8RmDGdE?MWmgOgIo=3m3Ca4O8Bl13a0O600?00?oo`0?
ool0:_oo0`0?1?oo00`03ooo0@l@7`4?4AlA3b4O8QlQ;b8_<Rl2<cl05TA?IEmEGgIoIfnHShR?ZZnl
_l_?cLoLgmgOg=oMcl_?_;nY[jZOMgm5CeAO0R8_00l13`0?00l@7`4?<RlR;eAOMgn7OjZOZJnl_mcO
gLl00]gO00[Lglg?blnZ[jV_R8nHWfM_IEmEG`94C`05<Slc?b8_4QlQ;`024Al01a4?41l13a0O0@oo
o`0?027oo`004ooo00<03oooool00_oo00<03ooo00l0700?0Q4O0WMo00DR;`4O4Al03`0O00<03`05
41l17b8_4RmgS`024AlM00l00ooo00ooo`0/ool00`0?ooooo`02ool00`0?ool03`0E00l02@0O0@l@
7`4?8BlB7d=?=3mVO`02Mgl01DEOE5lS;a0O0@l00P0?00l@7`4?8Sm5GeEOIgmgOfM_@dld?b4_4Ql@
7`4?01l05`0?00?oo`0?ool0:ooo00<03oooool00ooo00D03ooo41l13a0O00<A7`048BlB;b8o8Rl2
<cl06DA?EUmEKfMoMgn9ShROZZo;ckbog=o=gmgOcMoMgkc?blnJWjV_N7mDGdE?8SlS;a0O00803`05
0Al@7b8_8Sm5C`02Mgl02ZV_VZo;clgOgMoNgmgOcLoLgkbo0ZZ_00F8WhV?MgmFGeE_0094C`8c?`0<
8blR;a8O4BlB7a4O0@l@7`4?41ooo`0?8Ooo000Cool00`0?ooooo`02ool00`0?ool03`0Q00l0110?
00l@3`4?0P0?00<@3`0?40l08P0?00?oo`0?ool0;?oo00<03oooool00_oo00<03ooo00l05P0?00l@
3`0?00l13a0?4@l@7a4O8BlR7b8_8QlQ7`0?41l00`0?00/@7a4O8BlR;b4_8QlQ7a4?41l13a0?01X0
3`03ool03ooo02_oo`0300oooooo00?oo`0:00ooo`4?41l13a0O4@lA7a8O8Bl28Rl01C<_<Sm4?eAO
EDl00VI_00>7OgQoV9l00ZZ_00>k[kZo^kl00[^o0ZZ_00RHShV?MVm4?dA?8QlQ;`4?0P0?00D@7`4?
8RlR7d=?009VK`03RHnHSjZ_00:k_`0Lbknk_k^o^jnZ[iV?V9mhOhMoIVmDGeE?@dm4?c8o<blR;a8O
8BlA7b4O4@l@7`4?40l13ooo00lQool001?oo`0300oooooo00;oobD03`0301l13`0O00803`030@l0
3`0?02803`03ool03ooo02coo`0300oooooo00;ooaX03`0801l13`0O0@l@7`4O4AlB;`<R;`034Ql0
7`4?00803`0>01l13a4O4RlR;a8_8RlA7a0O0Al07`4?01l13aX03bcoo`0300oooooo00?oo`0:00oo
o`0O0@lA7`4O4AlB7b4_4Ql28Rl02S<o8cm3CdEOEEmFKfI_N7mgShV?0ZZ_00>k_j^o^ll00[^o0ZZ_
00R9ShROIVm4CcA?8RlB;a0O0P0?00X13a0O8RlR;cA?IWmWKhRORHnZ[`:k_`0C_;nkck^o^knJ[iVO
RImgSgQoIVm5GeEO=3m3Cb<o<clR;b4_4Ql00a4O00@13a4O0@l07`803b7oo`004_oo0P0?1?oo00<0
3ooo00l0C00?00?oo`0?ool0:ooo0P0?1?oo00<03ooo00l0700?00D@3`0?40l03a0?00T03`0340l0
3a0?00<03`0340l03`0?01X03`03ool03ooo02[oo`803`Goo`0700ooo`4?41l13a0O4@l00Q4O00HQ
;b8O8BlR;c8o<cl2A4l2EEl01GI_IVn7ShR?V8l01IVO0XR?00QfOgM_EElc?d<o4QlQ;`4?0P0?00D@
7`4?8BlB7c<o009EG`03MfmfOhR?00:IW`07ZJnIWiVOVInHWgMoQgl00VI_00=EGdA?A4l00S<o00Db
?b8_8RlB7b4O008A7`074@l@7`4?41l13ooo00l08Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0a
ool00`0?ool03`1=00l00ooo00ooo`0aool01P0?ool@7`4?41l17`8A7`0O4BlB7b8_4QlR?b8_<cld
?d=?ADm4GeEOEFmVKgMoIfmgSgQoQhmgOgN?IfmfOeIOEFm4Cc8o8blA;a8O41l00P0?00D13a0O4AlA
;b<_0094C`0:EFmFGgIoMgmgSgQoQhmgOgN?Igl2IVl02eE_EEm4Gc@o@dlS?c<o8RlR?a8_4Bl0114O
00H13a0O0@l@7ooo00lQool001Soo`0300ooo`0?04`03`03ool03ooo037oo`0300ooo`0?04d03`03
ool03ooo037oo`0700ooo`0?41l13a0O4@l00Q4O00XQ7b8O8BlR;c8_<bm3Cc@oE4m4C`9EG`05IVmg
KgIoMgn7O`03Mgl02GI_IfmUGeIOA4lS;c8o4AlQ7`0300l01A0?00lQ7a4O<Sl00TA?00=FGfEOIfl0
0WMo00F7OgMoQgmgOgIo009VK`07EEmUGdA?@dld?c8o<bl00R8_00`Q;a4O8AlA3a4O4@l@7`4?40l0
3ooo00lQool001Soo`0300ooo`0?04`03`03ool03ooo037ooe803c;oo`0800ooo`0O0@l@7`4?41l1
7`8A7`0E4BlB7b8_4RlR?b<o<cld?c=?ADm4CdE?EFmFGfI_EUmUKeIOIFm5GeEO0094C`068clR;b8_
4Al17`0O0P0?00D13`0O4AlA7a8_008c?`94C`0:EEmFGfE_EUmUKeI_IVmFGeEOAEl2A4l023=?8clc
?b<_8SlB;b8_4Ql34Al0204O41l13a0O0@l07ooo00lQool001Soo`0300ooo`0?04`03`03ool03ooo
037oo`0300ooo`0?04d03`03ool03ooo037oo`0800ooo`0?41l03a0O0@l@7`8A7`094QlQ7b8_8BlR
;c8o<cm3Cc@o0094C`07E5mEGfEOIUmUKeIOIFl00UEO00IECdA?A4lc?b8O8Bl24Al300l01a0?00l@
7a4O8Rlc?c8o0094C`0:EDmUKeEOIFmFGfE_IUmUGdE?E5l2A4l023@o<Slc?c8_8RlQ;b8_8Bl34Al0
210O0@l@7`0?41l03ooo00lQool001Soo`0300ooo`0?04`03`03ool03ooo037oo`0300ooo`0?04d0
3`03ool03ooo037oo`0800oooa0O0@l07`4?41l17`@A7`068BlB7b8_8blR?b<o0S<o00/cCcA?A4m4
CdAOADm4GdA?A5ldCdA?008c?`058blQ;a8O41l17`0300l01`4?00l17a0O4QlR?b8_008c?`94C`05
A5m5CdAOA4m4G`02A4l01S@o<dld?c<o8blR?`8R;`034QlQ;a8O008A7`0941l17a0O0@l07`4?41oo
o`0?027oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<OooDP0?<_oo00X03ooo00l@3`4?40l13a0O
4@l@7`<A7`098AlB7b8_8Qlb;b8_<SlS;c8o00<c?`06@clc?c<o<blb?c<_0R8_00DQ;a4O4Al13a0?
00<03`0=40l03a0O0@lA7b8O8BlR;c8_<blc?c<_@cl013<o00@c;c8o8blb;`8R;`048QlQ7a8O8Al2
4Al02a4?41l13a0O0@l@3`4?40l03ooo00l08Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0aool0
0`0?ool03`1=00l00ooo00ooo`0aool02P0?ool07`4?01l13`0O0@lA7`4O0a4O00<B7a4_4Rl00b8_
00<S;c8o8cl013<o00PcCc<o<clS;c8o8blR;a8O0Q4O00<@7`4?01l00`0?00H07`4?41l17b4_4Ql2
8Rl07c8o<clc?c<o<dld?c<o8clc?b<o<SlS;b8_4RlR;a8O4BlB7a4O0AlA7`4O4Al13`0O0@l07`4?
01ooo`0?027oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<Ooo00<03ooo00l0C@0?00?oo`0?ool0
<Ooo00`03ooo00l@3`0?41l13a0O4@l@7a4?41l34Al01B4O4AlQ;a8O8Bl00b8_00<b;b8_<Rl0128_
00PR7b4_4QlA7`4?41l03a0O1@0?00<@3`0?41l00Q4O00<B7b4_8Ql00R8_00<b;b8_<Rl01R8_00<B
7b4O4Al00Q4O00T@7a4O41l13a0O0@l@7`4?40l00`0?00?oo`0?ool08?oo000Hool00`0?ool03`1<
00l00ooo00ooo`0aool00`0?ool03`1=00l00ooo00ooo`0aool0300?ool07`4?01l13a0O0@l@7`4O
4Al17`<A7`054QlA;a8_8RlB;`028Rl01b8o8RlR?b<_8SlR;b8o008R;`074QlQ;a4O4Al17`0O0@l0
1@0?00<13`0O0Al00Q4O00XQ;a8O8RlR;b8o8blR?b<_8SlS;`DR;`034QlA;a8O00DA7`0:0@l@7`4?
41l13`0O0@l07ooo00lQool001Soo`0300ooo`0?04`03`03ool03ooo037ooe803c;oo`0>00ooo`0?
40l03a0?00l@7`4?41lA3a0O4@l@7`<A7`0=8AlA7b4_4QlQ;b8O8BlB7b4_8QlQ;a8O8Al00a4O00D@
7`4?41l03a0?00D03`0540l03a0?4@l@7`034Al02b4_4QlQ;b8O8BlB7b4_4QlQ;a8O8Al01A4O00h@
7a4?41l13a0O0@l@3`0?40l03a0?00ooo`0?8Ooo000Hool00`0?ool03`1<00l00ooo00ooo`0aool0
0`0?ool03`1=00l00ooo00ooo`0aool03P0?ool07`4?01l13`0O0@l@7`4?41l17a4O0Al34Al03Q8O
4BlB7b4_4QlQ;a8_8RlB7b4_4QlQ;a8O4Bl24Al01@4O01l13`0?0@l01@0?00D13`0?0@lA7`4O008A
7`0=4BlB7b4_4QlQ;a8_8RlB7b4_4QlQ;a8O4Bl00Q4O01017a4O0AlA7`4?41l13a0O0@l07`4?01l1
3`0Oool03b7oo`006?oo00<03ooo00l0C00?00?oo`0?ool0<Ooo00<03ooo00l0C@0?00?oo`0?ool0
<Ooo01003ooo00l@3`0?40l03a0?00l@7`4?41l13a0O0@l@7`LA7`038AlA7a4O00DA7`0541lA3a0O
00l@3`0700l01a0?00l@7`4?41lA3a0O00DA7`038AlA7a4O00DA7`0=41lA7a0O0@l@7`4?41l13a0?
00l@7`0?40l00`0?00?oo`0?ool08?oo000Hool00`0?ool03`1<00l00ooo00ooo`0aool00`0?ool0
3`1=00l00ooo00ooo`0aool0500?ool03`0?01l13`0O0@l07`4?41l13a0O0@l@7`4?41l17a4O0Al3
4Al03P4O4AlA7a4O0AlA7`4O4Al13a0O0@l07`0?01l700l0200O0@l@7`4?41l13a4O0Al34Al06P4O
4AlA7a4O0AlA7`4O4Al13a0O0@l@7`4?41l13a0O0@l07`4?01l03`0O0@l03ooo00lQool001Soo`03
00ooo`0?04`03`03ool03ooo037ooe803c;oo`0300ooo`0?00803`0A40l03a0?0@l@3`0?41l13a0?
0@l@7`4?41lA3a0O4@l@7`024Al03Q4?41lA3a0O4@l@7a4?41l13a0?00l@3`0?40l700l07A0?00l@
3`4?41lA3a0O4@l@7a4?4AlA3a0O4@lA7a4?41lA3a0O0@l@7`4?41l13a0?00l@3`0?40l00`0?00@@
3`0?ool03b7oo`004_oo0`0?0ooo00<03ooo00l0C00?00?oo`0?ool0:ooo0`0?0ooo00<03ooo00l0
C@0?00?oo`0?ool0:_oo0`0?1?oo00@03ooo00l13`803`0N01l13`0O0@l07`4?01l13`0O0@l@7`4?
41l13a4O0@l@7`4?4Al13a0O0@l@7`4?01l13`0O0@l07`4?1`0?02413`0?00l07`4?01l13`0O0@l@
7`4?41l13a4O0@l@7`4?4Al13a0O0@l@7`4?01l13`0O0@l07`4?00l13`0O0@l00`0?00?oo`0?ool0
8?oo000Bool00`0?ooooo`03ool00`0?ool03`1<00l00ooo00ooo`0[ool00`0?ooooo`03ool00`0?
ool03`1=00l00ooo00ooo`0Zool00`0?ooooo`04ool0100?ool03a0?0`0?01d@3`0?40l03a0?00l@
7`4?41l03a0O0@l@7`4?41l13a0O0@l@7`4?41l13a0O0@l@3`0?40l03a0?00/03`0I40l03a0O0@l@
7`4?41l13a0O0@l@7`4?41l13a0O0@l@7`0?41l13a0?00l@7`0?40l00`0?00H@3`0?00l03ooo00lQ
ool001?oo`0300oooooo00;oo`0300ooo`0?04`03`03ool03ooo02coo`0300oooooo00;oo`0300oo
o`0?04d03`03ool03ooo02_oo`0300oooooo00?oo`0600ooo`0?00l07`4?0P0?01X07`4?01l03`0O
0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l@7`4?01l13`0O00l07`4?3P0?01X07`4?01l13`0O0@l@
7`4?01l13a0O0@l07`4?41l13`0O0@l@7`4?01l13`0O00l07`4?0P0?00D07`0?00ooo`0?027oo`00
4_oo00<03ooo00l00ooo0P0?C_oo00<03oooool0:_oo00<03ooo00l00ooo0P0?C_oo0P0?:ooo00<0
3ooo00l01?oo00<03oooool0C?oo0P0?8Ooo000Cool200l3oomA00l]ool200l3oomB00l/ool200l4
oomA00lQool00?oooi;oo`00ooooT_oo003ooonBool0013oo`0300oooooo083oo`0300oooooo083o
o`0300oooooo07Soo`004Ooo00<03oooool0:ooo0`0?D_oo00<03oooool0:ooo0`0?D_oo00<03ooo
ool0:ooo0P0?B_oo000Aool00`0?ooooo`02ool01@0?ool03ooo00l00ooo00<03ooo00l07ooo00<0
3oooool0DOoo00<03oooool00_oo00D03ooo00ooo`0?00?oo`0300ooo`0?01koo`0300oooooo05;o
o`0300oooooo00;oo`0500ooo`0?ool03`03ool00`0?ool03`0Pool00`0?ooooo`17ool0013oo`03
00ooo`0?00?oo`0500ooo`0?ool03`03ool200lPool00`0?ooooo`1@ool00`0?ool03`03ool01@0?
ool03ooo00l00ooo0P0?8?oo00<03oooool0D?oo00<03ooo00l00ooo00D03ooo00ooo`0?00?oo`80
3b3oo`0300oooooo04Soo`004?oo00<03ooo00l00ooo00D03ooo00ooo`0?00Coo`0300oooooo01ko
o`0300oooooo053oo`0300ooo`0?00?oo`0500ooo`0?ool03`04ool00`0?ooooo`0Mool00`0?ool0
3`1Aool00`0?ool03`03ool01@0?ool03ooo00l01?oo00<03oooool07ooo00<03oooool0Aooo000@
ool00`0?ool03`03ool0100?ool03`0?1?oo0P0?7ooo0P0?D_oo00<03ooo00l00ooo00@03ooo00l0
3`Coo`803b3oo`803e7oo`0300ooo`0?00?oo`0400ooo`0?00l4ool200lOool200m:ool00?oooi;o
o`005_oo00<03oooool0P?oo00<03oooool0P?oo00<03oooool0L_oo003ooonBool00?oooi;oo`00
ooooT_oo003ooonBool00?oooi;oo`00ooooT_oo003ooonBool00?oooi;oo`00ooooT_oo003ooonB
ool00?oooi;oo`00ooooT_oo0000\
\>"],
  ImageRangeCache->{{{0, 399.9375}, {124.3125, 0}} -> {-2.079997, -2.069722, 
  0.01297, 0.01297}}]
}, Open  ]],

Cell[BoxData[
    \(\(Fig16x10 = 
      Table[DensityPlot[
          Evaluate[Abs[Eaz[x\ a, y\ a, \(10\^jj\ a\)\/1000]\^2]], {x, \(-2\), 
            2}, {y, \(-2\), 2}, 
          AxesLabel \[Rule] {"\<x in a\>", "\<y in a\>"}, 
          PlotLabel \[Rule] jj, Evaluate[opt1], 
          DisplayFunction \[Rule] Identity], {jj, 1, 3, 1}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{Fig16x10\[LeftDoubleBracket]1\[RightDoubleBracket], 
          Fig16x10\[LeftDoubleBracket]2\[RightDoubleBracket], 
          Fig16x10\[LeftDoubleBracket]3\[RightDoubleBracket]}]]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.31746 0.00744 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.02381 0.00744 0.321429 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25962 -0.0125 -7 -12 ]
[.25962 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.74038 -0.0125 -4 -12 ]
[.74038 -0.0125 4 0 ]
[.98077 -0.0125 -4 -12 ]
[.98077 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25962 -14 -6 ]
[-0.0125 .25962 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .74038 -8 -6 ]
[-0.0125 .74038 0 6 ]
[-0.0125 .98077 -8 -6 ]
[-0.0125 .98077 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000001010101010101000000000000
000000010101010101010000000000000000000000
000000000000000000010101010102020202010100000000
000101020202020101010101000000000000000000
000000000000000101010102020203040405060606020002
060606050404030202020101010100000000000000
000000000000010101010202030406090F26010000000000
000001260F09060403020201010101000000000000
00000000000101010102030406090F240400000000000000
0000000004240F0906040302010101010000000000
0000000000010101020304060A133D010000000000000000
0000000000013D130A060403020101010000000000
00000000010101020304060A133C01000000000000000000
000000000000013C130A0604030201010100000000
0000000101010202030509102A0A00000000000000000000
000000000000000A2A100905030202010101000000
000000010101020304070C1B980000000000000000000000
0000000000000000981B0C07040302010101000000
00000001010202030509112F070000000000000000000000
0000000000000000072F1109050302020101000000
0000010101020304060B175A000000000000000000000000
0000000000000000005A170B060403020101010000
0000010101020304070D1DB8000000000000000000000000
000000000000000000B81D0D070403020101010000
0000010101020305080E22FF000000000000000000000000
000000000000000000FF220E080503020101010000
0000010101020305080E24CB000000000000000000000000
000000000000000000CB240E080503020101010000
0000010101020305080E22FF000000000000000000000000
000000000000000000FF220E080503020101010000
0000010101020304070D1DB8000000000000000000000000
000000000000000000B81D0D070403020101010000
0000010101020304060B175A000000000000000000000000
0000000000000000005A170B060403020101010000
00000001010202030509112F070000000000000000000000
0000000000000000072F1109050302020101000000
000000010101020304070C1B980000000000000000000000
0000000000000000981B0C07040302010101000000
0000000101010202030509102A0A00000000000000000000
000000000000000A2A100905030202010101000000
00000000010101020304060A133C01000000000000000000
000000000000013C130A0604030201010100000000
0000000000010101020304060A133D010000000000000000
0000000000013D130A060403020101010000000000
00000000000101010102030406090F240400000000000000
0000000004240F0906040302010101010000000000
000000000000010101010202030406090F26010000000000
000001260F09060403020201010101000000000000
000000000000000101010102020203040405060606020002
060606050404030202020101010100000000000000
000000000000000000010101010102020202010100000000
000101020202020101010101000000000000000000
000000000000000000000001010101010101000000000000
000000010101010101010000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744 0.64881 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25962 -0.0125 -7 -12 ]
[.25962 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.74038 -0.0125 -4 -12 ]
[.74038 -0.0125 4 0 ]
[.98077 -0.0125 -4 -12 ]
[.98077 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25962 -14 -6 ]
[-0.0125 .25962 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .74038 -8 -6 ]
[-0.0125 .74038 0 6 ]
[-0.0125 .98077 -8 -6 ]
[-0.0125 .98077 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000001010101010101010101000000000000000000000000
000000000000000000010101010101010101010000
010101010101010101010101010101000000000000000000
000000000000010101010101010101010101010101
010101010101010101010101010101010000000000000000
000000000001010101010101010101010101010101
010101010101020202020202020101010100000000000000
000000000101010102020202020202010101010101
010101020202020202020202020202020101000000000000
000000010102020202020202020202020202010101
010202020202030303030303030303020201010000000000
000001010202030303030303030303020202020201
020202020303030404040405050404040302020100000000
000102020304040405050404040403030302020202
020203030304040505060606070706060504030201000000
010203040506060707060606050504040303030202
020303040405050607070809090A0A090807050301000000
0103050708090A0A09090807070605050404030302
0303040405060708090A0B0C0D0E0F0F0E0C090603000000
0306090C0E0F0F0E0D0C0B0A090807060504040303
030404050607080A0B0D0F11141617181816120C06010001
060C12161818171614110F0D0B0A08070605040403
0404050607090A0C0E1115181D22262A2C281F1308010001
08131F282C2A26221D1815110E0C0A090706050404
04050607090A0D0F13171C232B36414A4833180902000000
02091833484A41362B231C17130F0D0A0907060504
050607080A0C0F13181E273342576B673A15070200000000
000207153A676B574233271E18130F0C0A08070605
0506080A0C0F12171E283549668787411406020000000000
0000020614418787664935281E17120F0C0A080605
0607090B0E11161D2634496997AB55180702010000000000
00000102071855AB97694934261D16110E0B090706
06080A0C0F141A222F436294C883240A0301000000000000
00000001030A2483C89462432F221A140F0C0A0806
07090B0D11161E29395481C5CD4511050200000000000000
0000000002051145CDC5815439291E16110D0B0907
07090B0F1319222F4466A3EF9B250A030100000000000000
0000000001030A259BEFA366442F2219130F0B0907
080A0C10141B25344D79C4FF681706020100000000000000
000000000102061768FFC4794D34251B14100C0A08
080A0D10151D28395689DFF84A1105020000000000000000
00000000000205114AF8DF895639281D15100D0A08
080A0D11161E2A3C5B93F1E93C0E04010000000000000000
000000000001040E3CE9F1935B3C2A1E16110D0A08
080A0D11161E2A3D5D97F6E3380D04010000000000000000
000000000001040D38E3F6975D3D2A1E16110D0A08
080A0D11161E2A3C5B93F1E93C0E04010000000000000000
000000000001040E3CE9F1935B3C2A1E16110D0A08
080A0D10151D28395689DFF84A1105020000000000000000
00000000000205114AF8DF895639281D15100D0A08
080A0C10141B25344D79C4FF681706020100000000000000
000000000102061768FFC4794D34251B14100C0A08
07090B0F1319222F4466A3EF9B250A030100000000000000
0000000001030A259BEFA366442F2219130F0B0907
07090B0D11161E29395481C5CD4511050200000000000000
0000000002051145CDC5815439291E16110D0B0907
06080A0C0F141A222F436294C883240A0301000000000000
00000001030A2483C89462432F221A140F0C0A0806
0607090B0E11161D2634496997AB55180702010000000000
00000102071855AB97694934261D16110E0B090706
0506080A0C0F12171E283549668787411406020000000000
0000020614418787664935281E17120F0C0A080605
050607080A0C0F13181E273342576B673A15070200000000
000207153A676B574233271E18130F0C0A08070605
04050607090A0D0F13171C232B36414A4833180902000000
02091833484A41362B231C17130F0D0A0907060504
0404050607090A0C0E1115181D22262A2C281F1308010001
08131F282C2A26221D1815110E0C0A090706050404
030404050607080A0B0D0F11141617181816120C06010001
060C12161818171614110F0D0B0A08070605040403
0303040405060708090A0B0C0D0E0F0F0E0C090603000000
0306090C0E0F0F0E0D0C0B0A090807060504040303
020303040405050607070809090A0A090807050301000000
0103050708090A0A09090807070605050404030302
020203030304040505060606070706060504030201000000
010203040506060707060606050504040303030202
020202020303030404040405050404040302020100000000
000102020304040405050404040403030302020202
010202020202030303030303030303020201010000000000
000001010202030303030303030303020202020201
010101020202020202020202020202020101000000000000
000000010102020202020202020202020202010101
010101010101020202020202020101010100000000000000
000000000101010102020202020202010101010101
010101010101010101010101010101010000000000000000
000000000001010101010101010101010101010101
010101010101010101010101010101000000000000000000
000000000000010101010101010101010101010101
000001010101010101010101000000000000000000000000
000000000000000000010101010101010101010000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744 0.97619 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -7 -12 ]
[.01923 -0.0125 7 0 ]
[.25962 -0.0125 -7 -12 ]
[.25962 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.74038 -0.0125 -4 -12 ]
[.74038 -0.0125 4 0 ]
[.98077 -0.0125 -4 -12 ]
[.98077 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -14 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .25962 -14 -6 ]
[-0.0125 .25962 0 6 ]
[-0.0125 .5 -8 -6 ]
[-0.0125 .5 0 6 ]
[-0.0125 .74038 -8 -6 ]
[-0.0125 .74038 0 6 ]
[-0.0125 .98077 -8 -6 ]
[-0.0125 .98077 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -4 0 ]
[.5 1.0125 4 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -65 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1B1C1C1D1D1D1D1C1B1A181614110E0C0906040201000000
01020406090C0E111416181A1B1C1D1D1D1D1C1C1B
1E1F202121212121201E1C1A1714110E0B08050301000000
010305080B0E1114171A1C1E202121212121201F1E
22242526262726262524221F1C1915110D0A060301000000
0103060A0D1115191C1F2224252626272626252422
27282A2B2C2D2D2C2B2A2825211D1915100C080402000000
0204080C1015191D2125282A2B2C2D2D2C2B2A2827
2B2D2F313233343433312F2C28231E19130E090502000000
0205090E13191E23282C2F313334343332312F2D2B
313336383A3B3C3C3B3A37342F2A241E17110B0603000000
03060B11171E242A2F34373A3B3C3C3B3A38363331
36393C3F424345454543413D38322B231C140D0803000000
03080D141C232B32383D414345454543423F3C3936
3C4044474A4D4F50504E4B47413B332A2118100904010001
04091018212A333B41474B4E50504F4D4A4744403C
43484C5054575A5B5C5A57534C443B31261C130B05010001
050B131C26313B444C53575A5C5B5A5754504C4843
4A4F555A5F6366686968655F584F44392C20160C05010001
050C16202C39444F585F6568696866635F5A554F4A
51585E646A6F73767776736D655A4E413325190E06010001
060E192533414E5A656D73767776736F6A645E5851
5960686F767C81858685827B7266584939291B1007010001
07101B2939495866727B82858685817C766F686059
6169717A828990949695918A7F7262503F2D1E1107020002
07111E2D3F5062727F8A919596949089827A716961
68727B858E979EA3A6A5A1998D7D6B584431201208020002
0812203144586B7D8D99A1A5A6A39E978E857B7268
707A85909BA5ADB3B6B5B0A79988745E4934221308020002
08132234495E748899A7B0B5B6B3ADA59B90857A70
77838F9BA7B2BBC2C5C4BFB4A4917B644C37241409020002
091424374C647B91A4B4BFC4C5C2BBB2A79B8F8377
7E8B98A5B2BEC8D0D3D2CCC0AF9981685039251509020002
0915253950688199AFC0CCD2D3D0C8BEB2A5988B7E
8492A0AEBCC9D4DCE0DFD7CAB7A0876C523A261509020002
0915263A526C87A0B7CAD7DFE0DCD4C9BCAEA09284
8998A7B6C5D3DFE7EBE9E1D2BEA68A6F543B261509020002
0915263B546F8AA6BED2E1E9EBE7DFD3C5B6A79889
8E9DADBDCDDBE7F0F4F2E9D9C4AA8D70553C271609020002
0916273C55708DAAC4D9E9F2F4F0E7DBCDBDAD9D8E
91A0B1C2D2E1EEF7FAF8EEDEC7AD8F72563C271609020002
0916273C56728FADC7DEEEF8FAF7EEE1D2C2B1A091
93A3B3C5D5E5F2FBFEFBF1E1CAAE9173563C271609020002
0916273C567391AECAE1F1FBFEFBF2E5D5C5B3A393
93A3B4C6D6E6F3FCFFFDF3E2CAAF9173563D271609020002
0916273D567391AFCAE2F3FDFFFCF3E6D6C6B4A393
93A3B3C5D5E5F2FBFEFBF1E1CAAE9173563C271609020002
0916273C567391AECAE1F1FBFEFBF2E5D5C5B3A393
91A0B1C2D2E1EEF7FAF8EEDEC7AD8F72563C271609020002
0916273C56728FADC7DEEEF8FAF7EEE1D2C2B1A091
8E9DADBDCDDBE7F0F4F2E9D9C4AA8D70553C271609020002
0916273C55708DAAC4D9E9F2F4F0E7DBCDBDAD9D8E
8998A7B6C5D3DFE7EBE9E1D2BEA68A6F543B261509020002
0915263B546F8AA6BED2E1E9EBE7DFD3C5B6A79889
8492A0AEBCC9D4DCE0DFD7CAB7A0876C523A261509020002
0915263A526C87A0B7CAD7DFE0DCD4C9BCAEA09284
7E8B98A5B2BEC8D0D3D2CCC0AF9981685039251509020002
0915253950688199AFC0CCD2D3D0C8BEB2A5988B7E
77838F9BA7B2BBC2C5C4BFB4A4917B644C37241409020002
091424374C647B91A4B4BFC4C5C2BBB2A79B8F8377
707A85909BA5ADB3B6B5B0A79988745E4934221308020002
08132234495E748899A7B0B5B6B3ADA59B90857A70
68727B858E979EA3A6A5A1998D7D6B584431201208020002
0812203144586B7D8D99A1A5A6A39E978E857B7268
6169717A828990949695918A7F7262503F2D1E1107020002
07111E2D3F5062727F8A919596949089827A716961
5960686F767C81858685827B7266584939291B1007010001
07101B2939495866727B82858685817C766F686059
51585E646A6F73767776736D655A4E413325190E06010001
060E192533414E5A656D73767776736F6A645E5851
4A4F555A5F6366686968655F584F44392C20160C05010001
050C16202C39444F585F6568696866635F5A554F4A
43484C5054575A5B5C5A57534C443B31261C130B05010001
050B131C26313B444C53575A5C5B5A5754504C4843
3C4044474A4D4F50504E4B47413B332A2118100904010001
04091018212A333B41474B4E50504F4D4A4744403C
36393C3F424345454543413D38322B231C140D0803000000
03080D141C232B32383D414345454543423F3C3936
313336383A3B3C3C3B3A37342F2A241E17110B0603000000
03060B11171E242A2F34373A3B3C3C3B3A38363331
2B2D2F313233343433312F2C28231E19130E090502000000
0205090E13191E23282C2F313334343332312F2D2B
27282A2B2C2D2D2C2B2A2825211D1915100C080402000000
0204080C1015191D2125282A2B2C2D2D2C2B2A2827
22242526262726262524221F1C1915110D0A060301000000
0103060A0D1115191C1F2224252626272626252422
1E1F202121212121201E1C1A1714110E0B08050301000000
010305080B0E1114171A1C1E202121212121201F1E
1B1C1C1D1D1D1D1C1B1A181614110E0C0906040201000000
01020406090C0E111416181A1B1C1D1D1D1D1C1C1B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 90},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000LA000`40l00?003`ooooJOoo003ooomY
ool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00
ooooJOoo003ooomYool00?ooofWoo`006Ooo0`0?3_oo0`0?3?oo00<03oooool03?oo0`0?3_oo0`0?
<ooo0`0?3_oo0`0?3?oo00<03oooool03?oo0`0?3_oo0`0?<ooo0`0?3Ooo0`0?3?oo00<03oooool0
3Ooo0`0?3Ooo0`0?8Ooo000Iool00`0?ooooo`0?ool00`0?ooooo`0:ool00`0?ool03`0>ool00`0?
ooooo`0=ool00`0?ooooo`0cool00`0?ooooo`0?ool00`0?ooooo`0:ool00`0?ool03`0>ool00`0?
ooooo`0=ool00`0?ooooo`0cool00`0?ooooo`0>ool00`0?ooooo`0:ool00`0?ool03`0?ool00`0?
ooooo`0<ool00`0?ooooo`0Qool001Goo`<03`;oo`0300oooooo00Soo`<03`?oo`0300oooooo00[o
o`0300ooo`0?00koo`0300oooooo00koo`0300oooooo02koo`<03`;oo`0300oooooo00Soo`<03`?o
o`0300oooooo00[oo`0300ooo`0?00koo`0300oooooo00koo`0300oooooo02goo`<03`?oo`0300oo
oooo00Soo`<03`;oo`0300oooooo00[oo`0300ooo`0?00ooo`0300oooooo00goo`0300oooooo023o
o`006Ooo00<03ooo00l03ooo00<03oooool02_oo00<03ooo00l03_oo00<03oooool03Ooo00<03ooo
00l0<ooo00<03ooo00l03ooo00<03oooool02_oo00<03ooo00l03_oo00<03oooool03Ooo00<03ooo
00l0<ooo00<03ooo00l03_oo00<03oooool02_oo00<03ooo00l03ooo00<03oooool03?oo00<03ooo
00l08Ooo000Jool200l>ool200l=ool00`0?ooooo`0<ool200l@ool200ldool200l>ool200l=ool0
0`0?ooooo`0<ool200l@ool200ldool200l=ool200l=ool00`0?ooooo`0=ool200l?ool200lQool0
0?ooofWoo`00ooooJOoo001Pool00`0?ool03`03ool01@0?ool03ooo00l00ooo00<03ooo00l0IOoo
00<03ooo00l00ooo00D03ooo00ooo`0?00?oo`0300ooo`0?06Coo`0300ooo`0?00?oo`0600oooooo
00ooo`0?0ooo00<03ooo00l02ooo000@ool300m>ool00`0?ooooo`02ool01@0?ool03ooo00l00ooo
0P0?5_oo0`0?C_oo00<03oooool00_oo00D03ooo00ooo`0?00?oo`803aKoo`<03dgoo`0300oooooo
00;oo`0600oooooo00ooo`0?0ooo0P0?3?oo000@ool00`0?ooooo`1>ool00`0?ooooo`02ool01@0?
ool03ooo00l01?oo00<03oooool05?oo00<03oooool0C_oo00<03oooool00_oo00D03ooo00ooo`0?
00Coo`0300oooooo01Coo`0300oooooo04goo`0300oooooo00;oo`0600oooooo00ooo`0?1?oo00<0
3oooool02_oo000<ool300l2ool00`0?ooooo`03oom500l4ool00`0?ool03`03ool0100?ool03`0?
1?oo0P0?4Ooo0`0?0ooo00<03oooool00oooA@0?1?oo00<03ooo00l00ooo00@03ooo00l03`Coo`80
3a7oo`<03`?oo`0300oooooo00?oodD03`?oo`0300ooo`0?00?oo`0300oooooo00803`Coo`803`co
o`004?oo00<03ooo00l01?oo00<03ooo00l0@P0?:_oo00<03ooo00l01?oo00<03ooo00l00`0?00D0
7`0?00l03`0O00<03`0501l03`0?00l07`0O00l01@0O00l03`0?01l00`0?00D07`0?00l03`0O00H0
3b[oo`0300ooo`0?00Coo`0E00lB;b8_4RlQ;a8_8RlB;b8_4RlR;a8_8BlB;b8_4QlQ;a8O8BlA7a4_
008A7`070AlA7`4O41l13`0O0@l02P0?00@07`4?41l13`@A7`0E4BlB7b4_4QlQ;a8_8RlB7b4_4RlR
;a8_8RlB;b8_4RlQ;a8_8Rooo`0?023oo`004Ooo0P0?1?oo00<03ooo00l0@P0?2_oo00<03oooool0
7_oo0P0?1?oo00<03ooo00l0100?00D@3`0?00l03a0?00<03`0340l03`0?02403`0540l03`0?00l@
3`0300l01A0?00l03`0?40l01@0?2_oo00<03oooool07_oo0P0?1?oo01@03b4_8QlQ;b8O8BlR7b4_
8QlQ;b8O8BlR7b4_8QlQ;a8O8AlA7b4O0a4O00L@7a4?41l03a0O00l@3`0700l02A0?00l03`0?40l0
3a0O4@l@7`034Al0524O4AlQ;a8O8BlR7b4_8QlQ;b8O8BlR7b4_8QlQ;b8O8BlR7ooo00l9ool00`0?
ooooo`0Dool001Ooo`0300ooo`0?04803c7oo`0300ooo`0?00803`050@l03`0?00l13`0300l01@4?
00l03`0?0@l00`0?00<13`0?00l06@0?00D13`0?00l03`4?00<03`050@l03`0?00l13`0300l0104?
00l03`0?<Ooo00<03a8_8Rl00R8_00DB;b8_8RlR;a8_00<R;`094RlR;a8_8RlB7b4_4QlQ;a8O00<A
7`070@l@7`4?01l13`0O0@l01P0?00H07`4?01l13a0O0Al34Al01a8O8BlB7b4_4RlR;a8_00<R;`05
4RlR;b8_8RlB;`038Rl0118_8Rooo`0?8?oo000Gool00`0?ool03`1200laool00`0?ool03`1200la
ool0100?8RlR;c8_0b8_00Db;b8_<SlR;c8_00<R;`07<RlR;b8_8QlQ;b8O8Bl00a4O00<@7`4?41l0
2`0?00`@3`0?41l13a0O4AlQ7a4O8BlR7b4_8Ql48Rl02C8_8Rlb;b8_<RlR;c8_8Rlb;`038Rl00ooo
00ooo`0Oool001Ooo`0300ooo`0?04803c7oo`0300ooo`0O00<03`0501l03`0?00l07`0300l01@0O
00l03`0?01l00`0?00<07`0?00l05@0?00D07`0?00l03`0O00<03`0501l03`0?00l07`0300l01@0O
00l03`0?01l00P0?<Ooo00l03b8_8RlR;b8o8blR?b<_8SlS;b8o8blR?b<_8Sl0128_00@B;b4_4QlA
;`@A7`040@l07`4?01l700l0300O00l07`4O4Al17a4O4QlA;a8O8BlB;`<R;`0@8blR?b8_8SlS;b8o
8blR?b<_8SlR;b8o8blR;ooo00lPool001Ooo`0300ooo`0?04803c7oo`0400ooo`0?40l300l01A0?
00l03`0?40l00`0?00D@3`0?00l03a0?00<03`0340l03`0?01403`0540l03`0?00l@3`0300l01A0?
00l03`0?40l00`0?00D@3`0?00l03a0?00<03`0340l03ooo033oo`0B00lb;b8_<SlS;c8o<blb?b<_
<Slc;c8o8blb?c<_<SlS;c8_0R8_00@R7b4_4QlQ7`8A7`044@l@7`4?40l700l01Q0?00l@3`4?41lA
3`8A7`048BlB7b4_8Ql28Rl04S8o8blb?c<_<SlS;c8o<blb?b<_<Slc;c8o8blb;b8_ool03b3oo`00
5ooo00<03ooo00l0@P0?<Ooo00<03ooo00l00P0?00D13`0?00l07`4?00803`0601l13`0?00l07`4?
0P0?00H07`4?00l03`0O0@l?00l01@4?00l03`0O0@l00P0?00H07`4?00l03`0O0@l200l01P0O0@l0
3`0?01l13`<03`040@l03`0?00laool01P0?8blb?b<o<clS?`Dc?`03=3lc?c<o00<c?`048clb?b<_
<Sl28Rl00a8O8BlA7`034Al00`4?01l13`0600l0400O0@lA7`4O4AlB7b4_4RlR;b<_<SlS;c8o8clc
?b<o1c<o00PS?c<o8clc?b<_<Sooo`0?8?oo000Gool00`0?ool03`1200laool00`0?ool03`0600l0
1A0?00l03`0?40l00`0?00D@3`0?00l03a0?01L03`0540l03`0?00l@3`0300l01A0?00l03`0?40l0
0`0?00<@3`0?00l01@0?<Ooo00P03c8o8blb?c<o<Slc;c8o1c<o00Db?c<o<SlS;c8_008R;`0:8QlQ
;a8O4AlA3a0O0@l@7`0?40l700l0210?0@lA7a4?8AlB7b4_8Ql28Rl00c8o8blb?`0:<cl01c<_<Slc
;c8o8booo`0?023oo`005ooo00<03ooo00l0@P0?<Ooo00@03ooo01l13`803`0B01l13`0?00l07`4?
01l03`0O0@l07`0?01l13`0O00l07`4?0P0?00<07`0?00l03@0?01807`4?00l03`0O0@l07`0?01l1
3`0O00l07`4?01l03`0O0@l200l01@0O0@l03`0?01l00P0?<Ooo01X03c<o<clc?c=?=3m3Cc@o@dld
?d=?=3m3Cc@o@dld?c=?=3lc?b<o<clS;b8_4RlR;a8O0Q4O00<@7`4?41l01P0?00@13a0O0@l@7`8A
7`054QlR;b<_8RlS;`03<cl033@o<dld?d=?=3m3CcA?@dld?d=?=3m3C`@c?`03ool03ooo01ooo`00
5ooo00<03ooo00l0@P0?<Ooo00@03ooo00l@3`<03`0E40l03a0?00l@3`0?40l03a0?00l@3`4?40l0
3a0?00l@3`0?40l03a0?00/03`0I40l03`0?00l@3`0?40l03a0?00l@3`4?40l03a0?00l@3`0?40l0
3a0?00l@3`0?40l00`0?00<@3`0?ool0<?oo00T03d<o<cm3Cc@o@dm4?dA?A3l014A?00YDCdA?A4m4
?d=?A3m3?c@o<clc;`8R;`078BlA7b4O4@l@7`4?40l01@0?010@3`4?41lA3b4O4AlQ;b8_<Slc;c<o
=3m3?d@oA4m4?`A4C`0<E4m4CdA?A3m3Cd@o@dld?d<o<cooo`0?8?oo000Gool00`0?ool03`1200la
ool06P0?ool03`0?01l13`0?0@l07`4?00l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l200l0
0`0O0@l03`0900l05P0O0@l03`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0?0@l07`4?0P0?
00<07`4?00l00P0?<Ooo00H03c@o<dld?dA?=3l3A4l00cA?A4m5C`05A4l03cA?@dld?c=?8clb?b<_
8RlB7a4_4QlA7`4?41l13`0500l04`4?41l13a4O4QlA;a8_8RlS;c8o<clcCc@o@dldCdA?=4m4CdE?
00E4C`08=4m4Cc@o@dld?c=?ool03b3oo`005ooo00<03ooo00l0@P0?<Ooo00<03ooo00l00P0?01T@
3`0?00l03a0?00l@3`0?40l03a0O0@l@3`0?41l13a0O00l@7`4?40l03a0?00l@3`0;00l05A0?00l@
7`4?40l03a0O0@l@7`0?41l13a0?00l@7`0?40l03a0?00l@3`0300l0110?00l03`0?<Ooo00@03d=?
=3m3C`=4C`0IE4m4CeAOADmDGeE?E5m5CeAOA4mDGdA?@dm4Cd=?<clb?b<_8RlB7b4_4Al@7`4?40l0
1@0?00P@3`4?41lA7b4_4QlQ;b<_0S<o00m3CdA?@dm4CeAOA4mDGdE?E5mECeAOADmDGdA?E5l00TA?
00E4?d=?=3ooo`0?023oo`005ooo00<03ooo00l0@P0?<Ooo01l03ooo01l13`0O00l07`4?01l13`0O
0@l@7`4?41l13a0O0@l@7`4O41l13a0O0Al@7`4?41l13a0O00l07`0700l07`0O0@l@7`4?41l13a0O
0@l@7`4O4Al13a0O0@l@7`4?41l13a0O0@l07`4?01l13`0O0@l07`0?01l13`0?037oo`0600m4CdA?
ADmDGdE?0eEO01QFGfE_EUmEKeIOIFmFGeE_EUmEGdE?E5m4Cd=?8clc?b<_8RlB;a4_0AlA7`4?01l3
00l03P0O0@lA7`4O4BlB;b8_8blc?c@o@dm4CeAOADl2EEl01eE_EUmUKeIOEFmFGfE_00AEG`06ADm4
GdE?A4ooo`0?8?oo000Gool00`0?ool03`1200laool0800?ool03a0?00l@3`0?40l03a0?0@l@3`0?
41l13a0?0@l@7`4?41lA3a0O0@l@7a4?41l13a0?00l@3`0?40l700l07Q0?00l@7`4?41lA3a0O0@l@
7a4?41l13a0O0@l@7`4?40l03a0?0@l@3`0?40l03a0?00l@3`0?40l03c7oo`0R00m4CdA?E4m5CeAO
EDmEGeE?IEmEGfEOEUmUGeIOIEmEGfEOEEmDGdE?A4ld?c<o<blb;b8O8BlA7a0O4@l@3`0?40l300l0
3A0?4@l@7a4O8BlR7c8_<bm3Cc@oA4m5CeAO00=EG`05IEmFGfE_EUmUG`02EEl02EE?EEmECeAOA4mD
CdA?ool03`0Pool0013oo`<03`Coo`0300ooo`0?01003`050@l03`0?00l13`0300l00`4?00l03`0=
00l01@4?00l03`0?0@l00`0?00<13`0?00l03`0?:_oo0`0?1?oo01@03ooo00l13`0O0@l07`4?01l1
3a0O0@l@7`4?4Al13a4O0AlA7`4O0a4O00T17a4O4AlA7`4O41l13a0O0@l01@0?00L13a0O0@l@7`4O
4Al17`034Al05P4O4Al17a4O0@lA7`4O4Al13a0O0@l@7`4?01l13`0O0@l07`4?00l13`0?:_oo0`0?
1?oo00@03dE?A5m5G`9EG`04EFmFKfI_EVl3IVl03FM_IWmWKfI_EVmUKeIOEEm5CdA?=3m3Cb<_008R
;`044Bl17a4O0@l300l02P4?00l13a4O0AlA;a8_8RlS?d=?0TA?00A5GeEOEUmUK`=VK`03IWmWKfI_
009VK`04EVmVKeIOEFl2EEl014E?A5ooo`0?8?oo000Aool00`0?ooooo`03ool00`0?ool03`0D00l0
1A0?00l03`0?40l03`0?00<@3`0?00l05`0?:ooo00<03oooool00ooo01803ooo00l@3`0?40l03a0O
0@l@7`4?41l13a0O4@l@7a4O41l34Al02b4O4AlQ;a8O8BlA7b4_4Al@7a4?41l01@0?00d@3a4?41lA
7b4O4AlQ;a8O8BlA7b4_4AlQ7`034Al03A0O4@l@7`4?41l13a0O0@l@3`0?40l03a0?00<03b_oo`03
00oooooo00?oo`0<00mDGeE?IEmFGfE_IUmfKfI_MWmgKgIo0gMo015fOgM_MWmWKfE_IVmUKdE?@dm4
Cc<o8Rlb;a8O4AlA3a0?00D03`0441lA3a0O4Ql28Rl01C<oA4mDGdE?IEl00VI_00=WKgIoMfl017Mo
00MfOgM_MWmVKgI_IUmUK`02EEl00eE?ool03`0Pool000coo`<03`;oo`0300oooooo00?oo`0300oo
o`0?00T03`0501l03`0?00l07`0300l03P0O0@l07`0?01l13`0O0@l07`4?41l13`0O0@l200l03P0O
0@l@7`4?01l13a0O0@l07`4?01l03`0O0@l200l01@0O00l03`0?01l0300?9Ooo0`0?0ooo00<03ooo
ool00ooo00h03ooo01l13`0O0@l07`4?41l13a0O0AlA7`4O0Q4O00@A;a8O8BlB;`8R;`0:8SlS;c8o
8blb?b<_8RlA7a4_0@l500l02P4?4BlB7b8_8blR?b<o<SlS;b8o0R8_00@B;b4_4QlA;`@A7`0<0@l@
7`4O41l13`0O0@l@7`4?01l13`0?9Ooo0`0?0ooo00<03oooool00ooo00L03eIOEFmFGfIoIfmfO`02
Mgl00gQoQhmhO`03R8l03WR?QhmhSgN?IgmfOfI_EFm5CdAO=3lb?b<_8Bl24Al00`4?01l03`0200l0
4@0O0@lA7a4O8BlS;c8o=3m4GeIOEFmVKgIoIgmgSgQoQhl00XR?00EhShR?N8n7SgQo009gO`07MWmV
KfE_EVmEKooo00l08?oo000Aool00`0?ooooo`03ool00`0?ool03`0:00l01A0?00l03`0?40l00`0?
00d@3`0?40l03a0?00l@3`4?40l03a0O0@l@3`0300l02A0?00l@7`4?40l03a0?00l@3`0300l01A0?
00l03`0?40l03`0?:ooo00<03oooool00ooo00l03ooo00l@3`0?40l13a0?0@l@7`4?41lA3a4O4@l0
0Q4O00@Q7a8O8BlR7`8R;`06<RlS;c8o8blb;b8_0Q4O00l@7`0?00l03a0?00l@7a4O8AlR;c8o8blb
?b<_<Sl00b8_00<Q;a8O8Al00Q4O00lA3a0O4@l@7`4?41l13a0O0@l@3`0?40l03a0?00l0:ooo00<0
3oooool00ooo00h03fEOEEmUKfI_MVmgKgMoMfn7OhQoQhn8OhN?0XR?00ehOhN?MgmfOgM_IVmEGeA?
ADm3?b<_<SlB7`024Al00a0O00l@3`0300l04A0?4AlA7a8O<RlS;d=?ADmUGeEOIVmgKgIoMgn7SgQo
Qhl00XR?00f8OhN?R7n7OgM_MgmgKfI_EUmUKeEOool03`0Pool0013oo`803`Goo`0300ooo`0?00P0
3`050@l03`0?00l13`0200l02P0O0@l03`4?01l13a4O0AlA7b<_3@0?00/S;b8o4AlA7`4?01l13`0O
0@l07`4?00<03`030@l03`0?00/03b[oo`803`Goo`0O00ooo`0O0@l07`4?41l13a0O0AlA7`4O4AlB
7a4O4QlR;a8_8RlS;c8o=3m4CcA?A5m5CdAO<clA;`4?4Al01P0?00@13a4O0@lA;`8c?`0;ADm4GdE?
A4ld?c=?8blR;a8O8RlB7`034Al0304O4Al13a0O0@l@7`4?01l13`0O0@l03b[oo`803`Goo`0800mF
GfI_IfmgOfM_MhmhS`:8S`0CR9n9SiVORInIWhVOV9n9ShRON7n7SfM_IVm5GeEO=4lc?b<o8Rl00Q4O
00L13`0?00l03`4?00l13`024Al07B8_8blc?cA?EEmFKfI_Ign7SgQoR9n9SiRORInIWhVOVIn9ShRO
RHn8SgQoMhmWOfI_IfmVKooo00l08?oo000Gool00`0?ool03`0<00l02a0?00l03`0?40l03a0O4Al@
7b8_40l04@0?00T@3b8_8RlA7a0O0@l@7`0?40l04@0?<Ooo00X03ooo00l@7`4?41l13a0O0@l@7`<A
7`0A8BlA7b4_8Rlb;c<oA4m4?fEOIVmfOfI_@dlc?b4O0@l@3`0:00l0104?8AlA7d=?0fI_0UEO01A3
Cc<o<SlR;b4_4AlQ;a4O41lA7a0O0@l@7`4?41l13a0?00l@7`0?<Ooo00T03fI_IVmfOgMoQgn8OiR?
R8l00YVO01:YWiZOZJnZWjV_VInY[iVOV8n8ShN?IVmUGeEOA4lc;c8o8Rl24Al01a0O00l03`0?40l0
3a0O008A7`0M8Rlc?c<_A4mEGgIoIVn7OhR?V9nIWjV_VInY[jZOZJnJWjV_VInHWhR?V9n8OhMoMfmf
OfI_ool03`0Pool001Ooo`0300ooo`0?00T03`0:01l03`0?00l07`4?01l13`0O0Al24Al00b8o0@l0
7`0@00l02`4?8SlS;a4O0@l@7`4?01l13`0O0@l00P0?00<07`0?00l02P0?<Ooo00X03ooo01l13a0O
0@l@7`4O4Al17`<A7`064QlQ;b8_<SlS;c<o0TA?00YEGfIoIfmVKc@o@dlB7a0O00l07`L03`0601l1
3a0O4QlA;c@o0VI_00YVOeIOEEldCc<o8blb?a8_8BlB7`<A7`0:0AlA7`4?41l13a0O0@l07`4?00la
ool07@0?IfmVKfMoMhmhOhR?RHn8WiVOZJnJWjV_VZnZ[iZ_ZJnJWiVORHn8WgQoMWmEGeE_A4lc?b<o
8Rl00Q4O00<13`0O0@l00P0?00D07`4?4AlA7b8_008c?`0JA4mEKfM_MWmhOhRORHnIWiZOZJnJ[jZ_
VZnY[iZOZJn9WhRORHn8SgQoMWmWOfI_ool03b3oo`005ooo00<03ooo00l01P0?00l@3`0?00l03a0?
00l@3`0?40l03a0O0@lQ7d@o@dl05@0?00T@3d@o4AlA7a0O00l@7`0?40l00`0?00<@3`0?00l02@0?
<Ooo00T03ooo0@l@3`0?41l13a0O4@l00Q4O00DQ7a4O8RlR7c8_008c?`0:ADmVKfI_R8n8OhR?A3lQ
7a4O40l=00l01Q0O0@lQ7d@oA4n8O`:8S`07IVm5Cd<o<clb?b8O8Bl0114O00TA3a0O0@l@7`4?41l1
3a0?00l0<Ooo00L03gIoMfn7OhQoQhn9S`02VIl02ZV_ZZnj[j^_^[nk[kZoZjnj[jZO0YVO00F8SgM_
IFmFGeA?008c?`068RlQ7a4O41l03a0?0`0?00/@7a4O4AlR;d<o<cmDCeIOMWmgKhR?00:IW`0CZYnj
[j^_^[nk[kZoZjnj[jZ_ZJnIWjVORHn8SgMoQgmgKooo00l08?oo000Gool00`0?ool03`0800l03@4?
00l13`0O0@l@7`4?41lB7a4O=3l03`4?01L03`09=3m4Ca4O41l17a0O0@l07`4?00<03`030@l03`0?
00L03c7oo`0800oooa0O0@l07`4?4Al17`8A7`0<4BlB7b8_8blR?c<oA5m5CfI_RInIWj^_0UEO00<A
;`4?41l03P0?00H13`0?0@lA;a8OEEl2ZZl02YVOIVm5CdAO=3lR?b<_8RlB7a4_114O00H13a0O0@l@
7`4?00laool02P0?MgmgOgR?V9n9SiV_VZnZ[j^_0[^o00_;ckboblnl_k_?_;nj_iZ_ZZn9SgN?009V
K`07ADlcCc@o8RlB7a4_0@l00`0?01H13`0?0@lA;a8O8Rld?c=?ADmVKgQoMhn9SjZ_VYnj_kbo^lnl
_l_?_;o;c`:k_`0:ZjnZ[iZ_VJn9ShR?N7mgOooo00lPool001Ooo`0300ooo`0?00`03`0740l03a0O
0@lQ7a4O@dl06@0?00U3Cc@o4Al13a0O00l@3`0?40l03@0?<Ooo00T03ooo00l@7`4?41lA3a4O4@l0
0Q4O00/Q;b8O<RlR;c<oA4mDCfI_VInISjZ_009EG`034Ql@7`0?00h03`0640l03a0O4QlQ;eEO0ZZ_
00VHWfI_E5m4Cc<o8Rlb;b8O8Al00Q4O00TA3a0O4@l@7`4?41l03a0O00l0<Ooo00X03gMoMgn7ShR?
V9nIWjV_ZZnj_`>k_`0@blnl_l_?^ko;_j^_ZJnZWiROMgmUKfI_E5lc?d<o8Rl24Al06A0O00l03`0?
40l03a0O4AlQ7b8_@clc?eAOIVn7OgMoV9nZWjV_Zjo;_k^oblnl_l_?00>k_`0:^[nZ[jV_VInHWhQo
QhmgOooo00lPool001Ooo`0300ooo`0?00D03`0>01l03`0?00l07`4?01l13a0O0AlA7b<_<Sl17aT0
3`030@l@7b<_008A7`0641l13a0O00l07`4?0P0?00<07`0?00l01P0?<Ooo00H03ooo01l13a0O0@l4
4Al04B4_4RlR;b<o<cm4CfI_EVnHWkc?c<mhSb8o8blA7`0?01l03`0?00`07`4?4Al13b8oN8n8Skc?
V9mFKfI_A4l2<cl0128_4QlQ;a8O0a4O00H17a4O0@l07`4?00laool0100?N7n7ShR?0YVO00ZZ[j^_
^[nl_lc?_<o<glg?g=o=c`;<c`0@^ln[[jZoVIn7SfI_IWm5Gd=?=3lR?a8O4Bl13`0O0@l200l03`0O
0AlA;a8O8Sld?d=?AEmVOgR?QhnIWjZoZjnkc`02c<l04<g?g=o=clcO_<o<ck^o^[n[[jZ_VIn8WhV?
Qhooo`0?8?oo000Gool00`0?ool03`0600l0310?00l03`0?40l03a0O4@l@7b8OVInISa`03`09VIlR
7b4_4@l@3`4?40l03a0?00<03`0340l03`0?00D03c7oo`0700ooo`4?41lA3a0O4@l00Q4O00dQ7b8O
8BlS;d=?=3mEGhQoQhnl_mc?c<m4C`024AlC00l04A0?00l@3a4OE4m4Clc?_;n7ShQoEEld?d<o8blR
;b8O8Al00Q4O00LA3a0O4@l@7`4?40l03`0aool01`0?Qhn8OiROVYnYWjZ_00:k_`05blo=cmcOgLo]
g`02gMl04/g?g=o<ckZo^jnYWhR?MWmWKeAO=3m3Cb8_8AlA7a0O00l@3`<03`0841lA7b4O8Rm3?c@o
EEmWK`:8S`07ZJnk[kZoc<oLglg?kMl00]gO00gMcmc?cLo<ck^obknZ[jV_RHnHWhQoool03`0Pool0
01Ooo`0300ooo`0?00@03`0<0@l03`0?00l13`0?0@l07`4?4Al17b4_0YVO700?00N9Wb4_4RlA7`4?
01l13`0200l00`0O0@l03`0800laool01P0?ool@7`4?41l17`<A7`094QlR;a8_8Sld?d=?AEn7SgQo
00?<c`05ADlA7a4O01l13`0B00l00`0O0@lA7`02A4l02lg?c<mhOhN?EEm3Cc@o8SlB;b8_4Ql00a4O
00H13a4O0@l@7`4?00laool0300?N8n8ShV?ZJnJWjZo_;nk_kc?c=o=c`;Mg`0BgNoNgmgOcLo<cj^o
^knJWhR?IfmfOdEO<dld?b8o4QlA;`4?0`0?01413`0?0@lA;a8O8Sld?c=?AEmfOgR?R8nJWk^oZko<
clgO00;Mg`06gNoNgmgOcLo<gkc?0[^o00NZ_iZOVIn9ShR?ool03`0Pool001Ooo`0300ooo`0?00P0
3`0540l03a0O00l@7`024Al00c<_41l03`0L00l01a0O<blb?a4O41l13a0?00<03`0340l03`0?00L0
3c7oo`0600ooo`0?41l13a0O0a4O00@Q;b8_8Rlc;`94C`04IVnJWjV_k^l2VIl00c8_4@l@7`0E00l0
2A0?4@lR;b8_ZIo^kjV_VYmVK`02A4l03C<_8RlR;b4_4AlQ7a4O41l13a0O00l@7`0?037oo`0@00n8
ShR?V9nZ[jV_Zjo;ckbog=oMgngOg]o]knkOkNl2gMl03/c?bknk_jV_R8mfOfM_EEld?d=?8RlQ7a4O
41l300l02Q0?00l@7a4O8AlR;d=?=3mDGfM_0XR?00ZY[k^o^ko<cngOgMo]knkOkNoNg`;Mg`05g<nl
_l_?ZjnY[`02VIl00hR?ool03`0Pool001Ooo`0300ooo`0?00D03`0;01l13`0?00l07`4?41l17a4_
4QmUK`0O00l02fE_EUlA;`4O4Al13`0O0@l07`0?01l00`0?00<07`0?00l00P0?<Ooo01P03ooo41l1
7a4O0AlA7a8O4BlB7b8o8blc?dE?E5mhOl_?_;ooofM_IVlB7`0O0@l200l00`0O00l03`0A00l03`0O
4QlQ;fI_oonl_l_?MgmDGdEO<clR;b8o4RlA;`024Al01P4O4Al13a0O0@l03c7oo`0R00n9SiROVYnZ
_j^_^ko<clcOgMo]kmkOk_o_kokok^o]kmk_gMnl_l_?ZZnHWfM_MWmEGd=?=3lR?a8O8Bl13`0O0@l2
00l08@0O0AlQ;a8O8SldCd=?EEmfOhV?V9nZ[l_?_;oMgmk_kNo_kokokno^omk_kNo=glcOc<nk_jZ_
VJnJWiROool03`0Pool001Ooo`0300ooo`0?00803`0>40l03`0?00l@3`0?40l03a0?00l@7a8O8AmE
Gal03`08EEmUGa8O41lA3a0O00l@3`<03`0340l03`0?00D03c7oo`0H00ooo`4?41lA3a0O4@lQ7a4O
8BlR;c8_<cmDGdE?Qgnl_l_?oomfKfI_8Bl13a0?4`0?01X@3`0?00l13b4O4AmVKoooblnl_gMoADmD
Gc<o<RlR;b4_4AlQ7a4?41lA3a0O0@l@7`0?<Ooo00L03iR?R8nYWjZ_^Znk_`02c<l06McOk]o]knk_
o^o^kok_k]o]kmg?blnl_jZ_R8mfOfM_EEm4?d=?8blQ7a4O41l03a0?00<03`0P41lA7b4O8bm3Cd@o
EEmWKiR?R8nZ[kbobloMcng_k]onknk_o^o^kng_k]oMglc?g<nk_kZ_VInYWhR?ool03b3oo`004_oo
00<03oooool00_oo00<03ooo00l0100?00`13`0?00l07`4?01l13`0O0AlR;a8_^klO00l02[^oZklR
;`4O4Al13`0O0@l07`4?0`0?00<13`0?00l00`0?:ooo00<03oooool00ooo01T03ooo41l13a0O0AlA
7a8O4BlB;c8o8blcCeIOEEn8Smg_g]ooodE?A5lA7`0O0@l07`0C00l00`0O0@l07`024Al01DE?oooM
gmg_RHl00UEO00dcCb<_<SlB;a4_4QlA7`4O4Al17a0O0@l03`0[ool00`0?ooooo`03ool02P0?RHnH
WiZO^[n[[k_?cLo<gmkO0^k_00Cnono_ooo_k`;^k`0>gMnlclc?Zjn8WfMoMgmEGd=?=3lR?a8O4Bl1
3`<03`0@0@l03`4?4BlB7b8o=3m3CeIOMgn9ShROZjo<ckbogMl2k^l01>o_ooo_ooko0^k_00[NglcO
cLnkcj^_ZJnJWiROool03b3oo`004Ooo00<03ooo00l00ooo00<03ooo00l0200?00D@3`0?41l13a0O
008R;`03ool03`0?01d03`;oo`048RlA7a4?41l300l00a0?00l03`0700lZool00`0?ool03`04ool0
600?ool13a0O0@l@7a4O8BlA7b4_8blb?c@oIEmEGiROk^onknkO@dld?a0O00l@3aL03`044AlA3d=?
k]l2k^l049ROEEmUKc@o<SlS;b4_4AlQ7a4O41lA3a0O0@l@7`0?:_oo00<03ooo00l01?oo00d03iRO
RHnY[j^_^[nl_mcOcLo]knk_o^ook`02ool04Okok^o^kmgOblo<ckZ_RHmfOgM_EEld?d=?8RlQ;a4O
41l00`0?00d@3`0?41lA7b4O8Rm3Cc@oEEmgKiRORHnj[`02c<l01mgOo^o^kokoooonooo_00;^k`0:
kNo=cmcO_;nj_iZOZJn9Sooo00lPool0017oo`0300ooo`0?00?oo`0300ooo`0?00D03`0801l13`0?
00l07`4?41l17`8R;`03ool03`0?01d03`;oo`098RlA7a4O0@l07`4?01l03`0O00<03`0301l03`0?
00803b[oo`0300ooo`0?00Coo`0@00oooa0O0AlA7`4O4AlB7b4_4Rlb?b<_@dmFGeE_RIl2k^l01^g_
=4m3C`4O01l13aH03`0@01lA7a4O=3o]kno_k^n9SeE_EUm3Cb<_<SlR;b4_4Ql34Al0104?41l13`0?
:_oo00<03ooo00l01?oo00`03hVOVInJWkZoZjo;clg?g=oNgnkok^l3ool04nook_o_kmg__<o<cj^_
V9mWOgMoEEm3Cc@o8SlB7b4_0@l07`4?00803`0<01l17b4_4QlR?cA?@dmEGgMoRHnHWj^_0/c?00CM
knk_k_o_o`?oo`0<kno^omkOg=o=cl_?ZjnY[iZ_VIooo`0?8?oo000Aool00`0?ool03`03ool00`0?
ool03`0200l03Q0?00l03`0?40l03a0?0@l@7`4?4AlR;c8_c<lO00l2c<l01R8_41lA7a0O0@l@3`<0
3`0340l03`0?00D03b[oo`0300ooo`0?00Coo`0500ooo`4?41lA3`024Al04B4O4AlR;b<_<Sm4?fE_
EUnHWno_o_oNgd<o<clA7`0?40l05`0?01H@7a4?@coNgok_knnIWeIOIFm4?c8o8blQ;a4O8AlA7a0O
4@l@7`4?41l03b[oo`0300ooo`0?00Coo`0=00nHWiV?ZJn[[kZoc;oLglg?kNo^kok_onl00ooo01;^
kok_gMo<clbo^Zn9SgIoMfmUGd@o@dlS;b4O4Al@7`0?40l300l04A0O4AlQ7b<_@dm4?eEOMfnHWhV?
^Zo<_l_?gMonknk_o_l00_oo00gokok_k^o]klg?g=o<_kZoVYnY[iV?ool03`0Pool001;oo`0300oo
oooo00;oo`0300ooo`0?00@03`090@l03`0?01l13`0O0@l@7a4O008R;`03ool03`0?01d03`;oo`08
8Rl17a4O0@l07`4?01l13`<03`030@l03`0?00<03b_oo`0300oooooo00?oo`0H00oooa0O0@l@7`4O
4AlB7a4_4Rlb?b<_@dmFGfE_RHo^ono_k^ld?d=?4Al07`4?5@0?00D13`0O0AlA7c@o00;^k`0Ak_n9
WfE_EUm3Cb<_<SlB;a4_4QlA7`4O4Al17a0O0@l03`0[ool00`0?ooooo`03ool0400?RHnHWiZO^[n[
[l_?cLoLgmkOk_o_koookoooonoo0^k_00kMklc?c<n[[iROIgmgOeEO@dld?b8o4QlA;`4?0`0?01<1
3`0?0@lA;a8O8Sld?d=?EUmgOhV?V9n[[lc?_<oMkno_k^o_o`03ool03>o_k_oNgmcOcLo;cj^_ZZnJ
WiROool03b3oo`005ooo00<03ooo00l0200?00D@3`0?41l13a0O008R;`03ool03`0?01d03`;oo`04
8RlA7a4?41l300l00a0?00l03`0700laool0600?ool13a0O0@l@7a4O8BlA7b4_8blb?c@oIEmEGiRO
k^onknkO@dld?a0O00l@3aL03`044AlA3d=?k]l2k^l049ROEEmUKc@o<SlS;b4_4AlQ7a4O41lA3a0O
0@l@7`0?<Ooo00d03iRORHnY[j^_^[nl_mcOcLo]knk_o^ook`02ool04Okok^o^kmgOblo<ckZ_RHmf
OgM_EEld?d=?8RlQ;a4O41l00`0?00d@3`0?41lA7b4O8Rm3Cc@oEEmgKiRORHnj[`02c<l01mgOo^o^
kokoooonooo_00;^k`0:kNo=cmcO_;nj_iZOZJn9Sooo00lPool001Ooo`0300ooo`0?00D03`0;01l1
3`0?00l07`4?41l17b8_4Rnk_`0O00l00k^oZklR;`024Al01P4?01l13`0O00l07`<03`0301l03`0?
00803c7oo`0@00oooa0O0AlA7`4O4AlB7a4_4RlR?b<_@dmEGeE_R8l2gMl01_koADmDGa4O01l13aH0
3`0@01lA7a4OADonomkOgMn8SeE_EEm3Cb<_8SlB;a4_4Ql34Al0104?41l13`0?<Ooo00X03hV?V9nJ
WjZoZjo;clg?c=oNg`;^k`04o_o_ooooknl2k^l04=gO_<o;cj^_V9mWOgIoEEm3Cc@o8SlB7b4_0@l0
7`4?0P0?00l07`4O8BlB7b8o=4m3CeEOMWn9SiROZZo;ckc?gMl00^k_00C_ooookoono`;^k`0:gMo<
glg?bln[[iV_VYnHWooo00lPool001Ooo`0300ooo`0?00803`0>40l03`0?00l@3`0?40l03a0?00l@
7a8O8AmEGal03`08EEmUGa8O41lA3a0O00l@3`<03`0340l03`0?00D03c7oo`0H00ooo`4?41lA3a0O
4@lQ7a4O8BlR;c8_<cmDGdE?Qgnl_l_?oomfKfI_8Bl13a0?4`0?01X@3`0?00l13b4O4AmVKoooblnl
_gMoADmDGc<o<RlR;b4_4AlQ7a4?41lA3a0O0@l@7`0?<Ooo00L03iR?R8nYWjZ_^Znk_`02c<l06McO
k]o]knk_o^o^kok_k]o]kmg?blnl_jZ_R8mfOfM_EEm4?d=?8blQ7a4O41l03a0?00<03`0P41lA7b4O
8bm3Cd@oEEmWKiR?R8nZ[kbobloMcng_k]onknk_o^o^kng_k]oMglc?g<nk_kZ_VInYWhR?ool03b3o
o`005ooo00<03ooo00l0100?00T13`0?00l07`4?00l13`0O0@l00Q4O00<c?`4?41l0700?00L13c<o
8clA7`4?41l13`0200l00`0O0@l03`0800laool01P0?ool@7`4?41l17`8A7`054BlB7b8_8Rlc?`02
A4l02fI_ZJnJWnk_VInI[b<_4Al13`0O0@l04P0?00X07`4?4AlS;b8oVYo^kiZOZJmVK`94C`0=<clR
;b8_4QlA;a8O4Al13a4O0@l@7`4?00l0<Ooo02003hR?R8nIWjZ_VZnk_kboc<o=cmg_g]o^kmk_k^oN
kmgOg]o<gkbo^knJ[hROIfmgOdEO@dld?b8o4QlA;`4?0`0?02813`0?0@lA;a8O8Sld?d=?EEmgOhR?
R9nJ[k^o_;o<gmkOgMoNgnk_g^o^kmgOgNo=clc?_;nk_iZ_VIn9WhR?ool03b3oo`005ooo00<03ooo
00l0200?00D@3`0?41l03a0O008A7`03<bl@7`0?01`03`0741lc;c8o4Al@7`4?40l00`0?00<@3`0?
00l01`0?<Ooo00H03ooo00l@7`4?41l34Al0124_8RlR;c<_0TA?00AVKiZOZJo^k`:IW`03<RlA3a0O
01D03`0940lA3b8_8RnYWnk_ZJnJWfI_0094C`0=<blR;b8_8BlA7b4O4Al@7`4?41l03a0O00l0<Ooo
01003hR?R8nHWjZ_ZJn[[l_?_;oLgmgOkMoNgng_k]o]k`;Mg`0>c<o;_k^oZJn8SgIoIfmEGc@o@dlR
;b4O4Al@7`<03`0:40l03a0O4AlQ7b8_@dld?eAOIfl2R8l02ZV_^knk_lc?kMoMgng_k]o]kmkO0]gO
00GLckbobln[[jV_00:IW`03R8ooo`0?023oo`005ooo00<03ooo00l01@0?00/07`0?00l03`0O0@l0
7`4?4Al17b8_00:IWa`03`09VIlR;a8O4Al13a0O0@l07`4?00803`0301l03`0?00H03c7oo`0600oo
oa0O0Al@7`4O0a4O00XB7b8_8Rlb?c@o<dmEGhN?N7o;c`;<c`06A4lA7a4O41l03`0O400?00@13a0O
0@lA7`94C`0;c<o;cgR?QhmEGc=?=3lb?a8_8RlB7`034Al01P4O4Al13a0O0@l03c7oo`0>00mhShR?
RHnI[iZOZ[nk_k_?c<oLglg?gMoNg`;Mg`0Bg=o=glc?Zknk_iZOR8mWKfIoEEm3Cc@o8SlB7a4_0@l0
7`4?0P0?00T07`4O4BlB7b8o=3m3CdEOIWl00XR?00NJWk^oZko<clg?g=oNg`03gMl03<g?g=nlck_?
^knZ_iZOV9n9WhR?ool03b3oo`005ooo00<03ooo00l01P0?00d@3`0?00l03a0?00l@3`4?41lA7c8o
8bl@7`0I00l00a0O0@lb?`024Al01P4?40l03a0?00l@3`<03`0340l03`0?00D03c7oo`0700ooo`4?
41l13a0O4@l00Q4O01<Q7a8O8BlR;c<o<bm4CfIOIFnISl_?c;n7Sb8_<RlA3a0?00l@3`0?00l04A0?
4@l@7b8_Qhn8Ol_?VHmUKfIOA4lc;c8o8RlQ;a8O8Al00Q4O00LA3a0O4@l@7`4?40l03`0aool0400?
QgmhOiR?VHnIWjZO^[n[[l^oc;o;clc?g<o<cmc?0/c?00Fk_kZ_ZjnIWhQo009VK`09E5lc?d=?8RlQ
7a4O41l03a0?00<03`0>41lA7b4O8Rm3?c<oE5mVKhN?R7nIWj^_^Znk_`;<c`0@g<o<cmcOc<o;clbo
bkn[[kZ_ZYnIWhR?V8mhOooo00lPool001Ooo`0300ooo`0?00@03`0?0@l03`0?00l13`0?0@l07`4?
4Al13a4O8blb?`4?01T03`030AlA7b<_00<A7`030@l07`4?00803`0301l13`0?00P03c7oo`0F00oo
oa0O0@l@7`4O4Al17a4O4QlR;a8O8RlS?c<o=4mVKeI_VInlclc?N8l28Rl00a0O0@l03`0>00l04`4?
00l13a0O0AlR;gQoR8nlciVOEVmVKdA?<clS?b8_4QlR;a8O00<A7`060@l@7`4?41l13`0?<Ooo0100
3gQoMhn9SiVORInZ[j^_^[nl_lc?_<o<clg?c=o=c`;<c`0>^ln[[jZoVIn7SfM_IVm5Cc=?=3lR;a8O
4Bl13`<03`0@0@l03`4?4BlB7b8_=3lcCdEOIVmhOhN?VInZ_j^_^ll2c<l04<g?c=o=clc?_<o<ckbo
^[n[[jZ_VIn8ShV?Mhooo`0?8?oo000Gool00`0?ool03`0<00l01a0?00l@7`4?8AlA7d=?01T03`09
@dld?a4O0@l@7`0?40l03a0?00d03c7oo`0900ooo`0?41l13a0O4@lA7a4?008A7`0;8BlR7c8_8Rlc
?dA?E4mVKiVOVHnZ[`02EEl00a8O41l03`0>00l01Q0?00l@7a8O8BmEG`:Z[`09V9mVKeAOA4lc?b8_
<RlR7b4O008A7`094@l@7a4?41l13a0O00l@7`0?037oo`0:00mgOgMoQhn8SiROVInY[jZ_^[l3^kl0
4<_?_;o;ck^obkn[[jV_ZYnHWgMoIFmVKeAO<cm3?b8_0Q4O01T@7`0?00l03a0?00l@7a4O8AlR;d<o
<cmDGfI_QgmgOiROZYnY[j^_bknk_l_?_;o;c`03^kl02[ZoZZnY[iVOV9n8OhN?Mgooo`0?8?oo000G
ool00`0?ool03`0900l03@0O0@l03`0?01l13a0O0@l@7a8OA4ld?`0O01<03`0=01l03dA?4AlA;`4O
41l13`0O0@l07`0?01l0300?<Ooo00P03ooo01l13a0O0@l@7`4O0Q4O00HA;a4O8BlB;b8_8bl2<cl0
0dAOIVmVK`03R8l014A?4AlA;`4?3@0?00D13`0O4Qm4CcA?00>8S`05IVm4Gc@o<clS;`028Rl00b4_
4AlA;`024Al0204O41l13a0O0@l07`4?00laool0100?IgmfOgMo0XR?00fHWiVOVJnJ[jZoZZnj_j^o
^kn[[jZoZjnZ[`02VIl01HR?MgmFGfE_ADl00S<o00HR;a8O4Al13`0O0@l200l01@0O0@lA7a4O8Rl0
0S<o00E5CfE_MgmgOhR?00:IW`0CZZn[[jZoZknk_j^o^[n[[jZoVZnI[iZOV9mhSgN?N7mfOooo00l0
8?oo000Gool00`0?ool03`0600l03a0?00l03`0?40l03a0?00l@3`0?41l13b4OA3m3C`0E00l02A0?
A3lA7a4O41l03a0O00l@3`0300l00a0?00l03`0900laool02@0?ool13a0?00l@7`4?41lA3`024Al0
1B4O4AlR;b8O<Rl00S<o00Y5CfI_IVn8ShQoR8m4?b4O4Al@3`d03`0641l13b4OA3m4ChQo0XR?00MV
KdE?@clc?c8o8QlQ;`044Al02A4?41l13a0O0@l@7`4?40l03`0aool01`0?MWmgKhMoR7n7ShV?00:I
W`0:ZJnZ[kZ_Zjnj_k^_^[n[[kZ_ZYl2VIl01HR?MfmUKeIOE4l00S<o00HR;b4O4Al@7`0?40l300l0
2a0O4AlA7b8_@clc?eA?EUmfOgM_R8l00YVO01>ZWkZ_Zjnj_k^_^[n[[kZ_ZZnY[iVOZIn9ShR?Mgn7
OgM_ool03`0Pool001Ooo`0300ooo`0?00P03`0;0@l03`0?00l13`0?0@l07`4?41l13`024Al00b8_
0@l07`0@00l02@4?8RlR;a4O0@lA7`4?01l13`0200l00`0O0@l03`0200l00`4?00l03`0700laool0
7P0?ool07`4?01l13a0O0@l@7`4O4Al17a4_4QlQ;a8_8SlS;c<o=4m4CeIOIWmWKfI_=3m3Ca8O01l1
3`X03`0A01lB7a4_=3mVKfM_IWmEGeE_A4lc?b<_8SlB;b4_4QlA;`024Al02P4O41l17a0O0@l07`4?
01l13`0?<Ooo01X03fI_IWmWOgN?N7n8ShV?V9n9WiV_VYnZ[iZ_ZZnJ[jV_VYnIWhV?R9mhOfIoEUmE
GdA?0S<o00@R;a4O4Al13`<03`0R0@l03`4?4AlB7b8_8clc?dA?EEmWKfIoN7n8WhV?VInJWjV_VYnZ
[iZ_ZZnJWiV_VInHWhV?R8mhOgMoIfmVOooo00lPool0017oo`<03`?oo`0300ooo`0?01003`0640l0
3a0?0@l@3`4?0Q4O00<b;`0?00l02`0?00Lb;b8_41l13a0O0@l@3`0300l00a0?00l03`0?00lZool3
00l4ool07`0?ool03a0O00l@3`0?41l13a0O4Al@7a4O8AlA7b4_4QlQ;b8_<SlS;d<oA4m3CdE?E4m4
Cc<o4Ql@7`4?00H03`0440l13a0O4Ql2<cl015A?ADmDCdA?0S<o00Db?b8_8BlB7b4O00<A7`0<41lA
7a0O0@l@7`0?41l13a0?00l@3`0?:_oo0`0?1?oo01d03fE_EUmfKgM_MWmgOhN?R7n8ShV?V9nISiRO
VHnHWhV?V9n8ShN?N7mfOfIOE5mECd=?8blb?b8_008A7`0741l03`0?00l@3`0?41l00Q4O01PR;c8o
8bm3CeE?IFmVGgIoN7n7ShR?V9n9SiROVHnHWiV?V9n9ShR?R7n7SgMoMWl2IVl00eIOool03`0Pool0
01;oo`0300oooooo00;oo`0300ooo`0?00T03`0601l03`0?00l07`4?0P0?00D07`4?41l13a0O008A
7`038bl07`0?00X03`0:01lS;b8o4Al@7`4O41l13`0O0@l200l01@0O00l03`0?01l0300?:ooo00<0
3oooool00ooo00X03ooo01l13a0O0@l@7`4O41l13`@A7`084BlB7b8_4RlR?b<o<Slc?`94C`08E5m5
CdAO<clQ;`4?41l13`H03`0341l17b4_008c?`0JADmDGdE?A4ld?c=?8blR?a8_8RlB7a4_4QlA7`4O
4Al17a0O0@l@7`4?41l13`0O0@l03b_oo`0300oooooo00?oo`0=00mFKfI_IVmfOfMoMhmhOhN?R8nH
WhV?V9l00YVO00j9WiRORHn8SgQoQhmWOfI_AEmDGcA?<clS?b8_0Q4O00<13`0O0@l00P0?02407`4?
4AlA7b8_8clc?cA?E5mFKfI_Ign7SgQoR8n9SiRORInIWhVOV9n9SiROR8n7SgR?MhmWKfIoIfmVKooo
00l08?oo000Bool00`0?ooooo`02ool00`0?ool03`0:00l01A0?00l03`0?40l00`0?00d@3`0?40l0
3a0?00l@3`4?40l03a0O0@l@3`0300l02A0?00l@7`4?40l03a0?00l@3`0300l01A0?00l03`0?40l0
3`0?:ooo00<03oooool00ooo00l03ooo00l@3`0?40l13a0?0@l@7`4?41lA3a4O4@l00Q4O00@Q7a8O
8BlR7`8R;`06<RlS;c8o8blb;b8_0Q4O00l@7`0?00l03a0?00l@7a4O8AlR;c8o8blb?b<_<Sl00b8_
00<Q;a8O8Al00Q4O00lA3a0O4@l@7`4?41l13a0O0@l@3`0?40l03a0?00l0:ooo00<03oooool00ooo
00h03fEOEEmUKfI_MVmgKgMoMfn7OhQoQhn8OhN?0XR?00ehOhN?MgmfOgM_IVmEGeA?ADm3?b<_<SlB
7`024Al00a0O00l@3`0300l04A0?4AlA7a8O<RlS;d=?ADmUGeEOIVmgKgIoMgn7SgQoQhl00XR?00f8
OhN?R7n7OgM_MgmgKfI_EUmUKeEOool03`0Pool001;oo`0300oooooo00;oo`0300ooo`0?00`03`05
0@l03`0?00l13`0200l01P0O0@l03`0?01l13`/03`050@l03`0?01l13`0200l00`0O0@l03`0200l0
0`4?00l03`0?00l[ool00`0?ooooo`03ool0400?ool03`4?01l13`0O0@l07`4?41l13a0O0AlA7`4O
0a4O00lB7a4_4QlQ;a8O4BlB7b4_4QlA7`4O4Al13`0?0@l00`0?02013a4O0AlA7a8O4BlB7a4_4QlQ
;a8O4BlB7a4O0AlA7`4O4Al13a0O0@l@7`4?01l13`0O0@l07`4?00l13`0?:ooo00<03oooool00ooo
00`03dEOEEmFGfI_EUmVKfM_IWmWKgMoIgl5Mgl03fMoIWmVKfI_EUmDGcA?A4lc?b8o8blQ;`4O4Al1
3`0300l00`4?00l13`024Al03R4_8blR?c<oA4m5CeAOEUmVKeI_IWmWOgMoIgl3Mgl036MoMgmWKfIo
IfmVKeIOEEmFGeEOool03b3oo`004Ooo0P0?1?oo00<03ooo00l0500?00D@3`0?00l03a0?00l03`03
40l03`0?01L03b[oo`803`Goo`0B00ooo`0?40l03a0?00l@7`4?41l13a0O0@l@7a4?41lA7a0O0a4O
00/Q7a4O8BlB7b4_4AlQ;a4O41lA3a0O00D03`0=40lA3a0O4AlQ7a4O8BlB7b4_4AlQ;a4O8Al00a4O
00d@7a4?41l13a0O0@l@7`4?40l03a0?00l@3`0300lZool200l5ool0300?E5mECfEOEUmUKfIOMVmV
KgIoMfmfO`=gO`0AMWmgKgIoIfmUKfI_IFm5Cd=?A4lc?b8_<RlB7a4O4@l@3`0500l0110O4@l@7a8O
0R8_00Dc?dA?E5m5CfEO009VK`03IfmfOgM_00AgO`07MWmgKgIoIVmfKfIOIFl00UEO00=ECooo00l0
8?oo000Gool00`0?ool03`0A00l01@0O00l03`0?01l04`0?00D07`0?00l03`0O01@03c7oo`0B00oo
o`0O0@l07`4?01l13a0O0@l@7`4?41l13a0O0AlA7`4O0a4O00/17a4O4AlA7`4O4Al17a0O0@l07`4?
00H03`0401l13a0O0Al74Al0504O4Al17a4O0@l@7`4O41l13a0O0@l@7`4?01l13`0O00l07`4?00la
ool0100?ADmDGdEO0UEO00=UKeIOIFl00fI_00=VOfM_IWl016I_00iEGeE_AEm4Cc@o<dlS?b8_4RlA
;`4O4Al13`0O0`0?00D07`4?4Al17a4_008R;`078blcCdA?A4m5GeE_EUl00fI_00AWKfIoIVmVO`9V
K`0:EVmUKeI_IFmEGeAOAEmDGooo00lPool001Ooo`0300ooo`0?04803c7oo`0P00ooo`0?40l03a0?
00l@3`0?40l13a0?00l@7`4?40l13a0O0@l@7a4?41l13a0O4@l@7`4?40l03a0?00l@3`L03`0N40l0
3a0O0@l@7a4?41l13a0O4@l@7`4?41l13a0O0@l@3`0?40l13a0?00l@3`0?40l03a0?00l@3`0?<Ooo
02803dA?A4mDCdE?E5mECeEOEDmUGeEOIEmFGfEOEUmUGeEOIEmEGeAOADm4Cc@o<clc;c8_8QlQ;a4O
41lA3a0?00l@3`<03`0=40lA3a0O4AlQ;b8O<Rlc;d=?=3m4CdE?E5l00eEO00EUGeIOIFmFGfEO009E
G`09EDmEGeE?E5m4CeA?A4ooo`0?023oo`005ooo00<03ooo00l0@P0?<Ooo01h03ooo00l13`0O0@l0
7`4?01l13`0O0@l07`4?41l13a0O0@lA7`4?41l17a4O0@l@7`4?41l13`0O0@l700l07@4?00l13`0O
0@l@7`4?41l13a4O0@l@7`4?4Al13a0O0@l@7`4?01l13`0O0@l07`4?01l13`0O0@l00`0?<Ooo00H0
3cA?A4m5CeAOADl4EEl01UE_EUmUKeIOEFmFG`=EG`04ADmDGdA?@dl2<cl01b<_8RlB;a4O0@lA7`4?
00<03`0R0@l03`4?4Al17a4O4QlR;b<_<cld?d=?A4mDGdE?EEmFGeEOEUmEKeIOIFmFGeE_EUmEGdEO
EEm5CdAOADm4Cooo00lPool001Ooo`0300ooo`0?04803c7oo`0300ooo`0?00803`0I40l03`0?00l@
3`0?40l03a0?00l@7`4?40l03a0O0@l@7`0?41l13a0?00l@3`0?40l02`0?01D@3`0?41l13a0?00l@
7`4?41l03a0O0@l@3`0?41l03a0?00l@3`0?40l00`0?00@@3`0?00l03c7oo`0400m3Cc@o@dl3A4l0
6EA?A4mDGdE?E5mECeAOADmDGdA?E5m4Cd=?A4m3Cc<o<SlS;b8_4QlQ;a4O41l13a0?00D03`0840l1
3a0O4AlQ;a8O8BlS;`8c?`0?@dm4Cd=?A4mDGdA?E5m5CeAOEDmDGdE?E5m4CeAO0094C`05A3m3Cc@o
ool03`0Pool001Ooo`0300ooo`0?04803c7oo`0400ooo`0O0@l200l05P0O0@l07`0?01l13`0O0@l0
7`4?01l13`0O0@l@7`4?01l13`0O00l07`4?0P0?00<07`0?00l01@0?01X07`0?00l03`0O0@l07`4?
01l13`0O0@l07`4?01l13`0O0@l07`0?01l13`0O00l07`4?0P0?00<07`4?00l0<Ooo00P03c@o<dld
?d=?=4m4CcA?14A?00=4GdA?A4l014A?00Pd?c=?<clb?b8_8SlB;a4_0Q4O00<13a0O00l01@0?00l1
3a0O0@lA7a8O4BlB;b8o8clb?c<o<dld?dA?=4l014A?00=4GdA?A4l014A?00Hd?c=?=3lcCooo00lP
ool001Ooo`0300ooo`0?04803c7oo`0400ooo`0?40l300l04A0?00l03`0?40l03a0?00l@3`0?40l0
3a0?00l@3`0?40l00`0?00<@3`0?00l03@0?014@3`0?00l03a0?00l@3`0?40l03a0?00l@3`0?40l0
3a0?00<03`0640l03`0?00l@3`0?<Ooo00<03c8o<cl00S<o00e3?c<o@dld?d=?A3m3Cc@o@dld?d=?
<cm3?`02<cl01S<_<SlR;b8_8QlQ7`8A7`044@l@3`0?40l500l0110?00l@7a4?0Q4O01DQ;b8O<RlR
;c8o<blb?c<o@clc?d<o=3m3Cc@o@dm4?d=?=3m3?c<o@cl00c<o00?oo`0?ool07ooo000Gool00`0?
ool03`1200laool01P0?ool03`0?01l13`803`0B01l13`0?0@l07`4?00l13`0O0@l03`4?01l13`0?
0@l07`4?3`0?01413`0?00l07`4?00l13`0O0@l03`4?01l13`0?0@l07`4?00803`0601l13`0?00l0
7`4?0`0?<Ooo00<03b<o<cl00S<o01Dd?c=?=3m3Cc@o@dld?dA?=3m3Cc@o<dld?c<o8clc?b<_8SlB
;b8_4Ql00a4O00<13`0O0@l01@0?00<13`0O0@l00a4O01DB7b8_8RlR?b<_<clS?c<o=3lcCc@o@dld
?dA?=3m3Cc@o@dld?c=?=3l00c<o00?oo`0?ool07ooo000Gool00`0?ool03`1200laool00`0?ool0
3`0600l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?01L03`0540l03`0?00l@3`0300l01A0?00l0
3`0?40l00`0?00<@3`0?00l01@0?<Ooo00P03c8o8blb?c<o<Slc;c8o1c<o00Db?c<o<SlS;c8_008R
;`0:8QlQ;a8O4AlA3a0O0@l@7`0?40l700l0210?0@lA7a4?8AlB7b4_8Ql28Rl00c8o8blb?`0:<cl0
1c<_<Slc;c8o8booo`0?023oo`005ooo00<03ooo00l0@P0?<Ooo00<03ooo01l00`0?00H07`0?00l0
3`0O0@l200l01P0O0@l03`0?01l13`803`0501l03`0?00l07`0C00l01P0O00l03`0?01l13`803`05
01l13`0?00l07`0300l01@0O00l03`0?01l00P0?<Ooo01<03b<_<SlS;c8o8blb?b<_<SlS?c<o8clb
?b<o<SlS;b8o8blR?`028Rl0118_8BlB7a4_0Q4O00@17a0O0@l07`H03`050@l07`4?41l17`024Al0
114_4QlQ;a8_0R8_01<R?b<_8SlS;c8o8blb?b<o<clS?c8o8clb?b<_8SlS;c8oool03`0Pool001Oo
o`0300ooo`0?04803c7oo`0400ooo`0?40l300l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<0
3`0340l03`0?01403`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<0
3`0340l03ooo033oo`0B00lb;b8_<SlS;c8o<blb?b<_<Slc;c8o8blb?c<_<SlS;c8_0R8_00@R7b4_
4QlQ7`8A7`044@l@7`4?40l700l01Q0?00l@3`4?41lA3`8A7`048BlB7b4_8Ql28Rl04S8o8blb?c<_
<SlS;c8o<blb?b<_<Slc;c8o8blb;b8_ool03b3oo`005ooo00<03ooo00l0@P0?<Ooo00<03ooo00l0
0P0?00D13`0?00l03`4?00<03`050@l03`0?00l13`0300l00`4?00l03`0E00l01@4?00l03`0?0@l0
0`0?00D13`0?00l03`4?00<03`050@l03`0?00l13`0300laool0400?8RlR;b<_8RlS;b8o8blR?b<_
8SlS;b8o8blR?b<_0b8_00@B;b8_4QlA;`8A7`070Al@7`4O41l13`0O0@l01P0?00`07`4?41l13a0O
0AlA7a8O4BlB7b8_4Ql48Rl02R8o8blR?b<_8SlS;b8o8blR?b<_0b8_00?oo`0?ool07ooo000Aool3
00l3ool00`0?ool03`1200lZool300l4ool00`0?ool03`1200lZool300l4ool0100?8BlR7b4_0b8_
00DQ;b8_8RlR;b4_008R;`068QlQ;b8O8BlB7b4O0a4O00D@7a4O41l13a0O00/03`0540l03a0O0@l@
7`034Al02B4O4AlQ;a8O8BlR7b4_8QlQ;`038Rl01B4_8RlR;b8_8Bl00R8_00<R7ooo00l08?oo000A
ool00`0?ooooo`03ool00`0?ool03`1200lZool00`0?ooooo`04ool00`0?ool07`0300l01@0O00l0
3`0?01l00`0?00D07`0?00l03`0O00<03`0301l03`0?01D03`0501l03`0?00l07`0300l01@0O00l0
3`0?01l00`0?00D07`0?00l03`0O00803b[oo`0300oooooo00Coo`0400lR;b8_4Rl;8Rl0418_8BlB
;b4_4QlA;a8O4Al17a4O0Al@7`4?01l13`0O1`0?00H07`0?01l13a0O0Al44Al01A4_4QlQ;a8_8Bl0
0R8_00<B;b8_8Rl01B8_00HB;b8_8RlR;ooo00lPool001;oo`0300oooooo00;oo`0300ooo`0?0480
3b_oo`0300oooooo00?oo`0300ooo`0?00@03`0540l03`0?00l@3`0300l00a0?00l03`0Q00l01A0?
00l03`0?40l00`0?00D@3`0?00l03a0?00D03b_oo`0300oooooo00?oo`0D00lQ;b8O8BlR7b4_8QlQ
;b8O8BlR7b4_8QlQ;b8O8BlB7b4O4AlQ7`<A7`0741lA3a0O00l@7`0?40l01`0?00T@3`0?00l03a0?
00l@7a4?41l00a4O01@Q7a4O8BlB7b4_8QlQ;b8O8BlR7b4_8QlQ;b8O8BlR7b4_8Qooo`0?8?oo000A
ool00`0?ool03`03ool00`0?ooooo`11ool00`0?ooooo`0Xool00`0?ool03`04ool00`0?ooooo`11
ool00`0?ooooo`0Xool00`0?ool03`04ool00`0?ooooo`11ool00`0?ooooo`0Nool001;oo`803`?o
odD03b_oo`803`CoodD03b_oo`803`CoodD03b3oo`00ooooJOoo003ooomYool000koo`0300oooooo
07?oo`0300oooooo07?oo`0300oooooo06_oo`003ooo00<03oooool09_oo0`0?B_oo00<03oooool0
9_oo0`0?B_oo00<03oooool09Ooo0P0?@ooo000?ool00`0?ooooo`02ool01P0?ooooo`0?ool03`?o
o`0300ooo`0?01Woo`0300oooooo04Woo`0300oooooo00;oo`0600oooooo00ooo`0?0_oo00<03ooo
00l06Ooo00<03oooool0B_oo00<03oooool00_oo00D03ooo00ooo`0?00?oo`0300ooo`0?01[oo`03
00oooooo043oo`003_oo00<03ooo00l00ooo00H03oooool03ooo00l3ool200lJool00`0?ooooo`18
ool00`0?ool03`03ool01P0?ooooo`0?ool03`;oo`803a_oo`0300oooooo04Soo`0300ooo`0?00?o
o`0500ooo`0?ool03`03ool200lJool00`0?ooooo`11ool000koo`0300ooo`0?00?oo`0600oooooo
00ooo`0?1?oo00<03oooool06?oo00<03oooool0B?oo00<03ooo00l00ooo00H03oooool03ooo00l3
ool00`0?ooooo`0Hool00`0?ool03`19ool00`0?ool03`03ool01@0?ool03ooo00l01?oo00<03ooo
ool06Ooo00<03oooool0@?oo000>ool00`0?ool03`03ool00`0?ooooo`0200l4ool200lIool200m:
ool00`0?ool03`03ool00`0?ooooo`0200l3ool200lKool200m9ool00`0?ool03`03ool0100?ool0
3`0?1?oo0P0?6Ooo0P0?@ooo003ooomYool001Coo`0300oooooo07?oo`0300oooooo07?oo`0300oo
oooo06Goo`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00oooo
JOoo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {111.5, 0}} -> {-2.079997, -2.068441, 0.014444,
   0.014444}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Magnetic Field"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[Hax]\), 
    \(\(Hax[x_, y_, z_] = 
      \(\(-\(\(4\ x\ y\ v\)\/\(\[Pi]\ a\^2\ \((u\^2 + v\^2)\)\ 
                  \((1 + v\^2)\)\^2\)\)\) /. {u \[Rule] uu, v \[Rule] vv}
            \) /. case; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Hay]; \)\), 
    \(\(Hay[x_, y_, z_] = 
      \(1 - \(2\ \((ArcTan[v] + v\/\(u\^2 + v\^2\))\)\)\/\[Pi] + 
            \(2\ \((x\^2 - y\^2)\)\ v\)\/\(\[Pi]\ a\^2\ \((u\^2 + v\^2)\)\ 
                \((1 + v\^2)\)\^2\) /. {u \[Rule] uu, v \[Rule] vv}\) /. 
        case; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Haz]; \)\), 
    \(\(Haz[x_, y_, z_] = 
      \(\(-\(\(4\ a\ y\ u\)\/\(\[Pi]\ a\^2\ \((u\^2 + v\^2)\)\ 
                  \((1 + v\^2)\)\)\)\) /. {u \[Rule] uu, v \[Rule] vv}\) /. 
        case; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Ha]; \)\), 
    \(\(Ha[x_, y_, z_] = {Hax[x, y, z], Hay[x, y, z], Haz[x, y, z]}; \)\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Poynting Vector and Intensity"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetCoordinates[Cartesian]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Sa]; \)\), 
    \(Sa[x_, y_, z_] := 
      \(c\ CrossProduct[Ea[x, y, z], Ha[x, y, z]]\)\/\(4\ \[Pi]\) /. NSub\)}],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Ia]; \)\), 
    \(Ia[x_, y_, z_] := N[\@\(Sa[x, y, z].Sa[x, y, z]\)]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Fig16x11 = 
      Table[ListDensityPlot[
          Table[Ia[x\ a, y\ a, \(10\^jj\ a\)\/1000], {x, \(-2\), 2, .5}, {y, 
              \(-2\), 2, .5}], 
          AxesLabel \[Rule] {"\<x in a\>", "\<y in a\>"}, 
          PlotLabel \[Rule] jj, Evaluate[Take[opt1, \(-6\)]], 
          DisplayFunction \[Rule] Identity], {jj, 1, 3, 1}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{Fig16x11\[LeftDoubleBracket]1\[RightDoubleBracket], 
          Fig16x11\[LeftDoubleBracket]2\[RightDoubleBracket], 
          Fig16x11\[LeftDoubleBracket]3\[RightDoubleBracket]}]]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.31746 0.00744 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.02381 0.00744 0.321429 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.019231 0.106838 0.019231 0.106838 [
[.01923 -0.0125 -4 -12 ]
[.01923 -0.0125 4 0 ]
[.23291 -0.0125 -4 -12 ]
[.23291 -0.0125 4 0 ]
[.44658 -0.0125 -4 -12 ]
[.44658 -0.0125 4 0 ]
[.66026 -0.0125 -4 -12 ]
[.66026 -0.0125 4 0 ]
[.87393 -0.0125 -4 -12 ]
[.87393 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -8 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .23291 -8 -6 ]
[-0.0125 .23291 0 6 ]
[-0.0125 .44658 -8 -6 ]
[-0.0125 .44658 0 6 ]
[-0.0125 .66026 -8 -6 ]
[-0.0125 .66026 0 6 ]
[-0.0125 .87393 -8 -6 ]
[-0.0125 .87393 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -7 0 ]
[.5 1.0125 7 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.23291 0 m
.23291 .00625 L
s
gsave
.23291 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.44658 0 m
.44658 .00625 L
s
gsave
.44658 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.66026 0 m
.66026 .00625 L
s
gsave
.66026 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.87393 0 m
.87393 .00625 L
s
gsave
.87393 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07265 0 m
.07265 .00375 L
s
.12607 0 m
.12607 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.28632 0 m
.28632 .00375 L
s
.33974 0 m
.33974 .00375 L
s
.39316 0 m
.39316 .00375 L
s
.5 0 m
.5 .00375 L
s
.55342 0 m
.55342 .00375 L
s
.60684 0 m
.60684 .00375 L
s
.71368 0 m
.71368 .00375 L
s
.76709 0 m
.76709 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.92735 0 m
.92735 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .23291 m
.00625 .23291 L
s
gsave
-0.0125 .23291 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .44658 m
.00625 .44658 L
s
gsave
-0.0125 .44658 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .66026 m
.00625 .66026 L
s
gsave
-0.0125 .66026 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .87393 m
.00625 .87393 L
s
gsave
-0.0125 .87393 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .07265 m
.00375 .07265 L
s
0 .12607 m
.00375 .12607 L
s
0 .17949 m
.00375 .17949 L
s
0 .28632 m
.00375 .28632 L
s
0 .33974 m
.00375 .33974 L
s
0 .39316 m
.00375 .39316 L
s
0 .5 m
.00375 .5 L
s
0 .55342 m
.00375 .55342 L
s
0 .60684 m
.00375 .60684 L
s
0 .71368 m
.00375 .71368 L
s
0 .76709 m
.00375 .76709 L
s
0 .82051 m
.00375 .82051 L
s
0 .92735 m
.00375 .92735 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.23291 .99375 m
.23291 1 L
s
.44658 .99375 m
.44658 1 L
s
.66026 .99375 m
.66026 1 L
s
.87393 .99375 m
.87393 1 L
s
.125 Mabswid
.07265 .99625 m
.07265 1 L
s
.12607 .99625 m
.12607 1 L
s
.17949 .99625 m
.17949 1 L
s
.28632 .99625 m
.28632 1 L
s
.33974 .99625 m
.33974 1 L
s
.39316 .99625 m
.39316 1 L
s
.5 .99625 m
.5 1 L
s
.55342 .99625 m
.55342 1 L
s
.60684 .99625 m
.60684 1 L
s
.71368 .99625 m
.71368 1 L
s
.76709 .99625 m
.76709 1 L
s
.82051 .99625 m
.82051 1 L
s
.92735 .99625 m
.92735 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .23291 m
1 .23291 L
s
.99375 .44658 m
1 .44658 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .87393 m
1 .87393 L
s
.125 Mabswid
.99625 .07265 m
1 .07265 L
s
.99625 .12607 m
1 .12607 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .28632 m
1 .28632 L
s
.99625 .33974 m
1 .33974 L
s
.99625 .39316 m
1 .39316 L
s
.99625 .5 m
1 .5 L
s
.99625 .55342 m
1 .55342 L
s
.99625 .60684 m
1 .60684 L
s
.99625 .71368 m
1 .71368 L
s
.99625 .76709 m
1 .76709 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .92735 m
1 .92735 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -68 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
66.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
70.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%+ font Math2
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%+ Math2
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
%%+ font Math2
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
9 string
9 9 8 [9 0 0 9 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000
000001030303010000
00010735FF35070100
00012F6051602F0100
00003C5650563C0000
00012F6051602F0100
00010735FF35070100
000001030303010000
000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744 0.64881 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.019231 0.106838 0.019231 0.106838 [
[.01923 -0.0125 -4 -12 ]
[.01923 -0.0125 4 0 ]
[.23291 -0.0125 -4 -12 ]
[.23291 -0.0125 4 0 ]
[.44658 -0.0125 -4 -12 ]
[.44658 -0.0125 4 0 ]
[.66026 -0.0125 -4 -12 ]
[.66026 -0.0125 4 0 ]
[.87393 -0.0125 -4 -12 ]
[.87393 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -8 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .23291 -8 -6 ]
[-0.0125 .23291 0 6 ]
[-0.0125 .44658 -8 -6 ]
[-0.0125 .44658 0 6 ]
[-0.0125 .66026 -8 -6 ]
[-0.0125 .66026 0 6 ]
[-0.0125 .87393 -8 -6 ]
[-0.0125 .87393 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -7 0 ]
[.5 1.0125 7 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.23291 0 m
.23291 .00625 L
s
gsave
.23291 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.44658 0 m
.44658 .00625 L
s
gsave
.44658 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.66026 0 m
.66026 .00625 L
s
gsave
.66026 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.87393 0 m
.87393 .00625 L
s
gsave
.87393 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07265 0 m
.07265 .00375 L
s
.12607 0 m
.12607 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.28632 0 m
.28632 .00375 L
s
.33974 0 m
.33974 .00375 L
s
.39316 0 m
.39316 .00375 L
s
.5 0 m
.5 .00375 L
s
.55342 0 m
.55342 .00375 L
s
.60684 0 m
.60684 .00375 L
s
.71368 0 m
.71368 .00375 L
s
.76709 0 m
.76709 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.92735 0 m
.92735 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .23291 m
.00625 .23291 L
s
gsave
-0.0125 .23291 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .44658 m
.00625 .44658 L
s
gsave
-0.0125 .44658 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .66026 m
.00625 .66026 L
s
gsave
-0.0125 .66026 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .87393 m
.00625 .87393 L
s
gsave
-0.0125 .87393 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .07265 m
.00375 .07265 L
s
0 .12607 m
.00375 .12607 L
s
0 .17949 m
.00375 .17949 L
s
0 .28632 m
.00375 .28632 L
s
0 .33974 m
.00375 .33974 L
s
0 .39316 m
.00375 .39316 L
s
0 .5 m
.00375 .5 L
s
0 .55342 m
.00375 .55342 L
s
0 .60684 m
.00375 .60684 L
s
0 .71368 m
.00375 .71368 L
s
0 .76709 m
.00375 .76709 L
s
0 .82051 m
.00375 .82051 L
s
0 .92735 m
.00375 .92735 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.23291 .99375 m
.23291 1 L
s
.44658 .99375 m
.44658 1 L
s
.66026 .99375 m
.66026 1 L
s
.87393 .99375 m
.87393 1 L
s
.125 Mabswid
.07265 .99625 m
.07265 1 L
s
.12607 .99625 m
.12607 1 L
s
.17949 .99625 m
.17949 1 L
s
.28632 .99625 m
.28632 1 L
s
.33974 .99625 m
.33974 1 L
s
.39316 .99625 m
.39316 1 L
s
.5 .99625 m
.5 1 L
s
.55342 .99625 m
.55342 1 L
s
.60684 .99625 m
.60684 1 L
s
.71368 .99625 m
.71368 1 L
s
.76709 .99625 m
.76709 1 L
s
.82051 .99625 m
.82051 1 L
s
.92735 .99625 m
.92735 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .23291 m
1 .23291 L
s
.99375 .44658 m
1 .44658 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .87393 m
1 .87393 L
s
.125 Mabswid
.99625 .07265 m
1 .07265 L
s
.99625 .12607 m
1 .12607 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .28632 m
1 .28632 L
s
.99625 .33974 m
1 .33974 L
s
.99625 .39316 m
1 .39316 L
s
.99625 .5 m
1 .5 L
s
.99625 .55342 m
1 .55342 L
s
.99625 .60684 m
1 .60684 L
s
.99625 .71368 m
1 .71368 L
s
.99625 .76709 m
1 .76709 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .92735 m
1 .92735 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -68 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
66.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
70.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%+ font Math2
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%+ Math2
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
%%+ font Math2
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
9 string
9 9 8 [9 0 0 9 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000001010201010000
0001050A0C0A050100
0004178CC78C170400
00067BFFDFFF7B0600
00017DEDE2ED7D0100
00067BFFDFFF7B0600
0004178CC78C170400
0001050A0C0A050100
000001010201010000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744 0.97619 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.019231 0.106838 0.019231 0.106838 [
[.01923 -0.0125 -4 -12 ]
[.01923 -0.0125 4 0 ]
[.23291 -0.0125 -4 -12 ]
[.23291 -0.0125 4 0 ]
[.44658 -0.0125 -4 -12 ]
[.44658 -0.0125 4 0 ]
[.66026 -0.0125 -4 -12 ]
[.66026 -0.0125 4 0 ]
[.87393 -0.0125 -4 -12 ]
[.87393 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -8 -6 ]
[-0.0125 .01923 0 6 ]
[-0.0125 .23291 -8 -6 ]
[-0.0125 .23291 0 6 ]
[-0.0125 .44658 -8 -6 ]
[-0.0125 .44658 0 6 ]
[-0.0125 .66026 -8 -6 ]
[-0.0125 .66026 0 6 ]
[-0.0125 .87393 -8 -6 ]
[-0.0125 .87393 0 6 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[0 1.025 -11 0 ]
[0 1.025 11 12 ]
[.5 1.0125 -7 0 ]
[.5 1.0125 7 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.23291 0 m
.23291 .00625 L
s
gsave
.23291 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.44658 0 m
.44658 .00625 L
s
gsave
.44658 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.66026 0 m
.66026 .00625 L
s
gsave
.66026 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.87393 0 m
.87393 .00625 L
s
gsave
.87393 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07265 0 m
.07265 .00375 L
s
.12607 0 m
.12607 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.28632 0 m
.28632 .00375 L
s
.33974 0 m
.33974 .00375 L
s
.39316 0 m
.39316 .00375 L
s
.5 0 m
.5 .00375 L
s
.55342 0 m
.55342 .00375 L
s
.60684 0 m
.60684 .00375 L
s
.71368 0 m
.71368 .00375 L
s
.76709 0 m
.76709 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.92735 0 m
.92735 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .23291 m
.00625 .23291 L
s
gsave
-0.0125 .23291 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .44658 m
.00625 .44658 L
s
gsave
-0.0125 .44658 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .66026 m
.00625 .66026 L
s
gsave
-0.0125 .66026 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .87393 m
.00625 .87393 L
s
gsave
-0.0125 .87393 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .07265 m
.00375 .07265 L
s
0 .12607 m
.00375 .12607 L
s
0 .17949 m
.00375 .17949 L
s
0 .28632 m
.00375 .28632 L
s
0 .33974 m
.00375 .33974 L
s
0 .39316 m
.00375 .39316 L
s
0 .5 m
.00375 .5 L
s
0 .55342 m
.00375 .55342 L
s
0 .60684 m
.00375 .60684 L
s
0 .71368 m
.00375 .71368 L
s
0 .76709 m
.00375 .76709 L
s
0 .82051 m
.00375 .82051 L
s
0 .92735 m
.00375 .92735 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.23291 .99375 m
.23291 1 L
s
.44658 .99375 m
.44658 1 L
s
.66026 .99375 m
.66026 1 L
s
.87393 .99375 m
.87393 1 L
s
.125 Mabswid
.07265 .99625 m
.07265 1 L
s
.12607 .99625 m
.12607 1 L
s
.17949 .99625 m
.17949 1 L
s
.28632 .99625 m
.28632 1 L
s
.33974 .99625 m
.33974 1 L
s
.39316 .99625 m
.39316 1 L
s
.5 .99625 m
.5 1 L
s
.55342 .99625 m
.55342 1 L
s
.60684 .99625 m
.60684 1 L
s
.71368 .99625 m
.71368 1 L
s
.76709 .99625 m
.76709 1 L
s
.82051 .99625 m
.82051 1 L
s
.92735 .99625 m
.92735 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .23291 m
1 .23291 L
s
.99375 .44658 m
1 .44658 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .87393 m
1 .87393 L
s
.125 Mabswid
.99625 .07265 m
1 .07265 L
s
.99625 .12607 m
1 .12607 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .28632 m
1 .28632 L
s
.99625 .33974 m
1 .33974 L
s
.99625 .39316 m
1 .39316 L
s
.99625 .5 m
1 .5 L
s
.99625 .55342 m
1 .55342 L
s
.99625 .60684 m
1 .60684 L
s
.99625 .71368 m
1 .71368 L
s
.99625 .76709 m
1 .76709 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .92735 m
1 .92735 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 0 m
0 1 L
s
gsave
0 1.025 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
gsave
.5 1.0125 -68 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
66.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
70.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%+ font Math2
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%+ Math2
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
%%+ font Math2
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
9 string
9 9 8 [9 0 0 9 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0003090D0E0D090300
030D1C2A2F2A1C0D03
071B436C796C431B07
0B2A72BFD6BF722A0B
0B3088E5FFE588300B
0B2A72BFD6BF722A0B
071B436C796C431B07
030D1C2A2F2A1C0D03
0003090D0E0D090300
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{321.125, 100.125},
  ImageMargins->{{36.3125, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006B0000OQ000`40l00?003`ooooTooo003ooonC
ool00?oooi?oo`00ooooTooo003ooonCool00?oooi?oo`00ooooTooo003ooonCool00?oooi?oo`00
ooooTooo003ooonCool001Koo`0300oooooo00koo`<03a7oo`0300oooooo00koo`0300oooooo00ko
o`0300oooooo03Woo`0300oooooo00koo`<03a7oo`0300oooooo00koo`0300oooooo00ooo`0300oo
oooo03Soo`0300oooooo00koo`<03a7oo`0300oooooo00koo`0300oooooo00ooo`0300oooooo02_o
o`005Ooo00<03ooo00l03ooo00<03oooool03ooo0`0?3ooo00<03ooo00l03_oo00<03ooo00l0>Ooo
00<03ooo00l03ooo00<03oooool03ooo0`0?3ooo00<03ooo00l03ooo00<03ooo00l0>?oo00<03ooo
00l03ooo00<03oooool03ooo0`0?3ooo00<03ooo00l03ooo00<03ooo00l0;?oo000Eool00`0?ool0
3`0@ool00`0?ooooo`0>ool00`0?ool03`0?ool200l@ool00`0?ooooo`0hool00`0?ool03`0@ool0
0`0?ooooo`0>ool00`0?ool03`0?ool200lAool00`0?ooooo`0gool00`0?ool03`0@ool00`0?oooo
o`0>ool00`0?ool03`0?ool200lAool00`0?ooooo`0[ool001Goo`0300ooo`0?00ooo`0300ooo`0?
013oo`803`ooo`0300oooooo00koo`0300ooo`0?03Woo`0300ooo`0?00ooo`0300ooo`0?013oo`80
3`ooo`0300oooooo00ooo`0300ooo`0?03Soo`0300ooo`0?00ooo`0300ooo`0?013oo`803`ooo`03
00oooooo00ooo`0300ooo`0?02coo`005_oo00<03oooool03ooo0P0?4Ooo00<03oooool03_oo0P0?
3ooo00<03oooool0>Ooo00<03oooool03ooo0P0?4Ooo00<03oooool03_oo0P0?4?oo00<03oooool0
>?oo00<03oooool03ooo0P0?4Ooo00<03oooool03_oo0P0?4?oo00<03oooool0:ooo003ooonCool0
0?oooi?oo`00KOoo00<03ooo00l00ooo00D03ooo00ooo`0?00?oo`0300ooo`0?07;oo`0300ooo`0?
00?oo`0500ooo`0?ool03`03ool00`0?ool03`1bool00`0?ool03`03ool01P0?ooooo`0?ool03`?o
o`0300ooo`0?00goo`003ooo00<03oooool0G?oo00<03oooool00_oo00D03ooo00ooo`0?00?oo`80
3aGoo`0300oooooo05coo`0300oooooo00;oo`0500ooo`0?ool03`03ool200lEool00`0?ooooo`1L
ool00`0?ooooo`02ool01P0?ooooo`0?ool03`?oo`803`koo`003_oo00<03ooo00l01?ooE@0?1?oo
00<03oooool00_oo00D03ooo00ooo`0?00Coo`0300oooooo01;oo`0300ooo`0?00CooeD03`Coo`03
00oooooo00;oo`0500ooo`0?ool03`04ool00`0?ooooo`0Bool00`0?ool03`04oomE00l4ool00`0?
ooooo`02ool01P0?ooooo`0?ool03`Coo`0300oooooo00coo`003_oo00<03ooo00l01?oo0P0?1?oo
00D03oooooooo`0?00Coo`0500ooooooool03`04ool01@0?oooooooo00l01?oo00D03oooooooo`0?
00Coo`0500ooooooool03`04ool01@0?oooooooo00l01?oo00D03oooooooo`0?00?oo`0300oooooo
00;oo`0500ooooooool03`04ool00`0?ool03`03ool00`0?ool03`03ool0100?ool03`0?1?oo0P0?
5?oo00<03ooo00l01?oo0P0?1?oo00D03oooooooo`0?00Coo`0500ooooooool03`04ool01@0?oooo
oooo00l01?oo00D03oooooooo`0?00Coo`0500ooooooool03`04ool01@0?oooooooo00l01?oo00D0
3oooooooo`0?00Coo`0500ooooooool03`04ool01`0?oooooooo00ooo`0?00?oo`0300ooo`0?00?o
o`0400ooo`0?00l4ool200lDool00`0?ool03`04ool200l4ool01@0?oooooooo00l01?oo00D03ooo
ooooo`0?00Coo`0500ooooooool03`04ool01@0?oooooooo00l01?oo00D03oooooooo`0?00Coo`05
00ooooooool03`04ool01@0?oooooooo00l01?oo00D03oooooooo`0?00Coo`0700ooooooool03ooo
00l00ooo00<03ooo00l00ooo00<03oooool00P0?1?oo0P0?3_oo000>ool00`0?ool03`04ool00`0?
ool03`1?00l00ooo00l03`0Wool00`0?ool03`04ool00`0?ool03`0C00l01@4?00l03`0?0@l00`0?
00D13`0?00l03`4?00<03`050@l03`0?01l13`0200l00`0O0@l03`0200l01@4?00l03`0?0@l00`0?
00D13`0?00l03`4?01H03bOoo`0300ooo`0?00Coo`0300ooo`0?00P03`0K0@l03`4?01l13`0?0@l0
7`4?4Al13a0O0@lA7`4?41l13a4O0AlA7`4O4Al17a4O0AlA7`4O00<A7`0Q0AlA7a4O4Al17a4O0AlA
7`4O4Al17a4O0AlA7`4O4Al13a0O0@lA7`4?41l13a4O0@l07`4?00l13`0O0@l03`4?00/03b;oo`00
3ooo00<03oooool00ooo00<03ooo00l0C`0?0_oo00<03oooool01ooo00<03oooool07?oo00<03ooo
ool00ooo00<03ooo00l08`0?00D@3`0?00l03a0?00<03`0340l03`0?02803`03ool03ooo00Soo`03
00oooooo01coo`0300oooooo00?oo`0300ooo`0?00P03`0540l03`0?00l@3`0300l05A0?0@l@7`4?
41l13a0O0@l@7`4?41lA3a0O4Al@7a4?41lA7a0O4@l@7`024Al05a4?41lA7a4O4@l@7a4O41lA3a0O
4Al@7a4?41l13a0O0@l@7`4?41l13a0O0@l00P0?00D@3`0?00l03a0?00/03`03ool03ooo00Soo`03
00oooooo01Koo`005Ooo00<03ooo00l0C`0?0_oo00<03oooool0;?oo00<03ooo00l0500?00D07`0?
00l03`0O00<03`0501l03`0?00l07`0300l01P0O0@l03`0?01l13`803`0501l03`0?00l07`0300l0
1@0O00l03`0?01l00`0?00<07`0?00l04@0?00?oo`0?ool0;Ooo00<03ooo00l02@0?01407`4?01l0
3`0O0@l07`0?41l17a0O0@l@7`4O41l13a0O008A7`050AlA7a4O4Al17`034Al01@4O4AlA7a4O0Al0
0a4O00D17a4O4AlA7`4O00<A7`0C0Al@7`4O41l13a0O0Al@7`4?41l13`0O00l07`4?01l03`0O0@l0
2@0?00?oo`0?ool08Ooo000Eool00`0?ool03`1?00l2ool00`0?ooooo`0/ool00`0?ool03`0A00l0
1A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l01A0?00l03`0?40l0
0`0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0B00l00ooo00ooo`0]ool00`0?ool03`0800l0
6a0?00l@3`0?40l03a0?00l@3`4?41lA3a0O0@l@7a4?41l13a0O4@lA7a4?41lA3a4O4@l@7`024Al0
1Q4?41lA7a4O4@l@7`8A7`0J4@l@7a4?4AlA3a0O4@lA7`4?41lA3a0O0@l@7a4?41l13a0?00l@3`0?
40l03a0?00l@3`T03`03ool03ooo027oo`005Ooo00<03ooo00l0C`0?00?oo`0?00l0;_oo00<03ooo
00l04`0?00D13`0?00l03`4?00<03`050@l03`0?00l13`0300l01@4?00l03`0O0@l00P0?00<07`4?
00l00P0?00D13`0?00l03`4?00<03`050@l03`0?00l13`0F00l^ool00`0?ool03`0800l06`4?00l1
3`0O0@l03`4?01l13a4O0@l@7`4?4Al13a0O0@lA7`4O4Al17a4O0AlA7`4O4Al17`034Al08@4O4AlA
7a4O0AlA7`4O4Al17a4O0AlA7`4O4Al17a4O0@l@7`4?4Al13a0O0@lA7`4?01l13`0?0@l07`4?00l1
3`0;00lRool001Goo`0300ooo`0?04l03`;oo`0300oooooo02coo`0300ooo`0?02<03`0540l03`0?
00l@3`0300l00a0?00l03`0R00l00ooo00ooo`0]ool00`0?ool03`0800l01A0?00l03`0?40l00`0?
01D@3`4?41l13a0O0@l@7`4?41l13a0O4@l@7a4O41lA3a0O4Al@7a4?41l00Q4O01LA3a0O4AlA7a4?
41lA7a0O4@l@7a4O41lA3a0O0@l@7`4?41l13a0O0@l@7`4?00803`0540l03`0?00l@3`0;00l00ooo
00ooo`0Qool001Goo`0300ooo`0?04l03`;oo`0300oooooo02coo`0300ooo`0?01@03`0501l03`0?
00l07`0300l01@0O00l03`0?01l00`0?00H07`4?00l03`0O0@l200l01@0O00l03`0?01l00`0?00D0
7`0?00l03`0O00<03`0301l03`0?01403`03ool03ooo02goo`0300ooo`0?00T03`0A01l13`0O00l0
7`4?01l03a0O0Al@7`4?41l17a0O0@l@7`024Al01@4O4AlA7a4O0Al00a4O00D17a4O4AlA7`4O00<A
7`050AlA7a4O4Al17`034Al04`4O41l17a0O0@l@7`4O41l13a0O0@l07`0?01l13`0O00l07`4?00T0
3`03ool03ooo027oo`005Ooo00<03ooo00l0C`0?0_oo00<03oooool0;?oo00<03ooo00l04@0?00D@
3`0?00l03a0?00<03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<0
3`0540l03`0?00l@3`0300l01A0?00l03`0?40l04P0?00?oo`0?ool0;Ooo00<03ooo00l0200?01/@
3`0?40l03a0?00l@3`0?40l13a0O4@l@7`4?41lA3a0O0@l@7a4?4AlA3a0O4@lA7a4?41l00Q4O00HA
3a0O4AlA7a4?41l24Al06Q4?41lA3a4O4@l@7a4?4Al13a0O4@l@7`4?41lA3a0O0@l@3`0?40l03a0?
00l@3`0?40l900l00ooo00ooo`0Qool001Goo`0300ooo`0?04l03`;oo`0300oooooo02coo`0300oo
o`0?01<03`050@l03`0?00l13`0300l01@4?00l03`0?0@l00`0?00D13`0?00l07`4?00803`0301l1
3`0?00803`050@l03`0?00l13`0300l01@4?00l03`0?0@l0500?00?oo`0?ool0;Ooo00<03ooo00l0
200?01/13`0?0@l07`4?00l13`0O0@lA7`4?41l13a4O0@l@7`4?4Al17a4O0AlA7`4O4Al17a4O0Al0
0a4O02417a4O4AlA7`4O4Al17a4O0AlA7`4O4Al17a4O0AlA7`4?41l13a4O0@l@7`4?4Al13`0O0@l0
3`4?01l13`0?0@l02@0?00?oo`0?ool08Ooo000Eool00`0?ool03`0J00l01A0?00l03`0?40l00`0?
00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l00a0?00l03`0J00l00ooo00l03`0^ool00`0?
ool03`0A00l0;A0O00l@3`0?41l03a0?00l@7`4?41lA3a0O0@l@7a4?41l13a0O4@l@7a4?41lA3a0O
4@l@7a4?41l13a0O4@l@7`4?41lA3a0O00l@3`0?41l03a0?00l@7`0D00l^ool0100?ool03a0?0`0?
04D@3`0?00l03a0O4Al@7a4?41lA7a0O4@l@7b8O8BlB7b4_8QlQ;a8O8BlR7c8o8blb?b<_<SlS;c8o
8blb?c<_<Slc?c8o<blb?c<o<Slc;c8o8blb?b<_<SlS;c8o8blb?b8O8BlB7b4_8QlQ;a8O8BlR7a0O
4@l@7a4O41lA3a0O4Al@7`0?40l00`0?00<@3`0?00l00`0?8_oo000Eool00`0?ool03`0C00l01@0O
00l03`0?01l00`0?01X07`4?01l03`0O0@l07`0?01l13`0O00l07`4?01l03`0O0@l07`0?01l13`0O
00l07`4?0P0?00D07`0?00l03`0O01<03`;oo`0300oooooo02coo`0300ooo`0?00P03`0501l03`0?
00l07`0300l0;P0O0@l@7`4?01l13a0O0@l07`4?4Al13a0O0AlA7`4?41l17a4O0AlA7`4O4Al17a4O
0AlA7`4O41l17a4O0@l@7`4O4Al13a0O0@l@7`4?01l13a0O0@l07`4?0P0?00D07`0?00l03`0O00/0
3`03ool03ooo02goo`0<00ooo`0O00l07`4?01l03`0O0@l07`4O0a4O01T17a4O4AlA7`4O8BlB;b8_
4RlQ;a8_8RlB;b4_8blb?b<_<SlS;c8o8blb?b<_<clS?`03<cl05R<o<clc?c<o8blb?b<_<SlS;c8o
8blb?b<_8BlB;b8_4RlQ;a8_8RlB;b4_0Q4O00D17a4O4AlA7`4O008A7`0;01l03`0O0@l07`0?01l1
3`0Oool03`0Rool001Goo`0300ooo`0?01@03`0Q40l03`0?00l@3`0?40l03a0?00l@3`0?40l03a0?
00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00<03`0540l03`0?00l@3`0B00l2ool0
0`0?ooooo`0/ool00`0?ool03`0900l01A0?00l03`0?40l00`0?02d@3`0?40l13a0?00l@3`4?40lA
3a0O0@l@7a4?41l13a0O4@l@7a4?41lA3a0O4@l@7a4?41l13a0O4@l@7`4?41lA3a0O0@l@3`0?40l1
3a0?00l@3`4?40l00`0?00D@3`0?00l03a0?00X03`03ool03ooo02goo`1E00ooo`0?40l03a0?00l@
3`0?40l03a4O4@l@7a4?4AlA3a0O4@lA7b8O8BlR7b4_8QlQ;b8O8BlR7c8o8blb?b<_<SlS;c8o8blb
?c<_<clc;c8o<blc?c<_<Slc;c8o8blb?b<_<SlS;c8o8blb?b8O8BlR7b4_8QlQ;b8O8BlR7a0O4@lA
7a4?41lA3a4O4@l@7`0?40l03a0?00l@3`0?40l03ooo00l08_oo000Eool00`0?ool03`0B00l01@4?
00l03`0?0@l00`0?01d13`0?0@l07`4?00l13`0O0@l03`4?01l13`0?0@l07`4?00l13`0O0@l03`4?
01l13`0?0@l03`4?00<03`030@l03`0?01803`;oo`0300oooooo02coo`0300ooo`0?00/03`0e0@l0
3`0?00l13`0?0@l07`4?01l13`0O0@l07`4?41l17a4O0@l@7`4O4Al13a0O0AlA7`4O4Al17a4O0AlA
7`4O4Al13a0O0AlA7`4?41l17a4O0@l07`4?01l13`0O0@l07`4?00l13`0300l00`4?00l03`0:00l0
0ooo00ooo`0]ool0E@0?ool07`4?00l13`0O0@l03`4?01l17a4O0AlA7`4O4Al17a4O0AlR;a8O8RlB
;b8_4QlR;a8_8RlS;c8o8blb?b<_<SlS;c8o8blc?b<o<clS?c<o8clc?b<o<clS;c8o8blb?b<_<SlS
;c8o8blR;a8O8RlB;b8_4QlR;a8_8Rl17a4O0AlA7`4O4Al17a4O0Al07`4?00l13`0O0@l03`4?01oo
o`0?02;oo`005Ooo00<03ooo00l06P0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l01A0?
00l03`0?40l00`0?00<@3`0?00l06P0?00?oo`0?00l0;_oo00<03ooo00l04@0?02d@7`0?40l03a0O
00l@3`0?41l13a0O4@l@7`4?41lA3a0O0@l@7a4?41lA3a0O4@l@7a4?41lA3a0O0@l@7a4?41l13a0O
4@l@7`0?40l03a0O00l@3`0?41l0500?;_oo00@03ooo00l@3`<03`1540l03`0?00l@7a4O41lA3a0O
4Al@7a4?41lR7b4_4QlQ;b8O8BlB7b4_8Qlb?b<_<SlS;c8o8blb?b<_<Slc;c8o<clb?c<_<Slc?c8o
<blb?b<_<SlS;c8o8blb?b<_<SlR7b4_4QlQ;b8O8BlB7b4_8Ql@7a4?41lA7a0O4@l@7a4O41l03a0?
00<03`0340l03`0?00<03b;oo`005Ooo00<03ooo00l04`0?00D07`0?00l03`0O00<03`0J01l13`0O
00l07`4?01l03`0O0@l07`0?01l13`0O00l07`4?01l03`0O0@l07`0?01l13`803`0501l03`0?00l0
7`0C00l2ool00`0?ooooo`0/ool00`0?ool03`0800l01@0O00l03`0?01l00`0?02h07`4?41l13`0O
0@l@7`4?01l13a4O0@l@7`4O4Al13a0O0AlA7`4O4Al17a4O0AlA7`4O4Al17a0O0AlA7`4?41l17a4O
0@l@7`4?41l13`0O0@l@7`4?01l13`803`0501l03`0?00l07`0;00l00ooo00ooo`0]ool0300?ool0
7`0?01l13`0O00l07`4?01l17`<A7`0I0AlA7a4O4Al17b4_4RlR;a8_8BlB;b8_4RlQ;b<_<SlS;c8o
8blb?b<_<SlS;c<o8cl00c<o01HS?c<o<clc?b<_<SlS;c8o8blb?b<_<SlS;b4_4RlR;a8_8BlB;b8_
4RlQ;`8A7`050AlA7a4O4Al17`024Al02`0O00l07`4?01l03`0O0@l07ooo00l08_oo000>ool300l4
ool00`0?ool03`0D00l08A0?00l03`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?
40l03a0?00l@3`0?40l03a0?00l@3`0300l01A0?00l03`0?40l04P0?0_oo00<03oooool09Ooo0`0?
1?oo00<03ooo00l02@0?00D@3`0?00l03a0?00<03`0]40l03a0?0@l@3`0?40l13a0?4@l@7`4?41lA
3a0O0@l@7a4?41lA3a0O4@l@7a4?41lA3a0O0@l@7a4?41l13a0O4@l@7`4?40l03a0?0@l@3`0?40l1
3a0?00<03`0540l03`0?00l@3`0:00l00ooo00ooo`0Vool300l4ool0E@0?ool03a0?00l@3`0?40l0
3a0?00lA7a4?41lA3a4O4@l@7a4?4AlR7b4_8QlQ;b8O8BlR7b4_8Qlb?b<_<SlS;c8o8blb?b<_<Slc
;c<o<blb?c<_<clc;c8o<blb?b<_<SlS;c8o8blb?b<_<SlR7b4_8QlQ;b8O8BlR7b4_8Ql@7a4?4AlA
3a0O4@lA7a4?41l03a0?00l@3`0?40l03a0?00ooo`0?02;oo`003_oo00<03oooool01?oo00<03ooo
00l04P0?00D13`0?00l03`4?00<03`0M0@l03`4?01l13`0?0@l07`4?00l13`0O0@l03`4?01l13`0?
0@l07`4?00l13`0O0@l03`4?00l13`0300l00`4?00l03`0B00l2ool00`0?ooooo`0Uool00`0?oooo
o`04ool00`0?ool03`0;00l0=@4?00l03`0?0@l03`4?01l13`0O0@l07`4?01l13a0O0AlA7`4?41l1
7a4O0@l@7`4O4Al17a4O0AlA7`4O4Al17a4O0@l@7`4O4Al13a0O0AlA7`4?01l13`0O0@l07`4?01l1
3`0?0@l00`0?00<13`0?00l02P0?00?oo`0?ool09_oo00<03oooool01?oo05D03ooo01l13`0?0@l0
7`4?00l13`0O0AlA7`4O4Al17a4O0AlA7`4O8RlB7b8_4RlR;a8O8RlB;b8_8blb?b<_<SlS;c8o8blb
?b<_<clS?c<o8clc?b<o<clS?c<o8blb?b<_<SlS;c8o8blb?b<_8RlB7b8_4RlR;a8O8RlB;b8_0AlA
7`4O4Al17a4O0AlA7`4O01l13`0?0@l07`4?00l13`0Oool03`0Rool000ooo`0300oooooo00?oo`03
00ooo`0?01X03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<03`03
40l03`0?01X03`;oo`0300oooooo02Koo`0300oooooo00?oo`0300ooo`0?01403`0]41l03a0?00l@
7`0?40l03a0O0@l@7a4?41l13a0O4@l@7`4?41lA3a0O4@l@7a4?41lA3a0O4@l@7`4?41lA3a0O0@l@
7a4?41l03a0?00l@7`0?40l03a0O01803`03ool03ooo02Ooo`0300oooooo00?oo`0400ooo`0?40l3
00l0AA0?00l03`0?41lA7a0O4@l@7a4O41lA3a0O8QlQ;a8O8BlR7b4_4QlQ;b8O<SlS;c8o8blb?b<_
<SlS;c8o<blb?c<o<Slc;c8o<clb?c<_<SlS;c8o8blb?b<_<SlS;c8o8QlQ;a8O8BlR7b4_4QlQ;b8O
41lA3a0O4Al@7a4?41lA7a0O00l@3`0300l01Q0?00l03`0?ool03b;oo`003_oo00<03ooo00l01?oo
00<03ooo00l02`0?01807`0?00l03`0O00l@7`4?41l13a0O0@l@7`4?41lc?c=?=3l2<cl013=?=3lc
?c<o2Ooo00Dd?c<o<clcCc@o008c?`0=<dld?a0O0@l@7`4?41l13a0O0@l@7`0?01l00`0?00<07`0?
00l02@0?00?oo`0?00l09ooo00<03ooo00l01?oo00<03ooo00l0200?03l07`4?01l13`0O0@l07`4?
01lB7b4_4QlA;a8O8BlB7a4_4Qn8WhV?R9n9ShRORHn8WhV?R9nlcl_?_<o<ckc?blnlclc?_<n8WhV?
R9n9ShRORHn8WhV?R9lB7b4_4QlA;a8O8BlB7a4_4Ql07`4?01l13`0O0@l07`4?01l02`0?9ooo00<0
3ooo00l01?oo01@03ooo41l13a0O0@l@7`4?41l13a0O4QlQ;a8_8RlB7b4_4RlR;a8O2DA?00UWKgIo
IfmVOfM_MWmWKfIoIfl00WMo011gSgQoMgmgOgN?N7mgOfM_IWmWKgIoIfmVOfM_MWmWK`U4C`0B4RlR
;a8O8BlB;b8_4QlQ;a8_41l13a0O0@l@7`4?41l13a0O0P0?8_oo000?ool200l4ool00`0?ool03`08
00l01A0?00l03`0?40l00`0?00X@3`4?41l13a0?0@l@7`4?40l13`8c?`05@clc?c<o<cm3?`02<cl9
ool01D<o<clc?c<o@cl00c<o00Y3?`4?41l13a0?0@l@7`4?40l13`803`0540l03`0?00l@3`0:00l2
ool00`0?ooooo`0Vool200l4ool00`0?ool03`0900l0?A0?00l@3`0?40l03a0?00lQ7a4O8BlB7b4O
4AlQ;a8O8An8SiR?R8nHShR?V8n8SiR?R8o;clboblo<_l_?c;o;clbobln8SiR?R8nHShR?V8n8SiR?
R8lQ7a4O8BlB7b4O4AlQ;a8O8Al03a0?00l@3`0?40l03a0?00X03`03ool03ooo02Ooo`803`Coo`0E
00ooo`4?41l13a0?0@l@7`4?40l13b4_4QlQ;b8O8BlB7b4_8QlQ;d@o00=4C`0>A3m4CdA?A4m4?gI_
IVmfOfM_MVmVKgIoIfmfK`=gO`0@QgmgOgMoMgn7OgMoMWmWKgI_IVmfOfM_MVmVKgIoA3l3A4l06D@o
A4m4CdA?A3lQ;b8O8BlB7b4_8QlQ;a8O8Bl13a0O0@l@3`4?41l13a0?0@ooo`0?02;oo`005Ooo00<0
3ooo00l02P0?00D13`0?00l03`4?00803`0:01l13a0O0@l07`4?41l13`0O=3l2<cl01S=?=3lc?c<o
<dld?`Woo`03<clcCc@o008c?`0><dld?c<o<cl07`4?41l13`0O0@l@7`4?01l13`<03`050@l03`0?
00l13`0800l2ool00`0?ooooo`0/ool00`0?ool03`0800l0?`0O0@l07`4?01l13`0O0@l07a8O4BlB
7b4_4QlA;a8O8BlB7hRORHn8WhV?R9n9ShRORHn8Wkc?c<nl_lc?_<o<ckboc<nlchRORHn8WhV?R9n9
ShRORHn8Wa8O4BlB7b4_4QlA;a8O8BlB7`0O0@l07`4?01l13`0O0@l07`0900l00ooo00ooo`0]ool0
5P0?ool07`4?41l13`0O0@l@7`4?01lB;b8_4QlQ;a8_8RlB7b4_4Rm4CcA?0dA?00ldCdA?A4m4CfM_
IWmWKgIoIfmVOfM_MWmWKgN?N7l00WMo011gSgQoMgmgOgN?IfmfOfM_IWmWKgIoIfmVOfM_A4ldC`=4
C`0H=4m4CdA?A4lB7b4_4RlR;a8O8BlB;b8_4Ql07`4?41l13`0O0@l@7`4?01ooo`0?8_oo000Eool0
0`0?ool03`0A00l02P4?41l03a0O0@l@7`0?41l13d<o0c<o00E3?c<o<clc?d<o00Woo`8c?`05@clc
?c<o<cm3?`02<cl02@4?41l03a0O0@l@7`0?41l13`0A00l2ool00`0?ooooo`0/ool00`0?ool03`09
00l0?A0?00l@3`0?40l03a0?00lQ;a8O8AlA7b4_4QlQ7a4O8Bn8SiR?R8nHShR?V8n8SiR?R8o;clbo
blnl_l_?c;o;ckbobln8SiR?R8nHShR?V8n8SiR?R8lQ;a8O8AlA7b4_4QlQ7a4O8Bl03a0?00l@3`0?
40l03a0?00X03`03ool03ooo02goo`0D00ooo`4?41l03a0O0@l@7`0?41l13b4_8QlQ;a8O8BlR7b4_
4QlQ;`=4C`0A@dm4CdA?A4m3CdA?MWmWKgI_IVmfOfM_MVmVKgIoMgn7O`03Mgl03HMoMgmgOgMoMVmV
KgIoIfmfKfI_MWmWKgI_00=4C`0J@dm4CdA?A4m3CdA?8BlB7b4_8QlQ;a8O8BlR7b4_0@l@7`0?41l1
3a0O00l@7`4?ool03b;oo`005Ooo00<03ooo00l02`0?01807`0?00l03`0O00l@7`4?41l13a0O0@l@
7`4?41lc?c=?=3l2<cl013=?=3lc?c<o2Ooo00Dd?c<o<clcCc@o008c?`0=<dld?a0O0@l@7`4?41l1
3a0O0@l@7`0?01l00`0?00<07`0?00l02@0?00?oo`0?00l0;_oo00<03ooo00l0200?03l07`4?01l1
3`0O0@l07`4?01lB7b4_4QlA;a8O8BlB7a4_4Qn8WhV?R9n9ShRORHn8WhV?R9nlcl_?_<o<ckc?blnl
clc?_<n8WhV?R9n9ShRORHn8WhV?R9lB7b4_4QlA;a8O8BlB7a4_4Ql07`4?01l13`0O0@l07`4?01l0
2`0?;_oo01@03ooo41l13a0O0@l@7`4?41l13a0O4QlQ;a8_8RlB7b4_4RlR;a8O2DA?00UWKgIoIfmV
OfM_MWmWKfIoIfl00WMo011gSgQoMgmgOgN?N7mgOfM_IWmWKgIoIfmVOfM_MWmWK`U4C`0B4RlR;a8O
8BlB;b8_4QlQ;a8_41l13a0O0@l@7`4?41l13a0O0P0?8_oo000Eool00`0?ool03`0800l01A0?00l0
3`0?40l00`0?00X@3`4?41l13a0?0@l@7`4?40l13`8c?`05@clc?c<o<cm3?`02<cl9ool01D<o<clc
?c<o@cl00c<o00Y3?`4?41l13a0?0@l@7`4?40l13`803`0540l03`0?00l@3`0:00l2ool00`0?oooo
o`0/ool00`0?ool03`0900l0?A0?00l@3`0?40l03a0?00lQ7a4O8BlB7b4O4AlQ;a8O8An8SiR?R8nH
ShR?V8n8SiR?R8o;clboblo<_l_?c;o;clbobln8SiR?R8nHShR?V8n8SiR?R8lQ7a4O8BlB7b4O4AlQ
;a8O8Al03a0?00l@3`0?40l03a0?00X03`03ool03ooo02goo`0E00ooo`4?41l13a0?0@l@7`4?40l1
3b4_4QlQ;b8O8BlB7b4_8QlQ;d@o00=4C`0>A3m4CdA?A4m4?gI_IVmfOfM_MVmVKgIoIfmfK`=gO`0@
QgmgOgMoMgn7OgMoMWmWKgI_IVmfOfM_MVmVKgIoA3l3A4l06D@oA4m4CdA?A3lQ;b8O8BlB7b4_8QlQ
;a8O8Bl13a0O0@l@3`4?41l13a0?0@ooo`0?02;oo`005Ooo00<03ooo00l02P0?00D13`0?00l03`4?
00803`0:01l13a0O0@l07`4?41l13`0O=3l2<cl01S=?=3lc?c<o<dld?`Woo`03<clcCc@o008c?`0>
<dld?c<o<cl07`4?41l13`0O0@l@7`4?01l13`<03`050@l03`0?00l13`0800l2ool00`0?ooooo`0/
ool00`0?ool03`0800l0?`0O0@l07`4?01l13`0O0@l07a8O4BlB7b4_4QlA;a8O8BlB7hRORHn8WhV?
R9n9ShRORHn8Wkc?c<nl_lc?_<o<ckboc<nlchRORHn8WhV?R9n9ShRORHn8Wa8O4BlB7b4_4QlA;a8O
8BlB7`0O0@l07`4?01l13`0O0@l07`0900l00ooo00ooo`0]ool05P0?ool07`4?41l13`0O0@l@7`4?
01lB;b8_4QlQ;a8_8RlB7b4_4Rm4CcA?0dA?00ldCdA?A4m4CfM_IWmWKgIoIfmVOfM_MWmWKgN?N7l0
0WMo011gSgQoMgmgOgN?IfmfOfM_IWmWKgIoIfmVOfM_A4ldC`=4C`0H=4m4CdA?A4lB7b4_4RlR;a8O
8BlB;b8_4Ql07`4?41l13`0O0@l@7`4?01ooo`0?8_oo000Eool00`0?ool03`0A00l02P4?41l03a0O
0@l@7`0?41l13d<o0c<o00E3?c<o<clc?d<o00Woo`8c?`05@clc?c<o<cm3?`02<cl02@4?41l03a0O
0@l@7`0?41l13`0A00l2ool00`0?ooooo`0/ool00`0?ool03`0900l0?A0?00l@3`0?40l03a0?00lQ
;a8O8AlA7b4_4QlQ7a4O8Bn8SiR?R8nHShR?V8n8SiR?R8o;clboblnl_l_?c;o;ckbobln8SiR?R8nH
ShR?V8n8SiR?R8lQ;a8O8AlA7b4_4QlQ7a4O8Bl03a0?00l@3`0?40l03a0?00X03`03ool03ooo02go
o`0D00ooo`4?41l03a0O0@l@7`0?41l13b4_8QlQ;a8O8BlR7b4_4QlQ;`=4C`0A@dm4CdA?A4m3CdA?
MWmWKgI_IVmfOfM_MVmVKgIoMgn7O`03Mgl03HMoMgmgOgMoMVmVKgIoIfmfKfI_MWmWKgI_00=4C`0J
@dm4CdA?A4m3CdA?8BlB7b4_8QlQ;a8O8BlR7b4_0@l@7`0?41l13a0O00l@7`4?ool03b;oo`005Ooo
00<03ooo00l02`0?01807`0?00l03`0O00l@7`4?41l13a0O0@l@7`4?41lc?c=?=3l2<cl013=?=3lc
?c<o2Ooo00Dd?c<o<clcCc@o008c?`0=<dld?a0O0@l@7`4?41l13a0O0@l@7`0?01l00`0?00<07`0?
00l02@0?0_oo00<03oooool0;?oo00<03ooo00l0200?03l07`4?01l13`0O0@l07`4?01lB7b4_4QlA
;a8O8BlB7a4_4Qn8WhV?R9n9ShRORHn8WhV?R9nlcl_?_<o<ckc?blnlclc?_<n8WhV?R9n9ShRORHn8
WhV?R9lB7b4_4QlA;a8O8BlB7a4_4Ql07`4?01l13`0O0@l07`4?01l02@0?00?oo`0?ool0;Ooo01@0
3ooo41l13a0O0@l@7`4?41l13a0O4QlQ;a8_8RlB7b4_4RlR;a8O2DA?00UWKgIoIfmVOfM_MWmWKfIo
Ifl00WMo011gSgQoMgmgOgN?N7mgOfM_IWmWKgIoIfmVOfM_MWmWK`U4C`0D4RlR;a8O8BlB;b8_4QlQ
;a8_41l13a0O0@l@7`4?41l13a0Oool03b;oo`005Ooo00<03ooo00l0200?00D@3`0?00l03a0?00<0
3`0^40lc;c<o<blb?c<_<clc;c8o<bmUKeIOIFmVGfE_EUmUKfIOIFmECeAOEDmDGeE?E5mECeAOEDmU
KfIOIFmFGfE_IUmUKeIOIFlc;c<o<blb?c<_<clc;c8o<bl200l01A0?00l03`0?40l02P0?00?oo`0?
00l0;_oo00<03ooo00l0200?01813a0?00l@7`4?40l03a0O0@n7OgMoQgmgOhMoMgn7OgMoQgl9ool2
gMl01NgOgMoMgmgOkMl00]gO2Ooo0167OgMoQgmgOhMoMgn7OgMoQgl03a0O0@l@3`0?41l13a0?00`0
3bkoo`1C00oooa4?41lA3a0O4@l@7a4?41lA3c8o8blb?b<_<SlS;c8o8blb?gM_MWmgKgIoMfmfOgM_
MWmgKl^o^ko;_k^obknk_l^o^ko;_mg?g=o=cmcOgLoLglg?g=oMcl^o^ko;_k^obknk_l^o^ko;_gM_
MWmgKgIoMfmfOgM_MWmgKc8o8blb?b<_<SlS;c8o8blb?a4?41lA3a0O4@l@7a4?41lA3`0200lRool0
01Goo`0300ooo`0?00X03`050@l03`0?00l13`0200l0;S<o8clc?b<o<clS?c<o8clc?eI_IVmFGfE_
EVmVKeIOIFmFKeEOAEmEGdEOEEm5GeEOAEmEGeIOIFmFKfI_EUmUKeI_IVmFGc<o8clc?b<o<clS?c<o
8clc?`4?0`0?00D13`0?00l03`4?00P03`;oo`0300oooooo02coo`0300ooo`0?00P03`0B41l13`0O
0@l@7`4?01l13a0ON7mgSgQoMhmhOgN?N7mgSgQo2Ooo00GNgmgOgMoMkmkO00;Mg`03gNoNgooo00So
o`0BN7mgSgQoMhmhOgN?N7mgSgQo01l13a0O0@l07`4?41l13`0O2@0?00?oo`0?ool0;Ooo05D03ooo
4Al17a4O0@lA7`4O4Al13a4O8blb?b<_<SlS;c8o8blb?b<_MgmWKgMoIgmgOfM_MgmWOgMo_;nkckbo
^lnl_k_?_;nkckbog=o=cmgOcLoLglg?gMo=cmcO_;nkckbo^lnl_k_?_;nkckboMgmWKgMoIgmgOfM_
MgmWOgMo8blb?b<_<SlS;c8o8blb?b<_4Al17a4O0@lA7`4O4Al13a4Oool03`0Rool001Goo`0300oo
o`0?01403`0]<blb?c<o<Slc;c8o<clb?c<_IFmVGfE_EUmUKfIOIFmFGfE_EDmDGeE?E5mECeAOEDmD
GeE?IFmFGfE_IUmUKeIOIFmVGfE_<blb?c<o<Slc;c8o<clb?c<_01403`;oo`0300oooooo02coo`03
00ooo`0?00T03`0A41l13a0?00l@7`4?40l03hMoMgn7OgMoQgmgOhMoMgn7O`09ool01NgOgMoMgmgO
kMl00mgO00?]goooool01ooo01:7OgMoQgmgOhMoMgn7OgMoQgl13a0?00l@7`4?40l03a0O0@l900l0
0ooo00ooo`0]ool0E@0?ool13a0O4@l@7`4?41lA3a0O0@lb?b<_<SlS;c8o8blb?b<_<SmgKgIoIfmf
OgM_MWmWKgIoMfo;_k^obknk_l^o^ko;_k^obko=cmcOcLoLglg?g=o=cmcOcLo;_k^obknk_l^o^ko;
_k^obkmgKgIoIfmfOgM_MWmWKgIoMflb?b<_<SlS;c8o8blb?b<_<Sl13a0O4@l@7`4?41lA3a0O0@oo
o`0?02;oo`005Ooo00<03ooo00l02`0?00P07`0?00l03`0O00lc?b<o0c<o024S?c<o<clc?eIOIFmF
KfI_EUmUKeI_IVmFGeEOAEmEGdEOEEm5GeEOAEmEGeI_IVmFGfE_EVmVKeIOIFmFKc<o8cl00c<o00HS
?c<o<clc?`0?01l300l00`0O00l03`0900l2ool00`0?ooooo`0/ool00`0?ool03`0800l04P0O0@l@
7`4?01l13a0O0@l07gQoMhmhOgN?N7mgSgQoMhmhO`Woo`03gMoMkmkO00;Mg`04gNoNgmgOgMl9ool0
4WQoMhmhOgN?N7mgSgQoMhmhOa0O0@l07`4?41l13`0O0@l@7`T03`03ool03ooo02goo`1E00oooa4O
0Al@7`4O4Al17a0O0AlA7b<_<SlS;c8o8blb?b<_<SlS;gIoIgmgOfMoMWmWOgMoIgmfOkbo^lnl_k_?
_;nkckbo^lnl_mcOcLoLglgOg=o=cmcOcMoLgkbo^lnl_k_?_;nkckbo^lnl_gIoIgmgOfMoMWmWOgMo
IgmfOb<_<SlS;c8o8blb?b<_<SlS;a4O0Al@7`4O4Al17a0O0AlA7ooo00l08_oo000Eool00`0?ool0
3`0800l01A0?00l03`0?40l00`0?02h@3c<_<clc;c8o<blc?c<_<Slc;fE_EUmUKfIOIFmFGfE_IUmU
KeE?E5mECeAOEDmDGeE?E5mECfE_IUmUKeIOIFmVGfE_EUmUKc<_<clc;c8o<blc?c<_<Slc;`803`05
40l03`0?00l@3`0:00l00ooo00l03`0^ool00`0?ool03`0800l04P4?40l03a0O0@l@3`0?41l13hMo
Mgn7OgMoQgmgOhMoMgn7O`Woo`;Mg`05kMoMgmgOgMo]g`02gMl9ool04HMoMgn7OgMoQgmgOhMoMgn7
O`0?41l13a0?00l@7`4?40l0300?;_oo05<03ooo4@l@7a4?41lA3a0O4@l@7a4?<SlS;c8o8blb?b<_
<SlS;c8oMfmfOgM_MWmgKgIoMfmfOgM_bknk_l^o^ko;_k^obknk_l^ogLoLglg?g=oMcmcOcLoLgmg?
bknk_l^o^ko;_k^obknk_l^oMfmfOgM_MWmgKgIoMfmfOgM_<SlS;c8o8blb?b<_<SlS;c8o4@l@7a4?
41lA3a0O4@l@7a4?00803b;oo`005Ooo00<03ooo00l02P0?00D13`0?00l03`4?00803`0^<clS?c<o
8clc?b<o<clS?c<oEVmVKeIOIFmFKfI_EUmUKeI_EEm5GeEOAEmEGdEOEEm5GeEOEUmUKeI_IVmFGfE_
EVmVKeIO<clS?c<o8clc?b<o<clS?c<o0@l300l01@4?00l03`0?0@l0200?0_oo00<03oooool0;?oo
00<03ooo00l0200?018@7`4?01l13a0O0@l07`4?41mhOgN?N7mgSgQoMhmhOgN?N7l9ool01MkOgMoM
gmg_g]l00]gO00?MkmkOool02?oo019hOgN?N7mgSgQoMhmhOgN?N7l07`4?41l13`0O0@l@7`4?01l9
00l00ooo00ooo`0]ool0E@0?oolA7`4O4Al13a4O0AlA7`4?4AlS;c8o8blb?b<_<SlS;c8o8bmgOfM_
MgmWOgMoIfmgOfMoMgnl_k_?_;nkckbo^lnl_k_?_;oLglg?gMo=cmcOcLoMglg?g=nl_k_?_;nkckbo
^lnl_k_?_;mgOfM_MgmWOgMoIfmgOfMoMglS;c8o8blb?b<_<SlS;c8o8blA7`4O4Al13a4O0AlA7`4?
4Aooo`0?02;oo`004?oo00<03oooool00_oo00<03ooo00l04@0?02dc;c8o<clb?c<_<Slc?c8o<bmU
KfIOIFmFGfE_IUmUKeIOIFmECeAOEDmDGeE?E5mECeAOEDmUKeIOIFmVGfE_EUmUKfIOIFlc;c8o<clb
?c<_<Slc?c8o<bl04@0?0_oo00<03oooool09ooo00<03oooool00_oo00<03ooo00l02@0?014@7`4?
40l03a0O0@l@3`0?QgmgOhMoMgn7OgMoQgmgOhMo00Woo`05kMoMgmgOgMo]g`03gMl00ngOooooo`07
ool04XMoMgn7OgMoQgmgOhMoMgn7O`4?40l03a0O0@l@3`0?41l13`T03`03ool03ooo02Soo`0300oo
oooo00;oo`1E00ooo`4?41lA3a0O0@l@7a4?41l13c8o8blb?b<_<SlS;c8o8blb?gM_MWmWKgIoMfmf
OfM_MWmgKl^o^ko;_k^obknk_l^o^ko;_lg?g=o=cmcOcLoLglg?g=o=cl^o^ko;_k^obknk_l^o^ko;
_gM_MWmWKgIoMfmfOfM_MWmgKc8o8blb?b<_<SlS;c8o8blb?`4?41lA3a0O0@l@7a4?41l13ooo00l0
8_oo000>ool300l4ool00`0?ool03`0;00l0200O00l03`0?01l03c<o8cl3<cl08B<o<clc?c<oEUmU
KeI_IVmFGfE_EVmVKeIOEEm5GeEOAEmEGdEOEEm5GeEOEVmVKeIOIFmFKfI_EUmUKeI_<clS?`03<cl0
1R<o<clc?c<o00l07`<03`0301l03`0?00T03`;oo`0300oooooo02Goo`<03`Coo`0300ooo`0?00P0
3`0B01l13a0O0@l07`4?41l13`0ON7mgSgQoMhmhOgN?N7mgSgQo2Ooo00?Mgmg_g]l00]gO00CMkmkO
gMoMg`Woo`0BN7mgSgQoMhmhOgN?N7mgSgQo41l13`0O0@l@7`4?01l13a0O2@0?00?oo`0?ool09_oo
0`0?1?oo05D03ooo4Al17a0O0AlA7`4O41l17a4O8blb?b<_<SlS;c8o8blb?b<_MWmWOgMoIgmfOfMo
MgmWOgIo_;nkckbo^lnl_k_?_;nkckbog=o=cmcOcMoLglg?g=o=gmcO_;nkckbo^lnl_k_?_;nkckbo
MWmWOgMoIgmfOfMoMgmWOgIo8blb?b<_<SlS;c8o8blb?b<_4Al17a0O0AlA7`4O41l17a4Oool03`0R
ool000koo`0300ooo`0?00Coo`0300ooo`0?00P03`0540l03`0?00l@3`0300l0;Q0?<blc?c<_<Slc
;c<o<blb?c<_IFmFGfE_IUmUKeIOIFmVGfE_EDmDGeE?E5mECeAOEDmDGeE?IFmVGfE_EUmUKfIOIFmF
GfE_<blc?c<_<Slc;c<o<blb?c<_0P0?00D@3`0?00l03a0?00X03`;oo`0300oooooo02Goo`0300oo
o`0?00Coo`0300ooo`0?00P03`0B0@l@3`0?41l13a0?00l@7`4?QgmgOhMoMgn7OgMoQgmgOhMo2Ooo
0]gO00G]gmgOgMoMgngO00;Mg`Woo`0AQgmgOhMoMgn7OgMoQgmgOhMo00l@7`4?40l03a0O0@l@3`0:
00l00ooo00ooo`0Vool00`0?ool03`04ool0E@0?oolA3a0O4@l@7a4?41lA3a0O4@lb?b<_<SlS;c8o
8blb?b<_<SmgKgIoMfmfOgM_MWmgKgIoMfo;_k^obknk_l^o^ko;_k^obkoMcmcOcLoLgmg?g=o=cmcO
gLo;_k^obknk_l^o^ko;_k^obkmgKgIoMfmfOgM_MWmgKgIoMflb?b<_<SlS;c8o8blb?b<_<SlA3a0O
4@l@7a4?41lA3a0O4@ooo`0?02;oo`003ooo0P0?1?oo00<03ooo00l04@0?00Y3Cc@oA4ld?d=?=3m4
Cc@o@dmFG`=EG`0=EUmEGeEOEEmFGeEOADmEGdEOEEm5CeEOAEl00eEO00EFGeEOEEmEGeIO009EG`09
@dld?dA?=3m3Cc@oA4ld?d=?01403`03ool03`0?02Soo`803`Coo`0300ooo`0?00/03`0?0@l03`0?
00l13`0?N7mgSgQoQhmhOgN?N7n7SgQo00?^k`0Ag^o^knk_k^oNknk_g]oMkmkOgNoNgmg_g]oMkmkO
k^oNk`03k^l03mk_k^o^knk_N7mgSgQoQhmhOgN?N7n7SgQo00l13`0300l00`4?00l03`0<00lXool2
00l4ool0500?oolA7`4O4Al13a4O0AlA7`4?4AlS?c<o8clc?b<o<clS?c<o8cl9R8l02MkOgNoNgng_
g]oMkmkOkNoNg`09ool02MkOkNoNgmg_g]o]kmkOgNoNg`09R8l04R<o<clS?c<o8clc?b<o<clS?a4O
0AlA7`4?4Al17a4O0@lA7`803b;oo`004?oo00<03oooool00_oo00<03ooo00l04@0?00Td?d=?=3m3
Cc@o@dld?d=?=3l02EEO00UECeAOADmDGeE?E5m5CeAOEDl02EEO00Td?d=?=3m3Cc@o@dld?d=?=3l0
4@0?0_oo00<03oooool09ooo00<03oooool00_oo00<03ooo00l04@0?00^7SgQoQgmgOhN?N7n7OgMo
Qho^kng_00?^k`0=kNo^knk_k^o]gmgOkMoMgngOgMo]gmgOkMl00nk_00o]knk_k^o^kng_k^n7SgQo
QgmgOhN?N7n7OgMoQhl04P0?00?oo`0?ool0:?oo00<03oooool00_oo01@03ooo0@l@7a4?41l13a0O
4@l@7`4?<Slc?c8o<blb?c<o<Slc;c8o2HR?00W]kmkOkNoMgng_g]o]kmgOkNl02Ooo00W]kmgOkNoN
gng_gMo]kmkOkNl02HR?01@b?c<_<Slc?c8o<blb?c<o<Sl13a0O4@l@7`4?41lA3a0O0@ooo`0?8_oo
000Eool00`0?ool03`0A00l02d=?=3m3CcA?@dld?d=?=4m3CeEOEFl00eEO00eEKeEOEEmEGeAOAEmE
GdEOE5m5GeEOAEmDG`03EEl03eE_EEmEGeEOEFmEGd=?=3m3CcA?@dld?d=?=4m3C`0A00l2ool00`0?
ooooo`0/ool00`0?ool03`0800l01@0O00l03`0?01l00`0?00X07gQoQhmhOgN?N7n7SgQoMhmhO`W^
k`09g]oMkmkOgNoNgmg_g]oMkmkO00W^k`09N7n7SgQoMhmhOhN?N7mgSgQo00803`0501l03`0?00l0
7`0;00l00ooo00ooo`0]ool0300?oolA7`4O41l17a4O0Al@7`4O4AlS?`<c?`058clc?c<o<clS?`09
R8l02MkOkNoNgng_g]o]kmkOkNoNg`09ool02MkOkNoNgng_g]o]kmkOkNoNg`09R8l2<cl01B<o<clc
?c<o8cl00S<o00/A7`4O41l17a4O0Al@7`4O4Aooo`0?02;oo`005Ooo00<03ooo00l04@0?00U4?d=?
=3m3Cd@o@dld?d=?A3l00UEO00EUGeEOEEmEGfEO009EG`0:EDmDGeE?E5mECeAOEDmDGeE?IEl3EEl0
3VEOEEmEGeEOIEm4?d=?=3m3Cd@o@dld?d=?A3lA00l2ool00`0?ooooo`0/ool00`0?ool03`0900l0
1A0?00l03`0?40l00`0?00V7OgMoQhmhOhMoMgn7SgQoQgl00^k_00G^gnk_k^o^knkO00;^k`0:kMoM
gngOgMo]gmgOkMoMgngOk]l3k^l03^kOk^o^knk_k]n7OgMoQhmhOhMoMgn7SgQoQgl300l01A0?00l0
3`0?40l02P0?00?oo`0?ool0;Ooo01@03ooo4@l@7a4?41lA3a0O4@l@7a4?<clc;c8o<blc?c<_<Slc
;c<o2HR?00W]gmkOkNoNgngOg]o]kmkOkMl02Ooo00W]kmkOkMoNgng_g]o]gmkOkNl02HR?01@b?c<_
<clc;c8o<blc?c<_<SlA3a0O4@l@7a4?41lA3a0O4@ooo`0?8_oo000Eool00`0?ool03`0A00l02T=?
=3m4Cc@o@dld?dA?=3m3CeIO0eEO00eFGeEOEEmEGeIOEEm5CeEOAEmEGdE?EEm5G`03EEl01EIOEEmE
GeEOEUl00UEO00U3Cc@oA4ld?d=?=3m4Cc@o@dl04@0?00?oo`0?00l0;_oo00<03ooo00l02`0?00l1
3`0?00l03`4?00mhOgN?N7n7SgQoMhmhOhN?N7l00nk_017Nknk_k^o^kmk_k^oNgmg_g]oMkmkOgNoN
gmg_g]o^kmk_00?^k`0?g^o^knk_k^mhOgN?N7n7SgQoMhmhOhN?N7l03`4?00<03`030@l03`0?00`0
3bkoo`0D00oooa4O0AlA7`4?4Al17a4O0@lA7b<o<clS?c<o8clc?b<o<clS?`V8S`09g]oMkmkOkNoN
gmg_g]o]kmkO00Woo`09g]o]kmkOgNoNgng_g]oMkmkO00V8S`0B8clc?b<o<clS?c<o8clc?b<o4Al1
7a4O0@lA7`4O4Al13a4O0P0?8_oo000Eool00`0?ool03`0A00l02C@o@dld?d=?=3m3Cc@o@dld?`09
EEl02EE?E5m5CeAOEDmDGdE?E5mEC`09EEl02C@o@dld?d=?=3m3Cc@o@dld?`0A00l2ool00`0?oooo
o`0/ool00`0?ool03`0A00l02hN?N7n7OgMoQhmhOhMoMgn7Snk_kNl00nk_00g]knk_k^o^kngOgMo]
gmgOkMoMgngOgMo]g`03k^l03ng_k^o^knk_kNo^khN?N7n7OgMoQhmhOhMoMgn7S`0B00l00ooo00oo
o`0]ool0500?ool13a0O4@l@7`4?41lA3a0O0@lb?c<o<Slc;c8o<clb?c<_<Sl9R8l02Ng_g]o]kmgO
kNoNgng_gMo]k`09ool02Ng_gMo]kmkOkNoMgng_g]o]k`09R8l0538o<blb?c<o<Slc;c8o<clb?`4?
41lA3a0O0@l@7a4?41l13ooo00lRool001Goo`0300ooo`0?01403`0;@dld?d=?=4m3Cc@o@dldCd=?
EEmEK`03EEl03EE_EEmEGeEOE5m5GeEOAEmDGdEOEEm5GeAO00=EG`0?EFmEGeEOEEmEKeEO@dld?d=?
=4m3Cc@o@dldCd=?01403`;oo`0300oooooo02coo`0300ooo`0?00P03`0501l03`0?00l07`0300l0
2P0ON7n7SgQoMhmhOhN?N7mgSgQo2Nk_00WNgmg_g]oMkmkOgNoNgmg_g]l02Nk_00UhOhN?N7mgSgQo
QhmhOgN?N7l00P0?00D07`0?00l03`0O00/03`03ool03ooo02goo`0<00oooa4O0Al@7`4O4Al17a0O
0AlA7b<o0c<o00DS?c<o<clc?b<o00V8S`09g]o]kmkOkNoNgng_g]o]kmkO00Woo`09g]o]kmkOkNoN
gng_g]o]kmkO00V8S`8c?`058clc?c<o<clS?`02<cl02a4O0Al@7`4O4Al17a0O0AlA7ooo00l08_oo
000Eool00`0?ool03`0A00l02D@o@dld?d=?A3m3Cc@o@dm4?`02EEl01FEOEEmEGeEOIEl00UEO00YE
CeAOEDmDGeE?E5mECeAOEDmUG`=EG`0>IEmEGeEOEEmUGd@o@dld?d=?A3m3Cc@o@dm4?a403`;oo`03
00oooooo02coo`0300ooo`0?00T03`0540l03`0?00l@3`0300l02HMoMgn7SgQoQgmgOhN?N7n7O`02
k^l01NkOk^o^knk_k]l00^k_00[]gmgOkMoMgngOgMo]gmgOkMo^g`?^k`0>k]o^knk_k^o^ghMoMgn7
SgQoQgmgOhN?N7n7O`<03`0540l03`0?00l@3`0:00l00ooo00ooo`0]ool0500?oolA3a0O4@l@7a4?
41lA3a0O4@lc?c<_<Slc;c<o<blb?c<_<cl9R8l02NgOg]o]kmkOkMoNgng_g]o]g`09ool02Ng_g]o]
gmkOkNoNgngOg]o]k`09R8l0538o<blc?c<_<Slc;c<o<blb?a4?41lA3a0O4@l@7a4?41lA3ooo00lR
ool001Goo`0300ooo`0?01403`0:@dld?dA?=3m3Cc@oA4ld?d=?EUl3EEl03EIOEEmEGeEOEUmEGdE?
EEm5GeEOADmEGdEO00=EG`05EUmEGeEOEEmFG`02EEl02D=?=3m4Cc@o@dld?dA?=3m3C`0A00l2ool0
0`0?ooooo`0/ool00`0?ool03`0;00l03`4?00l03`0?0@l03gQoMhmhOhN?N7mgSgQoQhmhO`03k^l0
4Mk_k^o^knk_g^o^kmkOgNoNgmg_g]oMkmkOgNoNgnk_g^l00nk_00oNknk_k^o^kgQoMhmhOhN?N7mg
SgQoQhmhO`0?0@l00`0?00<13`0?00l02P0?00?oo`0?ool0;Ooo01@03ooo4Al17a4O0@lA7`4O4Al1
3a4O8clc?b<o<clS?c<o8clc?b<o2HR?00WNgmg_g]o]kmkOgNoNgng_g]l02Ooo00WNgng_g]oMkmkO
kNoNgmg_g]l02HR?01@S?c<o8clc?b<o<clS?c<o8clA7`4O4Al13a4O0AlA7`4?4Aooo`0?8_oo000E
ool00`0?ool03`0A00l0;C<_<Slc?c8o<blb?c<o<Slc;fE_IUmUKeIOIFmVGfE_EUmUKeE?E5mECeAO
EDmDGeE?E5mECfE_EUmUKfIOIFmFGfE_IUmUKc<_<Slc?c8o<blb?c<o<Slc;`0A00l00ooo00l03`0^
ool00`0?ool03`0900l04A0O0@l@3`0?41l13a0?00n7OgMoQgmgOhMoMgn7OgMoQgl02Ooo00G]gmgO
gMoMgngO00?Mg`03kMoooooo00Ooo`0BQgmgOhMoMgn7OgMoQgmgOhMo0@l@3`0?41l13a0?00l@7`4?
2`0?;_oo05<03ooo0@l@7a4?41l13a0O4@l@7`4?<SlS;c8o8blb?b<_<SlS;c8oMfmfOfM_MWmgKgIo
IfmfOgM_bknk_l^o^ko;_k^obknk_l^ocLoLglg?g=o=cmcOcLoLglg?bknk_l^o^ko;_k^obknk_l^o
MfmfOfM_MWmgKgIoIfmfOgM_<SlS;c8o8blb?b<_<SlS;c8o0@l@7a4?41l13a0O4@l@7`4?00803b;o
o`005Ooo00<03ooo00l02`0?00P07`0?00l03`0O00lc?b<o0c<o024S?c<o<clc?eIOIFmFKfI_EUmU
KeI_IVmFGeEOAEmEGdEOEEm5GeEOAEmEGeI_IVmFGfE_EVmVKeIOIFmFKc<o8cl00c<o00HS?c<o<clc
?`0?01l300l00`0O00l03`0900l2ool00`0?ooooo`0/ool00`0?ool03`0800l04P0O0@l@7`4?01l1
3a0O0@l07gQoMhmhOgN?N7mgSgQoMhmhO`Woo`03gMoMkmkO00;Mg`04gNoNgmgOgMl9ool04WQoMhmh
OgN?N7mgSgQoMhmhOa0O0@l07`4?41l13`0O0@l@7`T03`03ool03ooo02goo`1E00oooa4O0Al@7`4O
4Al17a0O0AlA7b<_<SlS;c8o8blb?b<_<SlS;gIoIgmgOfMoMWmWOgMoIgmfOkbo^lnl_k_?_;nkckbo
^lnl_mcOcLoLglgOg=o=cmcOcMoLgkbo^lnl_k_?_;nkckbo^lnl_gIoIgmgOfMoMWmWOgMoIgmfOb<_
<SlS;c8o8blb?b<_<SlS;a4O0Al@7`4O4Al17a0O0AlA7ooo00l08_oo000Eool00`0?ool03`0800l0
1A0?00l03`0?40l00`0?02h@3c<_<clc;c8o<blc?c<_<Slc;fE_EUmUKfIOIFmFGfE_IUmUKeE?E5mE
CeAOEDmDGeE?E5mECfE_IUmUKeIOIFmVGfE_EUmUKc<_<clc;c8o<blc?c<_<Slc;`803`0540l03`0?
00l@3`0:00l2ool00`0?ooooo`0/ool00`0?ool03`0800l04P4?40l03a0O0@l@3`0?41l13hMoMgn7
OgMoQgmgOhMoMgn7O`Woo`;Mg`05kMoMgmgOgMo]g`02gMl9ool04HMoMgn7OgMoQgmgOhMoMgn7O`0?
41l13a0?00l@7`4?40l02P0?00?oo`0?ool0;Ooo05D03ooo4@l@7a4?41lA3a0O4@l@7a4?<SlS;c8o
8blb?b<_<SlS;c8oMfmfOgM_MWmgKgIoMfmfOgM_bknk_l^o^ko;_k^obknk_l^ogLoLglg?g=oMcmcO
cLoLgmg?bknk_l^o^ko;_k^obknk_l^oMfmfOgM_MWmgKgIoMfmfOgM_<SlS;c8o8blb?b<_<SlS;c8o
4@l@7a4?41lA3a0O4@l@7a4?ool03`0Rool001Goo`0300ooo`0?00X03`050@l03`0?00l13`0200l0
;S<o8clc?b<o<clS?c<o8clc?eI_IVmFGfE_EVmVKeIOIFmFKeEOAEmEGdEOEEm5GeEOAEmEGeIOIFmF
KfI_EUmUKeI_IVmFGc<o8clc?b<o<clS?c<o8clc?`4?0`0?00D13`0?00l03`4?00P03`;oo`0300oo
oooo02coo`0300ooo`0?00P03`0B41l13`0O0@l@7`4?01l13a0ON7mgSgQoMhmhOgN?N7mgSgQo2Ooo
00GNgmgOgMoMkmkO00;Mg`03gNoNgooo00Soo`0BN7mgSgQoMhmhOgN?N7mgSgQo01l13a0O0@l07`4?
41l13`0O2@0?00?oo`0?ool0;Ooo05D03ooo4Al17a4O0@lA7`4O4Al13a4O8blb?b<_<SlS;c8o8blb
?b<_MgmWKgMoIgmgOfM_MgmWOgMo_;nkckbo^lnl_k_?_;nkckbog=o=cmgOcLoLglg?gMo=cmcO_;nk
ckbo^lnl_k_?_;nkckboMgmWKgMoIgmgOfM_MgmWOgMo8blb?b<_<SlS;c8o8blb?b<_4Al17a4O0@lA
7`4O4Al13a4Oool03`0Rool001Goo`0300ooo`0?01403`0]<blb?c<o<Slc;c8o<clb?c<_IFmVGfE_
EUmUKfIOIFmFGfE_EDmDGeE?E5mECeAOEDmDGeE?IFmFGfE_IUmUKeIOIFmVGfE_<blb?c<o<Slc;c8o
<clb?c<_01403`03ool03`0?02koo`0300ooo`0?00T03`0A41l13a0?00l@7`4?40l03hMoMgn7OgMo
QgmgOhMoMgn7O`09ool01NgOgMoMgmgOkMl00mgO00?]goooool01ooo01:7OgMoQgmgOhMoMgn7OgMo
Qgl13a0?00l@7`4?40l03a0O0@l;00l^ool0D`0?ool13a0O4@l@7`4?41lA3a0O0@lb?b<_<SlS;c8o
8blb?b<_<SmgKgIoIfmfOgM_MWmWKgIoMfo;_k^obknk_l^o^ko;_k^obko=cmcOcLoLglg?g=o=cmcO
cLo;_k^obknk_l^o^ko;_k^obkmgKgIoIfmfOgM_MWmWKgIoMflb?b<_<SlS;c8o8blb?b<_<Sl13a0O
4@l@7`4?41lA3a0O0@l00P0?8_oo000Eool00`0?ool03`0;00l0200O00l03`0?01l03c<o8cl3<cl0
8B<o<clc?c<oEUmUKeI_IVmFGfE_EVmVKeIOEEm5GeEOAEmEGdEOEEm5GeEOEVmVKeIOIFmFKfI_EUmU
KeI_<clS?`03<cl01R<o<clc?c<o00l07`<03`0301l03`0?00T03`;oo`0300oooooo02coo`0300oo
o`0?00P03`0B01l13a0O0@l07`4?41l13`0ON7mgSgQoMhmhOgN?N7mgSgQo2Ooo00?Mgmg_g]l00]gO
00CMkmkOgMoMg`Woo`0BN7mgSgQoMhmhOgN?N7mgSgQo41l13`0O0@l@7`4?01l13a0O2@0?00?oo`0?
ool0;Ooo05D03ooo4Al17a0O0AlA7`4O41l17a4O8blb?b<_<SlS;c8o8blb?b<_MWmWOgMoIgmfOfMo
MgmWOgIo_;nkckbo^lnl_k_?_;nkckbog=o=cmcOcMoLglg?g=o=gmcO_;nkckbo^lnl_k_?_;nkckbo
MWmWOgMoIgmfOfMoMgmWOgIo8blb?b<_<SlS;c8o8blb?b<_4Al17a0O0AlA7`4O41l17a4Oool03`0R
ool000ooo`0300oooooo00?oo`0300ooo`0?00P03`0540l03`0?00l@3`0300l0;Q0?<blc?c<_<Slc
;c<o<blb?c<_IFmFGfE_IUmUKeIOIFmVGfE_EDmDGeE?E5mECeAOEDmDGeE?IFmVGfE_EUmUKfIOIFmF
GfE_<blc?c<_<Slc;c<o<blb?c<_0P0?00D@3`0?00l03a0?00X03`;oo`0300oooooo02Koo`0300oo
oooo00?oo`0300ooo`0?00P03`0B0@l@3`0?41l13a0?00l@7`4?QgmgOhMoMgn7OgMoQgmgOhMo2Ooo
0]gO00G]gmgOgMoMgngO00;Mg`Woo`0AQgmgOhMoMgn7OgMoQgmgOhMo00l@7`4?40l03a0O0@l@3`0:
00l00ooo00ooo`0Wool00`0?ooooo`03ool0E@0?oolA3a0O4@l@7a4?41lA3a0O4@lb?b<_<SlS;c8o
8blb?b<_<SmgKgIoMfmfOgM_MWmgKgIoMfo;_k^obknk_l^o^ko;_k^obkoMcmcOcLoLgmg?g=o=cmcO
gLo;_k^obknk_l^o^ko;_k^obkmgKgIoMfmfOgM_MWmgKgIoMflb?b<_<SlS;c8o8blb?b<_<SlA3a0O
4@l@7a4?41lA3a0O4@ooo`0?02;oo`003_oo00<03ooo00l01?oo00<03ooo00l02P0?00D13`0?00l0
3`4?00803`0^<clS?c<o8clc?b<o<clS?c<oEVmVKeIOIFmFKfI_EUmUKeI_EEm5GeEOAEmEGdEOEEm5
GeEOEUmUKeI_IVmFGfE_EVmVKeIO<clS?c<o8clc?b<o<clS?c<o0@l300l01@4?00l03`0?0@l0200?
0_oo00<03oooool09Ooo00<03ooo00l01?oo00<03ooo00l0200?018@7`4?01l13a0O0@l07`4?41mh
OgN?N7mgSgQoMhmhOgN?N7l9ool01MkOgMoMgmg_g]l00]gO00?MkmkOool02?oo019hOgN?N7mgSgQo
MhmhOgN?N7l07`4?41l13`0O0@l@7`4?01l900l00ooo00ooo`0Vool00`0?ool03`04ool0E@0?oolA
7`4O4Al13a4O0AlA7`4?4AlS;c8o8blb?b<_<SlS;c8o8bmgOfM_MgmWOgMoIfmgOfMoMgnl_k_?_;nk
ckbo^lnl_k_?_;oLglg?gMo=cmcOcLoMglg?g=nl_k_?_;nkckbo^lnl_k_?_;mgOfM_MgmWOgMoIfmg
OfMoMglS;c8o8blb?b<_<SlS;c8o8blA7`4O4Al13a4O0AlA7`4?4Aooo`0?02;oo`003_oo0P0?1Ooo
00<03ooo00l04@0?02dc;c8o<clb?c<_<Slc?c8o<bmUKfIOIFmFGfE_IUmUKeIOIFmECeAOEDmDGeE?
E5mECeAOEDmUKeIOIFmVGfE_EUmUKfIOIFlc;c8o<clb?c<_<Slc?c8o<bl04@0?0_oo00<03oooool0
9Ooo0P0?1Ooo00<03ooo00l02@0?014@7`4?40l03a0O0@l@3`0?QgmgOhMoMgn7OgMoQgmgOhMo00Wo
o`05kMoMgmgOgMo]g`03gMl00ngOooooo`07ool04XMoMgn7OgMoQgmgOhMoMgn7O`4?40l03a0O0@l@
3`0?41l13`T03`03ool03ooo02Koo`803`Goo`1E00ooo`4?41lA3a0O0@l@7a4?41l13c8o8blb?b<_
<SlS;c8o8blb?gM_MWmWKgIoMfmfOfM_MWmgKl^o^ko;_k^obknk_l^o^ko;_lg?g=o=cmcOcLoLglg?
g=o=cl^o^ko;_k^obknk_l^o^ko;_gM_MWmWKgIoMfmfOfM_MWmgKc8o8blb?b<_<SlS;c8o8blb?`4?
41lA3a0O0@l@7a4?41l13ooo00l08_oo000>ool00`0?ooooo`04ool00`0?ool03`0;00l04P0O00l0
3`0?01l03a0O0@l@7`4?41l13a0O0@l@7c<o<dld?`8c?`04<dld?c<o<cl9ool01C@o<clc?c=?=3l0
0S<o00dcCc@o41l13a0O0@l@7`4?41l13a0O00l07`0300l00`0O00l03`0900l00ooo00l03`0Wool0
0`0?ooooo`04ool00`0?ool03`0800l0?`0O0@l07`4?01l13`0O0@l07a8O8BlB7a4_4QlQ;a8O4BlB
7hRORHn8WhV?R9n9ShRORHn8Wkc?blnlclc?_<o;ckc?c<nlchRORHn8WhV?R9n9ShRORHn8Wa8O8BlB
7a4_4QlQ;a8O4BlB7`0O0@l07`4?01l13`0O0@l07`0;00lWool00`0?ooooo`04ool0500?ool@7`4?
41l13a0O0@l@7`4?41lB7b4_4RlR;a8O8BlB;b8_4Ql9A4l02FM_MWmWKfIoIfmfOfM_IWmWK`02Mgl0
47N?N7mgOgMoMhmhOgMoIfmVOfM_MWmWKfIoIfmfOfM_2DA?018B;b8_4QlQ;a8_8RlB7b4_4Rl@7`4?
41l13a0O0@l@7`4?41l200lRool000ooo`803`Coo`0300ooo`0?00P03`0540l03`0?00l@3`0300l0
2Q0?0@l@7`4?40l13a0O0@l@3`4?0S<o00E3?c<o<clc?d<o008c?`Woo`05@clc?c<o<cm3?`03<cl0
2T<o0@l@7`4?40l13a0O0@l@3`4?0P0?00D@3`0?00l03a0?00X03`;oo`0300oooooo02Koo`803`Co
o`0300ooo`0?00T03`0m40l03a0?00l@3`0?40l03b4O4AlQ;a8O8AlA7b4_4QlQ7hR?V8n8SiR?R8nH
ShR?V8n8Sl_?c;o;clboblo<_l_?c;o;chR?V8n8SiR?R8nHShR?V8n8Sb4O4AlQ;a8O8AlA7b4_4QlQ
7`0?40l03a0?00l@3`0?40l02P0?00?oo`0?ool09ooo0P0?1?oo01D03ooo0@l@7`4?40l13a0O0@l@
3`4?8BlB7b4_8QlQ;a8O8BlR7b4_A3l00dA?00i4?dA?A4m4Cd@oMVmVKgIoIfmfKfI_MWmWKgI_0gMo
0127OgMoMgmgOhMoMgmfOfM_MVmVKgIoIfmfKfI_MWm4?`=4C`0IA3m4CdA?A4m4?b4_8QlQ;a8O8BlR
7b4_4QlQ;`4?41l13a0?0@l@7`4?40l13ooo00l08_oo000Eool00`0?ool03`0:00l01@4?00l03`0?
0@l00P0?00X07`4?41l13`0O0@l@7`4?01ld?`8c?`06<dld?c<o<clcCc@o2Ooo00<c?c=?=3l00S<o
00hcCc@o<clc?`0O0@l@7`4?01l13a0O0@l07`4?0`0?00D13`0?00l03`4?00P03`;oo`0300oooooo
02coo`0300ooo`0?00P03`0o01l13`0O0@l07`4?01l13`0O4QlA;a8O8BlB7a4_4QlQ;a8OR9n9ShRO
RHn8WhV?R9n9ShRO_<o<ckboc<nlclc?_;o<ckc?R9n9ShRORHn8WhV?R9n9ShRO4QlA;a8O8BlB7a4_
4QlQ;a8O01l13`0O0@l07`4?01l13`0O00T03`03ool03ooo02goo`0F00ooo`0O0@l@7`4?01l13a0O
0@l07a8_8RlB7b4_4RlR;a8O8BlB;dA?=4l3A4l03cA?A4m4CdA?IfmVOfM_MWmWKfIoIfmfOfM_Mhmh
O`02Mgl047N?N7mgOgMoMhmWKgIoIfmVOfM_MWmWKfIoIfm4CcA?0dA?01PdCdA?A4m4Ca8O8BlB;b8_
4QlQ;a8_8RlB7`0O0@l@7`4?01l13a0O0@l07ooo00lRool001Goo`0300ooo`0?01403`0:0@l@7`0?
41l13a0O00l@7`4?@cl3<cl01D<o<clc?c<o@cl02Ooo0S<o00E3?c<o<clc?d<o008c?`090@l@7`0?
41l13a0O00l@7`4?01403`;oo`0300oooooo02coo`0300ooo`0?00T03`0m40l03a0?00l@3`0?40l0
3b4_4QlQ7a4O8BlB7b4O4AlQ;hR?V8n8SiR?R8nHShR?V8n8Sl_?c;o;ckboblo<_l_?_;o;chR?V8n8
SiR?R8nHShR?V8n8Sb4_4QlQ7a4O8BlB7b4O4AlQ;`0?40l03a0?00l@3`0?40l02P0?00?oo`0?ool0
;Ooo01@03ooo0@l@7`0?41l13a0O00l@7`4?8BlR7b4_4QlQ;b8O8BlB7b4_0dA?0153CdA?A4m4Cd=?
A4mfOfM_MVmVKgIoIfmfKfI_MWmgOhMo00=gO`0=QgmgOgMoMgmfKfI_MWmWKgI_IVmfOfM_MVl00dA?
01Y3CdA?A4m4Cd=?A4lQ;a8O8BlR7b4_4QlQ;b8O8Bl13a0O00l@7`4?41l03a0O0@ooo`0?8_oo000E
ool00`0?ool03`0;00l04P0O00l03`0?01l03a0O0@l@7`4?41l13a0O0@l@7c<o<dld?`8c?`04<dld
?c<o<cl9ool01C@o<clc?c=?=3l00S<o00dcCc@o41l13a0O0@l@7`4?41l13a0O00l07`0300l00`0O
00l03`0900l00ooo00l03`0^ool00`0?ool03`0800l0?`0O0@l07`4?01l13`0O0@l07a8O8BlB7a4_
4QlQ;a8O4BlB7hRORHn8WhV?R9n9ShRORHn8Wkc?blnlclc?_<o;ckc?c<nlchRORHn8WhV?R9n9ShRO
RHn8Wa8O8BlB7a4_4QlQ;a8O4BlB7`0O0@l07`4?01l13`0O0@l07`0;00l^ool0500?ool@7`4?41l1
3a0O0@l@7`4?41lB7b4_4RlR;a8O8BlB;b8_4Ql9A4l02FM_MWmWKfIoIfmfOfM_IWmWK`02Mgl047N?
N7mgOgMoMhmhOgMoIfmVOfM_MWmWKfIoIfmfOfM_2DA?018B;b8_4QlQ;a8_8RlB7b4_4Rl@7`4?41l1
3a0O0@l@7`4?41l200lRool001Goo`0300ooo`0?00P03`0540l03`0?00l@3`0300l02Q0?0@l@7`4?
40l13a0O0@l@3`4?0S<o00E3?c<o<clc?d<o008c?`Woo`05@clc?c<o<cm3?`03<cl02T<o0@l@7`4?
40l13a0O0@l@3`4?0P0?00D@3`0?00l03a0?00X03`;oo`0300oooooo02coo`0300ooo`0?00T03`0m
40l03a0?00l@3`0?40l03b4O4AlQ;a8O8AlA7b4_4QlQ7hR?V8n8SiR?R8nHShR?V8n8Sl_?c;o;clbo
blo<_l_?c;o;chR?V8n8SiR?R8nHShR?V8n8Sb4O4AlQ;a8O8AlA7b4_4QlQ7`0?40l03a0?00l@3`0?
40l02P0?00?oo`0?ool0;Ooo01D03ooo0@l@7`4?40l13a0O0@l@3`4?8BlB7b4_8QlQ;a8O8BlR7b4_
A3l00dA?00i4?dA?A4m4Cd@oMVmVKgIoIfmfKfI_MWmWKgI_0gMo0127OgMoMgmgOhMoMgmfOfM_MVmV
KgIoIfmfKfI_MWm4?`=4C`0IA3m4CdA?A4m4?b4_8QlQ;a8O8BlR7b4_4QlQ;`4?41l13a0?0@l@7`4?
40l13ooo00l08_oo000Eool00`0?ool03`0:00l01@4?00l03`0?0@l00P0?00X07`4?41l13`0O0@l@
7`4?01ld?`8c?`06<dld?c<o<clcCc@o2Ooo00<c?c=?=3l00S<o00hcCc@o<clc?`0O0@l@7`4?01l1
3a0O0@l07`4?0`0?00D13`0?00l03`4?00P03`;oo`0300oooooo02coo`0300ooo`0?00P03`0o01l1
3`0O0@l07`4?01l13`0O4QlA;a8O8BlB7a4_4QlQ;a8OR9n9ShRORHn8WhV?R9n9ShRO_<o<ckboc<nl
clc?_;o<ckc?R9n9ShRORHn8WhV?R9n9ShRO4QlA;a8O8BlB7a4_4QlQ;a8O01l13`0O0@l07`4?01l1
3`0O00T03`03ool03ooo02goo`0F00ooo`0O0@l@7`4?01l13a0O0@l07a8_8RlB7b4_4RlR;a8O8BlB
;dA?=4l3A4l03cA?A4m4CdA?IfmVOfM_MWmWKfIoIfmfOfM_MhmhO`02Mgl047N?N7mgOgMoMhmWKgIo
IfmVOfM_MWmWKfIoIfm4CcA?0dA?01PdCdA?A4m4Ca8O8BlB;b8_4QlQ;a8_8RlB7`0O0@l@7`4?01l1
3a0O0@l07ooo00lRool001Goo`0300ooo`0?01403`0:0@l@7`0?41l13a0O00l@7`4?@cl3<cl01D<o
<clc?c<o@cl02Ooo0S<o00E3?c<o<clc?d<o008c?`090@l@7`0?41l13a0O00l@7`4?01403`;oo`03
00oooooo02coo`0300ooo`0?00T03`0m40l03a0?00l@3`0?40l03b4_4QlQ7a4O8BlB7b4O4AlQ;hR?
V8n8SiR?R8nHShR?V8n8Sl_?c;o;ckboblo<_l_?_;o;chR?V8n8SiR?R8nHShR?V8n8Sb4_4QlQ7a4O
8BlB7b4O4AlQ;`0?40l03a0?00l@3`0?40l02P0?00?oo`0?ool0;Ooo01@03ooo0@l@7`0?41l13a0O
00l@7`4?8BlR7b4_4QlQ;b8O8BlB7b4_0dA?0153CdA?A4m4Cd=?A4mfOfM_MVmVKgIoIfmfKfI_MWmg
OhMo00=gO`0=QgmgOgMoMgmfKfI_MWmWKgI_IVmfOfM_MVl00dA?01Y3CdA?A4m4Cd=?A4lQ;a8O8BlR
7b4_4QlQ;b8O8Bl13a0O00l@7`4?41l03a0O0@ooo`0?8_oo000Eool00`0?ool03`0;00l04P0O00l0
3`0?01l03a0O0@l@7`4?41l13a0O0@l@7c<o<dld?`8c?`04<dld?c<o<cl9ool01C@o<clc?c=?=3l0
0S<o00dcCc@o41l13a0O0@l@7`4?41l13a0O00l07`0300l00`0O00l03`0900l2ool00`0?ooooo`0/
ool00`0?ool03`0800l0?`0O0@l07`4?01l13`0O0@l07a8O8BlB7a4_4QlQ;a8O4BlB7hRORHn8WhV?
R9n9ShRORHn8Wkc?blnlclc?_<o;ckc?c<nlchRORHn8WhV?R9n9ShRORHn8Wa8O8BlB7a4_4QlQ;a8O
4BlB7`0O0@l07`4?01l13`0O0@l07`0900l00ooo00ooo`0]ool0500?ool@7`4?41l13a0O0@l@7`4?
41lB7b4_4RlR;a8O8BlB;b8_4Ql9A4l02FM_MWmWKfIoIfmfOfM_IWmWK`02Mgl047N?N7mgOgMoMhmh
OgMoIfmVOfM_MWmWKfIoIfmfOfM_2DA?01@B;b8_4QlQ;a8_8RlB7b4_4Rl@7`4?41l13a0O0@l@7`4?
41ooo`0?8_oo000Eool00`0?ool03`0D00l08A0?00l03`0?40l03a0?00l@3`0?40l03a0?00l@3`0?
40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0300l01A0?00l03`0?40l04P0?00?oo`0?
00l0;_oo00<03ooo00l02@0?00D@3`0?00l03a0?00<03`0]40l03a0?0@l@3`0?40l13a0?4@l@7`4?
41lA3a0O0@l@7a4?41lA3a0O4@l@7a4?41lA3a0O0@l@7a4?41l13a0O4@l@7`4?40l03a0?0@l@3`0?
40l13a0?00<03`0540l03`0?00l@3`0<00l^ool0DP0?ool03a0?00l@3`0?40l03a0?00lA7a4?41lA
3a4O4@l@7a4?4AlR7b4_8QlQ;b8O8BlR7b4_8Qlb?b<_<SlS;c8o8blb?b<_<Slc;c<o<blb?c<_<clc
;c8o<blb?b<_<SlS;c8o8blb?b<_<SlR7b4_8QlQ;b8O8BlR7b4_8Ql@7a4?4AlA3a0O4@lA7a4?41l0
3a0?00l@3`0?40l03a0?0`0?8_oo000Eool00`0?ool03`0B00l01@4?00l03`0?0@l00`0?01d13`0?
0@l07`4?00l13`0O0@l03`4?01l13`0?0@l07`4?00l13`0O0@l03`4?01l13`0?0@l03`4?00<03`03
0@l03`0?01803`;oo`0300oooooo02coo`0300ooo`0?00/03`0e0@l03`0?00l13`0?0@l07`4?01l1
3`0O0@l07`4?41l17a4O0@l@7`4O4Al13a0O0AlA7`4O4Al17a4O0AlA7`4O4Al13a0O0AlA7`4?41l1
7a4O0@l07`4?01l13`0O0@l07`4?00l13`0300l00`4?00l03`0:00l00ooo00ooo`0]ool0E@0?ool0
7`4?00l13`0O0@l03`4?01l17a4O0AlA7`4O4Al17a4O0AlR;a8O8RlB;b8_4QlR;a8_8RlS;c8o8blb
?b<_<SlS;c8o8blc?b<o<clS?c<o8clc?b<o<clS;c8o8blb?b<_<SlS;c8o8blR;a8O8RlB;b8_4QlR
;a8_8Rl17a4O0AlA7`4O4Al17a4O0Al07`4?00l13`0O0@l03`4?01ooo`0?02;oo`005Ooo00<03ooo
00l06P0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00<@3`0?
00l06P0?0_oo00<03oooool0;?oo00<03ooo00l04@0?02d@7`0?40l03a0O00l@3`0?41l13a0O4@l@
7`4?41lA3a0O0@l@7a4?41lA3a0O4@l@7a4?41lA3a0O0@l@7a4?41l13a0O4@l@7`0?40l03a0O00l@
3`0?41l04P0?00?oo`0?ool0;Ooo00@03ooo00l@3`<03`1540l03`0?00l@7a4O41lA3a0O4Al@7a4?
41lR7b4_4QlQ;b8O8BlB7b4_8Qlb?b<_<SlS;c8o8blb?b<_<Slc;c8o<clb?c<_<Slc?c8o<blb?b<_
<SlS;c8o8blb?b<_<SlR7b4_4QlQ;b8O8BlB7b4_8Ql@7a4?41lA7a0O4@l@7a4O41l03a0?00<03`06
40l03`0?00ooo`0?8_oo000Eool00`0?ool03`0C00l01@0O00l03`0?01l00`0?01X07`4?01l03`0O
0@l07`0?01l13`0O00l07`4?01l03`0O0@l07`0?01l13`0O00l07`4?0P0?00D07`0?00l03`0O01<0
3`;oo`0300oooooo02coo`0300ooo`0?00P03`0501l03`0?00l07`0300l0;P0O0@l@7`4?01l13a0O
0@l07`4?4Al13a0O0AlA7`4?41l17a4O0AlA7`4O4Al17a4O0AlA7`4O41l17a4O0@l@7`4O4Al13a0O
0@l@7`4?01l13a0O0@l07`4?0P0?00D07`0?00l03`0O00/03`03ool03ooo02goo`0<00ooo`0O00l0
7`4?01l03`0O0@l07`4O0a4O01T17a4O4AlA7`4O8BlB;b8_4RlQ;a8_8RlB;b4_8blb?b<_<SlS;c8o
8blb?b<_<clS?`03<cl05R<o<clc?c<o8blb?b<_<SlS;c8o8blb?b<_8BlB;b8_4RlQ;a8_8RlB;b4_
0Q4O00D17a4O4AlA7`4O008A7`0;01l03`0O0@l07`0?01l13`0Oool03`0Rool001Goo`0300ooo`0?
01@03`0Q40l03`0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?
00l@3`0?40l03a0?00<03`0540l03`0?00l@3`0B00l00ooo00l03`0^ool00`0?ool03`0900l01A0?
00l03`0?40l00`0?02d@3`0?40l13a0?00l@3`4?40lA3a0O0@l@7a4?41l13a0O4@l@7a4?41lA3a0O
4@l@7a4?41l13a0O4@l@7`4?41lA3a0O0@l@3`0?40l13a0?00l@3`4?40l00`0?00D@3`0?00l03a0?
00`03bkoo`1B00ooo`0?40l03a0?00l@3`0?40l03a4O4@l@7a4?4AlA3a0O4@lA7b8O8BlR7b4_8QlQ
;b8O8BlR7c8o8blb?b<_<SlS;c8o8blb?c<_<clc;c8o<blc?c<_<Slc;c8o8blb?b<_<SlS;c8o8blb
?b8O8BlR7b4_8QlQ;b8O8BlR7a0O4@lA7a4?41lA3a4O4@l@7`0?40l03a0?00l@3`0?40l300lRool0
01Goo`0300ooo`0?01803`050@l03`0?00l13`0300l07@4?00l13`0O0@l03`4?01l13`0?0@l07`4?
00l13`0O0@l03`4?01l13`0?0@l07`4?00l13`0?0@l00`0?00<13`0?00l04P0?0_oo00<03oooool0
;?oo00<03ooo00l02`0?03D13`0?00l03`4?00l13`0O0@l07`4?01l13`0O0@l@7`4O4Al13a0O0AlA
7`4?41l17a4O0AlA7`4O4Al17a4O0AlA7`4?41l17a4O0@l@7`4O4Al13`0O0@l07`4?01l13`0O0@l0
3`4?00<03`030@l03`0?00X03`03ool03ooo02goo`1E00ooo`0O0@l03`4?01l13`0?0@l07`4O4Al1
7a4O0AlA7`4O4Al17b8_4QlR;a8_8RlB7b8_4RlR;b<_<SlS;c8o8blb?b<_<SlS;c<o8clc?b<o<clS
?c<o8clc?b<_<SlS;c8o8blb?b<_<SlS;b8_4QlR;a8_8RlB7b8_4RlR;`4O4Al17a4O0AlA7`4O4Al1
7`0O0@l03`4?01l13`0?0@l07ooo00l08_oo000?ool00`0?ooooo`03ool00`0?ool03`0J00l01A0?
00l03`0?40l00`0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l00a0?00l03`0J00l2ool0
0`0?ooooo`0Vool00`0?ooooo`03ool00`0?ool03`0A00l0;A0O00l@3`0?41l03a0?00l@7`4?41lA
3a0O0@l@7a4?41l13a0O4@l@7a4?41lA3a0O4@l@7a4?41l13a0O4@l@7`4?41lA3a0O00l@3`0?41l0
3a0?00l@7`0B00l00ooo00ooo`0Wool00`0?ooooo`03ool0100?ool03a0?0`0?04D@3`0?00l03a0O
4Al@7a4?41lA7a0O4@l@7b8O8BlB7b4_8QlQ;a8O8BlR7c8o8blb?b<_<SlS;c8o8blb?c<_<Slc?c8o
<blb?c<o<Slc;c8o8blb?b<_<SlS;c8o8blb?b8O8BlB7b4_8QlQ;a8O8BlR7a0O4@l@7a4O41lA3a0O
4Al@7`0?40l00`0?00H@3`0?00l03ooo00lRool000koo`0300ooo`0?00Coo`0300ooo`0?01<03`05
01l03`0?00l07`0300l06P0O0@l07`0?01l13`0O00l07`4?01l03`0O0@l07`0?01l13`0O00l07`4?
01l03`0O0@l200l01@0O00l03`0?01l04`0?0_oo00<03oooool09Ooo00<03ooo00l01?oo00<03ooo
00l0200?00D07`0?00l03`0O00<03`0^01l13a0O0@l07`4?41l13`0O0@lA7`4?41l17a4O0@l@7`4O
4Al17a4O0AlA7`4O4Al17a4O0Al@7`4O4Al13a0O0AlA7`4?41l13a0O0@l07`4?41l13`0O0@l200l0
1@0O00l03`0?01l02`0?00?oo`0?ool09_oo00<03ooo00l01?oo00`03ooo01l03`0O0@l07`0?01l1
3`0O0Al34Al06@4O4AlA7a4O0AlQ;a8_8RlB;b4_4RlR;a8_8BlS;c8o8blb?b<_<SlS;c8o8blc?b<o
00<c?`0F8clc?c<o<clS;c8o8blb?b<_<SlS;c8o8blQ;a8_8RlB;b4_4RlR;a8_8Bl24Al01@4O4AlA
7a4O0Al00Q4O00/07`0?01l13`0O00l07`4?01ooo`0?02;oo`003ooo00<03oooool00ooo00<03ooo
00l0500?024@3`0?00l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?
40l03a0?00l@3`0?40l00`0?00D@3`0?00l03a0?01803`;oo`0300oooooo02Koo`0300oooooo00?o
o`0300ooo`0?00T03`0540l03`0?00l@3`0300l0;A0?00l@3`4?40l03a0?0@l@3a4?41l13a0O4@l@
7`4?41lA3a0O4@l@7a4?41lA3a0O4@l@7`4?41lA3a0O0@l@7a4?41l13a0?00l@3`4?40l03a0?0@l@
3`0300l01A0?00l03`0?40l02P0?00?oo`0?ool09ooo00<03oooool00ooo05D03ooo00l@3`0?40l0
3a0?00l@3`0?4AlA3a0O4@lA7a4?41lA3a4O8QlQ;b8O8BlR7b4_8QlQ;b8O<SlS;c8o8blb?b<_<SlS
;c8o<blc?c<_<Slc;c<o<blb?c<_<SlS;c8o8blb?b<_<SlS;c8o8QlQ;b8O8BlR7b4_8QlQ;b8O41lA
3a4O4@l@7a4?4AlA3a0O00l@3`0?40l03a0?00l@3`0?ool03`0Rool000koo`0300ooo`0?00Coo`03
00ooo`0?04l03`03ool03`0?02Ooo`0300ooo`0?00Coo`0300ooo`0?01<03`050@l03`0?00l13`03
00l01@4?00l03`0?0@l00`0?00D13`0?00l07`4?00803`0301l13`0?00803`050@l03`0?00l13`03
00l01@4?00l03`0?0@l05P0?9ooo00<03ooo00l01?oo00<03ooo00l0200?01/13`0?0@l07`4?00l1
3`0O0@lA7`4?41l13a4O0@l@7`4?4Al17a4O0AlA7`4O4Al17a4O0Al00a4O02417a4O4AlA7`4O4Al1
7a4O0AlA7`4O4Al17a4O0AlA7`4?41l13a4O0@l@7`4?4Al13`0O0@l03`4?01l13`0?0@l02`0?8_oo
000?ool00`0?ooooo`03ool00`0?ool03`1?00l2ool00`0?ooooo`0Vool00`0?ooooo`03ool00`0?
ool03`0S00l01A0?00l03`0?40l00`0?00<@3`0?00l08P0?00?oo`0?ool09ooo00<03oooool00ooo
00<03ooo00l0200?00D@3`0?00l03a0?00<03`0E40l13a0O0@l@7`4?41l13a0O0@l@7a4?41lA7a0O
4@l@7a4O41lA3a0O008A7`0G4@l@7a4O4AlA3a0O4Al@7a4?41lA7a0O4@l@7`4?41l13a0O0@l@7`4?
41l13`0200l01A0?00l03`0?40l02`0?00?oo`0?ool08Ooo000Eool00`0?ool03`1?00l2ool00`0?
ooooo`0/ool00`0?ool03`0D00l01@0O00l03`0?01l00`0?00D07`0?00l03`0O00<03`0601l13`0?
00l07`4?0P0?00D07`0?00l03`0O00<03`0501l03`0?00l07`0300l00`0O00l03`0A00l00ooo00oo
o`0]ool00`0?ool03`0900l04@0O0@l07`0?01l13`0O00l@7`4O41l13a0O0Al@7`4?41l00Q4O00D1
7a4O4AlA7`4O00<A7`050AlA7a4O4Al17`034Al01@4O4AlA7a4O0Al00a4O01<17a0O0Al@7`4?41l1
7a0O0@l@7`4?01l03`0O0@l07`0?01l13`0900l00ooo00ooo`0Qool001Goo`0300ooo`0?04l03`;o
o`0300oooooo02coo`0300ooo`0?01403`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00D@
3`0?00l03a0?00<03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?0180
3`03ool03ooo02goo`0300ooo`0?00P03`0K40l03a0?00l@3`0?40l03a0?0@l@7a4?41l13a0O4@l@
7`4?41lA3a4O4@l@7a4?4AlA3a0O008A7`064@l@7a4O4AlA3a0O0Q4O01XA3a0O4@lA7a4?41lA3a4O
0@l@7a4?41l13a0O4@l@7`4?40l03a0?00l@3`0?40l03a0?2@0?00?oo`0?ool08Ooo000Eool00`0?
ool03`1?00l00ooo00l03`0^ool00`0?ool03`0C00l01@4?00l03`0?0@l00`0?00D13`0?00l03`4?
00<03`050@l03`0?01l13`0200l00`0O0@l03`0200l01@4?00l03`0?0@l00`0?00D13`0?00l03`4?
01H03bkoo`0300ooo`0?00P03`0K0@l03`4?01l13`0?0@l07`4?4Al13a0O0@lA7`4?41l13a4O0AlA
7`4O4Al17a4O0AlA7`4O00<A7`0Q0AlA7a4O4Al17a4O0AlA7`4O4Al17a4O0AlA7`4O4Al13a0O0@lA
7`4?41l13a4O0@l07`4?00l13`0O0@l03`4?00/03b;oo`005Ooo00<03ooo00l0C`0?0_oo00<03ooo
ool0;?oo00<03ooo00l08`0?00D@3`0?00l03a0?00<03`0340l03`0?02803`03ool03ooo02goo`03
00ooo`0?00P03`0540l03`0?00l@3`0300l05A0?0@l@7`4?41l13a0O0@l@7`4?41lA3a0O4Al@7a4?
41lA7a0O4@l@7`024Al05a4?41lA7a4O4@l@7a4O41lA3a0O4Al@7a4?41l13a0O0@l@7`4?41l13a0O
0@l00P0?00D@3`0?00l03a0?00/03`03ool03ooo027oo`005Ooo00<03ooo00l0C`0?0_oo00<03ooo
ool0;?oo00<03ooo00l0500?00D07`0?00l03`0O00<03`0501l03`0?00l07`0300l01P0O0@l03`0?
01l13`803`0501l03`0?00l07`0300l01@0O00l03`0?01l00`0?00<07`0?00l04@0?00?oo`0?ool0
;Ooo00<03ooo00l02@0?01407`4?01l03`0O0@l07`0?41l17a0O0@l@7`4O41l13a0O008A7`050AlA
7a4O4Al17`034Al01@4O4AlA7a4O0Al00a4O00D17a4O4AlA7`4O00<A7`0C0Al@7`4O41l13a0O0Al@
7`4?41l13`0O00l07`4?01l03`0O0@l02@0?00?oo`0?ool08Ooo000Eool00`0?ool03`1?00l2ool0
0`0?ooooo`0/ool00`0?ool03`0A00l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<03`0540l0
3`0?00l@3`0300l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0B00l0
0ooo00ooo`0]ool00`0?ool03`0800l06a0?00l@3`0?40l03a0?00l@3`4?41lA3a0O0@l@7a4?41l1
3a0O4@lA7a4?41lA3a4O4@l@7`024Al01Q4?41lA7a4O4@l@7`8A7`0J4@l@7a4?4AlA3a0O4@lA7`4?
41lA3a0O0@l@7a4?41l13a0?00l@3`0?40l03a0?00l@3`T03`03ool03ooo027oo`005Ooo00<03ooo
00l0C`0?0_oo00<03oooool0;?oo00<03ooo00l04`0?00D13`0?00l03`4?00<03`050@l03`0?00l1
3`0300l01@4?00l03`0O0@l00P0?00<07`4?00l00P0?00D13`0?00l03`4?00<03`050@l03`0?00l1
3`0D00l00ooo00ooo`0]ool00`0?ool03`0800l06`4?00l13`0O0@l03`4?01l13a4O0@l@7`4?4Al1
3a0O0@lA7`4O4Al17a4O0AlA7`4O4Al17`034Al08@4O4AlA7a4O0AlA7`4O4Al17a4O0AlA7`4O4Al1
7a4O0@l@7`4?4Al13a0O0@lA7`4?01l13`0?0@l07`4?00l13`0900l00ooo00ooo`0Qool001Goo`03
00oooooo053oo`803bkoo`0300oooooo053oo`803bkoo`0300oooooo053oo`803b;oo`005OooE@0?
;_ooE@0?;_ooE@0?8_oo003ooonCool00?oooi?oo`00ooooTooo000<ool00`0?ooooo`20ool00`0?
ooooo`20ool00`0?ooooo`1mool000goo`0300oooooo02coo`@03e3oo`0300oooooo02coo`@03e3o
o`0300oooooo02coo`<03dgoo`003Ooo00<03oooool00_oo00D03ooo00ooo`0?00?oo`0300ooo`0?
01koo`0400ooo`0?00l4ool200m;ool00`0?ooooo`02ool01@0?ool03ooo00l00ooo00<03ooo00l0
7_oo00<03ooo00l01Ooo0P0?Booo00<03oooool00_oo00D03ooo00ooo`0?00?oo`0300ooo`0?01ko
o`0500ooo`0?ool03`03ool200m7ool000coo`0300ooo`0?00?oo`0500ooo`0?ool03`03ool200lP
ool00`0?ool03`02ool200m<ool00`0?ool03`03ool01@0?ool03ooo00l00ooo0P0?8?oo00<03ooo
00l00_oo0P0?C?oo00<03ooo00l00ooo00D03ooo00ooo`0?00?oo`803b3oo`0300ooo`0?00;oo`80
3dWoo`003?oo00<03ooo00l00ooo00D03ooo00ooo`0?00Coo`0300oooooo01goo`0400ooo`0?00l4
ool200m:ool00`0?ool03`03ool01@0?ool03ooo00l01?oo00<03oooool07Ooo00D03ooo00ooo`0?
00?oo`803d[oo`0300ooo`0?00?oo`0500ooo`0?ool03`04ool00`0?ooooo`0Mool01@0?ool03ooo
00l00ooo0P0?Aooo000<ool00`0?ool03`03ool0100?ool03`0?1?oo0P0?8?oo0`0?D?oo00<03ooo
00l00ooo00@03ooo00l03`Coo`803b3oo`0400ooo`0?00m?ool00`0?ool03`03ool0100?ool03`0?
1?oo0P0?8?oo0`0?COoo003ooonCool001;oo`0300oooooo083oo`0300oooooo083oo`0300oooooo
07Ooo`00ooooTooo003ooonCool00?oooi?oo`00ooooTooo003ooonCool00?oooi?oo`00ooooTooo
003ooonCool00?oooi?oo`00ooooTooo0000\
\>"],
  ImageRangeCache->{{{0, 400.375}, {124.125, 0}} -> {-0.191398, -0.156625, 
  0.029221, 0.029221}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tbl2 = 
      TableForm[{N[micro\ Ia[0, 0, a\/100]], N[micro\ Ia[0, 0, a\/10]], 
          N[micro\ Ia[0, 0, a\ 1\/1]]}, 
        TableHeadings \[Rule] {{"\<a/100\>", "\<a/10\>", "\<a\>"}}]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("a/100"\), "12.414236409732946`"},
          {\("a/10"\), "9.86047427231414808`"},
          {\("a"\), "0.661048093040890272`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[
       {12.41423640973294518, 9.86047427231414808, 0.66104809304089027}, 
        TableHeadings -> {{"a/100", "a/10", "a"}}]]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Discussion of the Models"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Electric Field"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig16x12 = 
      Plot[Evaluate[{Abs[Edx[a\ x, a\/1000, a]], 
            Abs[Eax[a\ x, a\/1000, a]]}], {x, \(-2\), 2}, 
        FrameLabel \[Rule] {"\<x in a\>", "\<Ex in a.u\>"}, Evaluate[opt]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.238095 -0.073708 4.299483 [
[.02381 -0.0125 -7 -12 ]
[.02381 -0.0125 7 0 ]
[.2619 -0.0125 -7 -12 ]
[.2619 -0.0125 7 0 ]
[.5 -0.0125 -4 -12 ]
[.5 -0.0125 4 0 ]
[.7381 -0.0125 -4 -12 ]
[.7381 -0.0125 4 0 ]
[.97619 -0.0125 -4 -12 ]
[.97619 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -11 -24 ]
[.5 -0.0125 11 -12 ]
[-0.0125 .01228 -18 -6 ]
[-0.0125 .01228 0 6 ]
[-0.0125 .09827 -18 -6 ]
[-0.0125 .09827 0 6 ]
[-0.0125 .18426 -18 -6 ]
[-0.0125 .18426 0 6 ]
[-0.0125 .27025 -18 -6 ]
[-0.0125 .27025 0 6 ]
[-0.0125 .35624 -14 -6 ]
[-0.0125 .35624 0 6 ]
[-0.0125 .44223 -18 -6 ]
[-0.0125 .44223 0 6 ]
[-0.0125 .52822 -18 -6 ]
[-0.0125 .52822 0 6 ]
[-0.0125 .61421 -18 -6 ]
[-0.0125 .61421 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30 -16.5 ]
[-0.01875 .30902 -18 16.5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .09827 m
1 .09827 L
s
0 .18426 m
1 .18426 L
s
0 .27025 m
1 .27025 L
s
0 .35624 m
1 .35624 L
s
0 .44223 m
1 .44223 L
s
0 .52822 m
1 .52822 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -72 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .01228 m
.00625 .01228 L
s
gsave
-0.0125 .01228 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .09827 m
.00625 .09827 L
s
gsave
-0.0125 .09827 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.04) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .18426 m
.00625 .18426 L
s
gsave
-0.0125 .18426 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.06) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .27025 m
.00625 .27025 L
s
gsave
-0.0125 .27025 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.08) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .35624 m
.00625 .35624 L
s
gsave
-0.0125 .35624 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .44223 m
.00625 .44223 L
s
gsave
-0.0125 .44223 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.12) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .52822 m
.00625 .52822 L
s
gsave
-0.0125 .52822 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.14) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .61421 m
.00625 .61421 L
s
gsave
-0.0125 .61421 -79 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.16) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .03378 m
.00375 .03378 L
s
0 .05528 m
.00375 .05528 L
s
0 .07677 m
.00375 .07677 L
s
0 .11977 m
.00375 .11977 L
s
0 .14127 m
.00375 .14127 L
s
0 .16276 m
.00375 .16276 L
s
0 .20576 m
.00375 .20576 L
s
0 .22726 m
.00375 .22726 L
s
0 .24875 m
.00375 .24875 L
s
0 .29175 m
.00375 .29175 L
s
0 .31325 m
.00375 .31325 L
s
0 .33474 m
.00375 .33474 L
s
0 .37774 m
.00375 .37774 L
s
0 .39924 m
.00375 .39924 L
s
0 .42073 m
.00375 .42073 L
s
0 .46373 m
.00375 .46373 L
s
0 .48522 m
.00375 .48522 L
s
0 .50672 m
.00375 .50672 L
s
0 .54972 m
.00375 .54972 L
s
0 .57121 m
.00375 .57121 L
s
0 .59271 m
.00375 .59271 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -101.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
77.5 10 translate
90 rotate
-77.5 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Ex) show
73.875000 13.000000 moveto
(in) show
82.062500 13.000000 moveto
(a) show
85.562500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
87.562500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
91.562500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01228 m
1 .01228 L
s
.99375 .09827 m
1 .09827 L
s
.99375 .18426 m
1 .18426 L
s
.99375 .27025 m
1 .27025 L
s
.99375 .35624 m
1 .35624 L
s
.99375 .44223 m
1 .44223 L
s
.99375 .52822 m
1 .52822 L
s
.99375 .61421 m
1 .61421 L
s
.125 Mabswid
.99625 .03378 m
1 .03378 L
s
.99625 .05528 m
1 .05528 L
s
.99625 .07677 m
1 .07677 L
s
.99625 .11977 m
1 .11977 L
s
.99625 .14127 m
1 .14127 L
s
.99625 .16276 m
1 .16276 L
s
.99625 .20576 m
1 .20576 L
s
.99625 .22726 m
1 .22726 L
s
.99625 .24875 m
1 .24875 L
s
.99625 .29175 m
1 .29175 L
s
.99625 .31325 m
1 .31325 L
s
.99625 .33474 m
1 .33474 L
s
.99625 .37774 m
1 .37774 L
s
.99625 .39924 m
1 .39924 L
s
.99625 .42073 m
1 .42073 L
s
.99625 .46373 m
1 .46373 L
s
.99625 .48522 m
1 .48522 L
s
.99625 .50672 m
1 .50672 L
s
.99625 .54972 m
1 .54972 L
s
.99625 .57121 m
1 .57121 L
s
.99625 .59271 m
1 .59271 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .01472 m
.06244 .02968 L
.10458 .0503 L
.14415 .07504 L
.18221 .10529 L
.22272 .14649 L
.26171 .19714 L
.30316 .26489 L
.34309 .34394 L
.3815 .42881 L
.42237 .5168 L
.44268 .55354 L
.45262 .56858 L
.46172 .58027 L
.47043 .5894 L
.47994 .59685 L
.48516 .59976 L
.48769 .60087 L
.49 .6017 L
.49238 .60238 L
.49462 .60285 L
.49585 .60304 L
.49699 .60318 L
.49824 .60327 L
.49955 .60332 L
.50077 .60331 L
.50146 .60329 L
.5021 .60325 L
.50327 .60315 L
.50451 .60299 L
.50562 .60281 L
.50666 .6026 L
.50903 .602 L
.51158 .60115 L
.51392 .60019 L
.51919 .59739 L
.52812 .59071 L
.53752 .58115 L
.55726 .55363 L
.57563 .52072 L
.61468 .4374 L
.65617 .34551 L
.69616 .26615 L
.73462 .20254 L
.77554 .14851 L
.81494 .10786 L
.85283 .07718 L
.89317 .05155 L
.932 .03212 L
.97327 .01574 L
Mistroke
.97619 .01472 L
Mfstroke
[ .05 ] 0 setdash
.02381 .05543 m
.06244 .08551 L
.10458 .12712 L
.14415 .17567 L
.18221 .23097 L
.22272 .29698 L
.26171 .36314 L
.30316 .42996 L
.34309 .48542 L
.3815 .52743 L
.40134 .5444 L
.42237 .55886 L
.4419 .5691 L
.45065 .57271 L
.4602 .57597 L
.47058 .57871 L
.47536 .57969 L
.48045 .58054 L
.48549 .5812 L
.49005 .58162 L
.49226 .58177 L
.49342 .58183 L
.49465 .58189 L
.49572 .58193 L
.4969 .58196 L
.49797 .58198 L
.49897 .58199 L
.50023 .58199 L
.50087 .58199 L
.50157 .58199 L
.50281 .58196 L
.50398 .58193 L
.50535 .58189 L
.5066 .58183 L
.50942 .58166 L
.51173 .58147 L
.51425 .58122 L
.51932 .58058 L
.52397 .57981 L
.52894 .57881 L
.53788 .57654 L
.54812 .57317 L
.55923 .56859 L
.57938 .5578 L
.59925 .54394 L
.6203 .52573 L
.65818 .48383 L
.69852 .42741 L
.73735 .36472 L
.77863 .29472 L
Mistroke
.81839 .23005 L
.85663 .17462 L
.89733 .12501 L
.93651 .08642 L
.97619 .05543 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{134.125, 82.5},
  ImageMargins->{{103.125, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002X0000J1000`40l00?003`Z?oo002Xool00:So
o`00Z?oo001Jool00`0?ool03`03ool01P0?ooooo`0?ool03`;oo`0300ooo`0?03goo`00Fooo00<0
3oooool00_oo00H03oooool03ooo00l2ool200lnool005_oo`0300oooooo00;oo`0600oooooo00oo
o`0?0ooo00<03oooool0??oo001Jool00`0?ool03`03ool00`0?ooooo`0200l3ool200lnool00:So
o`00H?oo00<03oooool0AOoo002Xool00:Soo`00Z?oo002Xool00:Soo`00Z?oo000/ool300lIool3
00lGool00`0?ooooo`0Hool300lIool300l<ool002coo`0300oooooo01[oo`0300oooooo01Goo`03
00ooo`0?01[oo`0300oooooo01Soo`0300oooooo00coo`00:?oo0`0?0_oo00<03oooool05?oo0`0?
0_oo00<03oooool05Ooo00<03ooo00l06_oo00<03oooool06Ooo00<03oooool02ooo000/ool00`0?
ool03`0Jool00`0?ooooo`0Eool00`0?ool03`0Jool00`0?ooooo`0Hool00`0?ool03`0<ool002go
o`803aWoo`803aSoo`0300oooooo01Soo`803a_oo`803`coo`00Z?oo002Xool00:Soo`00Z?oo000H
ool0100?ooooo`0?0_oo00<03oooool00`0?Q?oo000Gool00`0?ool03`03ool01@0?ool03ooo00l0
1_ooMP0?2_oo000Gool00`0?ool03`03ool00`0?ool03`02ool00`0?ooooo`03ool200l00ooo00oo
o`0Jool00`0?ooooo`0Iool00`0?ooooo`0Iool00`0?ooooo`0Hool0100?ool03`0?2_oo000Gool0
0`0?ool03`03ool01`0?ool03ooo00ooo`0?00Coo`0300oooooo00@03aSoo`0308oooooo01Woo`03
00oooooo01Woo`0308oooooo01Koo`<03`;oo`0300oooooo00Soo`006?oo00<03oooool00ooo00@0
3oooooooo`803`Coo`0300oooooo00?oo`<03aKoo`0307oooooo01Woo`0300oooooo01Woo`0307oo
oooo01?oo`@03`Coo`0300oooooo00Soo`00:?oo0P0?1_oo0`0?5?oo00<0Soooool06Ooo00<03ooo
ool06Ooo00<0Soooool04Ooo0`0?1ooo00<03oooool02?oo000Xool00`0?ooooo`07ool300lBool0
0`1oooooo`0Iool00`0?ooooo`0Iool00`1oooooo`0?ool300l9ool00`0?ooooo`08ool002Soo`80
3`03ool03ooo00Ooo`<03a3oo`0308oooooo01Woo`0300oooooo01Woo`0308oooooo00koo`803`_o
o`0300oooooo00Soo`00:?oo00D03oooooooo`0?00Woo`<03`koo`0307oooooo01Woo`0300oooooo
01Woo`0307oooooo00coo`<03`Soo`0500ooooooool03`0:ool002Soo`0300oooooo00;oo`803`Wo
o`803`goo`0308oooooo01Woo`0300oooooo01Woo`0308oooooo00_oo`803`Woo`0300oooooo00;o
o`0300oooooo00Soo`006?oo00@03oooool03`;oo`0300oooooo00;oo`0300oooooo00;oo`803`Go
o`0300oooooo00Ooo`803`coo`0307oooooo01Woo`0300oooooo01Woo`0307oooooo00Woo`803`[o
o`0300oooooo00?oo`0300oooooo00Soo`005ooo00<03ooo00l00ooo00@03ooo00ooo`<03`Coo`03
00oooooo00Goo`0300oooooo00Ooo`<03`[oo`0308oooooo01Woo`0300oooooo01Woo`0308oooooo
00Soo`803`[oo`0300oooooo00Coo`0300oooooo00Soo`005ooo00<03ooo00l00ooo00L03ooo00oo
o`0?ool03`04ool200l04P2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`803`1;08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00803`0A07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0
S`1o08l0O`0200l:ool001Ooo`0300ooo`0?00?oo`0300ooo`0?00;oo`803`Coo`0300oooooo01;o
o`803`Soo`0308oooooo01Woo`0300oooooo01Woo`0308oooooo00Goo`<03a?oo`0300oooooo00So
o`006?oo00<03oooool00ooo00<03oooool00_oo00<03oooool00_oo00<03oooool04ooo0P0?1ooo
00<0Ooooool06Ooo00<03oooool06Ooo00<0Ooooool01?oo0P0?5Ooo00<03oooool02?oo000Xool2
00l:ool00`0?ooooo`08ool200l6ool00`2?ooooo`0Iool00`0?ooooo`0Iool00`2?ooooo`04ool0
0`0?ooooo`0Dool00`0?ooooo`08ool002Soo`0300oooooo00[oo`0300oooooo00Soo`803`Goo`03
07oooooo01Woo`0300oooooo01Woo`0307oooooo00?oo`803`[oo`0300oooooo00Woo`0300oooooo
00Soo`00:?oo0P0?3?oo00<03oooool02?oo0P0?1?oo00<0Soooool06Ooo00<03oooool06Ooo00<0
Soooool00_oo0P0?2_oo00<03oooool02_oo00<03oooool02?oo000Xool00`0?ooooo`0<ool00`0?
ooooo`08ool200l3ool00`1oooooo`0Iool00`0?ooooo`0Iool0101ooooooooo0P0?2_oo00<03ooo
ool02ooo00<03oooool02?oo000Xool00`0?ooooo`0=ool00`0?ooooo`08ool200l2ool00`2?oooo
o`0Iool00`0?ooooo`0Iool00`2?ooooo`0200l:ool00`0?ooooo`0<ool00`0?ooooo`08ool001So
o`0400oooooo00l2ool01@0?oooooooo00l01Ooo0P0?6_oo00@03oooool0Oa_oo`0300oooooo01Wo
o`0407ooo`0?00l:ool00`0?ooooo`0=ool00`0?ooooo`08ool001Ooo`0300ooo`0?00?oo`0700oo
o`0?ool03ooo00l01?oo00<03oooool06Ooo0P0?00?oo`2?ool06_oo00<03oooool06Ooo00<0S`0?
00l06ooo00<03oooool02?oo000Gool00`0?ool03`03ool0100?ool03ooo0P0?1Ooo0P0?01/0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l00P0?05D0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0200l:ool000coo`03
00oooooo00;oo`0300oooooo00?oo`0300ooo`0?00?oo`0500ooo`0?ool03`06ool00`0?ooooo`0K
ool200lKool00`0?ooooo`0Iool200lLool00`0?ooooo`08ool000coo`H03`Koo`0300oooooo00?o
o`0400ooooooool200l4ool00`0?ooooo`0@ool00`0?ooooo`09ool00`0?ooooo`0Iool00`0?oooo
o`0Hool200lMool00`0?ooooo`08ool000coo`0600oooooo00ooo`0?5_oo0P0?4_oo00<03oooool0
2?oo0P0?6_oo00<03oooool06?oo00<03`2?ool02Ooo00<03oooool04?oo00<03oooool02?oo000<
ool01P0?ooooo`0?ool03aKoo`0300oooooo017oo`0300oooooo00Soo`0307l03`0?01Woo`0300oo
oooo01Ooo`803`0307oooooo00Ooo`0300oooooo017oo`0300oooooo00Soo`003?oo0P0?0ooo00<0
3oooool05?oo0P0?4ooo00<03oooool01ooo00<0Sooo00l06Ooo00<03oooool05_oo0P0?00?oo`2?
ool01ooo00<03oooool04_oo00<03oooool02?oo000>ool0100?ooooo`0?5_oo00<03oooool04ooo
00<03oooool01_oo00@0Oooo00l03aSoo`0300oooooo01Koo`0400oooooo07l8ool00`0?ooooo`0B
ool00`0?ooooo`08ool000koo`<03aOoo`0300oooooo01?oo`0300oooooo00Koo`0408oooooo00lH
ool00`0?ooooo`0Eool200l2ool00`2?ooooo`05ool00`0?ooooo`0Cool00`0?ooooo`08ool000oo
o`<03`Koo`0400oooooo00l2ool01@0?oooooooo00l01Ooo0P0?7Ooo00<0Ooooool00P0?5ooo00<0
3oooool05Ooo00D03oooooooo`1o00Ooo`0300oooooo01?oo`0300oooooo00Soo`004Ooo00<03ooo
ool00ooo00<03ooo00l00ooo00L03ooo00ooo`0?ool03`04ool00`0?ooooo`0Lool0102?oooooooo
0P0?5_oo00<03oooool05?oo0P0?0ooo00<0Soooool06ooo00<03oooool02?oo000Gool00`0?ool0
3`03ool00`0?ool03`02ool00`0?ooooo`03ool200l0C`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?00803`0Q07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o00803`[oo`005ooo00<03ooo00l00ooo00L03ooo00ooo`0?
ool03`04ool00`0?ooooo`0Lool00`2?ooooo`02ool200lEool00`0?ooooo`0Cool00`0?ooooo`03
ool00`2?ooooo`0Kool00`0?ooooo`08ool000ooo`0300ooo`0?00Koo`0300oooooo00?oo`0500oo
ooooool03`05ool00`0?ooooo`0Gool00`0?ooooo`02ool00`1oooooo`03ool00`0?ooooo`0Cool0
0`0?ooooo`0Bool200l5ool00`1oooooo`0Kool00`0?ooooo`08ool000coo`0300ooo`0?00<03aKo
o`803aSoo`0300oooooo00;oo`0308oooooo00?oo`803aCoo`0300oooooo01;oo`0300oooooo00Co
o`0408ooooooool200lHool00`0?ooooo`08ool000koo`@03aKoo`0300oooooo01Soo`0500oooooo
ool0O`06ool00`0?ooooo`0Bool00`0?ooooo`0Aool200l6ool01@1ooooooooo00l06Ooo00<03ooo
ool02?oo000>ool0100?ooooo`0?5_oo0P0?6Ooo00D03oooooooo`2?00Koo`803a?oo`0300oooooo
017oo`0300oooooo00Goo`0408oooooo00lJool00`0?ooooo`08ool000koo`0300oooooo01Ooo`03
00oooooo01Woo`0400oooooo07l7ool00`0?ooooo`0Aool00`0?ooooo`0@ool200l7ool0101ooooo
o`0?6_oo00<03oooool02?oo000?ool300lFool00`0?ooooo`0Iool0100?ooooo`2?1ooo0P0?4_oo
00<03oooool04?oo00<03oooool01_oo00<0Sooo00l06ooo00<03oooool02?oo000Lool01@0?oooo
o`0?ool00`0?1?oo0P0?7Ooo00<0Ooooool01_oo00<03oooool04?oo00<03oooool03ooo0P0?2?oo
00<0Oooo00l06ooo00<03oooool02?oo000Kool00`0?ool03`04ool00`0?ooooo`03ool00`0?oooo
o`0Lool00`2?ooooo`06ool200lAool00`0?ooooo`0?ool00`0?ooooo`07ool00`2?ooooo`0Kool0
0`0?ooooo`08ool000koo`0300ooo`0?00[oo`0300ooo`0?00Coo`0300oooooo00?oo`803`1:08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`803`0V08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`803`[oo`003_oo0P0?
00?oo`0?ool02?oo00<03ooo00l01?oo00<03oooool00ooo00<03oooool07?oo00<0Soooool01ooo
0P0?4?oo00<03oooool03_oo00<03oooool02?oo00<0Soooool06ooo00<03oooool02?oo000?ool3
00l:ool00`0?ooooo`02ool200l5ool00`0?ooooo`0Lool00`0?ooooo`08ool00`0?ooooo`0>ool0
0`0?ooooo`0>ool00`0?ooooo`08ool00`1oooooo`0Kool00`0?ooooo`08ool0017oo`0300oooooo
01Coo`803agoo`0308l03ooo00Soo`803`ooo`0300oooooo00goo`0300oooooo00Ooo`803`0308oo
oooo01_oo`0300oooooo00Soo`004Ooo00<03oooool05?oo00<03oooool07?oo00<0Oooo00l02Ooo
00<03oooool03Ooo00<03oooool03Ooo00<03oooool01ooo00<03ooo07l07Ooo00<03oooool02?oo
000>ool300lGool200lMool00`2?ool03`09ool00`0?ooooo`0=ool00`0?ooooo`0<ool200l8ool0
100?ooooo`2?7Ooo00<03oooool02?oo000Aool00`0?ooooo`0Dool00`0?ooooo`0Lool0101ooooo
o`0?2?oo0P0?3_oo00<03oooool03?oo00<03oooool01ooo00@03oooool0Oagoo`0300oooooo00So
o`003_oo100?5_oo00<03oooool07?oo00D0Soooooooo`0?00Soo`0300oooooo00coo`0300oooooo
00_oo`803`Soo`0500ooooooool0S`0Mool00`0?ooooo`08ool001Soo`0500oooooo00ooo`0300l0
1?oo00l03`0?1?oo0P0?7Ooo00<0Ooooool02_oo0P0?3Ooo00<03oooool02ooo00<03oooool01_oo
00<03oooool00_oo00<0Ooooool06ooo00<03oooool02?oo000Gool00`0?ool03`04ool0100?oooo
o`0?1_oo00<03oooool07?oo00<0Soooool02ooo00<03oooool02ooo00<03oooool02_oo0P0?3Ooo
00<0Soooool06ooo00<03oooool02?oo000Gool00`0?ool03`04ool01@0?oooooooo00l01Ooo0P0?
02/0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0200l0A@1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?
08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0200l:ool0
01Ooo`0300ooo`0?00Coo`0600oooooo00ooo`0?1?oo00<03oooool07?oo00<0Soooool03?oo00<0
3oooool02_oo00<03oooool02Ooo0P0?3_oo00<0Soooool06ooo00<03oooool02?oo000Hool00`0?
ooooo`02ool200l3ool200l4ool00`0?ooooo`0Lool00`1oooooo`04ool00`0?ooooo`05ool200l;
ool00`0?ooooo`09ool00`0?ooooo`0=ool00`1oooooo`0Kool00`0?ooooo`08ool002Soo`803ago
o`0308oooooo00Goo`0300oooooo00Goo`0300oooooo00Woo`0300oooooo00Soo`803`Ooo`0300oo
oooo00Goo`0308oooooo01_oo`0300oooooo00Soo`00:?oo00<03oooool07?oo00<0Ooooool01Ooo
00<03oooool01Ooo0P0?2_oo00<03oooool02?oo00<03oooool01Ooo00<03oooool01_oo00<0Oooo
ool06ooo00<03oooool02?oo000Xool200lMool00`2?ooooo`06ool00`0?ooooo`05ool00`0?oooo
o`08ool00`0?ooooo`08ool00`0?ooooo`04ool00`0?ooooo`07ool00`2?ooooo`0Kool00`0?oooo
o`08ool002Soo`0300oooooo01coo`0307oooooo00Ooo`0300oooooo00Coo`803`Woo`0300oooooo
00Ooo`803`Koo`0300oooooo00Ooo`0307oooooo01_oo`0300oooooo00Soo`00:?oo00<03oooool0
7?oo00<0Soooool03ooo00<03oooool01ooo00<03oooool01ooo00<03oooool01?oo00<03oooool0
2?oo00<0Soooool06ooo00<03oooool02?oo000Hool01@0?ooooo`0?ool00`0?0ooo00<03oooool0
0_oo0P0?7Ooo00<0Ooooool03ooo00<03oooool01ooo00<03oooool01_oo0P0?4Ooo00<0Ooooool0
6ooo00<03oooool02?oo000Gool00`0?ool03`04ool00`0?ooooo`0300l4ool00`0?ooooo`0Lool0
0`2?ooooo`0?ool200l8ool00`0?ooooo`06ool00`0?ooooo`0@ool00`2?ooooo`0Kool00`0?oooo
o`08ool001Ooo`0300ooo`0?00Coo`0600oooooo00ooo`0?1?oo0P0?0440S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?00803`0_
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0200l:ool001Ooo`0300ooo`0?00Coo`04
00ooooooool200l4ool00`0?ooooo`0Lool00`2?ooooo`0;ool200l3ool200l7ool00`0?ooooo`05
ool01@0?oooooooo00l03ooo00<0Soooool06ooo00<03oooool02?oo000Hool00`0?ooooo`02ool2
00l4ool00`0?ooooo`02ool00`0?ooooo`0Lool00`1oooooo`0=ool0100?oooooooo0P0?1_oo00<0
3oooool01?oo0P0?0_oo0P0?3ooo00<0Ooooool06ooo00<03oooool02?oo000Xool200lMool00`2?
ooooo`0>ool01@0?oooooooo00l01_oo00<03oooool00ooo0P0?0_oo0P0?4?oo00<0Soooool06ooo
00<03oooool02?oo000Xool00`0?ooooo`0Lool00`1oooooo`0?ool200l00ooo00l03`05ool00`0?
ooooo`03ool0100?ool03`0?4_oo00<0Ooooool06ooo00<03oooool02?oo000Xool200lMool00`2?
ooooo`0Cool200l4ool00`0?ooooo`02ool200l00ooo00ooo`0Bool00`2?ooooo`0Kool00`0?oooo
o`08ool002Soo`0300oooooo01coo`0307oooooo01Coo`<03`;oo`0400ooooooool200lFool00`1o
ooooo`0Kool00`0?ooooo`08ool002Soo`0300oooooo01coo`0308oooooo01Coo`803`03ool03`0?
00D03aOoo`0308oooooo01_oo`0300oooooo00Soo`006?oo00D03oooool03ooo00<03`;oo`0300oo
oooo00?oo`803agoo`0307oooooo01Goo`803`;oo`0400ooo`0?00lHool00`1oooooo`0Kool00`0?
ooooo`08ool001Ooo`0300ooo`0?00Coo`0600oooooo00ooo`0?1?oo00<03oooool07?oo00<0Sooo
ool05ooo1@0?6Ooo00<0Soooool06ooo00<03oooool02?oo000Gool00`0?ool03`04ool00`0?oooo
o`0200l5ool200l00ooo00ooo`0Jool00`0?ooooo`0Iool00`0?ooooo`0Iool00`0?ooooo`0Hool0
100?ool03`0?2_oo000Gool00`0?ool03`04ool0100?ooooo`0?1_ooMP0?2_oo000Hool00`0?oooo
o`02ool200l3ool200n4ool00:Soo`00Z?oo002Xool00:Soo`00\
\>"],
  ImageRangeCache->{{{0, 166.625}, {102.125, 0}} -> {-3.574244, -0.031612, 
  0.044995, 0.002492}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Intensity"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig16x13 = 
      Plot[Evaluate[{micro\ Idc[a\ x, a\/1000, a], 
            micro\ Ia[a\ x, a\/1000, a]}], {x, \(-2\), 2.1}, 
        FrameLabel \[Rule] {"\<x in a\>", "\<Intensity in a.u\>"}, 
        Evaluate[opt]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.488386 0.232288 -0.014139 0.887839 [
[.02381 -0.0125 -7 -12 ]
[.02381 -0.0125 7 0 ]
[.2561 -0.0125 -7 -12 ]
[.2561 -0.0125 7 0 ]
[.48839 -0.0125 -4 -12 ]
[.48839 -0.0125 4 0 ]
[.72067 -0.0125 -4 -12 ]
[.72067 -0.0125 4 0 ]
[.95296 -0.0125 -4 -12 ]
[.95296 -0.0125 4 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -11 -24 ]
[.5 -0.0125 11 -12 ]
[-0.0125 .07465 -14 -6 ]
[-0.0125 .07465 0 6 ]
[-0.0125 .16343 -14 -6 ]
[-0.0125 .16343 0 6 ]
[-0.0125 .25221 -14 -6 ]
[-0.0125 .25221 0 6 ]
[-0.0125 .341 -14 -6 ]
[-0.0125 .341 0 6 ]
[-0.0125 .42978 -14 -6 ]
[-0.0125 .42978 0 6 ]
[-0.0125 .51856 -14 -6 ]
[-0.0125 .51856 0 6 ]
[-0.0125 .60735 -14 -6 ]
[-0.0125 .60735 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26 -26 ]
[-0.01875 .30902 -14 26 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2561 0 m
.2561 .61803 L
s
.48839 0 m
.48839 .61803 L
s
.72067 0 m
.72067 .61803 L
s
0 .07465 m
1 .07465 L
s
0 .16343 m
1 .16343 L
s
0 .25221 m
1 .25221 L
s
0 .341 m
1 .341 L
s
0 .42978 m
1 .42978 L
s
0 .51856 m
1 .51856 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.2561 0 m
.2561 .00625 L
s
gsave
.2561 -0.0125 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.48839 0 m
.48839 .00625 L
s
gsave
.48839 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.72067 0 m
.72067 .00625 L
s
gsave
.72067 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.95296 0 m
.95296 .00625 L
s
gsave
.95296 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07027 0 m
.07027 .00375 L
s
.11672 0 m
.11672 .00375 L
s
.16318 0 m
.16318 .00375 L
s
.20964 0 m
.20964 .00375 L
s
.30256 0 m
.30256 .00375 L
s
.34901 0 m
.34901 .00375 L
s
.39547 0 m
.39547 .00375 L
s
.44193 0 m
.44193 .00375 L
s
.53484 0 m
.53484 .00375 L
s
.5813 0 m
.5813 .00375 L
s
.62776 0 m
.62776 .00375 L
s
.67422 0 m
.67422 .00375 L
s
.76713 0 m
.76713 .00375 L
s
.81359 0 m
.81359 .00375 L
s
.86005 0 m
.86005 .00375 L
s
.9065 0 m
.9065 .00375 L
s
.99942 0 m
.99942 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -72 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(a) show
80.687500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .07465 m
.00625 .07465 L
s
gsave
-0.0125 .07465 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .16343 m
.00625 .16343 L
s
gsave
-0.0125 .16343 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .25221 m
.00625 .25221 L
s
gsave
-0.0125 .25221 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .341 m
.00625 .341 L
s
gsave
-0.0125 .341 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .42978 m
.00625 .42978 L
s
gsave
-0.0125 .42978 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .51856 m
.00625 .51856 L
s
gsave
-0.0125 .51856 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .60735 m
.00625 .60735 L
s
gsave
-0.0125 .60735 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.7) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .0924 m
.00375 .0924 L
s
0 .11016 m
.00375 .11016 L
s
0 .12792 m
.00375 .12792 L
s
0 .14567 m
.00375 .14567 L
s
0 .18119 m
.00375 .18119 L
s
0 .19894 m
.00375 .19894 L
s
0 .2167 m
.00375 .2167 L
s
0 .23446 m
.00375 .23446 L
s
0 .26997 m
.00375 .26997 L
s
0 .28773 m
.00375 .28773 L
s
0 .30548 m
.00375 .30548 L
s
0 .32324 m
.00375 .32324 L
s
0 .35875 m
.00375 .35875 L
s
0 .37651 m
.00375 .37651 L
s
0 .39427 m
.00375 .39427 L
s
0 .41202 m
.00375 .41202 L
s
0 .44754 m
.00375 .44754 L
s
0 .46529 m
.00375 .46529 L
s
0 .48305 m
.00375 .48305 L
s
0 .50081 m
.00375 .50081 L
s
0 .53632 m
.00375 .53632 L
s
0 .55408 m
.00375 .55408 L
s
0 .57184 m
.00375 .57184 L
s
0 .58959 m
.00375 .58959 L
s
0 .05689 m
.00375 .05689 L
s
0 .03913 m
.00375 .03913 L
s
0 .02137 m
.00375 .02137 L
s
0 .00362 m
.00375 .00362 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
87 10 translate
90 rotate
-87 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Intensity) show
92.750000 13.000000 moveto
(in) show
100.937500 13.000000 moveto
(a) show
104.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
106.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
110.437500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.2561 .61178 m
.2561 .61803 L
s
.48839 .61178 m
.48839 .61803 L
s
.72067 .61178 m
.72067 .61803 L
s
.95296 .61178 m
.95296 .61803 L
s
.125 Mabswid
.07027 .61428 m
.07027 .61803 L
s
.11672 .61428 m
.11672 .61803 L
s
.16318 .61428 m
.16318 .61803 L
s
.20964 .61428 m
.20964 .61803 L
s
.30256 .61428 m
.30256 .61803 L
s
.34901 .61428 m
.34901 .61803 L
s
.39547 .61428 m
.39547 .61803 L
s
.44193 .61428 m
.44193 .61803 L
s
.53484 .61428 m
.53484 .61803 L
s
.5813 .61428 m
.5813 .61803 L
s
.62776 .61428 m
.62776 .61803 L
s
.67422 .61428 m
.67422 .61803 L
s
.76713 .61428 m
.76713 .61803 L
s
.81359 .61428 m
.81359 .61803 L
s
.86005 .61428 m
.86005 .61803 L
s
.9065 .61428 m
.9065 .61803 L
s
.99942 .61428 m
.99942 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07465 m
1 .07465 L
s
.99375 .16343 m
1 .16343 L
s
.99375 .25221 m
1 .25221 L
s
.99375 .341 m
1 .341 L
s
.99375 .42978 m
1 .42978 L
s
.99375 .51856 m
1 .51856 L
s
.99375 .60735 m
1 .60735 L
s
.125 Mabswid
.99625 .0924 m
1 .0924 L
s
.99625 .11016 m
1 .11016 L
s
.99625 .12792 m
1 .12792 L
s
.99625 .14567 m
1 .14567 L
s
.99625 .18119 m
1 .18119 L
s
.99625 .19894 m
1 .19894 L
s
.99625 .2167 m
1 .2167 L
s
.99625 .23446 m
1 .23446 L
s
.99625 .26997 m
1 .26997 L
s
.99625 .28773 m
1 .28773 L
s
.99625 .30548 m
1 .30548 L
s
.99625 .32324 m
1 .32324 L
s
.99625 .35875 m
1 .35875 L
s
.99625 .37651 m
1 .37651 L
s
.99625 .39427 m
1 .39427 L
s
.99625 .41202 m
1 .41202 L
s
.99625 .44754 m
1 .44754 L
s
.99625 .46529 m
1 .46529 L
s
.99625 .48305 m
1 .48305 L
s
.99625 .50081 m
1 .50081 L
s
.99625 .53632 m
1 .53632 L
s
.99625 .55408 m
1 .55408 L
s
.99625 .57184 m
1 .57184 L
s
.99625 .58959 m
1 .58959 L
s
.99625 .05689 m
1 .05689 L
s
.99625 .03913 m
1 .03913 L
s
.99625 .02137 m
1 .02137 L
s
.99625 .00362 m
1 .00362 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.48839 0 m
.48839 .61803 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .01747 m
.06244 .02312 L
.08255 .02678 L
.10458 .03153 L
.14415 .04278 L
.16372 .05014 L
.18466 .05981 L
.20453 .0712 L
.22611 .08668 L
.26604 .12699 L
.28587 .15438 L
.3069 .19002 L
.34474 .27343 L
.38503 .38704 L
.4238 .50214 L
.44351 .55116 L
.45466 .57305 L
.46 .58164 L
.46502 .58851 L
.46986 .59395 L
.47241 .59633 L
.4751 .59848 L
.47737 .59998 L
.47986 .60132 L
.48213 .60224 L
.48322 .60259 L
.48424 .60285 L
.48551 .60309 L
.48618 .60319 L
.4869 .60326 L
.48809 .60332 L
.48941 .60329 L
.49058 .60319 L
.49185 .60299 L
.49304 .60272 L
.49413 .60241 L
.4966 .60146 L
.49929 .60005 L
.50473 .59601 L
.51002 .5906 L
.515 .5842 L
.52434 .56907 L
.54529 .52255 L
.58376 .41131 L
.62468 .29254 L
.66408 .20114 L
.70197 .13841 L
.72141 .11445 L
.74231 .09374 L
.76205 .07806 L
Mistroke
.78358 .0644 L
.82334 .04609 L
.84306 .0394 L
.86404 .03353 L
.90568 .02463 L
.94579 .0184 L
.97619 .01472 L
Mfstroke
[ .05 ] 0 setdash
.02381 .03031 m
.04262 .0378 L
.06244 .04719 L
.10458 .07345 L
.14264 .10652 L
.18314 .15369 L
.22214 .21154 L
.26358 .28428 L
.30351 .35985 L
.34193 .43039 L
.38279 .49517 L
.40311 .5213 L
.42214 .54133 L
.44037 .55611 L
.45061 .56242 L
.45998 .5669 L
.46474 .5687 L
.46982 .57026 L
.47462 .57138 L
.47673 .57178 L
.47896 .57212 L
.48024 .57228 L
.48163 .57243 L
.48292 .57255 L
.48409 .57263 L
.48475 .57267 L
.48547 .5727 L
.48624 .57273 L
.48696 .57275 L
.48763 .57276 L
.48835 .57277 L
.48964 .57275 L
.49082 .57272 L
.4921 .57266 L
.49331 .57259 L
.49441 .5725 L
.49698 .57223 L
.49969 .57183 L
.50469 .57083 L
.50923 .5696 L
.51943 .56577 L
.52888 .56089 L
.5378 .55514 L
.55781 .5383 L
.57626 .51822 L
.61567 .46255 L
.65355 .39677 L
.69389 .32058 L
.73272 .24884 L
.77399 .18134 L
Mistroke
.81375 .12861 L
.852 .08974 L
.8927 .05948 L
.93188 .0388 L
.95333 .03017 L
.97351 .02343 L
.97619 .02263 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{135, 83},
  ImageMargins->{{103.1875, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002Y0000J1000`40l00?003`ZOoo002Yool00:Wo
o`00FOoo00<03ooo00l00ooo00H03oooool03ooo00l3ool00`0?ool03`0nool005[oo`0300oooooo
00;oo`0600oooooo00ooo`0?0ooo0P0??ooo001Jool00`0?ooooo`02ool01P0?ooooo`0?ool03`Co
o`0300oooooo03goo`00FOoo00<03ooo00l00ooo00<03oooool00P0?1?oo0P0??ooo002Yool005oo
o`0300oooooo04Ooo`00ZOoo002Yool00:Woo`00ZOoo002Yool00:Woo`00:_oo0`0?6Ooo0`0?5ooo
00<03oooool06?oo0`0?6?oo0`0?4?oo000Zool00`0?ooooo`0Jool00`0?ooooo`0Eool00`0?ool0
3`0Jool00`0?ooooo`0Gool00`0?ooooo`0@ool002Koo`<03`;oo`0300oooooo01?oo`<03`?oo`03
00oooooo01Goo`0300ooo`0?01[oo`0300oooooo01Soo`0300oooooo00ooo`00:_oo00<03ooo00l0
6_oo00<03oooool05Ooo00<03ooo00l06_oo00<03oooool05ooo00<03ooo00l04?oo000[ool200lI
ool200lHool00`0?ooooo`0Hool200lJool200l@ool00:Woo`00ZOoo002Yool00:Woo`00ZOoo000V
oomh00l;ool002Koo`803`03ool03ooo00Coo`0300oooooo00;oo`0300oooooo00?oo`0300oooooo
00;oo`0300oooooo00?oo`0300oooooo00;oo`0300oooooo00?oo`0300oooooo00;oo`0300oooooo
00?oo`0300oooooo00?oo`0300oooooo00;oo`0300oooooo00?oo`0300oooooo00;oo`0300oooooo
00?oo`0300oooooo00;oo`0300oooooo00?oo`0300oooooo00;oo`0300oooooo00?oo`0300oooooo
00;oo`0300oooooo00?oo`0300oooooo00;oo`0300oooooo00Woo`009_oo00<03oooool00`0?6Ooo
00<0Ooooool06Ooo00<03oooool06?oo00<0Soooool06?oo1@0?00?oo`0?ool02_oo000Vool200l3
ool700lCool00`2?ooooo`0Iool00`0?ooooo`0Hool00`1oooooo`0Bool600l6ool00`0?ooooo`09
ool002Koo`0300oooooo00803`Koo`D03`ooo`0307oooooo01Woo`0300oooooo01Soo`0308oooooo
00goo`H03`_oo`0300oooooo00Woo`009_oo0P0?0ooo0`0?1ooo100?3?oo00<0Soooool06Ooo00<0
3oooool06?oo00<0Ooooool02_oo100?2?oo00<03oooool01Ooo00<03oooool02Ooo000Vool00`0?
ooooo`05ool200l8ool400l9ool00`1oooooo`0Iool00`0?ooooo`0Hool00`2?ooooo`08ool300l9
ool200l8ool00`0?ooooo`09ool001[oo`0500oooooo00ooo`0300l4ool200lCool300l7ool00`2?
ooooo`0Iool00`0?ooooo`0Hool00`1oooooo`06ool300l9ool200l:ool00`0?ooooo`09ool001Wo
o`0300ooo`0?00Coo`0300oooooo00?oo`0300oooooo01Coo`803`Koo`0307oooooo01Woo`0300oo
oooo01Soo`0308oooooo00Coo`<03`[oo`0300oooooo00[oo`0300oooooo00Woo`006Ooo00<03ooo
00l01?oo00<03oooool00ooo0P0?01H0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`<03`1008l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l300l06P1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o00l;ool001Woo`0300ooo`0?00Coo`0300oooooo00?oo`0300oooooo00_o
o`0300oooooo00Woo`803`?oo`0307oooooo01Woo`0300oooooo01Soo`0408ooooooool200lKool0
0`0?ooooo`09ool001[oo`0300oooooo00;oo`803`Goo`803`goo`0300oooooo00Woo`803`;oo`03
08oooooo01Woo`0300oooooo01Soo`0307oooooo00803`[oo`0300oooooo00ooo`0300oooooo00Wo
o`009_oo00<03oooool03Ooo00<03oooool02Ooo0P0?00?oo`1oool06_oo00<03oooool06?oo00@0
Sooo00l03`_oo`0300oooooo00ooo`0300oooooo00Woo`009_oo0P0?3ooo00<03oooool02Ooo0P0?
00<0Soooool06Ooo00<03oooool06?oo00<0O`0?00l02ooo00<03oooool04?oo00<03oooool02Ooo
000>ool00`0?ooooo`02ool00`0?ooooo`0@ool00`0?ooooo`0?ool00`0?ooooo`09ool200lKool0
0`0?ooooo`0Hool200l;ool00`0?ooooo`0Aool00`0?ooooo`09ool000koo`H03a;oo`803agoo`80
3a[oo`0300oooooo01Ooo`803`_oo`0300oooooo01;oo`0300oooooo00Woo`003_oo00<03ooo00l0
0`0?4_oo00<03oooool07?oo00<0O`0?00l06Ooo00<03oooool05_oo0P0?00<0Soooool02?oo00<0
3oooool04ooo00<03oooool02Ooo000@ool0100?ooooo`0?1_oo00D03oooool03ooo00<03`Coo`03
00oooooo01coo`0408ooo`0?00lHool00`0?ooooo`0Eool200l00ooo07ooo`0Oool00`0?ooooo`09
ool0013oo`0300oooooo00Koo`0300ooo`0?00?oo`0300oooooo00Coo`803aCoo`0300oooooo00Ko
o`0407oooooo00lHool00`0?ooooo`0Eool0100?ooooo`2?8?oo00<03oooool02Ooo000Aool300l5
ool00`0?ool03`04ool00`0?ooooo`03ool00`0?ooooo`0Cool200l7ool00`2?ooooo`0200lGool0
0`0?ooooo`0Dool200l2ool00`1oooooo`0Nool00`0?ooooo`09ool000ooo`@03`Koo`0300ooo`0?
00?oo`0300ooo`0?00Coo`803`0Q08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?00l0S`1o08l0O`2?07l0S`1o08l0O`2?00803`1C07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l03`0;ool0013oo`0400oooooo00l6ool00`0?ooooo`03ool200l4ool0
0`0?ooooo`0Eool00`0?ooooo`04ool00`2?ooooo`02ool00`0?ooooo`0Dool00`0?ooooo`0Cool2
00l3ool00`1oooooo`04ool00`0?ooooo`0Gool00`0?ooooo`09ool0017oo`803a?oo`803aOoo`03
00oooooo00?oo`0307oooooo00;oo`803aGoo`0300oooooo01;oo`803`Coo`0308oooooo00?oo`80
3aWoo`0300oooooo00Woo`004?oo0P0?00?oo`0?ool04Ooo00<03oooool05_oo00<03oooool00ooo
00<0Soooool00ooo00<03oooool04ooo00<03oooool04_oo00<03oooool00ooo00<0Ooooool00ooo
00<03oooool06?oo00<03oooool02Ooo000@ool200l00ooo00ooo`0Aool200lMool00`1oooooo`03
ool200lDool00`0?ooooo`0Aool200l5ool00`2?ooooo`02ool00`0?ooooo`0Iool00`0?ooooo`09
ool001;oo`0300oooooo017oo`0300oooooo01coo`0308oooooo00Coo`0300oooooo01;oo`0300oo
oooo017oo`0300oooooo00Coo`0507ooooooool03`0Lool00`0?ooooo`09ool0013oo`@03a;oo`80
3agoo`0307oooooo00Coo`803a?oo`0300oooooo013oo`803`Koo`0308oooooo01koo`0300oooooo
00Woo`004?oo00@03oooool03a;oo`0300oooooo01coo`0308oooooo00Goo`0300oooooo017oo`03
00oooooo013oo`0300oooooo00Goo`0307oooooo01koo`0300oooooo00Woo`004?oo00<03oooool0
1ooo00D03oooool03ooo00803`Goo`803a[oo`0400oooooo07l7ool200lBool00`0?ooooo`0@ool0
0`0?ooooo`05ool00`2?ooooo`0Nool00`0?ooooo`09ool0017oo`<03`Goo`0300ooo`0?00Goo`03
00oooooo00;oo`0300oooooo01[oo`0300ooo`2?00Soo`0300oooooo013oo`0300oooooo00ooo`80
3`Ooo`0307oooooo01koo`0300oooooo00Woo`004Ooo00<03ooo00l01Ooo00<03ooo00l01?oo00<0
3oooool00ooo0P0?07H0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l03`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?07l0S`1o08l0O`2?
07l0S`0?08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l03`_oo`004?oo0P0?00?oo`0?ool01?oo00<03ooo00l01Ooo00<03oooool00_oo00<0
3oooool06ooo00<03`2?ool01ooo0P0?4Ooo00<03oooool03_oo0P0?2?oo00<0O`0?ool07_oo00<0
3oooool02Ooo000@ool00`0?ool03`07ool00`0?ooooo`02ool200l5ool200lMool00`0?ooooo`07
ool00`0?ooooo`0?ool00`0?ooooo`0>ool00`0?ooooo`07ool00`0?ooooo`0Nool00`0?ooooo`09
ool0017oo`0300ooo`0?01;oo`0300oooooo01coo`0300oooooo00Ooo`803a3oo`0300oooooo00go
o`803`Woo`0300oooooo01koo`0300oooooo00Woo`003_oo00<03ooo00l00`0?4_oo0P0?7Ooo00<0
Ooooool02?oo00<03oooool03_oo00<03oooool03Ooo00<03oooool01ooo00<03`2?ool07ooo00<0
3oooool02Ooo000?ool500lBool00`0?ooooo`0Lool00`2?ooooo`08ool00`0?ooooo`0>ool00`0?
ooooo`0=ool00`0?ooooo`07ool00`0?07ooo`0Oool00`0?ooooo`09ool0013oo`0400oooooo00lB
ool00`0?ooooo`0Lool00`1oooooo`08ool200l?ool00`0?ooooo`0<ool200l9ool00`0?08ooo`0O
ool00`0?ooooo`09ool002Koo`803agoo`0308oooooo00Woo`0300oooooo00goo`0300oooooo00co
o`0300oooooo00Woo`0307oooooo01koo`0300oooooo00Woo`004?oo00<03oooool00_oo00<03ooo
ool00_oo00@03oooool03`?oo`0300oooooo00;oo`0300oooooo01coo`0407oooooo00l8ool00`0?
ooooo`0=ool00`0?ooooo`0<ool00`0?ooooo`09ool00`2?ooooo`0Nool00`0?ooooo`09ool0013o
o`<03`03ool03`0?00?oo`0300ooo`0?00?oo`<03`Coo`803agoo`0408oooooo00l8ool200l>ool0
0`0?ooooo`0;ool200l;ool00`1oooooo`0Nool00`0?ooooo`09ool001;oo`803`Goo`0300ooo`0?
00?oo`0300ooo`0?00Coo`0300oooooo01coo`0507ooooooool03`08ool00`0?ooooo`0<ool00`0?
ooooo`0;ool00`0?ooooo`0:ool00`2?ooooo`0Nool00`0?ooooo`09ool0013oo`803`Ooo`0300oo
o`0?00Coo`803`Coo`803`0Z07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?0P0?04X0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`0?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`1o08l0
3`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`0?2ooo000Jool00`0?ooooo`04ool00`0?ooooo`02ool00`0?ooooo`0Lool0
0`1oooooo`02ool00`0?ooooo`06ool00`0?ooooo`0;ool00`0?ooooo`0:ool200l7ool00`0?oooo
o`02ool00`2?ooooo`0Nool00`0?ooooo`09ool0017oo`0300ooo`0?01;oo`803agoo`0308oooooo
00?oo`0300oooooo00Goo`0300oooooo00_oo`0300oooooo00[oo`0300oooooo00Koo`0300oooooo
00;oo`0307oooooo01koo`0300oooooo00Woo`003_oo00<03ooo00l00`0?4_oo00<03oooool07?oo
00<0Ooooool00ooo00<03oooool01Ooo0P0?3?oo00<03oooool02_oo00<03oooool01Ooo00<03ooo
ool00ooo00<0Soooool07_oo00<03oooool02Ooo000@ool400lBool200lMool00`2?ooooo`0<ool0
0`0?ooooo`0:ool00`0?ooooo`09ool200l6ool00`0?ooooo`04ool00`1oooooo`0Nool00`0?oooo
o`09ool0013oo`0400oooooo00lBool00`0?ooooo`0Lool00`1oooooo`0<ool00`0?ooooo`0:ool0
0`0?ooooo`09ool00`0?ooooo`05ool00`0?ooooo`04ool00`2?ooooo`0Nool00`0?ooooo`09ool0
013oo`0300oooooo01?oo`803agoo`0308oooooo00coo`803`_oo`0300oooooo00Soo`803`koo`03
07oooooo01koo`0300oooooo00Woo`004Ooo0`0?4_oo00<03oooool07?oo00<0Ooooool03Ooo00<0
3oooool02Ooo00<03oooool02?oo00<03oooool03Ooo00<0Soooool07_oo00<03oooool02Ooo000J
ool01@0?ooooo`0?ool00P0?1Ooo0P0?7Ooo00<0Soooool01_oo00<03oooool01?oo00<03oooool0
2Ooo00<03oooool02?oo00<03oooool03Ooo00<0Ooooool07_oo00<03oooool02Ooo000Iool00`0?
ool03`05ool00`0?ooooo`02ool00`0?ooooo`0Lool00`1oooooo`06ool00`0?ooooo`04ool200l:
ool00`0?ooooo`07ool200l?ool00`2?ooooo`0Nool00`0?ooooo`09ool0013oo`0300ooo`0?00Ko
o`0300ooo`0?00?oo`803`Goo`803`1f07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l03`2?
07l0S`1o08l0O`2?07l0S`1o00l0O`2?07l0S`1o08l0O`2?07l03`1o08l0O`2?07l0S`0?08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o00l;ool0013oo`803`03ool03ooo00Coo`0300ooo`0?00?oo`0300oo
oooo00Coo`0300oooooo01coo`0307oooooo00Ooo`0300oooooo00Coo`0300oooooo00Soo`0300oo
oooo00Ooo`0300oooooo00Coo`0300oooooo00Ooo`0308oooooo01koo`0300oooooo00Woo`004Ooo
0`0?1_oo00<03oooool00_oo0`0?1?oo0P0?7Ooo00<0Soooool02?oo00<03oooool00ooo0P0?2Ooo
00<03oooool01_oo0P0?1Ooo00<03oooool02?oo00<0Ooooool07_oo00<03oooool02Ooo000Cool0
0`0?ooooo`0@ool00`0?ooooo`0Lool00`1oooooo`09ool00`0?ooooo`03ool00`0?ooooo`07ool0
0`0?ooooo`06ool00`0?ooooo`03ool00`0?ooooo`09ool00`2?ooooo`0Nool00`0?ooooo`09ool0
02Koo`0300oooooo01coo`0308oooooo00ooo`0300oooooo00Ooo`0300oooooo00Koo`0300oooooo
00?oo`0300oooooo00Woo`0307oooooo01koo`0300oooooo00Woo`004ooo00<03oooool04?oo0P0?
7Ooo00<0Ooooool03ooo0P0?2?oo00<03oooool01Ooo0P0?1?oo00<03oooool02_oo00<0Soooool0
7_oo00<03oooool02Ooo000@ool300lCool00`0?ooooo`0Lool00`2?ooooo`0@ool00`0?ooooo`06
ool00`0?ooooo`05ool00`0?ooooo`0@ool00`1oooooo`0Nool00`0?ooooo`09ool001?oo`0300oo
oooo013oo`803agoo`0307oooooo013oo`0300oooooo00Koo`0300oooooo00Goo`0300oooooo013o
o`0308oooooo01koo`0300oooooo00Woo`004?oo100?1_oo00@03oooool03`;oo`0300oooooo00?o
o`0300oooooo01coo`0308oooooo00coo`0400ooooooool200l7ool00`0?ooooo`04ool200lBool0
0`1oooooo`0Nool00`0?ooooo`09ool001Woo`0300ooo`0?00?oo`0300ooo`0?00Coo`803agoo`03
07oooooo00goo`0500ooooooool03`07ool00`0?ooooo`04ool00`0?ooooo`0Aool00`2?ooooo`0N
ool00`0?ooooo`09ool001Woo`0300ooo`0?00?oo`803`Goo`0300oooooo01coo`0308oooooo00go
o`0500ooooooool03`07ool00`0?ooooo`04ool0100?ooooo`0?4?oo00<0Ooooool07_oo00<03ooo
ool02Ooo000Iool00`0?ool03`03ool00`0?ooooo`04ool200l0<@2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o
08l0O`2?07l0S`1o00l0O`2?00803`0<07l0S`1o08l0O`2?00l0S`1o08l0O`2?0P0?03D0O`2?00l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0?00_oo`006_oo00<03oooool00ooo
0P0?1?oo00<03oooool07?oo00<0Soooool03ooo00@03oooool03`Koo`0300oooooo00?oo`0400oo
oooo00lAool00`1oooooo`0Nool00`0?ooooo`09ool002Koo`803agoo`0307oooooo013oo`0400oo
o`0?00l5ool00`0?ooooo`02ool200l00ooo00ooo`0Aool00`2?ooooo`0Nool00`0?ooooo`09ool0
02Koo`0300oooooo01coo`0308oooooo01?oo`0300oooooo00?oo`0300oooooo00;oo`<03a?oo`03
07oooooo01koo`0300oooooo00Woo`009_oo0P0?7Ooo00<0Ooooool04ooo0P0?1?oo00@03ooooooo
o`803aGoo`0308oooooo01koo`0300oooooo00Woo`009_oo00<03oooool07?oo00<0Soooool05?oo
00<03oooool00_oo00D03oooooooo`0?01Koo`0307oooooo01koo`0300oooooo00Woo`009_oo0P0?
7Ooo00<0Ooooool05?oo1`0?00?oo`0?00l05_oo00<0Soooool07_oo00<03oooool02Ooo000Vool0
0`0?ooooo`0Lool00`2?ooooo`0Eool01@0?oooooooo00l00_oo00<03oooool05Ooo00<0Ooooool0
7_oo00<03oooool02Ooo000Jool0100?ooooo`0?0_oo00<03oooool00ooo0P0?7Ooo00<0Ooooool0
5Ooo0P0?0_oo00@03ooo00l03aOoo`0308oooooo01koo`0300oooooo00Woo`006Ooo00<03ooo00l0
1?oo00<03oooool00ooo00<03oooool07?oo00<0Soooool05_oo0P0?00Coo`0?00l03aSoo`0307oo
oooo01koo`0300oooooo00Woo`006Ooo00<03ooo00l01Ooo00<03oooool00_oo0P0?7Ooo00<0Oooo
ool05ooo100?6Ooo00<0Soooool07_oo00<03oooool02Ooo000Iool00`0?ool03`05ool00`0?oooo
o`02ool0100?ooooo`0?1Ooo00<03oooool00_oo00<03oooool00ooo00<03oooool00_oo00<03ooo
ool00ooo00<03oooool00_oo00<03oooool00ooo00<03oooool00_oo00<03oooool00ooo00<03ooo
ool00ooo00<03oooool00_oo00<03oooool00ooo00<03oooool00_oo00<03oooool00ooo00<03ooo
ool00_oo00<03oooool00ooo00<03oooool00_oo00<03oooool00ooo00<03oooool00_oo00<03ooo
ool00ooo00<03oooool00_oo00<03oooool02Ooo000Jool00`0?ooooo`02ool300l4oomh00l;ool0
0:Woo`00ZOoo002Yool00:Woo`00\
\>"],
  ImageRangeCache->{{{0, 167.75}, {102.75, 0}} -> {-3.5114, -0.21589, 
  0.045228, 0.011833}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fig16x11", "Subsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.31746 0.00744 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.02381 0.00744 0.321429 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.019231 0.023452 0.019231 0.023452 [
[(0)] .01923 0 0 2 Msboxa
[(10)] .25375 0 0 2 Msboxa
[(20)] .48827 0 0 2 Msboxa
[(30)] .7228 0 0 2 Msboxa
[(40)] .95732 0 0 2 Msboxa
[(0)] -0.0125 .01923 1 0 Msboxa
[(10)] -0.0125 .25375 1 0 Msboxa
[(20)] -0.0125 .48827 1 0 Msboxa
[(30)] -0.0125 .7228 1 0 Msboxa
[(40)] -0.0125 .95732 1 0 Msboxa
[({1})] .5 1 0 -2 Msboxa
[(x [a])] 1.025 0 -1 0 Msboxa
[(y [a])] 0 1 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.01923 0 m
.01923 .00625 L
s
P
[(0)] .01923 0 0 2 Mshowa
p
.002 w
.25375 0 m
.25375 .00625 L
s
P
[(10)] .25375 0 0 2 Mshowa
p
.002 w
.48827 0 m
.48827 .00625 L
s
P
[(20)] .48827 0 0 2 Mshowa
p
.002 w
.7228 0 m
.7228 .00625 L
s
P
[(30)] .7228 0 0 2 Mshowa
p
.002 w
.95732 0 m
.95732 .00625 L
s
P
[(40)] .95732 0 0 2 Mshowa
p
.001 w
.06614 0 m
.06614 .00375 L
s
P
p
.001 w
.11304 0 m
.11304 .00375 L
s
P
p
.001 w
.15994 0 m
.15994 .00375 L
s
P
p
.001 w
.20685 0 m
.20685 .00375 L
s
P
p
.001 w
.30066 0 m
.30066 .00375 L
s
P
p
.001 w
.34756 0 m
.34756 .00375 L
s
P
p
.001 w
.39447 0 m
.39447 .00375 L
s
P
p
.001 w
.44137 0 m
.44137 .00375 L
s
P
p
.001 w
.53518 0 m
.53518 .00375 L
s
P
p
.001 w
.58208 0 m
.58208 .00375 L
s
P
p
.001 w
.62899 0 m
.62899 .00375 L
s
P
p
.001 w
.67589 0 m
.67589 .00375 L
s
P
p
.001 w
.7697 0 m
.7697 .00375 L
s
P
p
.001 w
.8166 0 m
.8166 .00375 L
s
P
p
.001 w
.86351 0 m
.86351 .00375 L
s
P
p
.001 w
.91041 0 m
.91041 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01923 m
.00625 .01923 L
s
P
[(0)] -0.0125 .01923 1 0 Mshowa
p
.002 w
0 .25375 m
.00625 .25375 L
s
P
[(10)] -0.0125 .25375 1 0 Mshowa
p
.002 w
0 .48827 m
.00625 .48827 L
s
P
[(20)] -0.0125 .48827 1 0 Mshowa
p
.002 w
0 .7228 m
.00625 .7228 L
s
P
[(30)] -0.0125 .7228 1 0 Mshowa
p
.002 w
0 .95732 m
.00625 .95732 L
s
P
[(40)] -0.0125 .95732 1 0 Mshowa
p
.001 w
0 .06614 m
.00375 .06614 L
s
P
p
.001 w
0 .11304 m
.00375 .11304 L
s
P
p
.001 w
0 .15994 m
.00375 .15994 L
s
P
p
.001 w
0 .20685 m
.00375 .20685 L
s
P
p
.001 w
0 .30066 m
.00375 .30066 L
s
P
p
.001 w
0 .34756 m
.00375 .34756 L
s
P
p
.001 w
0 .39447 m
.00375 .39447 L
s
P
p
.001 w
0 .44137 m
.00375 .44137 L
s
P
p
.001 w
0 .53518 m
.00375 .53518 L
s
P
p
.001 w
0 .58208 m
.00375 .58208 L
s
P
p
.001 w
0 .62899 m
.00375 .62899 L
s
P
p
.001 w
0 .67589 m
.00375 .67589 L
s
P
p
.001 w
0 .7697 m
.00375 .7697 L
s
P
p
.001 w
0 .8166 m
.00375 .8166 L
s
P
p
.001 w
0 .86351 m
.00375 .86351 L
s
P
p
.001 w
0 .91041 m
.00375 .91041 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
.01923 .99375 m
.01923 1 L
s
P
p
.002 w
.25375 .99375 m
.25375 1 L
s
P
p
.002 w
.48827 .99375 m
.48827 1 L
s
P
p
.002 w
.7228 .99375 m
.7228 1 L
s
P
p
.002 w
.95732 .99375 m
.95732 1 L
s
P
p
.001 w
.06614 .99625 m
.06614 1 L
s
P
p
.001 w
.11304 .99625 m
.11304 1 L
s
P
p
.001 w
.15994 .99625 m
.15994 1 L
s
P
p
.001 w
.20685 .99625 m
.20685 1 L
s
P
p
.001 w
.30066 .99625 m
.30066 1 L
s
P
p
.001 w
.34756 .99625 m
.34756 1 L
s
P
p
.001 w
.39447 .99625 m
.39447 1 L
s
P
p
.001 w
.44137 .99625 m
.44137 1 L
s
P
p
.001 w
.53518 .99625 m
.53518 1 L
s
P
p
.001 w
.58208 .99625 m
.58208 1 L
s
P
p
.001 w
.62899 .99625 m
.62899 1 L
s
P
p
.001 w
.67589 .99625 m
.67589 1 L
s
P
p
.001 w
.7697 .99625 m
.7697 1 L
s
P
p
.001 w
.8166 .99625 m
.8166 1 L
s
P
p
.001 w
.86351 .99625 m
.86351 1 L
s
P
p
.001 w
.91041 .99625 m
.91041 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
[({1})] .5 1 0 -2 Mshowa
p
.002 w
.99375 .01923 m
1 .01923 L
s
P
p
.002 w
.99375 .25375 m
1 .25375 L
s
P
p
.002 w
.99375 .48827 m
1 .48827 L
s
P
p
.002 w
.99375 .7228 m
1 .7228 L
s
P
p
.002 w
.99375 .95732 m
1 .95732 L
s
P
p
.001 w
.99625 .06614 m
1 .06614 L
s
P
p
.001 w
.99625 .11304 m
1 .11304 L
s
P
p
.001 w
.99625 .15994 m
1 .15994 L
s
P
p
.001 w
.99625 .20685 m
1 .20685 L
s
P
p
.001 w
.99625 .30066 m
1 .30066 L
s
P
p
.001 w
.99625 .34756 m
1 .34756 L
s
P
p
.001 w
.99625 .39447 m
1 .39447 L
s
P
p
.001 w
.99625 .44137 m
1 .44137 L
s
P
p
.001 w
.99625 .53518 m
1 .53518 L
s
P
p
.001 w
.99625 .58208 m
1 .58208 L
s
P
p
.001 w
.99625 .62899 m
1 .62899 L
s
P
p
.001 w
.99625 .67589 m
1 .67589 L
s
P
p
.001 w
.99625 .7697 m
1 .7697 L
s
P
p
.001 w
.99625 .8166 m
1 .8166 L
s
P
p
.001 w
.99625 .86351 m
1 .86351 L
s
P
p
.001 w
.99625 .91041 m
1 .91041 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
[(x [a])] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
[(y [a])] 0 1 0 -4 Mshowa
p
.002 w
0 0 m
0 1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
41 string
41 41 8 [41 0 0 41 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
000000000000000000000000000000000101010101010101
0100000000000000000000000000000000
000000000000000000000000000101010101010202020101
0101010100000000000000000000000000
000000000000000000000001010102020303030303030303
0302020101010000000000000000000000
000000000000000000000101020203040607080808080807
0604030202010100000000000000000000
0000000000000000000101020305070B121E32433743321E
120B070503020101000000000000000000
000000000000000000010203050A143E782B1D1817181D2B
783E140A05030201000000000000000000
0000000000000000010103050B1EFF341F18151413141518
1F34FF1E0B050301010000000000000000
0000000000000000010204091DC42B1C1714131212121314
171C2BC41D090402010000000000000000
000000000000000101030613FE2A1C171413121211121213
14171C2AFE130603010100000000000000
000000000000000101040A3C321C17151312121111111212
1315171C323C0A04010100000000000000
000000000000000102040F741E1715131312111111111112
131315171E740F04020100000000000000
000000000000000001051927181514131212111111111112
1213141518271905010000000000000000
00000000000000000104281A151413131212111111111112
12131314151A2804010000000000000000
000000000000000000022E16141413121212111111111112
1212131414162E02000000000000000000
000000000000000000000D15141313121212111111111112
1212131314150D00000000000000000000
000000000000000000022E16141413121212111111111112
1212131414162E02000000000000000000
00000000000000000104281A151413131212111111111112
12131314151A2804010000000000000000
000000000000000001051927181514131212111111111112
1213141518271905010000000000000000
000000000000000102040F741E1715131312111111111112
131315171E740F04020100000000000000
000000000000000101040A3C321C17151312121111111212
1315171C323C0A04010100000000000000
000000000000000101030613FE2A1C171413121211121213
14171C2AFE130603010100000000000000
0000000000000000010204091DC42B1C1714131212121314
171C2BC41D090402010000000000000000
0000000000000000010103050B1EFF341F18151413141518
1F34FF1E0B050301010000000000000000
000000000000000000010203050A143E782B1D1817181D2B
783E140A05030201000000000000000000
0000000000000000000101020305070B121E32433743321E
120B070503020101000000000000000000
000000000000000000000101020203040607080808080807
0604030202010100000000000000000000
000000000000000000000001010102020303030303030303
0302020101010000000000000000000000
000000000000000000000000000101010101010202020101
0101010100000000000000000000000000
000000000000000000000000000000000101010101010101
0100000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744 0.64881 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.019231 0.023452 0.019231 0.023452 [
[(0)] .01923 0 0 2 Msboxa
[(10)] .25375 0 0 2 Msboxa
[(20)] .48827 0 0 2 Msboxa
[(30)] .7228 0 0 2 Msboxa
[(40)] .95732 0 0 2 Msboxa
[(0)] -0.0125 .01923 1 0 Msboxa
[(10)] -0.0125 .25375 1 0 Msboxa
[(20)] -0.0125 .48827 1 0 Msboxa
[(30)] -0.0125 .7228 1 0 Msboxa
[(40)] -0.0125 .95732 1 0 Msboxa
[({2})] .5 1 0 -2 Msboxa
[(x [a])] 1.025 0 -1 0 Msboxa
[(y [a])] 0 1 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.01923 0 m
.01923 .00625 L
s
P
[(0)] .01923 0 0 2 Mshowa
p
.002 w
.25375 0 m
.25375 .00625 L
s
P
[(10)] .25375 0 0 2 Mshowa
p
.002 w
.48827 0 m
.48827 .00625 L
s
P
[(20)] .48827 0 0 2 Mshowa
p
.002 w
.7228 0 m
.7228 .00625 L
s
P
[(30)] .7228 0 0 2 Mshowa
p
.002 w
.95732 0 m
.95732 .00625 L
s
P
[(40)] .95732 0 0 2 Mshowa
p
.001 w
.06614 0 m
.06614 .00375 L
s
P
p
.001 w
.11304 0 m
.11304 .00375 L
s
P
p
.001 w
.15994 0 m
.15994 .00375 L
s
P
p
.001 w
.20685 0 m
.20685 .00375 L
s
P
p
.001 w
.30066 0 m
.30066 .00375 L
s
P
p
.001 w
.34756 0 m
.34756 .00375 L
s
P
p
.001 w
.39447 0 m
.39447 .00375 L
s
P
p
.001 w
.44137 0 m
.44137 .00375 L
s
P
p
.001 w
.53518 0 m
.53518 .00375 L
s
P
p
.001 w
.58208 0 m
.58208 .00375 L
s
P
p
.001 w
.62899 0 m
.62899 .00375 L
s
P
p
.001 w
.67589 0 m
.67589 .00375 L
s
P
p
.001 w
.7697 0 m
.7697 .00375 L
s
P
p
.001 w
.8166 0 m
.8166 .00375 L
s
P
p
.001 w
.86351 0 m
.86351 .00375 L
s
P
p
.001 w
.91041 0 m
.91041 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01923 m
.00625 .01923 L
s
P
[(0)] -0.0125 .01923 1 0 Mshowa
p
.002 w
0 .25375 m
.00625 .25375 L
s
P
[(10)] -0.0125 .25375 1 0 Mshowa
p
.002 w
0 .48827 m
.00625 .48827 L
s
P
[(20)] -0.0125 .48827 1 0 Mshowa
p
.002 w
0 .7228 m
.00625 .7228 L
s
P
[(30)] -0.0125 .7228 1 0 Mshowa
p
.002 w
0 .95732 m
.00625 .95732 L
s
P
[(40)] -0.0125 .95732 1 0 Mshowa
p
.001 w
0 .06614 m
.00375 .06614 L
s
P
p
.001 w
0 .11304 m
.00375 .11304 L
s
P
p
.001 w
0 .15994 m
.00375 .15994 L
s
P
p
.001 w
0 .20685 m
.00375 .20685 L
s
P
p
.001 w
0 .30066 m
.00375 .30066 L
s
P
p
.001 w
0 .34756 m
.00375 .34756 L
s
P
p
.001 w
0 .39447 m
.00375 .39447 L
s
P
p
.001 w
0 .44137 m
.00375 .44137 L
s
P
p
.001 w
0 .53518 m
.00375 .53518 L
s
P
p
.001 w
0 .58208 m
.00375 .58208 L
s
P
p
.001 w
0 .62899 m
.00375 .62899 L
s
P
p
.001 w
0 .67589 m
.00375 .67589 L
s
P
p
.001 w
0 .7697 m
.00375 .7697 L
s
P
p
.001 w
0 .8166 m
.00375 .8166 L
s
P
p
.001 w
0 .86351 m
.00375 .86351 L
s
P
p
.001 w
0 .91041 m
.00375 .91041 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
.01923 .99375 m
.01923 1 L
s
P
p
.002 w
.25375 .99375 m
.25375 1 L
s
P
p
.002 w
.48827 .99375 m
.48827 1 L
s
P
p
.002 w
.7228 .99375 m
.7228 1 L
s
P
p
.002 w
.95732 .99375 m
.95732 1 L
s
P
p
.001 w
.06614 .99625 m
.06614 1 L
s
P
p
.001 w
.11304 .99625 m
.11304 1 L
s
P
p
.001 w
.15994 .99625 m
.15994 1 L
s
P
p
.001 w
.20685 .99625 m
.20685 1 L
s
P
p
.001 w
.30066 .99625 m
.30066 1 L
s
P
p
.001 w
.34756 .99625 m
.34756 1 L
s
P
p
.001 w
.39447 .99625 m
.39447 1 L
s
P
p
.001 w
.44137 .99625 m
.44137 1 L
s
P
p
.001 w
.53518 .99625 m
.53518 1 L
s
P
p
.001 w
.58208 .99625 m
.58208 1 L
s
P
p
.001 w
.62899 .99625 m
.62899 1 L
s
P
p
.001 w
.67589 .99625 m
.67589 1 L
s
P
p
.001 w
.7697 .99625 m
.7697 1 L
s
P
p
.001 w
.8166 .99625 m
.8166 1 L
s
P
p
.001 w
.86351 .99625 m
.86351 1 L
s
P
p
.001 w
.91041 .99625 m
.91041 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
[({2})] .5 1 0 -2 Mshowa
p
.002 w
.99375 .01923 m
1 .01923 L
s
P
p
.002 w
.99375 .25375 m
1 .25375 L
s
P
p
.002 w
.99375 .48827 m
1 .48827 L
s
P
p
.002 w
.99375 .7228 m
1 .7228 L
s
P
p
.002 w
.99375 .95732 m
1 .95732 L
s
P
p
.001 w
.99625 .06614 m
1 .06614 L
s
P
p
.001 w
.99625 .11304 m
1 .11304 L
s
P
p
.001 w
.99625 .15994 m
1 .15994 L
s
P
p
.001 w
.99625 .20685 m
1 .20685 L
s
P
p
.001 w
.99625 .30066 m
1 .30066 L
s
P
p
.001 w
.99625 .34756 m
1 .34756 L
s
P
p
.001 w
.99625 .39447 m
1 .39447 L
s
P
p
.001 w
.99625 .44137 m
1 .44137 L
s
P
p
.001 w
.99625 .53518 m
1 .53518 L
s
P
p
.001 w
.99625 .58208 m
1 .58208 L
s
P
p
.001 w
.99625 .62899 m
1 .62899 L
s
P
p
.001 w
.99625 .67589 m
1 .67589 L
s
P
p
.001 w
.99625 .7697 m
1 .7697 L
s
P
p
.001 w
.99625 .8166 m
1 .8166 L
s
P
p
.001 w
.99625 .86351 m
1 .86351 L
s
P
p
.001 w
.99625 .91041 m
1 .91041 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
[(x [a])] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
[(y [a])] 0 1 0 -4 Mshowa
p
.002 w
0 0 m
0 1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
41 string
41 41 8 [41 0 0 41 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000010101010101010101010101
0101010101000000000000000000000000
000000000000000000010101010101010101020202020201
0101010101010101000000000000000000
000000000000000001010101010202020202020202020202
0202020201010101010000000000000000
000000000000010101010202020203030303030304030303
0303030202020201010101000000000000
000000000001010101020203030404040505050505050505
0504040403030202010101010000000000
000000000101010102020304040506070708080808080808
0707060504040302020101010100000000
0000000001010102030304050608090A0B0C0D0D0D0D0D0C
0B0A090806050403030201010100000000
0000000101010203030506080A0C0E101214151515151514
12100E0C0A080605030302010101000000
00000001010202030506080B0E12171B2023252626262523
201B17120E0B0806050302020101000000
000001010102030406080C10161D27313C44494B4B4B4944
3C31271D16100C08060403020101010000
0000010102030405080B1018233247627E90948F8B8F9490
7E6247322318100B080504030201010000
00000101020304070A0F1724395B8FC6DACBB5A7A2A7B5CB
DAC68F5B3924170F0A0704030201010000
00000101020305080D14213862ACF4F4D5BBABA29FA2ABBB
D5F4F4AC623821140D0805030201010000
00000101020406090F1A2E57A9FFF7D5BDAEA49E9D9EA4AE
BDD5F7FFA9572E1A0F0906040201010000
000001010204060B12214086EEF5D5BFB1A7A19D9C9DA1A7
B1BFD5F5EE864021120B06040201010000
000001010204070B152856B8EBD4C0B3AAA4A09D9C9DA0A4
AAB3C0D4EBB85628150B07040201010000
000001010204060B162E6AC7CEBFB4ADA7A29F9D9D9D9FA2
A7ADB4BFCEC76A2E160B06040201010000
000000010203060B152F74B6B8B3AEA9A5A29F9E9D9E9FA2
A5A9AEB3B8B6742F150B06030201000000
0000000101020409122B6DA1ABACAAA7A4A2A09E9E9EA0A2
A4A7AAACABA16D2B120904020101000000
00000000010103060D235E95A5A9A9A7A4A2A09F9E9FA0A2
A4A7A9A9A5955E230D0603010100000000
00000000000102050B1E5791A3A8A8A6A4A2A09F9E9FA0A2
A4A6A8A8A391571E0B0502010000000000
00000000010103060D235E95A5A9A9A7A4A2A09F9E9FA0A2
A4A7A9A9A5955E230D0603010100000000
0000000101020409122B6DA1ABACAAA7A4A2A09E9E9EA0A2
A4A7AAACABA16D2B120904020101000000
000000010203060B152F74B6B8B3AEA9A5A29F9E9D9E9FA2
A5A9AEB3B8B6742F150B06030201000000
000001010204060B162E6AC7CEBFB4ADA7A29F9D9D9D9FA2
A7ADB4BFCEC76A2E160B06040201010000
000001010204070B152856B8EBD4C0B3AAA4A09D9C9DA0A4
AAB3C0D4EBB85628150B07040201010000
000001010204060B12214086EEF5D5BFB1A7A19D9C9DA1A7
B1BFD5F5EE864021120B06040201010000
00000101020406090F1A2E57A9FFF7D5BDAEA49E9D9EA4AE
BDD5F7FFA9572E1A0F0906040201010000
00000101020305080D14213862ACF4F4D5BBABA29FA2ABBB
D5F4F4AC623821140D0805030201010000
00000101020304070A0F1724395B8FC6DACBB5A7A2A7B5CB
DAC68F5B3924170F0A0704030201010000
0000010102030405080B1018233247627E90948F8B8F9490
7E6247322318100B080504030201010000
000001010102030406080C10161D27313C44494B4B4B4944
3C31271D16100C08060403020101010000
00000001010202030506080B0E12171B2023252626262523
201B17120E0B0806050302020101000000
0000000101010203030506080A0C0E101214151515151514
12100E0C0A080605030302010101000000
0000000001010102030304050608090A0B0C0D0D0D0D0D0C
0B0A090806050403030201010100000000
000000000101010102020304040506070708080808080808
0707060504040302020101010100000000
000000000001010101020203030404040505050505050505
0504040403030202010101010000000000
000000000000010101010202020203030303030304030303
0303030202020201010101000000000000
000000000000000001010101010202020202020202020202
0202020201010101010000000000000000
000000000000000000010101010101010101020202020201
0101010101010101000000000000000000
000000000000000000000000010101010101010101010101
0101010101000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744 0.97619 0.30506 MathSubStart
%% DensityGraphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.019231 0.023452 0.019231 0.023452 [
[(0)] .01923 0 0 2 Msboxa
[(10)] .25375 0 0 2 Msboxa
[(20)] .48827 0 0 2 Msboxa
[(30)] .7228 0 0 2 Msboxa
[(40)] .95732 0 0 2 Msboxa
[(0)] -0.0125 .01923 1 0 Msboxa
[(10)] -0.0125 .25375 1 0 Msboxa
[(20)] -0.0125 .48827 1 0 Msboxa
[(30)] -0.0125 .7228 1 0 Msboxa
[(40)] -0.0125 .95732 1 0 Msboxa
[({3})] .5 1 0 -2 Msboxa
[(x [a])] 1.025 0 -1 0 Msboxa
[(y [a])] 0 1 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.01923 0 m
.01923 .00625 L
s
P
[(0)] .01923 0 0 2 Mshowa
p
.002 w
.25375 0 m
.25375 .00625 L
s
P
[(10)] .25375 0 0 2 Mshowa
p
.002 w
.48827 0 m
.48827 .00625 L
s
P
[(20)] .48827 0 0 2 Mshowa
p
.002 w
.7228 0 m
.7228 .00625 L
s
P
[(30)] .7228 0 0 2 Mshowa
p
.002 w
.95732 0 m
.95732 .00625 L
s
P
[(40)] .95732 0 0 2 Mshowa
p
.001 w
.06614 0 m
.06614 .00375 L
s
P
p
.001 w
.11304 0 m
.11304 .00375 L
s
P
p
.001 w
.15994 0 m
.15994 .00375 L
s
P
p
.001 w
.20685 0 m
.20685 .00375 L
s
P
p
.001 w
.30066 0 m
.30066 .00375 L
s
P
p
.001 w
.34756 0 m
.34756 .00375 L
s
P
p
.001 w
.39447 0 m
.39447 .00375 L
s
P
p
.001 w
.44137 0 m
.44137 .00375 L
s
P
p
.001 w
.53518 0 m
.53518 .00375 L
s
P
p
.001 w
.58208 0 m
.58208 .00375 L
s
P
p
.001 w
.62899 0 m
.62899 .00375 L
s
P
p
.001 w
.67589 0 m
.67589 .00375 L
s
P
p
.001 w
.7697 0 m
.7697 .00375 L
s
P
p
.001 w
.8166 0 m
.8166 .00375 L
s
P
p
.001 w
.86351 0 m
.86351 .00375 L
s
P
p
.001 w
.91041 0 m
.91041 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01923 m
.00625 .01923 L
s
P
[(0)] -0.0125 .01923 1 0 Mshowa
p
.002 w
0 .25375 m
.00625 .25375 L
s
P
[(10)] -0.0125 .25375 1 0 Mshowa
p
.002 w
0 .48827 m
.00625 .48827 L
s
P
[(20)] -0.0125 .48827 1 0 Mshowa
p
.002 w
0 .7228 m
.00625 .7228 L
s
P
[(30)] -0.0125 .7228 1 0 Mshowa
p
.002 w
0 .95732 m
.00625 .95732 L
s
P
[(40)] -0.0125 .95732 1 0 Mshowa
p
.001 w
0 .06614 m
.00375 .06614 L
s
P
p
.001 w
0 .11304 m
.00375 .11304 L
s
P
p
.001 w
0 .15994 m
.00375 .15994 L
s
P
p
.001 w
0 .20685 m
.00375 .20685 L
s
P
p
.001 w
0 .30066 m
.00375 .30066 L
s
P
p
.001 w
0 .34756 m
.00375 .34756 L
s
P
p
.001 w
0 .39447 m
.00375 .39447 L
s
P
p
.001 w
0 .44137 m
.00375 .44137 L
s
P
p
.001 w
0 .53518 m
.00375 .53518 L
s
P
p
.001 w
0 .58208 m
.00375 .58208 L
s
P
p
.001 w
0 .62899 m
.00375 .62899 L
s
P
p
.001 w
0 .67589 m
.00375 .67589 L
s
P
p
.001 w
0 .7697 m
.00375 .7697 L
s
P
p
.001 w
0 .8166 m
.00375 .8166 L
s
P
p
.001 w
0 .86351 m
.00375 .86351 L
s
P
p
.001 w
0 .91041 m
.00375 .91041 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
.01923 .99375 m
.01923 1 L
s
P
p
.002 w
.25375 .99375 m
.25375 1 L
s
P
p
.002 w
.48827 .99375 m
.48827 1 L
s
P
p
.002 w
.7228 .99375 m
.7228 1 L
s
P
p
.002 w
.95732 .99375 m
.95732 1 L
s
P
p
.001 w
.06614 .99625 m
.06614 1 L
s
P
p
.001 w
.11304 .99625 m
.11304 1 L
s
P
p
.001 w
.15994 .99625 m
.15994 1 L
s
P
p
.001 w
.20685 .99625 m
.20685 1 L
s
P
p
.001 w
.30066 .99625 m
.30066 1 L
s
P
p
.001 w
.34756 .99625 m
.34756 1 L
s
P
p
.001 w
.39447 .99625 m
.39447 1 L
s
P
p
.001 w
.44137 .99625 m
.44137 1 L
s
P
p
.001 w
.53518 .99625 m
.53518 1 L
s
P
p
.001 w
.58208 .99625 m
.58208 1 L
s
P
p
.001 w
.62899 .99625 m
.62899 1 L
s
P
p
.001 w
.67589 .99625 m
.67589 1 L
s
P
p
.001 w
.7697 .99625 m
.7697 1 L
s
P
p
.001 w
.8166 .99625 m
.8166 1 L
s
P
p
.001 w
.86351 .99625 m
.86351 1 L
s
P
p
.001 w
.91041 .99625 m
.91041 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
[({3})] .5 1 0 -2 Mshowa
p
.002 w
.99375 .01923 m
1 .01923 L
s
P
p
.002 w
.99375 .25375 m
1 .25375 L
s
P
p
.002 w
.99375 .48827 m
1 .48827 L
s
P
p
.002 w
.99375 .7228 m
1 .7228 L
s
P
p
.002 w
.99375 .95732 m
1 .95732 L
s
P
p
.001 w
.99625 .06614 m
1 .06614 L
s
P
p
.001 w
.99625 .11304 m
1 .11304 L
s
P
p
.001 w
.99625 .15994 m
1 .15994 L
s
P
p
.001 w
.99625 .20685 m
1 .20685 L
s
P
p
.001 w
.99625 .30066 m
1 .30066 L
s
P
p
.001 w
.99625 .34756 m
1 .34756 L
s
P
p
.001 w
.99625 .39447 m
1 .39447 L
s
P
p
.001 w
.99625 .44137 m
1 .44137 L
s
P
p
.001 w
.99625 .53518 m
1 .53518 L
s
P
p
.001 w
.99625 .58208 m
1 .58208 L
s
P
p
.001 w
.99625 .62899 m
1 .62899 L
s
P
p
.001 w
.99625 .67589 m
1 .67589 L
s
P
p
.001 w
.99625 .7697 m
1 .7697 L
s
P
p
.001 w
.99625 .8166 m
1 .8166 L
s
P
p
.001 w
.99625 .86351 m
1 .86351 L
s
P
p
.001 w
.99625 .91041 m
1 .91041 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
[(x [a])] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
[(y [a])] 0 1 0 -4 Mshowa
p
.002 w
0 0 m
0 1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
41 string
41 41 8 [41 0 0 41 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000102030304050608090A0A0B0C0D0D0D0E0E0E0E0E0D
0D0D0C0B0A0A0908060504030302010000
0001020304050607090A0B0C0E0F10101112121212121212
1110100F0E0C0B0A090706050403020100
01020304050608090B0D0E10111314151617171717171717
1615141311100E0D0B0908060504030201
0103040507080A0C0E1012141618191B1C1D1D1E1E1E1D1D
1C1B1918161412100E0C0A080705040301
02030507080A0D0F111417191C1E20222324252525252524
2322201E1C191714110F0D0A0807050302
030406080A0D0F1215181C1F2225282A2C2D2E2E2F2E2E2D
2C2A2825221F1C1815120F0D0A08060403
0406070A0C0F12161A1E22262A2E31343638393A3A3A3938
3634312E2A26221E1A16120F0C0A070604
0507090B0E12161A1F24292E33383C3F4244464747474644
423F3C38332E29241F1A16120E0B090705
06080A0D1115191F242A31373D43484D5053545556555453
504D48433D37312A241F1915110D0A0806
06090C0F13181D232A3239414950565B6063656667666563
605B5650494139322A231D18130F0C0906
070A0D11161B21293139434C555E656C7175777879787775
716C655E554C43393129211B16110D0A07
080B0F13181E262E37424C57626C757D83878A8C8C8C8A87
837D756C62574C42372E261E18130F0B08
090C10151B222A333E4A5663707B868E959A9D9FA09F9D9A
958E867B7063564A3E332A221B15100C09
090D11171D252E394552606F7D8A96A0A7ADB1B3B3B3B1AD
A7A0968A7D6F605245392E251D17110D09
0A0E12181F28323E4B5A6A7A8A99A6B0B9BFC3C5C6C5C3BF
B9B0A6998A7A6A5A4B3E32281F18120E0A
0B0E1319212A35425161728496A6B4BFC8CFD3D5D6D5D3CF
C8BFB4A6968472615142352A2119130E0B
0B0F141B232C384656677A8DA0B1C0CCD6DDE1E4E4E4E1DD
D6CCC0B1A08D7A675646382C231B140F0B
0B0F151B242E3A495A6C8094A8BACAD7E1E8EDEFF0EFEDE8
E1D7CABAA894806C5A493A2E241B150F0B
0B10151C252F3C4B5D70859AAEC1D1DFE9F0F5F8F9F8F5F0
E9DFD1C1AE9A85705D4B3C2F251C15100B
0B10151C25303D4C5E72879DB2C5D6E3EEF5FAFDFEFDFAF5
EEE3D6C5B29D87725E4C3D30251C15100B
0B10151D25303D4D5F73889EB3C6D7E5F0F7FCFFFFFFFCF7
F0E5D7C6B39E88735F4D3D30251D15100B
0B10151C25303D4C5E72879DB2C5D6E3EEF5FAFDFEFDFAF5
EEE3D6C5B29D87725E4C3D30251C15100B
0B10151C252F3C4B5D70859AAEC1D1DFE9F0F5F8F9F8F5F0
E9DFD1C1AE9A85705D4B3C2F251C15100B
0B0F151B242E3A495A6C8094A8BACAD7E1E8EDEFF0EFEDE8
E1D7CABAA894806C5A493A2E241B150F0B
0B0F141B232C384656677A8DA0B1C0CCD6DDE1E4E4E4E1DD
D6CCC0B1A08D7A675646382C231B140F0B
0B0E1319212A35425161728496A6B4BFC8CFD3D5D6D5D3CF
C8BFB4A6968472615142352A2119130E0B
0A0E12181F28323E4B5A6A7A8A99A6B0B9BFC3C5C6C5C3BF
B9B0A6998A7A6A5A4B3E32281F18120E0A
090D11171D252E394552606F7D8A96A0A7ADB1B3B3B3B1AD
A7A0968A7D6F605245392E251D17110D09
090C10151B222A333E4A5663707B868E959A9D9FA09F9D9A
958E867B7063564A3E332A221B15100C09
080B0F13181E262E37424C57626C757D83878A8C8C8C8A87
837D756C62574C42372E261E18130F0B08
070A0D11161B21293139434C555E656C7175777879787775
716C655E554C43393129211B16110D0A07
06090C0F13181D232A3239414950565B6063656667666563
605B5650494139322A231D18130F0C0906
06080A0D1115191F242A31373D43484D5053545556555453
504D48433D37312A241F1915110D0A0806
0507090B0E12161A1F24292E33383C3F4244464747474644
423F3C38332E29241F1A16120E0B090705
0406070A0C0F12161A1E22262A2E31343638393A3A3A3938
3634312E2A26221E1A16120F0C0A070604
030406080A0D0F1215181C1F2225282A2C2D2E2E2F2E2E2D
2C2A2825221F1C1815120F0D0A08060403
02030507080A0D0F111417191C1E20222324252525252524
2322201E1C191714110F0D0A0807050302
0103040507080A0C0E1012141618191B1C1D1D1E1E1E1D1D
1C1B1918161412100E0C0A080705040301
01020304050608090B0D0E10111314151617171717171717
1615141311100E0D0B0908060504030201
0001020304050607090A0B0C0E0F10101112121212121212
1110100F0E0C0B0A090706050403020100
00000102030304050608090A0A0B0C0D0D0D0E0E0E0E0E0D
0D0D0C0B0A0A0908060504030302010000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{321.875, 100.25},
  ImageMargins->{{36.25, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000OQ000`40l00?003`ooooU?oo003ooonD
ool00?oooiCoo`005Ooo00<03oooool03ooo0`0?0_oo00<03oooool03_oo0`0?0_oo00<03oooool0
3_oo0P0?0ooo00<03oooool04?oo00@03oooool03jcoo`0300oooooo00ooo`<03`;oo`0300oooooo
00koo`<03`;oo`0300oooooo00koo`803`?oo`0300oooooo013oo`0400oooooo00lNool001Coo`03
00ooo`0?017oo`0600oooooo00ooo`0?3ooo00L03oooooooo`0?ool03`0Aool01@0?ool03ooo00l0
3ooo0`0?00Coo`0?ool03bSoo`0300oooooo00ooo`<03`;oo`0300oooooo00koo`<03`;oo`0300oo
oooo00koo`803`?oo`0300oooooo013oo`0400oooooo00lXool00`0?ool03`0Aool01P0?ooooo`0?
ool03`ooo`0700ooooooool03ooo00l04Ooo00D03ooo00ooo`0?00ooo`<03`04ool03ooo00lMool0
01Coo`0300ooo`0?017oo`0600oooooo00ooo`0?4?oo00H03oooool03ooo00l@ool01P0?ooooo`0?
ool03`ooo`0700ooo`0?ool03ooo00l09ooo00<03ooo00l04Ooo00H03oooool03ooo00l?ool01`0?
oooooooo00ooo`0?017oo`0500ooo`0?ool03`0?ool300l01?oo00ooo`0?9ooo00<03ooo00l04Ooo
00H03oooool03ooo00l@ool01P0?ooooo`0?ool03a3oo`0600oooooo00ooo`0?3ooo00L03ooo00oo
o`0?ool03`0Mool001Coo`0300ooo`0?017oo`0600oooooo00ooo`0?3ooo00L03ooo00ooo`0?ool0
3`0Aool01@0?ool03ooo00l04?oo0P0?00Coo`0?ool03bOoo`0300ooo`0?017oo`0600oooooo00oo
o`0?4?oo00H03oooool03ooo00l@ool01P0?ooooo`0?ool03`ooo`0700ooo`0?ool03ooo00l09ooo
00<03ooo00l04Ooo00H03oooool03ooo00l?ool01`0?ool03ooo00ooo`0?017oo`0500ooo`0?ool0
3`0@ool200l01?oo00ooo`0?7Ooo000Eool00`0?ooooo`0?ool200l3ool00`0?ooooo`0?ool200l2
ool00`0?ooooo`0>ool200l3ool00`0?ooooo`0@ool0100?ooooo`0?:?oo00<03ooo00l04Ooo00H0
3oooool03ooo00l?ool01`0?ool03ooo00ooo`0?017oo`0500ooo`0?ool03`0@ool200l01?oo00oo
o`0?:?oo00<03oooool03ooo0P0?0ooo00<03oooool03ooo0P0?0_oo00<03oooool03_oo0P0?0ooo
00<03oooool04?oo00@03oooool03akoo`00NOoo0P0?1Ooo0P0?5_oo00<03oooool03ooo0P0?0ooo
00<03oooool03ooo0P0?0_oo00<03oooool03_oo0P0?0ooo00<03oooool04?oo00@03oooool03`[o
o`803`Goo`803g[oo`803`Goo`803`_oo`00NOoo00<03oooool01Ooo00<03oooool0N?oo00<03ooo
ool01Ooo00<03oooool0N?oo00<03oooool01Ooo00<03oooool02Ooo001cool00`0?ool03`03ool0
1P0?ooooo`0?ool03`;oo`0300oooooo07;oo`0300ooo`0?00?oo`0600oooooo00ooo`0?0_oo00<0
3oooool0L_oo00<03ooo00l00ooo00H03oooool03ooo00l2ool00`0?ooooo`09ool0013oo`0300oo
oooo05h03`?oo`0300oooooo00;oo`0300oooooo00803`?oo`0300oooooo00ooo`0300oooooo067o
o`0300oooooo00;oo`0300oooooo00803`?oo`0300oooooo00ooo`0400oooooooomN00l2ool00`0?
ooooo`02ool00`0?ooooo`0200l3ool00`0?ooooo`09ool000ooo`0700ooo`0?ool03ooo00l00ooo
00<03oooool00_oo00D03oooooooo`0?00?oo`0300oooooo00;oo`0500ooooooool03`03ool00`0?
ooooo`02ool01@0?oooooooo00l01?oo00D03oooooooo`0?00?oo`0300oooooo00;oo`0500oooooo
ool03`04ool01@0?oooooooo00l00ooo00<03oooool00_oo00D03oooooooo`0?00?oo`0500oooooo
ool03`03ool00`0?ooooo`02ool01@0?oooooooo00l00ooo00<03oooool03_oo00@03ooo00oooeh0
3`?oo`0300oooooo00;oo`0500ooooooool03`03ool00`0?ooooo`0>ool00`0?ool03`02ool200l4
ool01@0?oooooooo00l01?oo00D03oooooooo`0?00?oo`0300oooooo00;oo`0500ooooooool03`03
ool00`0?ooooo`02ool01@0?oooooooo00l01?oo00D03oooooooo`0?00?oo`0300oooooo00;oo`05
00ooooooool03`04ool01@0?oooooooo00l00ooo00<03oooool00_oo00D03oooooooo`0?00?oo`04
00oooooo00l4ool01@0?oooooooo00l00ooo00<03oooool02Ooo000?ool0100?ool03ooo0P0?Fooo
00H03oooool03ooo00l3ool00`0?ooooo`0200l3ool00`0?ooooo`0>ool01@0?ool03ooo00l0G?oo
00H03oooool03ooo00l3ool00`0?ooooo`0200l3ool00`0?ooooo`0>ool00`0?ool03`02ool00`0?
ooooo`1Iool200l01?oo00ooo`0?0ooo00<03oooool00P0?0ooo00<03oooool02Ooo000?ool01P0?
ool03ooo00oooeX03`03ool03ooo00Ooo`803`Goo`803a3oo`0600ooo`0?ool03ooo6P0?00D13`0?
00l03`4?00<03`050@l03`0?00l13`0300l01@4?00l03`0?0@l00`0?00D13`0?00l03`4?00<03`05
0@l03`0?00l13`0K00l00ooo00ooo`07ool200l5ool200l@ool00`0?ool03`02ool00`0?ool03`05
00l08`4?00l03`0O0@l03`4?01l13`0O0@l07`4?41l13a0O0@lA7`4?41l17a4O0@lA7`4O4Al17a4O
0AlA7`4O4Al17a4O0Al00a4O02L17a4O4AlA7`4O4Al17a4O0AlA7`4O4Al17a4O0AlA7`4?41l17a4O
0@l@7`4?4Al13a0O0@l@7`4?01l13`0O0@l07`4?00l13`0O0@l01`0?00?oo`0?ool01_oo0P0?1Ooo
0P0?2ooo000@ool01@0?ooooo`0?ool0FP0?00?oo`0?ool08Ooo00D03oooool03ooo05X03`03ool0
3ooo027oo`0600ooooooool03ooo1P0?00D@3`0?00l03a0?00<03`0I40l03a0O0@l@3`0?41l13a0O
0@l@7`4?41lA3a0O0@l@7a4?41lA3a0O4Al@7a4?41l00Q4O00HA3a0O4AlA7a4?41l24Al07Q4?41lA
7a0O4@l@7a4O41lA3a0O4@l@7`4?41lA3a0O0@l@7`4?41l13a0?00l@7`0?40l03a0?00l@3`<03`03
40l03`0?00D03`03ool03ooo01[oo`004ooo00<03ooo00l0F@0?00?oo`0?ool09?oo00<03ooo00l0
5P0?00D07`0?00l03`0O00<03`0501l03`0?00l07`0300l01P0O0@l03`0?01l13`803`0501l13`0?
00l07`0300l01@0O00l03`0?01l00`0?00D07`0?00l03`0O01H03`03ool03ooo02Goo`0300ooo`0?
00803`0H01l13`0?00l07`4?01l13`0O0@l@7`4?41l13a0O0@l@7`4O4Al17a0O0AlA7`4O314O00DA
;a4O4AlA7a4_00<A7`054BlA7a4O4AlA;`0:4Al05`4O4Al17a4O0Al@7`4O4Al13a0O0@l@7`4?01l1
3a0O0@l07`4?01l03`0O0@l00P0?00D07`0?00ooo`0?01_oo`004ooo00<03ooo00l0F@0?00?oo`0?
ool09?oo00<03ooo00l04`0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l01A0?00l03`0?
40l00`0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00<@3`0?
00l04`0?00?oo`0?ool09Ooo00<03ooo00l00`0?01P@3`0?40l03a0?00l@3`4?40l03a0O0@l@3a4?
41l13a0O4@l@7a4?41lA3a4O4@l34Al00a4?4AlA7`064Al01B4O4AlA7a4O8Al00a4O00<Q7a4O4Al0
114O00DA3a4O4AlA7a4?00<A7`0F4@l@7a4?41lA3a0O4@l@7`4?40l13a0O0@l@3`0?40l03a0?00l@
3`0?40l500l00ooo00ooo`0Jool001?oo`0300ooo`0?05T03`03ool03ooo02Coo`0300ooo`0?0140
3`050@l03`0?00l13`0300l01@4?00l03`0O0@l00P0?00H07`4?00l03`0O0@l200l01P0O0@l03`0?
01l13`803`0601l13`0?00l07`4?0P0?00<07`4?00l00P0?00D13`0?00l03`4?00<03`030@l03`0?
01403`03ool03ooo02Goo`0G00ooo`0?00l13`0?0@l07`4?01l13`0O0@l@7`4?41l13a4O0@lA7`4O
4Al17`034Al00`4O4AlA7`024Al07Q4_4QlA7a8O4BlB7a4_4QlA;a8O8BlB7a4_4QlQ;a8O4BlB7b4_
4QlA;a8O8BlB7a4_4QlA;a8O4BlB7`DA7`0G0AlA7a4O4Al17a4O0AlA7`4?41l13a0O0@l07`4?01l1
3`0O0@l03`4?01l13`0300l00ooo00ooo`0Jool001?oo`0300ooo`0?05T03`03ool03ooo02Coo`03
00ooo`0?01d03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<03`05
40l03`0?00l@3`0O00l00ooo00ooo`0Uool01@0?ool03`0?40l00`0?014@3`0?40l03a0?00l@7`4?
41l13a0O0@l@7a4?41lA3a0O00LA7`0M8AlA7a4O4AlQ7a4O8BlB7b4O4AlQ;a8O8AlA7b4_4QlQ7a4O
8BlB7b4O4AlQ;a4O8AlA7b4O4AlQ7`074Al04A0O4Al@7a4?41lA3a0O0@l@7`4?41l13a0?00l@7`0?
40l00`0?00H@3`0?00l03ooo00lKool001?oo`0300ooo`0?05T03`03ool03ooo02Coo`0300ooo`0?
00h03`0501l03`0?00l07`0300l01P0O0@l03`0?01l13`803`0N01l13`0O00l07`4?01l03`0O0@l0
7`0?01l13`0O00l07`4?01l03`0O0@l07`0?01l13`0O00l07`4?0P0?00D07`4?00l03`0O00<03`05
01l03`0?00l07`0>00l00ooo00ooo`0Uool00`0?ool03`0200l0400O0@l07`4?01l13a0O0@l@7`4?
4Al13a4O0AlA7`4O114O01@A;a8O4BlB7a4_4QlQ;a8O8BlB7b8_4QlQ;a8_8RlB;b8_4RlR;a8_0b8_
01HB;b8_4RlR;a8_8RlB;b8_4RlQ;a8_8BlB7b4_4QlQ;a8O4BlB7a4_4AlA;`8A7`0B0AlA7`4O4Al1
3a0O0Al@7`4?41l13a0O0@l07`4?01l03`0O0P0?00?oo`0?ool06_oo000Cool00`0?ool03`1I00l0
0ooo00ooo`0Tool00`0?ool03`0?00l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<03`0M40l0
3a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0300l0
1A0?00l03`0?40l00`0?00D@3`0?00l03a0?00d03`03ool03ooo02Goo`0C00oooa0?00l@3`0?40l0
3a0?0@l@3`4?41l13a0O4@l@7a4?41l00Q4O00<A3a4O4Al00Q4O02TQ7a4O8AlB7b4O4QlQ;a8O8BlR
7b4_8QlQ;b8O8BlR7b4_8QlR;b8O8BlR7b8_8QlQ;b8O8BlR7b4_8QlQ;a8O8BlB7b4_4QlQ7a4O8AlA
7b4O00HA7`0E4@l@7a4?41l13a0O0@l@7`4?40l03a0?00l@3`0?40l03a0?00ooo`0?01_oo`004ooo
00<03ooo00l0F@0?00?oo`0?ool09?oo00<03ooo00l03@0?00D13`0?00l03`4?00<03`050@l03`0?
01l13`0200l07P0O0@l03`4?01l13`0?0@l07`4?00l13`0O0@l03`4?01l13`0?0@l07`4?00l13`0O
0@l03`4?01l13`803`0601l13`0?00l07`4?0`0?00D13`0?00l03`4?00l03`03ool03ooo02Goo`0C
00ooo`0?00l13`0?0@l07`4?01l13`0O0@l@7`4?41l17a4O0Al00a4O03417a4O4QlA7a8O4BlB7a4_
4QlA;a8O8BlB7b4_4RlR;a8O8RlB;b8_4RlR;a8_8RlB;b8_4RlR;a8_8RlB;b8_4QlR;a8_8RlB7b4_
4QlQ;a8O4BlB7a4O4QlA;a8O4Al17`034Al03`4O4Al17a4O0@l@7`4?41l13`0O0@l07`4?01l13`03
00l00ooo00ooo`0Jool001?oo`0300ooo`0?05T03`03ool03ooo02Coo`0300ooo`0?01D03`0540l0
3`0?00l@3`0300l08A0?00l@3`0?40l03a0O00l@3`0?41l03a0?00l@7`0?40l03a0O00l@3`0?41l0
3a0?00l@3`0?40l03a0?00l@3`0300l00a0?00l03`0E00l00ooo00ooo`0Uool04@0?ool03`0?40l0
3a0O00l@7`0?41l13a0O4@l@7a4?41l01a4O00TQ7a4O8BlB7b4_8QlQ;b8O8Bl01b8_00Db;b8_8RlR
;c8_00<R;`05<RlR;b8_8Rlb;`068Rl02R8O8BlR;b4_4QlQ;a8O8BlB7b4O1a4O00d@7a4O41l13a0O
0@l@7`4?41l03a0O00l@3`0300l00ooo00ooo`0Jool001?oo`0300ooo`0?05T03`03ool03ooo02Co
o`0300ooo`0?00X03`0501l03`0?00l07`0300l0<P0O0@l03`0?01l13`0O00l07`4?01l13`0O0@l0
7`4?01l13a0O0@l07`4?41l13`0O0@l@7`4?01l13a0O0@l07`4?41l13`0O0@l07`4?01l13`0O00l0
7`4?01l03`0O0@l200l01@0O00l03`0?01l03P0?00?oo`0?ool09Ooo00<03ooo0@l00P0?00`07`4?
41l13a0O0@l@7`4?41l17a4O0Al54Al0218O4BlB7a4_4QlQ;a8_8Bl28Rl00a8_8RlR;`028Rl04B8o
8RlR;b8_8SlS;b8o8RlR?b<_8SlR;b8o8blR?b8_8Sl01R8_00`B;b8_8RlR;a8_8BlB7b4_4QlA;a8O
4Bl44Al04P4O4AlA7a4O0@l@7`4?41l13`0O0@l07`0?01l13`0?ool03a_oo`004ooo00<03ooo00l0
F@0?00?oo`0?ool09?oo00<03ooo00l02`0?00D@3`0?00l03a0?00<03`0a40l03a0?00l@3`0?40l0
3a0?00l@3`4?40l13a0O0@l@3`4?41l13a0O0@l@7`4?41l13a0O0@l@7`4?41l13a0O0@l@7`4?40l0
3a0O0@l@3`0?40l03a0?00l@3`0?40l00`0?00D@3`0?00l03a0?00<03`0340l03`0?00L03`03ool0
3ooo02Goo`0?00oooa0?00l@3`0?40l03a0O0@l@7a4?41lA3a0O00<A7`098AlA7b4O4AlQ7a8O8BlR
7b4_00<R;`0Q<RlR;c8_8blb;b<_<SlS;c8o<blb?c<_<Slc;c8o<blb?c<_<Slc;c8o<blb?c<_<Slc
;c8o8blb?b8_<SlR;c8_008R;`0:8QlQ;b8_8BlR7b4O4QlQ7a4O8Al24Al04A4?4AlA3a4O0@l@7`4?
41l13a0?00l@3`0?40l03ooo00l06ooo000Cool00`0?ool03`1I00l00ooo00ooo`0Tool00`0?ool0
3`0900l01@4?00l03`0?0@l00`0?03413`0?00l07`4?00l13`0O0@l07`4?01l13a0O0@l07`4?41l1
3a0O0@l@7`4?41l13a0O0@l@7`4?41l13a0O0@l@7`4?01l13a0O0@l07`4?01l13`0O0@l07`4?01l1
3`0200l00`0O0@l03`0200l01@4?00l03`0?0@l02`0?00?oo`0?ool09Ooo00l03ooo0@l07`4?01l1
3`0O0@l@7`4?41l17a4O0Al0114O00PA;a8O4BlB7a4_4RlR;a8_0b8_024S;b8o8blb?b<_<SlS;c<o
8blc?b<o<clS?c<o8clc?b<o<clS?c<o8clc?b<o<clS;c8o8clb?b<_8SlS;b8_8bl00b8_00PB;b8_
4RlR;a8O4BlB7a4_114O01017a4O0AlA7`4?41l13a0O0@l07`4?01l13`0Oool03a_oo`004ooo00<0
3ooo00l0F@0?00?oo`0?ool09?oo00<03ooo00l04@0?034@3`0?00l03a0?00l@7`0?40l03a0O0@l@
7`4?41l13a0O4@l@7a4?41lA3a0O4@l@7a4O41lA3a0O4Al@7a4?41lA3a0O0@l@7a4?41l13a0O0@l@
7`4?40l03a0O00l@3`0300l01A0?00l03`0?40l03`0?00?oo`0?ool09Ooo00d03ooo40l03a0?00l@
7`4?41lA3a0O4@l@7`054Al01R4_4QlQ;a8O8BlR7`8R;`07<RlR;c8o8blb?c<_<Sl01c<o00e3?c<o
@dld?d=?<cm3Cc@o@dlc?d=?=3m3?`03<cl02d<o<clc?c<_<Slc;c8o8blb?b8_<Rl00b8_00DQ;b8O
8BlB7b4_00DA7`0>41lA3a0O0@l@7`0?41l13a0?00l@3`0?ool03a_oo`004ooo00<03ooo00l09@0?
00D07`0?00l03`0O00<03`0501l03`0?00l07`0300l00`0O00l03`0Q00l00ooo00ooo`0Tool00`0?
ool03`0:00l01P0O00l03`0?01l13`803`0D01l13`0O0@l07`4?41l13`0O0@l@7`4?41l17a4O0@l@
7`4O4Al17`<A7`050AlA7a4O4Al17`034Al05`4O4Al17a4O0Al@7`4O41l13a0O0@l@7`4?01l13a0O
0@l07`4?01l03`0O0@l00P0?00D07`0?00l03`0O00X03`03ool03ooo02Goo`0=00ooo`4?01l13`0O
0@l@7`4?41l17a4O0Al0114O00DA;a8O8BlB7b4_00@R;`078blR?b<_<SlS?c<o8cl013<o01DcCc@o
@dld?c=?=3m3Cc@o@dld?d=?=3m3Cc@o@dld?c=?=3lcCc<o<dl00S<o00PS?c<o8clb?b<_8SlS;b8o
128_00HB7b4_4QlQ;a4O4Bl44Al0304O4Al13a0O0@l@7`4?01l13`0Oool03a_oo`004ooo00<03ooo
00l07P0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00D@3`0?
00l03a0?01h03`03ool03ooo02Coo`0300ooo`0?00L03`0540l03`0?00l@3`0300l04A0?00l@3`0?
40l03a0O0@l@7`4?41l13a0O4@l@7a4?41l00a4O014Q7a4O8AlA7b4O4AlQ7a4O8AlA7b4O4AlQ7a4O
8AlA7b4O008A7`0F4@lA7a4O4AlA3a0O4@l@7`4?41l13a0O0@l@3`0?40l03a0?00l@3`0?40l300l0
0a0?00l03`0700l00ooo00ooo`0Uool02`0?ool@3`0?41l13a0O4@l@7a4?41l00a4O00DQ7a4O8AlB
7b4_008R;`078Qlb;b8_<SlS;c8o<bl00S<o00U3?c<o@cld?d=?A3m3Cd@o@dl00dA?00UDCdA?E4m4
CeA?A4mDCdA?E4l00dA?00U3CdA?A4m4?d=?A3m3Cc@o@cl00S<o00Hc;c8o<blb?b<_<Rl28Rl01R8O
8BlR7b4O4QlQ7`8A7`0=4@l@7a4?41l13a0O0@l@7`4?40l03ooo00l06ooo000Cool00`0?ool03`0L
00l01@4?00l03`0?0@l00`0?00D13`0?00l03`4?00803`0601l13`0?00l07`4?0`0?00D13`0?00l0
3`4?00<03`030@l03`0?01X03`03ool03ooo02Coo`0300ooo`0?00T03`0G0@l03`0?01l13`0?0@l0
7`4?00l13`0O0@l@7`4?41l17a4O0@lA7`4O4Al17`044Al0514_4QlA7a8O4BlB7a4_4QlA;a8O4BlB
7a4_4QlA7a8O4AlB7a4O0Al34Al03`4O41l17a4O0@l@7`4?41l13`0O0@l03`4?01l13`0300l01@4?
00l03`0?0@l01`0?00?oo`0?ool09Ooo00/03ooo0@l07`4?41l13a0O0AlA7`4?00@A7`044BlB7b8_
4Ql48Rl0128o8blb?b<o0c<o00Td?c=?=3m4Cc@oA4ldCdA?=4l014A?00I4GdE?A4m5CdAOADl2A4l0
14AOA4m4CcA?0dA?00DdCd=?=3lcCc@o00<c?`068clc?b<_<SlR;b8o0R8_01@B7b4_4QlA;a8O4AlB
7a4O0AlA7`4O4Al13`0O0@l@7`4?01ooo`0?6ooo000Cool00`0?ool03`0P00l01A0?00l03`0?40l0
0`0?00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l00a0?00l03`0N00l00ooo00ooo`0Tool0
0`0?ool03`0=00l03A0?00l03`0?40l03a0O0@l@7`4?41l13a0O00DA7`038BlB7b4_00LR;`05<RlR
;c8_8Rlb;`068Rl01R8O8BlR7b4_4QlQ7`8A7`0:4@l@7a4O41l13a0O0@l@7`4?40l300l01A0?00l0
3`0?40l02`0?00?oo`0?ool09Ooo00/03ooo41l13a0O0@l@7`4?41lA7a0O00<A7`038AlB7b4_00<R
;`0:<RlR;c8o8blb?c<o@clc?d=?A3l2A4l02D=?A4mDCdE?E5mECeAOEDmDG`0;EEl02EAOEEmDGdE?
E5m5CeAOA4mDC`02A4l02S@o@dlc?d<o<clb?c<o<SlS;c8_0R8_00HR7b4_4QlQ;a4O8Al24Al02a4?
41lA3a0O0@l@7`4?41l13ooo00l06ooo000Cool00`0?ool03`0I00l01P0O00l03`0?01l13`803`0F
01l13`0O00l07`4?01l03`0O0@l07`0?01l13`0O00l07`4?01l03`0O0@l200l01@0O00l03`0?01l0
6`0?00?oo`0?ool09?oo00<03ooo00l01P0?00H07`0?00l03`0O0@l200l0300O0@l07`4?01l13a0O
0@l@7`4O4Al17`@A7`044BlB7b8_4Ql48Rl03B8o8blR?b<_8SlS;b8o8blR?b<_8SlR;b8o008R;`06
4RlQ;a8_8BlB7a4_0Q4O00l17a4O0AlA7`4?41l13a0O0@l07`4?01l03`0O0@l00P0?00<07`0?00l0
200?00?oo`0?ool09Ooo00T03ooo0@l@7`4?41l17a4O0Al0114O00@A;a8O8BlB7`@R;`098SlS;c8o
8clc?c@o<dld?d=?00=4C`08A5m5CeAOADmDGdEOEEm5G`]EG`09AEmEGdEOEEm5GeAOAEm4GdE?00=4
C`0:=3lcCc@o<dlS?c<o8blb?b8_8Sl28Rl01A8O8BlB7a4_4Ql00a4O00X17a0O0Al@7`4?41l13a0O
ool03a_oo`002ooo0`0?0_oo00D03oooool03ooo01L03`0540l03`0?00l@3`0300l07A0?00l@3`0?
40l03a0O0@l@3`4?41l13a0O0@l@7`4?41l13a0O0@l@3`4?41l13a0?00l@3`0?40l00`0?00D@3`0?
00l03a0?01H03`03ool03ooo01coo`<03`;oo`0500oooooo00ooo`0800l01A0?00l03`0?40l00`0?
00d@3`0?40l13a0?00l@7`4?41lA3a4O4@l@7`024Al01Q8O8AlR7b4_8QlQ;`<R;`09<RlR;c8_8Rlb
;b8_<RlR;c8_00<R;`09<RlR;b8_4QlQ;a4O8BlA7b4O008A7`0>4@l@7a4?41l13a0?00l@3`4?40l0
3a0?00l@3`<03`0340l03`0?00L03`03ool03ooo01coo`<03`;oo`0>00ooooooool03ooo40l03a0O
0@l@7a4?4AlA3`<A7`094QlQ7b8O8BlR;c8_8blb?b<_008c?`0B@dld?d=?A3mDCdE?E5mECeAOEEmU
GeEOIFmFGfE_IUmVKfIO16I_00=fKfI_IVl016I_00IVGfE_IUmUKeIOIEl2EEl02EE?E5m4CeA?A3m3
Cd@o@dld?`02<cl02c8o8blb;b8_8BlR7b4_4QlQ;a4O8Al00Q4O00TA3a0O4@l@7`4?40l03ooo00l0
6ooo000<ool02@0?ooooo`0?ool03ooo00ooo`0I00l08@4?00l03`0O0@l03`4?01l13`0O0@l07`4?
41l13a0O0@l@7`4?41l13a0O0@l@7`4?41l13`0O0@l@7`4?01l13`0200l00`0O0@l03`0200l00`4?
00l03`0F00l00ooo00ooo`0Mool02@0?ooooo`0?ool03ooo00ooo`0600l01@4?00l03`0?0@l00P0?
01@07`4?01l13`0O0@l@7`4?41l17a4O0AlA7a8O4BlB7b8_4RlR?b<_0S<o00=4Cc@oA4l00TA?00Y5
CdAOADmDGdE?A5m5CeAOADm4G`=4C`0J@dld?c<o8clR?b<_8RlB;a4_4QlA;`4O4Al17a4O0@l@7`4?
41l13`0O0@l03`4?01l13`<03`030@l03`0?00D03`03ool03ooo01goo`0600oooooo00ooo`0?0_oo
00L03ooo0@l07`4?4Al17`034Al01`4O4BlB7b4_4QlR;a8_008R;`0><SlS;c8o8clc?c@o@dldCdA?
ADm4GdE?EEm5G`9EG`08EFmFGfI_EUmVKeI_IVmFK`MVK`0HEVmVKeI_IVmFGfE_EVmUKeIOEEmFGeEO
ADm4GdE?A4ldCdA?=3m3Cb<o<clS;c8o0R8_00DB;b8_4RlA;a8O00DA7`080Al@7`4?4Al13`0Oool0
3a_oo`003?oo00L03oooool03ooo00ooo`0O00l07A0?00l03`0?40l03a0O0@l@3`0?41l13a0O0@l@
7`4?41l13a0O0@l@7`4?41l13a0?00l@3`0?40l00`0?00<@3`0?00l06P0?00?oo`0?ool07Ooo00T0
3oooool03ooo00ooo`0?ool03P0?00X@3`0?40l03a0?00l@7`4?41lA3`8A7`0;8AlA7b4_8QlQ;b8_
<Slc;c8o=3m3C`03A4l02EAOA4mDGdA?E5m5CeAOA4mDG`04A4l02S@o@dlc?c<o8Rlb;b8O8BlA7b4O
0a4O00T@7a4?41l13a0?00l@3`0?40l00`0?00<@3`0?00l02@0?00?oo`0?ool07Ooo00H03oooool0
3ooo00l2ool02@0?ool@7`4?41l13a0O4@l@7`034Al01B4O4AlQ;b8O8Bl00R8_00<S;c8o8bl00S<o
00U3?c<o@dm4?eA?A4mDGdE?E5l00UEO00IFGfEOIUmUKfIOIFl;IVl01fE_IVmUKeIOIFmEGfE_009E
G`08EDmDGdA?E4m4Cd=?A3m3?`<c?`09<SlS;b8_8RlQ;b8O8BlB7b4_00<A7`0841lA3a0O0@l@7`4?
41l13`803a_oo`003?oo00T03oooool03ooo00ooo`0?ool05P0?00d07`0?00l03`0O0@l07`4?01l1
3a0O0Al@7`034Al28Rl2<cl2A4l00c=?=3m4C`02A4l2<cl28Rl02a4O4Bl17a4O0@l@7`4?41l13`0O
0@l00P0?00<07`0?00l05@0?00?oo`0?ool07Ooo00T03oooool03ooo00ooo`0?ool01`0?00h07`0?
00l03`0O0@l07`4?01l13a0O0@l@7`4O0a4O00DB7b4_8RlR?b8_008c?`0LA5m5CfI_EVn7SgQoV9n9
SiRORInIWhV?V9n9ShRORHnHWhVOVIn9SiRORHn7SgQoIVmFKdAOA4l2<cl28Rl00b8o4QlQ;`024Al0
3@4O4Al13a0O0@l@7`4?01l13`0O00l07`4?00803`0301l03`0?00@03`03ool03ooo01goo`0600oo
oooo00ooo`0?0_oo00H03ooo0@l@7`4?41l54Al0124_4QlQ;a8_0R8_00Lb?b<_<clS?c<o=3m3C`02
A4l01dE?E5mEGeEOEVmUKeIO009VK`06MWmWKgIoIgmgOfMo17Mo00EgSgQoMgmgOgN?009gO`07Igmg
OfMoMgmWKfIoIfl00VI_00MUKeI_EEmEGeAOADmDG`02A4l01S@o@dlS?c<o8blb?`@R;`034QlA;a8O
00DA7`060@l@7`4?41ooo`0?6ooo000;ool200l3ool01@0?ooooo`0?ool05`0?00d@3`0?00l03a0?
00l@3`4?40l13a0O4@lQ7`024Al02B8O8Blc?c<oA3m4Cc<o@cm4?`02A4l013<o<blQ;b8O0Q4O00T@
7a4?41l13a0?00l@3`0?40l00`0?00<@3`0?00l0500?00?oo`0?ool07?oo0P0?0ooo00D03oooool0
3ooo00P03`0B40l03`0?00l@3`0?40l13a0?00l@7`4?41lA3a4O4@lQ7a8O0R8_024b;c<o<cm4CeA?
IUmUKgQoQgn9SiRORHnHWiV?V9n9SiR?R8nHWhV?V9nISiRORHnHSgQoQhmVGfE_A4mDCc<_<cl00b8_
014Q7a8O4AlA3a0O4@l@7`4?40l03a0?00l@3`0?40l03a0?00<03`0340l03`0?00<03`03ool03ooo
01coo`803`?oo`0<00ooooooool03ooo40l13a0O0@l@7a4?114O00<Q7a8O8Bl00R8_00/S;c8_<clc
?c<_@clc?dA?A3mDGdE?009EG`04IFmVGfE_IUl2IVl00gIoIfmfO`07Mgl00hMoMgmgO`04Mgl01WM_
MWmgKgIoIfmfK`9VK`0:EUmUKeEOEEm5CeAOADm4Cd@o@cl2<cl02S<_<RlS;b8_8QlR;b8O8BlB7b4O
0Q4O00TA3a0O4@l@7`4?40l13ooo00l06ooo000Cool00`0?ool03`0D00l03P4?00l03`0O0@l03`4?
01l17a4O4QlA;cA?A4l2Mgl07GQo<clS;b8_4RlQ;a8O4BlB7b4_4QlA;a8_8RlS;c8oN7mgOc@oA4lB
7a4O0@l@7`4O01l13`0O0@l00`0?00<13`0?00l04P0?00?oo`0?ool09?oo00<03ooo00l01@0?01l1
3`0?00l07`4?00l13`0O0@l@7`4?01l17a4O0AlA7a8O8BlR;b8o=3m3Cc@oEFmFGiRORHo;ckc?gMo=
g`03c<l02Z^_^[nJ[jZ_VYnY[iZ_ZZn[[kZo0/c?01^lcmgOcMo<ckboR9n9SfE_EUlcCc@o@dlR;b8o
4QlQ;`4O4Al17a4O0@l07`4?01l13`0O0@l00`0?00<13`0?00l01@0?00?oo`0?ool09Ooo00T03ooo
0@l@7`4O4Al17a4O4Ql00Q4O01`A;a8O8RlB;b8o8blc?b<o<dld?c=?=4m4CdE?E5mEGeE_EVmVKfM_
IWmWKgMoIgmgSgQoR8mhO`B8S`09R9n9ShRORHn8WhV?R9n8ShRO00:8S`05N7n8SgR?QhmhO`02Mgl0
17IoIfmVKeI_0UEO01]EKdE?E5ldCdA?=3lcCb<o<clS;b8o8blR;a8_8BlB7a4_4QlA7`4O4Al17a4O
0@l@7ooo00l06ooo000Cool00`0?ool03`0H00l01Q0?00l@7`0?41lA3`8A7`03@dm4?gMo009gO`0?
8blb?b8O8BlA7b4_4QlQ7a4O8BlB7b4_8Qlb?b<_009gO`0;@dld?b4O4Al@7`4?41l03a0O00l@3`0H
00l00ooo00ooo`0Tool00`0?ool03`0900l02Q0?00l03`0?40l03a0O0@l@7a4?0Q4O01dQ7a4O8RlR
;d<o<cm3CeIOIEn8SiRO_;o;cmgOg=o<cl_?c<nj_j^_ZJnZ[jV_VYnY[jZ_^[n[[l_?00;<c`0;gLoL
glbobln9SiROEEmUKc@o@clc?`028Rl03B4O4AlA7a4O41lA3a0O0@l@7`0?40l03a0?00/03`03ool0
3ooo02Goo`0600oooa0O0@l@7a4?0Q4O018Q7a4O4AlB7b4_8RlQ;b8_<Rlc;c8o<cm3?c<oA4m4?eAO
ADl2EEl01FE_IUmfOfM_MVl00WMo00IhOhMoR7n7ShR?Qhl3R8l01IR?R8nHShR?V8l00hR?00f7ShR?
QhmhOhN?Mgn7SgM_MWmVKgIoIUmUK`03EEl04EAOADm4Cd@o@clc?c8o<blb;b8_<RlR7b4_4AlQ;a4O
8Al00Q4O00L13a0O4@l@7`4?ool03`0Kool001?oo`0300ooo`0?01403`0=01l03`0?00l07`4?41l1
3`0O0AlA7a8_8Rl00_oo00/c?c=?8RlR;a8_8BlB7a4_4QlA;a8O008A7`094BlB7a4_4QlA;a8O8BlB
;b8_008c?`;oo`8R;`074Rl@7`4O41l13`0O0@l00P0?00<07`0?00l04@0?00?oo`0?ool09?oo00<0
3ooo00l01P0?00l07`0?00l03`0O0@l@7`4?41l13a0O0AlA7a8O4Bl00R8_00Dd?d=?EVmVKeI_00:Z
[`06k_o_kokoknoLglg?0k^o0ZZ_00JJWjV_VYnY[iZOZJl2ZZl3^kl03McOcLo^ono_o_o_kjZoZjmV
KeI_IVld?d=?008R;`0=4QlA;`4O4Al13a0O0@l07`4?01l03`0O0@l00P0?00<07`0?00l0100?00?o
o`0?ool09Ooo00D03ooo0Al@7`4O00<A7`054QlA;a8O8RlB7`028Rl02c8o8blc?c<oA4ldCd=?ADmD
GeEOEFl00VI_00EWKgIoN7mgSgQo00:8S`04V9n9SiVORIl2VIl069V_VYnI[iZOVJnJWjV_VYnI[iZO
VJnIWiV_RInIWhVOR9n9ShR?N8mgSgQoMWmWK`=VK`06EEmEKdE?E5ldCd=?0S<o00<S;c8o8bl00R8_
00@Q;a8_4BlB7`<A7`060AlA7`4O41ooo`0?6ooo000Cool00`0?ool03`0B00l0310?00l03`0?40l0
3a0?0@l@7a4?8RlR7`;oo`8c?`098BlR;b8_4QlQ7a4O8AlA7b4O00<A7`0:8AlA7b4O4AlQ7a8O8RlR
7d<o<cl2ool02B4_8QlR;a4?41l03a0?00l@3`0300l00a0?00l03`0@00l00ooo00ooo`0Tool00`0?
ool03`0700l05A0?00l03`0?40l03a0?0@l@7`4?4AlA3b4O4AlR;b8O@clc?fE_IUmUK`02ZZl01^o_
o^o^kok_cLoLg`>k_`0:^ZnZ[jV_VYnYWiVOZJnJWkZ_ZZl3^kl04<g?g=o_kok_k^onkjZ_^ZmVGfE_
IUm3?c<o8RlR7b4O0Q4O00XA3a0O0@l@7`4?40l03a0?00l@3`<03`0340l03`0?00<03`03ool03ooo
02Goo`0600oooa0O4@l@7a4?0Q4O00DQ7a4O8AlR7b4_008R;`098blb?c<o<cm4?d=?A3mDCdA?009E
G`0=IFmVGgIoIfn7OgMoQgn8OhN?R8nHWiV?V9l00iVO00VYWiVOZJnJWjVOVInY[iZOZIl00iVO00FH
WiV?V9n9SiR?00:8S`07Mgn7OgM_MWmVGfE_IUl00UEO00ADCdA?@dm4?`8c?`03<SlS;c8o008R;`0=
4QlQ;a4O8AlA3a4O4@l@7a4?41lA3ooo00l06ooo000Cool00`0?ool03`0C00l05P0O0@l07`4?41l1
3a4O4RlR;kbobllS;c8o4RlR;a8O4BlB7a4O4QlA;a8O0a4O01TB7a4O4AlA7a8O4AlB7a4_4QlQ;a8O
8RlS;c<o_;o;ckbo8RlB;a0O0@l07`4?01l13`0D00l00ooo00ooo`0Tool00`0?ool03`0500l0304?
00l03`0O0@l07`4?01l13a4O0@l@7`8A7`064QlQ;b<o<cmEGeE_0ZZ_00NJ[oooooonono_g=o=c`02
^kl05ZZoZjnZ_iZOZJnJWiV_VYnI[iZOVJnJWjV_ZjnZ_j^_^lnl_mcOcLonono_0_oo0jZ_00IEGeE_
8clc?a8O8Bl24Al01`4?41l13a0O0@l07`4?00<03`030@l03`0?00D03`03ool03ooo02Goo`0500oo
o`4?41l17`034Al0=A8O8BlB7b8_4RlR;b<_<clS?d=?=3m4CdE?A4m5GeEOEVmVKfM_MWmhOhN?R8n8
WhV?VIn9WiV_VYnZ[iZ_Z[n[[kZoZjnZ_j^_^[n[[kZoZjnj_j^_Z[n[[jZ_VZnZ[iZ_ZJnJWiVORIl0
0XR?01IgSgQoMgmWKgIoEVmVKdEOEEm5CdA?=3lcCb<o<clS?b8o8blR;a8_4BlB7`<A7`060AlA7`4?
41ooo`0?6ooo000Cool00`0?ool03`0D00l04A0?00l@3`4?41l13b4_8Qo;ckbo<SlS;b4_8QlQ;a8O
8Al00a4O00<Q7a4O4Al01A4O01DQ7a4O4AlA7b4O4AlQ;a8O<SlS;l_?_;o;cb8O8Bl13a0O00l@3`0?
40l0500?00?oo`0?ool09?oo00<03ooo00l02@0?00h@3`0?40l13a0?0@l@7`4?41lA7b4_4Qlb?c<_
0UEO00>Y[jZ_ZZl00_oo00C_kokocLoLg`:k_`0FZZnj[jZ_ZJnJWjVOVInYWiVOZInIWjV_VYnj[jZ_
^Znk_l^ocLoLgno_o_l2ool00jZ_ZJnZ[`02EEl03C8o<blQ;a8O41lA7a0O0@l@7`0?41l03a0?00/0
3`03ool03ooo02Goo`0500oooa0O0@l@7`034Al01B4O4AlQ;b8O8Bl00R8_00@c;c8o<cm3C`=4C`08
E5mECfE_IUmfOfM_QgmgO`:8S`0MV8nIWiROVYnYWjZ_ZJnZ[kZ_ZZnj_j^_^[n[[kZoZjnj_j^_^[n[
[kZ_ZZnY[jZOZJnIWjV_VHnHW`02R8l02GQoQgmWKgIoIfmUKfIOE5mEC`02A4l02d=?=3lb?c<_<SlR
;c8_8QlQ;a8O8Al00Q4O00LA3a0O4Al@7`4?ool03`0Kool001?oo`0300ooo`0?01403`0601l03`0O
00l07`4?0Q4O00hA;ooooolS;c8o4RlR;a8O4BlB7a4_4AlA;a8O0Q4O00DA;a4O4AlA7a4_00<A7`0<
4BlB7a4O4AlA;a8O8BlB;b4_8blb?b<_0_oo0Q4O00D07`4?01l03`0O00<03`0301l03`0?00d03`03
ool03ooo02Coo`0300ooo`0?00H03`0:01l03`0?00l07`4?41l13a0O0Al24Al01A4_8RlR;cA?A4l0
0XR?0nk_01Knono_g=o=ck_?_;nZ_j^_ZZnJ[jZ_VYnY[iZOVJnJWiV_VYnI[iZOZJnJ[`:Z[`08^[n[
[k_?_;oLglg?k_o_k`?^k`:8S`0?=4m4Cb8_8RlA7a4_0AlA7`4O01l13`0O0@l07`4?00803`0301l0
3`0?00@03`03ool03ooo02Goo`0500ooo`4O4Al17`034Al01a8O8BlB7b8_4RlR?b<_008c?`0=@dld
CeAOADmDGeIOIFmWKfIoN7mgShR?R9l00iVO00BZ[iZ_^[n[[`:k_`0?^lnl_l_?_;o;ckboblnlclc?
_;o;ckboblnl_k_?00:k_`05ZknZ_j^_ZZnJ[`02VIl2R8l02gN?N7mgSfM_IWmFGfE_ADmDGcA?A4l0
0c<o00Lb?b<_8RlR;b4_4QlA;`024Al01P4O4Al17a4Oool03a_oo`004ooo00<03ooo00l04P0?00D@
3`0?40l13a0?00<A7`;oo`0;<SlS;b4_8QlQ;a8O8AlA7b4O4AlQ7`034Al01B4O4AlA7a4O8Al00a4O
00dQ7a4O8AlA7b4O4AlQ;b8O<SlS;c8oonooo`024Al01P4?40l03a0?00l@3a803`03ool03ooo02Co
o`0300ooo`0?00L03`0:40l03`0?00l@3`0?41lA3a0O4@l24Al28Rl014=?A3n7ShR?1>k_01onolg?
g=nk_l^oZjnj[jZOZZnZWjVOVYnYWiVOZInIWjVOVInYWiZOZZnZWjV_ZZnj_k^obko=cmcOknonk`03
k^l018N?R8m3Cd@o0R8_0Q4O00T@7a4?41l13a0?00l@3`0?40l00`0?00<@3`0?00l00`0?00?oo`0?
ool09Ooo00/03ooo41lA3a4O4@lQ7a4O8BlB7b4O008R;`0?8blb;c<o<cm4?d=?ADmDGdE?IEmEGgI_
IVn7OgMo00:8S`>IW`0FZYnY[jZ_^Znk[kZo^ko;_kbobknl_l_?_;o;clboblnl_l^o_;o;_k^o^[l2
^kl01:^_^ZnZWjV_0YVO0XR?01IgOhMoMgmfKfI_IEmEGeAOADm3Cd@o<clc;c<o8Rlb?b8O8BlB7b4_
4AlQ7`8A7`054@l@7a4?ool03`0Kool001?oo`0300ooo`0?01003`0E0@l03`0?01l13a0O0@lA;a8O
4Ao_oooo8blb?a8O8RlB7b4_4QlA;a8O00<A7`034QlA7a4O00DA7`0E4QlA7a4O4BlB7a4O4QlA;a8_
8RlS;c8o8booonoo4BlB7a0O0@l07`4?00<03`030@l03`0?00h03`03ool03ooo02Coo`0300ooo`0?
00D03`0D0@l03`0?01l13`0O0@l07`4?4Al13a4O4QlA7a8_8RldCdA?N8n8S`?^k`0Pk_o_kmcOcLnk
ckbo^[n[[jZ_VZnZ[iZOVJnJWiV_VYnI[iZOVJnJWiV_VZnZ[iZ_Z[n[[k_?_;oLglg?o_o_k`?^k`0?
N8n8ScA?A4lB;b8_4QlA7`4?4Al17a0O0@l07`4?00<03`030@l03`0?00D03`03ool03ooo02Goo`04
00ooo`4?41l44Al00a8O8BlB7`028Rl04C8o8blc?c<oA4ld?dAOADmDGeIOEFmWKfIoN7mgShV?R8l0
0iVO01JZ[iZ_Z[n[[k^oZknkckboblnl_k_?_;o<ckboblnl_lc?_;nkckbo^ln[_`:k_`04Z[n[[jZ_
VZl2VIl03HRORHmgOgQoMhmWKfIoEUmEKdE?E5ld?dA?008c?`078clR?b<_8RlB;a4_4Ql01A4O00@1
3a0Oool03a_oo`004ooo00<03ooo00l0500?00H@3a4?41ld?d=?=3l2<cl01B4_8QlQ;a8O8Al00a4O
00<Q7a4O4Al03A4O00TQ7a4O8AlA7b4O4AlQ;a8O8Bl00S<o00Hd?d=?4@l@7`0?40lD00l00ooo00oo
o`0Tool00`0?ool03`0900l0310?00l@3`4?41lA3a0O0@lQ7a4O<SlS;`9EG`0;^[nk[ng_k^o]klg?
g=nk_l^oZjnj_`02ZZl01YZOZJnZWjV_VYnYW`>IW`07ZInIWjV_VYnY[jZOZJl00ZZ_00^[[kZo^ko;
_lc?g=o^gng_k^nj_k^_009EG`0;<SlS;b4O4Al@7`4?41l03a0O00l@3`0;00l00ooo00ooo`0Uool0
1@0?ool@7`4?41l00a4O00TQ;a8O8BlR;b4_8blb?c<o@cl00TA?03YECeAOEDmUKeIOMWmgKhN?R7nH
WiVOZJnZWjV_Zjnj_k^obko<_l_?c<oLclc?g=o=cmcOcLoLglg?g=o=cmcOcLoLclc?blo<_l_?^ko;
_j^_^[nZWjV_VHnHWhQoQhn8OgIoMfmUKeIOE5mECdA?A3m3?`8c?`068blb?b8_8RlB7b4_0Q4O00LA
3a0O4Al@7`4?ool03`0Kool001?oo`0300ooo`0?01403`0901l03`0O0@l@7`4O@dld?d=?008c?`07
4RlQ;a8O8BlB7a4_4Ql00Q4O00<A;a4O4Al02A4O00`A;a4O4AlA7a4_4QlA;a8O4BlB;b8_4Rl2<cl0
1d=?=3l@7`4O01l13`0O00<03`0301l03`0?00d03`03ool03ooo02Coo`0300ooo`0?00H03`0A01l0
3`0?00l07`4?41l13a0O0AlA7a8O4BlS;c8oEEmEK`02^kl02Mk_k^o^kmcOcLnkckbo^[n[[`03ZZl0
3iZOZJnJWjV_VYnI[iZOVJnJWiV_VYnY[iZOZJnJ[`02ZZl02KZoZjnkckbog=o=cnk_g^o^k`02^kl0
3eEOEFlS;c8o4QlA;`4O4Al17a0O0@l07`4?01l13`0200l00`0O00l03`0400l00ooo00ooo`0Uool0
2`0?ool17a4O0AlA7a8O4AlB7b4_4Ql00R8_00@b?b<_<clc?`94C`0gEEm5GeEOEVmVKfMoMWmhShR?
RInIWiZ_ZZnJ[kZoZknkckboc<nlclcOc<o<glg?g=o=cmcOcMoLglg?g=o=cmcOc<o<gkc?c<nlck_?
_;nj_j^_ZZnJ[iVORIn8SgR?R8mWOgIoEVmVKdEOEEl00TA?00Dc?c=?=3lb?b<_008R;`0;8BlB7a4_
4QlA7`4O4Al17a4Oool03`0Kool001?oo`0300ooo`0?01803`0=40l03a0?4@lA7gM_MgmgKb4_8QlQ
;a8O8Al00a4O00DQ7a4O4AlA7b4O00/A7`0E8AlA7a4O4AlQ7a4O8AlA7b4O4AlQ;b8O8BmgKgMo4@lA
7`0?40l03a0?01803`03ool03ooo02Coo`0300ooo`0?00L03`0B40l03`0?00l@3`0?41lA3a0O4@lQ
7a8O<Slc;gI_IVo;clbo0/c?01[Lck^obkn[[kZoZZnj[jZOZJnJWjV_VYnYWiVOZInIWjVOVInYWiVO
ZInIWjV_VYnY[jZO0ZZ_00Fj[k^_^[nk_l^o00?<c`0Ablo<_gI_IVlb?c<_8AlB7a0O4@l@7`4?40l0
3a0?00l@3`0300l00a0?00l03`0300l00ooo00ooo`0Uool02`0?ool@7a4?4AlA3b4O4AlQ;a8O8Bl0
0R8_00HS;c8o<cm3?dA?E4l3EEl03GI_IVn7OgMoV8n8SjV_VYnj[jZ_^[nk_l^o00;<c`03cLoLgmgO
00;Mg`09kMoMgng_g]o]gmgOkNoNgngO00?Mg`03g=oMcmcO00;<c`0=^ko;_j^_^ZnIWjV_RHnHShR?
QgmgOgI_IVl00UEO00eDCdA?@cld?d<o<blb?b8_<RlR7b4_4AlQ7`024Al01A4?41lA3ooo00l06ooo
000Cool00`0?ool03`0@00l04@4?00l03`0O0@lA7`4OMgmWOgMo4RlR;a8O8BlB7a4_4Ql00Q4O00<A
;a8O4Al03Q4O014B7a4O4AlA;a8O4BlB7a4_4QlR;a8_MgmWOa4O0Al07`4?00803`0301l13`0?00l0
3`03ool03ooo02Coo`0300ooo`0?00D03`0E0@l03`0?01l13`0O0@l07`4?4Al13a4O4QlA;b<o<cmW
KfIo_;o<clg?00;<c`0b^lnl_k^oZjnZ_j^_ZZnJ[jV_VYnY[iZOVJnJWiV_VYnI[iZOVJnJWiV_VYnY
[iZOZZnJ[jZ_Zjnj_j^_^lnl_lcOcLo<ckboc<mWKfIo8clc?a8O4Bl13a4O0Al@7`4?01l13`<03`03
0@l03`0?00D03`03ool03ooo02Goo`0300ooo`4?00<A7`0;4QlA;a8_8RlB7b8_8blc?b<_<dld?`02
A4l00eEOEUmEG`02IVl02gQoMgn9ShROVYnY[j^_Z[n[[k_?_;l00/c?00?Mglg?gMl00]gO00[Ngmg_
g]o]kmkOgNoNgng_g]oMk`;Mg`03cLoLglg?00;<c`0;^lnl_kZoZjnI[iZOR9n9ShRON7mgO`02IVl0
2EIOEEm4CdAO=3lcCc@o<SlS?`028Rl0124_4RlA7a8O0a4O00@13a4Oool03a_oo`004ooo00<03ooo
00l0500?00T@3a8O8BlR;c8_8RlQ;a8O8Al00a4O00<Q7a4O4Al05A4O00dQ7a4O8AlA7b4O4AlQ;b8_
<RlB7b4_00l@3`0D00l00ooo00ooo`0Tool00`0?ool03`0900l0;A0?00l03`4?40lA3a0O0@lQ7a4O
<Slc;gIoMgnj_j^_^[nk_kZoZjnj_jZ_^ZnZ[jV_ZYnY[iZOZJnJWjV_VYnYWiVOZInIWjVOVInY[iZO
ZJnJWjV_VYnY[`03ZZl05KZ_Zjnj_k^_^[nk_kZoZjmfOgMo<Slc;b4O4Al@7`4?41l03a0O00l@3`0;
00l00ooo00ooo`0Uool07P0?ool@7`4?41lA7b4O4AlQ;b8O8BlR;c8_<blb?c@o@dm4CeAOEEmUGeEO
MWmWKhN?N7nHWhV?ZJnZ[`:k_`05^[o<clc?cLoLg`02gMl00mkOkNo^k`0:k^l02Ng_k]oMgmgOkMoM
cmcOc;o;c`02^kl04ZZOZJnISiRORHn7SgQoMWmWKfEOEEmDGdA?@dlc?d=?<blb?`8R;`0;4QlQ;a4O
8AlA7a0O4Al@7`4?ool03`0Kool001?oo`0300ooo`0?01403`0A01l03a0O0@lQ;a8O<SlS;b8o4QlQ
;a8O4BlB7a4_4AlA;`034Al00a4_4AlA7`0=4Al04A4_4QlA7a4O4BlB7a4_4QlQ;a8O<SlS;b4_4Ql@
7`4?01l04`0?00?oo`0?ool09?oo00<03ooo00l01P0?00d07`0?00l03`0O0@l@7`4?41l17a4O4QlA
;`02<cl01FMoMgn[_k^oZkl00[^o00Bj_j^_Z[n[[`:Z[`0DZJnJ[jV_VYnY[iZOZJnJWiV_VYnI[iZO
VJnJWjV_VYnY[iZOZZnJ[`:Z[`0;Z[n[[kZoZjnk_j^o^kn[_k^oIgmgO`02<cl02a8O4Bl17a4O0Al0
7`4?01l03`0O0@l02@0?00?oo`0?ool09Ooo00<03ooo0Al00a4O00DB7a4_4QlQ;a8_008R;`0A<clS
?d=?=3m4GdE?IFmFGeE_IfmfOgQoQhn9WiVOVZnZ[`03^kl2c<l01]gOcLoMkmkOk^oNg`C^k`05k_o^
knk_k^o^o`02k^l02MkOkNoNgmg_gMoLglgOc<nlc`02^kl06:Z_VZnHWhVOVImhOhN?IfmfOeIOEFm5
CeAO=3m3Cc@o<clS?b8o8blR;a8O4BlB7`<A7`040AlA7ooo00lKool001?oo`0300ooo`0?01803`0=
40l03a0?8blb;b8O8BlB7b4O4AlQ7a4O8Al00a4O00DQ7a4O4AlA7b4O00/A7`058AlA7a4O4AlQ7`03
4Al03B4O4AlQ7a4O8AlR7b4_8blb;`0?40l03a0?01803`03ool03ooo02Coo`0300ooo`0?00L03`0:
40l03`0?00l@3`0?40l13a0O4@l24Al01S8o<bmfOfM_ZInJW`:Z[`03^ZnZ[jZ_00:Z[`0HZYnZ[iZO
ZJnJWjV_VYnYWiVOZInJWjVOVInYWiZOZInIWjV_VYnY[jZOZJnZWjV_0jZ_00Zj[jZ_ZZnZ[jVOVYmf
OfM_<Slc;`8A7`0541lA3a0O00l@3`0300l00a0?00l03`0700l00ooo00ooo`0Uool08`0?ool@7a4?
4AlA3b4O4AlQ;b8O8BlR;c8_<blb?d@o@dm5CeA?EUmUKeIOMWmgKhR?R7nYWiVO^ZnZ[l^o^ko;_lc?
g<l00]gO00k^gng_k^o^kno_o^o^kokoknonooo_o_o_kok_0nk_027]knkOkNoMgngOc<oLckbobknZ
[kZ_VInYWiVOR8n8OgIoMfmUKeIOE4m5Cd=?=3m3Cc<_<clR;c8_8QlQ;a4O8Al00Q4O00DA3a0O4@oo
o`0?01_oo`004ooo00<03ooo00l04`0?00X07`4?<SlS;b4_4QlR;a8O4BlB7`8A7`034BlB7a4O008A
7`034QlA7a4O00dA7`0A4QlA7a4O4BlB7a4O4QlA;a8O4BlB7b4_4Qlb?b<_01l13`0D00l00ooo00oo
o`0Tool00`0?ool03`0900l04@4?00l03`0O0@lA7`4?41lB7a4O8blb?fM_MWnJWiV_Zjl00ZZ_00>Z
_j^_ZZl00ZZ_01NJ[jZ_VYnY[iZOZJnJWiV_VYnI[iZOVJnJWiV_VYnI[iZOZJnJWjV_VZnZ[iZ_00FZ
[`0AZjnZ[iZOVJmWKgIo8blb?a8O4Al13a0O0@l07`4?01l13`0300l00`4?00l03`0500l00ooo00oo
o`0Uool00`0?ool13`034Al0518O4BlB;b8_4QlR?b<_<clS?d=?=3mDGdE?IFmFGfE_IfmfOgR?R8l2
VIl07J^_Z[nl_k_?_;o<glg?gNoNgnk_g]o^kno_o_o_knkoknooono_o_o_koookno^ono_k^oNgnk_
g^l00]gO00K<glg?^lnl_jZoZjl3VIl04gR?R8mWKgIoEUmUKdE?A5ld?dA?=3lc?b<o8RlS;b8_4RlA
;a8O00<A7`040@lA7ooo00lKool000_oo`<03`;oo`0500oooooo00ooo`0E00l01A0?<blb?a4O8Al0
0a4O00<Q7a4O4Al06A4O00DQ7a4O4AlA7b4O00<A7`058Alc;c8o00l@3`0D00l00ooo00ooo`0Lool3
00l2ool01@0?ooooo`0?ool03P0?00H@3`0?41l13a0O4Al28Rl02FE_EUnHWiV?ZJnZWjV_ZZnY[`02
ZZl06ZZOZJnZWjV_VYnY[iZOZJnJWjVOVInY[iVOZInIWjV_VYnY[iZOZJnJWjV_ZZnY[jZ_ZJl2ZZl0
1iZOZJnZWiROVHmUKeIO008R;`0541lA7a0O0@l@3`0?00l00ooo00ooo`0Lool300l2ool0:@0?oooo
oooo00oooa0O0@l@7a4O8AlA7b4_8QlQ;b8_<Rlc?c8o=3m3CdE?E5mFGfE_EUmfOfM_Qhn8SjVOVInj
_jZ_blnl_l_?cLoLgmgOkMl00^k_00K_kok_ononono_o_l3ool01Okoooonono_o^l01>k_01SMgng_
cLoLgkbobln[[kZoVInYWiVOQhn8SgIoIfmUKeIOE5m5Cd=?A3m3Cc<_<Sl28Rl02a8O8BlA7b4O4Al@
7a4O41l13ooo00l06ooo000;ool02P0?oooooooo00ooo`0?ool03ooo5P0?00Xc?b<o8BlB7a4_4QlA
;a4O4BlB7`8A7`054BlA7a4O4AlA;`0?4Al03Q4_4AlA7a4O4BlB7a4_4AlA;a8O8BlB7c<o8clF00l0
0ooo00ooo`0Lool02P0?oooooooo00ooo`0?ool03ooo2`0?00T07`0?01l03`0O0@l@7`4O4Al00R8_
00MFGfE_RInIWiZ_ZJnJ[`05ZZl05IZ_ZJnJ[jV_VYnY[iZOZJnJWiV_VYnY[iZOVJnJWjV_VYnY[iZO
ZZnJW`07ZZl01YZ_ZJn9WiVOEUmUK`8R;`070AlA7`4?41l13`0O0@l00P0?00<07`0?00l0200?00?o
o`0?ool07?oo00L03oooooooo`0?ool03`02ool00`0?ool17`034Al01a8O4BlB;b4_4RlR?b8_008c
?`09A4ld?eAOADmUKeIOIFmWOgMo00:8S`0;VYnI[j^_^[nlcl_?_;oLglgOkNoNg`02k^l01_koknon
onooooo_o`?oo`06koooonooooo_knko0nk_00_MkmkOg=o=cl_?_<nj_j^_VJnJWiV_00:8S`0AIgmg
OeIOIFm5CeAO=3m3CcA?<clS?b8o8blR;a8_4BlB7`034Al0104O4Aooo`0?6ooo000<ool01`0?oooo
o`0?ool03ooo01P03`0:<blb?a4O8AlB7b4O4AlQ7a4O8Al34Al01B4O4AlA7a4O8Al02a4O00DQ7a4O
4AlA7b4O00<A7`098AlA7b4O4AlQ7a4O8Alc;c8o01H03`03ool03ooo01goo`0900oooooo00ooo`0?
ool03ooo00`03`0A40l03a0?0@l@3`0?4AlA3c8_8RmUKeIOV9nISjV_ZYnY[`02ZZl06ZZOZZnZWjZ_
VYnY[iZOZJnJWjVOVInY[iZOZInIWjV_VYnYWiVOZJnJWjV_ZYnY[jZOZJl2ZZl04ZZOZZnZWjV_ZYnH
WiV?IFmFGc8_8RlA7a4?40l03a0O00l@3`<03`0340l03`0?00L03`03ool03ooo01goo`0600oooooo
00ooo`0?0_oo02D03ooo41lA3a4O4@lQ7a4O8BlR7b4_8Rlb;c<_<Sm4?d=?ADmDGfIOIFmFGgIoMfn8
ShQoZInIWkZoZjo;clboblo=cmcOgMo]g`03k^l01_koononooo_ooook`?oo`05ononooo_o_o_k`03
k^l07]kOkMoMcmcO_;o;cj^_^[nIWjVOVIn8ShQoMWmgKfE_EUmDGdE?@dld?d=?<blc?b8_<RlR7b4_
4AlQ7`8A7`034@l@7a4?00803a_oo`002ooo00X03ooo00ooo`0?ool03ooo00oooaH03`084Al17a4_
4QlA;a8O4BlB7`8A7`034BlB7a4O008A7`034QlA7a4O00dA7`054QlA7a4O4AlB7`024Al0214_4QlA
7a8O4BlB7a4O0AlF00l00ooo00ooo`0Lool02P0?ool03ooo00ooo`0?ool03ooo3@0?01007`4?01l1
3`0O0AlA7a8_8RmFGeEORHnHWiZOZZnJW`>Z[`0IVZnZ[iZ_ZZnJWjV_VYnY[iZOVJnJWjV_VYnI[iZO
ZJnJWiV_VYnY[iZOZJnJ[jZ_VZl00jZ_00nJ[jV_VYnZ[hV?V9mFGeEO4RlR;`4O4Al13`0O0@l00`0?
00<13`0?00l02@0?00?oo`0?ool07?oo00L03ooo00ooo`0?ool03`02ool00`0?ool13`034Al04Q8O
4BlB;b8_4RlR?b<_<clS?d=?=4mEGdE?IFmFKfI_IgmgO`:8S`0;VYnI[j^_^[nl_l_?_<oMglg?gNoN
g`02k^l01?koknooonoo1ooo00C_ooooknono`;^k`0<kno]kmkOg=o=glc?_;nj_j^_VJnJWiV_0XR?
015WOgMoEVmVKdE?E5ldCdA?=3lc?b<o8RlS;b8_4RlA;a8O00<A7`040@lA7ooo00lKool000coo`80
3`;oo`0500oooooo00ooo`0F00l0114O41lA7b4O0a4O00<Q7a4O4Al06A4O00DQ7a4O4AlA7b4O00<A
7`038AlA7a0O01H03`03ool03ooo01goo`803`;oo`0500oooooo00ooo`0>00l04A0?00l@7`0?41lA
3b4_8QmUGeEOV9n9SjV_VYnY[jZOZJl00ZZ_01ZZWjV_ZYnY[iZOZJnJWjV_VYnYWiVOZJnIWjVOVInY
[iZOZJnJWjV_VYnY[jZOZJnZWjV_0ZZ_00jJWjV_VYnHWhV?IEmEGb4_8Ql@7a4?41l03a0?3`0?00?o
o`0?ool07Ooo0P0?0_oo01`03oooooooo`0?ool@7`4?41lA7b4O4AlQ;b8O8BlR;c8_<clb?c@o@dm5
CeAOEUmUKfIOMWmgK`:8S`0;ZJnIWkZoZjo;ckbobloMcmcOg]o]k`02k^l01No_o_ooookoonl01_oo
00Cnooo_o_o_k`?^k`0;gMo]klg?g=o<_l_?Zjnj_iVOZJnIW`02R8l02gIoMfmUKfIOE5m5Cd=?A3m3
Cc<_<Sl00R8_00/R7b4_4AlQ7a4O41lA7a0O0@ooo`0?01_oo`004ooo00<03ooo00l05@0?00Xc?b<o
8BlB7a4_4QlA;a4O4BlB7`8A7`054BlA7a4O4AlA;`0?4Al03Q4_4AlA7a4O4BlB7a4_4AlA;a8O8BlB
7c<o8clF00l00ooo00ooo`0Tool00`0?ool03`0:00l02@0O00l07`0?01l13a0O0AlA7`028Rl01eIO
IFn9WiVOVZnY[iZ_00FZ[`0EVZnY[iZ_ZJnJWjV_VYnY[iZOVJnJWjV_VYnI[iZOZJnJWjV_VYnZ[iZO
00NZ[`06VZnY[hVOVImFGfE_0R8_00L17a4O0@l@7`4?01l13`0200l00`0O00l03`0800l00ooo00oo
o`0Uool00`0?ool17`034Al01a8O4BlB;b4_4RlR?b8_008c?`09A4ld?eAOADmUKeIOIFmWOgMo00:8
S`0;VYnI[j^_^[nlcl_?_;oLglgOkNoNg`02k^l01_koknononooooo_o`?oo`06koooonooooo_knko
0nk_00_MkmkOg=o=cl_?_<nj_j^_VJnJWiV_00:8S`0AIgmgOeIOIFm5CeAO=3m3CcA?<clS?b8o8blR
;a8_4BlB7`034Al0104O4Aooo`0?6ooo000Cool00`0?ool03`0E00l02S<_<SlA7b4O4QlQ7a4O8AlA
7b4O0a4O00DQ7a4O4AlA7b4O00/A7`058AlA7a4O4AlQ7`034Al02B4O4AlQ7a4O8AlA7b4O<blb?`0F
00l00ooo00ooo`0Tool00`0?ool03`0;00l04A0?00l@3`4?40l03a4O4@lb;b8_IFmFGiROVHnY[jZO
ZJl00ZZ_01ZZWjZ_ZYnZ[iZOZJnJWjV_VYnYWiVOZJnJWjVOVInY[iZOZInIWjV_VYnY[jZOZJnZWjV_
0ZZ_01:ZWjZ_ZYnY[jZOV9nISfE_EUlb;b8_4AlA3a0?00l@7`0?40l300l00a0?00l03`0700l00ooo
00ooo`0Uool09@0?ool@7a4?4AlA3b4O4AlQ;b8O8BlR;c8_<blb?d@o@dm5CeAOIUmUKeIOMWmgKhR?
R7nYWiVO^[n[[l_?c;o;clg?g=oMgngO00?^k`06o_ookokoonooooo_0ooo00Gokokoononono_00?^
k`0Ng]o]gmg?g=nl_l_?Zjnj_iVOZInIWhR?R7mfOgM_IFmFGeAOADm3Cc@o@dlc;c<o8Rlb;b8O8BlA
7b4O0Q4O00DA3a0O4@ooo`0?01_oo`004ooo00<03ooo00l04`0?00X07`4?<SlS;b4_4QlR;a8O4BlB
7`8A7`034BlB7a4O008A7`034QlA7a4O00dA7`0A4QlA7a4O4BlB7a4O4QlA;a8O4BlB7b4_4Qlb?b<_
01l13`0D00l00ooo00ooo`0Tool00`0?ool03`0900l04@4?00l03`0O0@lA7`4?41lB7a4O8blb?fM_
MWnJWiV_Zjl00ZZ_00>Z_j^_ZZl00ZZ_01NJ[jZ_VYnY[iZOZJnJWiV_VYnI[iZOVJnJWiV_VYnI[iZO
ZJnJWjV_VZnZ[iZ_00FZ[`0AZjnZ[iZOVJmWKgIo8blb?a8O4Al13a0O0@l07`4?01l13`0300l00`4?
00l03`0500l00ooo00ooo`0Uool00`0?ool13`034Al0518O4BlB;b8_4QlR?b<_<clS?d=?=3mDGdE?
IFmFGfE_IfmfOgR?R8l2VIl07J^_Z[nl_k_?_;o<glg?gNoNgnk_g]o^kno_o_o_knkoknooono_o_o_
koookno^ono_k^oNgnk_g^l00]gO00K<glg?^lnl_jZoZjl3VIl04gR?R8mWKgIoEUmUKdE?A5ld?dA?
=3lc?b<o8RlS;b8_4RlA;a8O00<A7`040@lA7ooo00lKool001?oo`0300ooo`0?01@03`0940lR;c8o
4QlQ;a8O8AlA7b4O00<A7`038AlA7a4O01DA7`0=8AlA7a4O4AlQ7a4O8AlB7b4_8Rlb?`0?40l0500?
00?oo`0?ool09?oo00<03ooo00l03@0?00@@3`4?41l13`8A7`06<SlS;gIoIVnY[iZO1:Z_01^j[jZ_
ZZnZWjV_ZYnY[iZOZJnJWjV_VYnYWiVOZJnIWjVOVInY[iZOZJnJWjV_VYnY[jZ_ZJl01jZ_00JY[iZO
MWmVKc8o8bl24Al01a0O0@l@7`0?40l03a0?00/03`03ool03ooo02Goo`0J00oooa0O0@l@7a4O8AlA
7b4_8QlQ;b8_<Rlc?c8o=3m3CdA?E5mFGfE_EUmfOfM_Qhn8S`:IW`0;^ZnZ[l_?^ko;_lc?g<oMgngO
k]o]k`03k^l02_koknonono_o_o_kokoknonono_0^k_00?]kmkOkNl00]gO00K<cmc?^ko;cjZ_^Zl3
VIl03HN?R8mfOfM_IFmFGeAOADm3Cc@o@dlc;c8o008R;`0;4QlQ;a4O8AlA7a0O4Al@7`4?ool03`0K
ool001?oo`0300ooo`0?01403`0A01l03a0O0@lQ;a8O<SlS;b8o4QlQ;a8O4BlB7a4_4AlA;`034Al0
0a4_4AlA7`0=4Al04A4_4QlA7a4O4BlB7a4_4QlQ;a8O<SlS;b4_4Ql@7`4?01l04`0?00?oo`0?ool0
9?oo00<03ooo00l01P0?00d07`0?00l03`0O0@l@7`4?41l17a4O4QlA;`02<cl01FMoMgn[_k^oZkl0
0[^o00Bj_j^_Z[n[[`:Z[`0DZJnJ[jV_VYnY[iZOZJnJWiV_VYnI[iZOVJnJWjV_VYnY[iZOZZnJ[`:Z
[`0;Z[n[[kZoZjnk_j^o^kn[_k^oIgmgO`02<cl02a8O4Bl17a4O0Al07`4?01l03`0O0@l02@0?00?o
o`0?ool09Ooo00<03ooo0Al00a4O00DB7a4_4QlQ;a8_008R;`0A<clS?d=?=3m4GdE?IFmFGeE_Ifmf
OgQoQhn9WiVOVZnZ[`03^kl2c<l01]gOcLoMkmkOk^oNg`C^k`05k_o^knk_k^o^o`02k^l02MkOkNoN
gmg_gMoLglgOc<nlc`02^kl06:Z_VZnHWhVOVImhOhN?IfmfOeIOEFm5CeAO=3m3Cc@o<clS?b8o8blR
;a8O4BlB7`<A7`040AlA7ooo00lKool001?oo`0300ooo`0?01803`0=40l03a0?4QlQ;b8_<RlS;b4O
4QlQ7a4O8Al00a4O00DQ7a4O4AlA7b4O00/A7`0E8AlA7a4O4AlQ7a4O8AlA7b4O4AlQ7a8O8AlR;c8_
4QlQ;`0?40l03a0?01803`03ool03ooo02Coo`0300ooo`0?00L03`0I40l03`0?00l@3`0?41lA3a0O
4@lQ7a4O<Slc;gMoMfnj_k^_^knk[kZoZjnj_jZ_^Zl00ZZ_01FZWjV_VYnY[iZOZInIWjVOVYnYWiVO
ZInJWjVOVInY[iZOZJnZWjV_ZYl00ZZ_01Nj[j^_^[nk[k^o^jnj_k^_MgmgKc8o<blQ7a4O41lA3a0O
0@l@3`0?40l03a0?00T03`03ool03ooo02Goo`0;00oooa0O4@lA7a4?8AlA7b4_4QlQ;`028Rl04C<_
<Sld?d=?ADmDCeEOIEmFGgI_IVn7SgQoV9nISjZ_ZYl00k^o00W<_l_?gLoLgmgOkMo^gng_k]l01>k_
00?nknk_k^l00nk_00O]kmkOkMoMgngOcLoLg`02c<l06[^_^knZ[jZ_VHnHWiV?QhmhOgI_IVmUGeIO
E4m4Cd=?=3m3?c<_<SlR;c8_8QlQ;a4O8Al24Al01A4?41lA3ooo00l06ooo000Cool00`0?ool03`0@
00l04@4?00l03`0O0@lA7`4OMgmWOgMo4RlR;a8O8BlB7a4_4Ql00Q4O00<A;a8O4Al03Q4O014B7a4O
4AlA;a8O4BlB7a4_4QlR;a8_MgmWOa4O0Al07`4?00803`0301l13`0?00l03`03ool03ooo02Coo`03
00ooo`0?00D03`0E0@l03`0?01l13`0O0@l07`4?4Al13a4O4QlA;b<o<cmWKfIo_;o<clg?00;<c`0b
^lnl_k^oZjnZ_j^_ZZnJ[jV_VYnY[iZOVJnJWiV_VYnI[iZOVJnJWiV_VYnY[iZOZZnJ[jZ_Zjnj_j^_
^lnl_lcOcLo<ckboc<mWKfIo8clc?a8O4Bl13a4O0Al@7`4?01l13`<03`030@l03`0?00D03`03ool0
3ooo02Goo`0300ooo`4?00<A7`0;4QlA;a8_8RlB7b8_8blc?b<_<dld?`02A4l00eEOEUmEG`02IVl0
2gQoMgn9ShROVYnY[j^_Z[n[[k_?_;l00/c?00?Mglg?gMl00]gO00[Ngmg_g]o]kmkOgNoNgng_g]oM
k`;Mg`03cLoLglg?00;<c`0;^lnl_kZoZjnI[iZOR9n9ShRON7mgO`02IVl02EIOEEm4CdAO=3lcCc@o
<SlS?`028Rl0124_4RlA7a8O0a4O00@13a4Oool03a_oo`004ooo00<03ooo00l0500?00d@3a4O4Amg
KgIoMglQ;b8O8AlA7b4O4AlQ7`034Al00b4O4AlA7`0=4Al03B4O4AlA7a4O8AlA7b4_4QlQ7b8_8Bmg
KgIo008A7`0300l@3`0?01<03`03ool03ooo02Coo`0300ooo`0?00T03`0A40l03a0?0@l@3a4?41l1
3b4O4Alb?c<_MVmVKl_?_;oLc`02c<l06[^obkn[[kZoZZnj[jZ_ZJnJWjV_VYnY[iZOZInIWjVOVInY
WiVOZJnJWjV_VYnY[jZOZJl2ZZl05Z^_^[nk_l^oc<oLclc?blnl_gI_IVlb?c<_8AlA7a0O0@l@7`0?
41l03a0?2`0?00?oo`0?ool09Ooo00D03ooo41l13a0O00<A7`038BlR7b4_008R;`04<blb?c<o@cl2
A4l3EEl2IVl02hMoMgnHWhR?ZInIWkZoZjnj[k^obkl00/c?00?=cmcOgMl01=gO00G]gmgOkNoNgngO
00GMg`03g=o=cmcO00;<c`0;^ko;_jZ_^[nJWjVOR8nHWhR?QgmgO`02IVl2EEl2A4l01D<o<cm3Cb<_
<Sl00R8_00<B7b4_4Al00Q4O00H@7a4O41l13ooo00lKool001?oo`0300ooo`0?01403`0401l13`0O
0@l24Al00gMoIgmgO`028Rl01a8O4BlB7a4_4AlA;a8O008A7`034BlA7a4O00dA7`084BlB7a4O4QlA
;a8O8BlB7`8R;`08MgmWOa4O4Al07`4?01l13`803`0301l03`0?00d03`03ool03ooo02Coo`0300oo
o`0?00H03`0B01l03`0?00l07`4?41l13a0O0AlA7a8O4BlS?c<oIfmVOkc?0/c?00O<glg?^lnl_kZo
ZknZ_`03ZZl06:V_VYnY[iZOZJnJWiV_VYnI[iZOVJnJWjV_VYnY[iZOZZnJ[jZoZjnj_j^_^lnl_`;<
c`0Bc=nlclc?IfmVOb<o<clB7a4_0AlA7`4O01l13`0O0@l07`4?0P0?00<07`0?00l0100?00?oo`0?
ool09Ooo00<03ooo0Al00a4O00DB7a4_4QlQ;a8_008R;`06<SlS?d=?=3m4GdE?0UEO00iEKfI_IVmg
OgN?RHnHWiZOVJn[[kZoZjnkckbo0/c?00oLglgOgMoMgmg_g]oMkmkOgNoNgng_g]oMkmkOgNl00]gO
00?=gmcOcLl00/c?00^kckboZ[n[[jV_VYn8WhV?V9mgOgN?009VK`0:EEmEKdE?A4ld?c=?=3lc?b<_
8Sl28Rl00a8O4BlB7`034Al0104O4Aooo`0?6ooo000Cool00`0?ool03`0B00l0210?00l@3`4?41m4
?d=?=3l2<cl01b4_8QlQ7a4O8AlA7b4O00<A7`038AlA7a4O00TA7`0E8AlA7a4O4AlQ7a4O8BlB7b4_
8QlQ;c<_<cm4?d=?0@l@7`0?40l03a0?01803`03ool03ooo02Coo`0300ooo`0?00L03`0>40l03`0?
00l@3`4?41lA3a0O4@lQ7a4O<RlR;`9EG`0;^[nk[nk_k]o]klg?g=nk_l^oZjnj_`02ZZl04:ZOZJnJ
WjVOVInYWiVOZInIWjVOVInYWiVOZJnJWjV_0ZZ_00^[[kZo^ko;_lg?g<o^gnk_k]nj_k^_009EG`0=
<RlR;b4O4Al@7a4?41l13a0?00l@3`0?40l00`0?00<@3`0?00l00`0?00?oo`0?ool09Ooo00/03ooo
41lA3a4O4@lQ7a4O8BlB7b4_008R;`0o8blb?c<o<cm4?d=?EDmDGeE?IFmVGgIoMfn7ShQoVInISjV_
ZYnY[j^_^[nk_l^oc;o;clc?g<o=cmc?c<oLglg?g=oMcmcOcLoLclc?g<o<cl_?c;o;ck^obknk[kZo
ZYnY[iV?VIn8OhN?R7mfOgM_IFmVGeAOEDm3CdA?008c?`09@clS;c8o8QlR;a8O8BlA7b4O008A7`05
4@l@7a4?ool03`0Kool001?oo`0300ooo`0?01003`0E0@l03`0?01l13a4O0@m3Cc@oA4lS?c<o4RlR
;a8O4BlB7a4_4AlA;a8O00<A7`034QlA7a4O00DA7`0E4QlA7a4O4AlB7a4O4QlA;a8O8BlB7b8_4Rlc
?b<o@dld?a4O0@l07`4?00<03`030@l03`0?00h03`03ool03ooo02Coo`0300ooo`0?00D03`0M0@l0
3`0?01l13`0O0@l07`4?4Al13a4O4QlA;b<_8SmFGeEOZknk_mk_k^oNklcOcLnkckbo^[n[[`02ZZl0
4:V_VZnZ[iZOVJnJWiV_VYnI[iZOVJnJWiV_VZnZ[iZO0ZZ_01Rj_j^_^lnl_mcOcLo^kmk_k^n[_k^o
EUmEGb<_8SlB7a4_0@lA7`4O41l13`0O0@l300l00`4?00l03`0500l00ooo00ooo`0Uool00`0?ool1
3`044Al0114_4QlQ;a8O0R8_040b?b<_<dld?dA?=4mEGdEOEEmFGfI_IgmgOgR?R8n9WiVOVZnZ[iZ_
^kn[[k_?_;o<ckc?c=o=cmcOcLo<glg?g=o=cmcOcLoLglg?c=o=clc?_<o<ckc?^lnl_kZoZjnZ[iZ_
VIn9WhR?N8n8SfMoMgmFGfI_AEmEGcA?A4ld?`8c?`06<SlS;b8_4RlQ;a8O1A4O00@13a4Oool03a_o
o`004ooo00<03ooo00l0500?00H@3`0?41lA7b4O4Al2ool01C8o8blQ;a8O8Al00a4O00<Q7a4O4Al0
3A4O00TQ7a4O8BlB7b4_8Qlb?b<_<Sl00_oo00HA7b4O00l@7`0?40lD00l00ooo00ooo`0Tool00`0?
ool03`0900l0210?00l@3`4?40lA3a0O0@l24Al28Rl014=?A3n8ShQo0nk_00k_kok_cLoLgk^obknZ
[kZoZYnY[jZ_ZJnJWjVO0iVO00nYWiVOZJnJWjV_ZZnY[j^_^Znk_l^ocLoLgnk_o_l00nk_00B8ShQo
@dm4?`8R;`8A7`0741l13a0O00l@7`0?40l02`0?00?oo`0?ool09Ooo00D03ooo41l13a0O00<A7`0B
8BlA7b4_8QlQ;b8_<Slc?c8oA3m3CdE?E5m4CfE_EEmfKfI_0WMo00>HShR?VIl00YVO00BZWjV_ZZnj
[`>k_`0=bknk_l_?_;o;ckboblnl_l_?_;o;ckbobkl00[^o00Jk[kZoZZnj_jZOZJl2VIl00hR?V8mg
O`02Mgl02GI_IVmUKeEOE5m4Cd=?=3lb?`02<cl01R<_<RlR;b8_4QlQ;`8A7`074@l@7a4O41l13ooo
00l06ooo000Cool00`0?ool03`0A00l01P0O00l07`0?01l13`8A7`0>4Boooooo8blb?a8_8RlB7a4_
4QlA;a4O4BlB7`8A7`054BlA7a4O4AlA;`034Al0314_4QlA7a4O4BlB7b4_4RlQ;b<_<SlS;`;oo`8A
7`0501l13`0O00l07`0300l00`0O00l03`0=00l00ooo00ooo`0Tool00`0?ool03`0600l02P0O00l0
3`0?01l13a0O0@l@7`4O0Q4O00DA;b8_8RldCdA?00:8S`?^k`0Fo_o_kmcOcLnkckboZ[n[[jZ_VZnZ
[iZOZJnJWiV_VYnI[iZOVJnJWjV_VZl2ZZl02;ZoZjnkckbog=o=cnkoknl3k^l2R8l03cA?A4lR;b8_
4AlA;`4O4Al17`0O0@l07`4?01l13`0200l00`0O00l03`0400l00ooo00ooo`0Uool01@0?ool17a4O
0Al00a4O00LB7b4_4QlR;a8_8SlS;`02<cl03D=?=4mDGdE?E5mFGfE_IfmVOgQoMhn8ShRO00>IW`04
ZZnJ[kZoZjl2^kl03k_?_;o;ckboblnl_l_?_<o<ckboblnl_l_?_;nkc`02^kl01J^oZ[n[[jZ_VZl0
0YVO0XR?00]gSgQoMhmWKfIoEUmUKdE?E5ldCdA?00<c?`07<SlS;b8_8RlQ;a8O4Bl00Q4O00H17a4O
0AlA7ooo00lKool001?oo`0300ooo`0?01803`0E40l03`0?00l@3a4?41l13b4_8Qo;ckbo<Slc;b4_
8QlQ7a4O8BlA7b4O00<A7`058AlA7a4O4AlQ7`034Al04B4O4AlQ;a8O8BlR7c8o8bo;ckbobllR7b4_
4@l@7`0?40l00`0?00<@3`0?00l0400?00?oo`0?ool09?oo00<03ooo00l01`0?01D@3`0?00l03a0?
00l@7`4?41lA3a4O4@lQ;b8O<Slc;fEOEEnZ[jZOZZl00_oo01K_kokocLoLgk^obknZ[kZ_ZZnY[jZO
ZInJWjVOVInYWiZOZJnZWkZ_ZZnj[`:k_`04cLoLgno_o_l2ool2ZZl04ZZOIEmEGc8o<blQ;b8O4AlA
3a0O4@l@7`4?40l03a0?00l@3`<03`0340l03`0?00<03`03ool03ooo02Goo`0600oooa0O4@lA7a4?
0Q4O00/Q;a8O8AlR7b4_8Rlb;c<_<Sld?d<o00=4C`09E5mECfE_EUmfOgM_QhmhOiR?00:8S`0WVHnH
WiVOZJnZWjV_ZZnj[j^_^ZnZ[kZoZjnj_j^_^[n[[kZ_ZZnj[jZ_ZJnZWjZ_VYnYWiV?VIn8SiR?Mgn7
SfM_MWmgKfE_EUmDGeE?0094C`0;@clc?c8o<blb?b8_<RlR7b4_4AlQ;`024Al01a4?4AlA3a0O4@oo
o`0?01_oo`004ooo00<03ooo00l04`0?01H07`4?01l13a0O0@lA7a8_8Rnl_l_?8blb?a8_8RlB7a4_
4QlA7a8O4BlB7`<A7`0I4QlA7a4O4AlB7a4O4QlA;a8O8BlB7b8_8blc?kboblnl_b8_4Rl@7`4?01l1
3`0O0@l0500?00?oo`0?ool09?oo00<03ooo00l01@0?00`13`0?00l07`4?01l13`0O0@lA7`4?41l2
4Al01Q8O8BlS?c<oEEmEK`:Z[`07VZooooooo_o_kmcOcLl00[^o01JZ_j^_Z[nJWjV_VYnI[iZOVJnJ
WiV_VYnY[j^_Z[n[[k_?_;oLglg?o_o_k`;oo`>Z[`06EEmEKb<o<clB7b4_0Q4O00L13a0O0@l@7`4?
01l13`0300l00`4?00l03`0500l00ooo00ooo`0Uool01@0?ool13a0O0Al00a4O03DB7b4_4QlR;a8_
8RlS;c<o8cm3Cc@oA4m5CdA?AEmEGeI_IVmWKgIoN7n7ShR?R9n9SiVORInI[iZOZZnJ[jZoZjnj_j^_
Z[n[[kZoZjnj_j^_^[n[[jZoZjnZ[iZ_ZZnJ[jV_VYnIWhVO00:8S`0FMhmhOgMoIfmfOeI_IVm5GeEO
ADm4Cc@o<dlS?c<o8clR?b<_8RlB;a4_4Ql34Al01P4O4Al13a0Oool03a_oo`004ooo00<03ooo00l0
600?00H@3`0?41l13b4_8Rl2ool2<cl01b8_8QlQ;a4O8BlA7b4O00<A7`0:8AlA7a4O4AlQ7a4O8BlB
7b4_8Rl2<cl2ool01b4_8QlQ;a4?41l03a0?01P03`03ool03ooo02Coo`0300ooo`0?00T03`0940l0
3`0?00l@3`4?41l13a0O00<A7`0?8BlR;d=?<cmUKfIOIFnZ[kZ_k^ononk_o^o=cmcO00>k_`:Z[`06
ZJnJWjV_VYnY[iZO0ZZ_0k^o00K=cmcOk^ononk_o^l2ZZl01fIOIFmVGd=?<clQ;b8_008A7`0941lA
7a0O0@l@7`0?41l03a0?00/03`03ool03ooo02Goo`0600oooa0O0@l@7a4?0Q4O00DQ7a4O8AlB7b4_
008R;`098blb?c<o<cld?d=?A3mDGdE?009EG`07IFmVGgIoIfn7OgMoQgl00XR?00B9SiR?VHnHW`>I
W`09ZInIWjVOVInY[iZOZInIWjVO00>IW`0>V9nISiROR8nHWhQoQhmgOhMoIfmfOfI_IFmVG`9EG`04
E5m5Cd=?A3l2<cl00c8o8blb?`028Rl0128O8BlA7b4O0Q4O00LA3a0O4@l@7`4?ool03`0Kool001?o
o`0300ooo`0?01403`0=01l03`0?00l07`4?41l13`0O0AlA7a8_8Rl00_oo00/c?c=?8RlR;a8_8BlB
7a4_4QlA;a8O008A7`094BlB7a4_4QlA;a8O8BlB;b8_008c?`;oo`8R;`074Rl@7`4O41l13`0O0@l0
0P0?00<07`0?00l04@0?00?oo`0?ool07?oo0P0?0ooo00D03oooool03ooo00L03`0?01l03`0?00l0
7`4?41l13a0O0@l@7`4O4AlB7a4_008R;`05=3m3CeI_IVmFK`02ZZl01^koknonono_g=o=c`>k_`:Z
[`06VYnY[iZOZJnJWjV_0ZZ_0k^o00gLglg?k_o_kokoknnZ_j^_IVmFKfI_=3m3C`028Rl03A8O4Bl1
7a4O0@l@7`4?01l13`0O00l07`4?00803`0301l03`0?00@03`03ool03ooo02Goo`0500ooo`4O41l1
7`034Al01A8O4BlB7b8_4Ql00R8_00/b?b<_<clc?dA?=4m3CdE?E5mEGeE_009VK`05IfmfOgQoMhmh
O`02R8l019RORHnIWhVO0YVO01RI[iZOVJnJWiV_VYnY[iZOVJnJWiV_VInI[hVOVIn9WhRORHn8SgR?
MhmhOgIoIfl3IVl01UEOEFm5CeAO=4m3C`8c?`038blb?b<_008R;`048BlB;a4_4Ql34Al01P4O4Al1
7a0Oool03a_oo`002ooo0P0?0ooo00D03oooool03ooo01L03`0=40l03a0?00l@3`0?41l13b4O4Am3
Cd@oQgl00WMo00lS;c8o8QlQ;a8O8AlA7b4_4QlQ7a8O8BlR7c8o<bl00WMo00e3Cd@o8AlA7a0O4@l@
7`4?40l03a0?00l@3`0F00l00ooo00ooo`0Nool0200?ool03ooo00ooo`0?ool800l0310?00l03`0?
40l03a0?0@l@3`4?41l13`8A7`0?8BlB7c8_8Rm3Cc@o@cmEGfE_RHnHSlbobloMcmcO00;<c`0Mc;nj
_k^_ZZnZWjV_VYnZ[jZO^[nk[lc?c;o<cmg?gMnl_l_?RHnHWeIOIElc?d=?=3lb;b8_8BlB7`024Al0
2a0O0@l@3`4?41l03a0?00l@3`0?40l00`0?00<@3`0?00l00`0?00?oo`0?ool07?oo0P0?0ooo00X0
3oooooooo`0?ool@7`4?41lA3`@A7`0M8AlB7b4_8QlQ;b8_<Rlc;c8o<cm3?c<o@dm4CeAOADmUGeEO
IFmVGgI_IVmfOgM_MWmgOhN?R7n7S`03R8l02IR?R8nHShR?V8n8SiR?R8nHS`02R8l01XQoQhn8OhN?
N7n7O`9gO`0FIfmfKfIOIFmEGfEOEEmDGdE?@dm4Cd<o<clb?c<_<RlR;c8_8QlR;a8O8Al24Al02A4?
4AlA3a0O4@l@7`4?ool03`0Kool000goo`0800ooo`0?ool03ooo00oooaD03`0>0@l03`0?01l13`0?
0@l07`4O4AlB7a4_=4m4C`9gO`0MN7lc?b<_8RlB;b4_4QlA;a8O8BlB7a4_4RlR;b<_<SmhOgMo=3m4
Ca8O4Al13a0O0Al07`4?01l13`0300l00`4?00l03`0B00l00ooo00ooo`0Mool02@0?ooooo`0?ool0
3ooo00ooo`0600l07`4?00l03`0O0@l03`4?01l13a0O0@l07`4O4Al17a4O4QlQ;b8_8Sld?d=?=3mE
KeIOV9n9Sl_?_<oMglgO00?<c`0:Zjnj_iZ_ZZnJWjV_VZnZ[j^_^[l2c<l06kc?gMo=glc?_;n8WhV?
IFmFGc=?=3m3Cb8_8SlB7b4_0AlA7`4O4Al13`0O0@l07`4?01l13`0300l00`4?00l03`0500l00ooo
00ooo`0Nool01@0?ool03ooo00l00_oo00T03ooo0@l@7`4O4Al17a4O4Ql00Q4O01`A;a8O8RlB;b8o
8blc?b<o<dld?c=?=4m4CdE?E5mEGeE_EVmVKfM_IWmWKgMoIgmgSgQoR8mhO`B8S`09R9n9ShRORHn8
WhV?R9n8ShRO00:8S`05N7n8SgR?QhmhO`02Mgl017IoIfmVKeI_0UEO01]EKdE?E5ldCdA?=3lcCb<o
<clS;b8o8blR;a8_8BlB7a4_4QlA7`4O4Al17a4O0@l@7ooo00l06ooo000<ool01`0?ooooo`0?ool0
3ooo01/03`0:40l03`0?00l@3`0?41l13a0O4@l34Al0128_8Blc?c8o0TA?00<c?d<oA4l00TA?00@b
?c<o8BlR7`8A7`0741l13a0O00l@7`0?40l00`0?00<@3`0?00l05P0?00?oo`0?ool07_oo00P03ooo
00ooo`0?ool03ooo2P0?010@3`0?00l03a0?00l@7`0?41l13a0O0@l@7a4O8BlB7`<R;`0><clb?dA?
A4mVGfE_Mgn7ShV?V9n8SiRORHnHW`>8S`0=V9n8SiRORHnHWhR?V9mhOhN?IUmUKdA?E4l00S<o0b8_
00lQ;a8O41lA7a0O0@l@7`4?41l03a0?00l@3`0?40l02`0?00?oo`0?ool07Ooo00H03oooool03ooo
00l2ool0200?ool@7`4?41lA3a0O4@l44Al0424O8QlQ;b8_8BlR;c8o<blb?c<o@dld?d=?A4mDGdE?
0UEO00=UKeIOIFl00VI_00IWKgI_MfmfOgM_MWl;Mgl02gIoMgmfOfM_MWmVKgIoIVmUKeIOIFl00UEO
00a5CeAOADm3CdA?@dld?c8o<clb?b<_8Bl28Rl0118O8BlA7b4_0a4O00H@7`4?41lA3a0O0@l200lK
ool000goo`0800ooo`0?ool03ooo00oooaH03`0=01l03`0?00l07`4?01l13`0O0@l@7`4O41l00a4O
0R8_0S<o0TA?00<cCc@oA4l00TA?0S<o0R8_00/A7a4_0AlA7`4?41l13a0O0@l07`4?00803`0301l0
3`0?01D03`03ool03ooo01coo`803`?oo`0500oooooo00ooo`0700l03P0O00l03`0?01l13`0O0@l0
7`4?41l13a0O0Al34Al01A8O8BlR;b8o8Rl00S<o01a4GdE?IVmFKhN?N7nHWhV?V9n9WiVORHnHWhV?
R9n9SiRORInIWhV?V9n9ShN?N7mVKeI_A5m4C`8c?`8R;`038SlB7b4_008A7`0=0AlA7`4?41l13a0O
0@l07`4?01l03`0O0@l00P0?00<07`0?00l0100?00?oo`0?ool07_oo00D03ooo00ooo`0?00;oo`06
00ooo`4?41l13a0O1A4O00@Q;a8O8BlB;`8R;`07<SlS;c<o8clc?c@o@dl00TA?00M5CeAOEEmEGeI_
IFmFG`02IVl01WIoIfmfOfMoMgmWO`AgO`05MhmhOgMoMgmgS`02Mgl01fMoMgmWOgMoIfmVOfM_009V
K`07IFmFKeEOEEmDGdE?E5l00TA?00Hd?d=?8clc?b<_<Sl48Rl00a8O4BlB7`054Al01P4?41l13a0O
ool03a_oo`002ooo0P0?0ooo00D03oooool03ooo01L03`0=40l03`0?00l@3`0?40l13a0?0@l@7a4?
8Al00Q4O00TR7b4_<clc?d@oA4lc?d<oA3l00TA?00@c?c<_8BlR7`8A7`0941lA3a0O0@l@3`0?40l0
3a0?00<03`0340l03`0?01@03`03ool03ooo02Coo`0300ooo`0?00L03`0B40l03`0?00l@3`0?40l1
3a0?00l@7`4?41lA3a4O4@lQ7a8O0R8_024b;c<o<cm4CeA?IUmUKgQoQgn9SiRORHnHWiV?V9n9SiR?
R8nHWhV?V9nISiRORHnHSgQoQhmVGfE_A4mDCc<_<cl00b8_014Q7a8O4AlA3a0O4@l@7`4?40l03a0?
00l@3`0?40l03a0?00<03`0340l03`0?00<03`03ool03ooo01coo`803`?oo`0<00ooooooool03ooo
40l13a0O0@l@7a4?114O00<Q7a8O8Bl00R8_00/S;c8_<clc?c<_@clc?dA?A3mDGdE?009EG`04IFmV
GfE_IUl2IVl00gIoIfmfO`07Mgl00hMoMgmgO`04Mgl01WM_MWmgKgIoIfmfK`9VK`0:EUmUKeEOEEm5
CeAOADm4Cd@o@cl2<cl02S<_<RlS;b8_8QlR;b8O8BlB7b4O0Q4O00TA3a0O4@l@7`4?40l13ooo00l0
6ooo000Cool00`0?ool03`0H00l08@4?00l03`0O0@l03`4?01l13`0O0@l07`4?41l13a0O0@l@7`4?
41l13a0O0@l@7`4?41l13`0O0@l@7`4?01l13`0200l00`0O0@l03`0200l00`4?00l03`0F00l00ooo
00ooo`0Tool00`0?ool03`0500l01@4?00l03`0?0@l00P0?01@07`4?01l13`0O0@l@7`4?41l17a4O
0AlA7a8O4BlB7b8_4RlR?b<_0S<o00=4Cc@oA4l00TA?00Y5CdAOADmDGdE?A5m5CeAOADm4G`=4C`0J
@dld?c<o8clR?b<_8RlB;a4_4QlA;`4O4Al17a4O0@l@7`4?41l13`0O0@l03`4?01l13`<03`030@l0
3`0?00D03`03ool03ooo02Goo`0700ooo`4?01l13a4O0Al00a4O00L17a4_4QlQ;a8O8RlB;`028Rl0
3S8o8blb?b<o<cld?d=?=4m4CdE?A5m5CeEOAEl2EEl025E_EUmVKeIOIVmFKfI_EVl7IVl065I_IVmF
KfI_EUmUKeI_IFmFGeEOEUmEGdE?A5m5CdA?=4m4Cc@o@dlS?c<o8blb?`8R;`054RlR;a8_4BlB7`05
4Al0204O41l13a4O0@l07ooo00lKool001?oo`0300ooo`0?01`03`0M40l03`0?00l@3`0?41l13a0?
00l@7`4?41l13a0O0@l@7`4?41l13a0O0@l@7`4?40l03a0?00l@3`0300l00a0?00l03`0J00l00ooo
00ooo`0Tool00`0?ool03`0=00l02Q0?00l@3`0?40l03a0O0@l@7a4?0Q4O00/Q7a4O8BlR7b4_8Rlb
?c<_<Sld?d=?00=4C`09E5m4CeAOA4mDGdE?E5m4CeAO00A4C`0:=3m3Cc<o<clR;c8_8QlQ;a4O8Al3
4Al02A0O4@l@7`4?40l03a0?00l@3`0300l00a0?00l03`0900l00ooo00ooo`0Uool02@0?ool@7`4?
41l13a0O4@l@7`034Al01B4O4AlQ;b8O8Bl00R8_00<S;c8o8bl00S<o00U3?c<o@dm4?eA?A4mDGdE?
E5l00UEO00IFGfEOIUmUKfIOIFl;IVl01fE_IVmUKeIOIFmEGfE_009EG`08EDmDGdA?E4m4Cd=?A3m3
?`<c?`09<SlS;b8_8RlQ;b8O8BlB7b4_00<A7`0:41lA3a0O0@l@7`4?41l13ooo00lKool001?oo`03
00ooo`0?01T03`0601l03`0?00l07`4?0P0?01H07`4?01l03`0O0@l07`0?01l13`0O00l07`4?01l0
3`0O0@l07`0?01l13`803`0501l03`0?00l07`0K00l00ooo00ooo`0Tool00`0?ool03`0600l01P0O
00l03`0?01l13`803`0<01l13`0O0@l07`4?41l13a0O0AlA7`4O114O00@A;a8O8RlB7`@R;`0=8SlS
;b8o8blR?b<_8SlS;b8o8blR?b8_8Sl00R8_00HB;b4_4RlQ;a8O4Bl24Al03`4O4Al17a4O0@l@7`4?
41l13`0O0@l07`0?01l13`0200l00`0O00l03`0800l00ooo00ooo`0Uool02@0?ool13a0O0@l@7`4O
4Al17`044Al0114_4QlQ;a8O128_00TR?b<_<SlS?c<o=3lcCc@o@dl00dA?00Q4GdE?E5m5CeAOAEmE
GdEO2eEO00U5GeEOAEmEGdEOE5m5GdAOADl00dA?00Xd?c=?=3lcCb<o<clS;c8o8RlR?`8R;`054QlQ
;a8O4BlB7`034Al02P4O41l17a0O0@l@7`4?41ooo`0?6ooo000Cool00`0?ool03`0J00l01A0?00l0
3`0?40l00`0?01D@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l03a0?00l@3`0?40l00`0?00D@
3`0?00l03a0?01X03`03ool03ooo02Coo`0300ooo`0?00L03`0540l03`0?00l@3`0300l03A0?00l@
3`4?40l03a0O0@l@7a4?4AlA3a0O008A7`064QlQ7b8O8BlR7b4_0b8_00Tb;b8_<RlR;c8_8Rlb;b8_
<Rl00b8_00Tb;b8_8RlB7b4_4AlQ;a4O8Al00Q4O00hA3a0O4@l@7`4?40l03a0?0@l@3`0?40l03a0?
0`0?00<@3`0?00l01`0?00?oo`0?ool09Ooo00/03ooo40l03a0O0@l@7a4?4AlA3a0O00<A7`058AlB
7b4_8QlQ;`038Rl0238o8blc?c<_@clc?d=?=3l4A4l01EA?EDmDGeE?E5l00UEO00=ECeEOEEl00UEO
00=UGeEOEEl015EO00iECeAOEDmDGdE?E5m4CeA?A3m4Cd@o@dlc?d<o0S<o00<c;c8o8bl00R8_00LQ
;b8_8BlB7b4_4AlQ7`024Al02a4?4Al13a0O0@l@7`4?40l03ooo00l06ooo000Cool00`0?ool03`0L
00l01@4?00l03`0?0@l00`0?00D13`0?00l03`4?00803`0601l13`0?00l07`4?0`0?00D13`0?00l0
3`4?00<03`030@l03`0?01X03`03ool03ooo02Coo`0300ooo`0?00T03`0G0@l03`0?01l13`0?0@l0
7`4?00l13`0O0@l@7`4?41l17a4O0@lA7`4O4Al17`044Al0514_4QlA7a8O4BlB7a4_4QlA;a8O4BlB
7a4_4QlA7a8O4AlB7a4O0Al34Al03`4O41l17a4O0@l@7`4?41l13`0O0@l03`4?01l13`0300l01@4?
00l03`0?0@l01`0?00?oo`0?ool09Ooo00/03ooo0@l07`4?41l13a0O0AlA7`4?00@A7`044BlB7b8_
4Ql48Rl0128o8blb?b<o0c<o00Td?c=?=3m4Cc@oA4ldCdA?=4l014A?00I4GdE?A4m5CdAOADl2A4l0
14AOA4m4CcA?0dA?00DdCd=?=3lcCc@o00<c?`068clc?b<_<SlR;b8o0R8_01@B7b4_4QlA;a8O4AlB
7a4O0AlA7`4O4Al13`0O0@l@7`4?01ooo`0?6ooo000Cool00`0?ool03`0/00l00a0?00l03`0Z00l0
0ooo00ooo`0Tool00`0?ool03`0=00l04A0?00l03`0?40l03a0O00l@3`0?41l13a0O4@l@7a4?41l0
0a4O014@7a4O4AlA7b4O4AlQ7a4O8AlA7b4O4AlQ7a4O8AlA7b4O00HA7`0>4@l@7a4?41l13a0O4@l@
7`4?40l03a0O00l@3`<03`0340l03`0?00d03`03ool03ooo02Goo`0=00oooa0O00l@7`0?41l13a0O
4@l@7a4?41l00a4O00DQ7a8O8BlR7b4_00<R;`04<SlR;c8o<bl2<cl01d=?<cm3?c@o@dm4?d=?00M4
C`05E4m4CdA?A4mDC`06A4l024@o@dm4?d=?=3m3Cc<o@dl2<cl013<_<Slc;c8o0b8_00LQ;b8_8BlB
7b4O4AlQ;`044Al02`4?41l13a0O0@l@7`0?41l03ooo00l06ooo000Cool00`0?ool03`0U00l01@0O
00l03`0?01l00`0?00D07`0?00l03`0O00<03`0301l03`0?02403`03ool03ooo02Coo`0300ooo`0?
00X03`0601l03`0?00l07`4?0P0?01@07`4?01l13`0O0@l@7`4?01l13a0O0@l@7`4O4Al13a0O0AlA
7`4O0a4O00D17a4O4AlA7`4O00<A7`0G0AlA7`4O4Al17a0O0Al@7`4?41l13a0O0@l07`4?41l13`0O
0@l07`0?01l13`0200l01@0O00l03`0?01l02P0?00?oo`0?ool09Ooo00d03ooo0@l07`4?01l13a0O
0@l@7`4O4Al17`044Al01A4_4QlQ;a8O8Bl0128_00LS;b8o8blb?b<o<clS?`04<cl05C=?=3m3Cc@o
<dld?d=?=3m3Cc@o@dld?d=?=3m3Cc@o<dld?c=?<clcC`02<cl022<o<clS?c8o8blR?b<_8Sl48Rl0
1Q8O8BlB7b4_4AlA;`@A7`0<0AlA7`4?41l13a0O0@l07`4?01ooo`0?6ooo000Cool00`0?ool03`0R
00l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<03`0340l03`0?02@03`03ool03ooo02Coo`03
00ooo`0?00/03`0m40l03`0?00l@3`0?40l03a0?00l@3`0?40l03a0O0@l@3`4?41l13a0O4@l@7a4?
41lA3a0O4@l@7a4?4AlA3a0O4@lA7a4?41lA3a0O4@l@7a4?41l13a0O4@l@7`4?41l03a0O0@l@3`0?
40l03a0?00l@3`0?40l00`0?00D@3`0?00l03a0?00T03`03ool03ooo02Goo`0>00oooa0?00l@7`4?
40l13a0O0@l@7a4?41lA3`<A7`074QlQ7b8O8BlB7b4_8Ql00R8_00Tb;b8_<SlS;c8o<blb?c<_<Sl0
0c<o01E3?c<o@cld?d<o<cm3Cc@o@cld?d=?=3m3?c<o@cld?d<o<cm3?c<o@cl00S<o00Hc;c8o8blb
?b8_<Rl38Rl01B4_8QlQ;a8O8Al00a4O010Q7a4O4AlA3a0O4@l@7`4?40l03a0O0@l@3`0?ool03a_o
o`004ooo00<03ooo00l0F@0?00?oo`0?ool09?oo00<03ooo00l02@0?00D13`0?00l03`4?00<03`0a
0@l03`0?01l13`0?0@l07`4?01l13`0O0@l@7`4?01l13a0O0@l@7`4?41l13a0O0@l@7`4?41l13a0O
0@l@7`4?41l13`0O0@l@7`4?01l13`0O0@l07`4?01l13`0O0@l00P0?00<07`4?00l00P0?00D13`0?
00l03`4?00/03`03ool03ooo02Goo`0?00ooo`4?01l13`0O0@l07`4?41l13a0O0AlA7`4O00@A7`08
4BlB7a4_4QlA;a8_8RlB;`<R;`0Q8blR?b<_<SlS;c8o8blc?b<_<clS?c<o8clc?b<o<clS?c<o8clc
?b<o<clS?c<o8blb?b<o<SlS;b8o8blR;b<_00<R;`084RlR;a8_8RlB7a4_4QlA;`@A7`0@0AlA7`4O
4Al13a0O0@l@7`4?01l13`0O0@l07ooo00lKool001?oo`0300ooo`0?05T03`03ool03ooo02Coo`03
00ooo`0?01403`0a40l03`0?00l@3`0?40l03a0?00l@3`0?40l03a0O0@l@7`0?41l13a0O0@l@7`4?
41l13a0O0@l@7`4?41l13a0O0@l@7`4?41l03a0O0@l@3`0?41l03a0?00l@3`0?40l00`0?00<@3`0?
00l04@0?00?oo`0?ool09Ooo01403ooo00l03a0?00l@7`4?41l13a0O0@l@7a4O41lA7a0O00<A7`08
8AlA7b4_4QlQ;b8O8RlR7`@R;`0M<RlR;c8o8blb?c<_<SlS;c8o<blb?c<_<Slc;c8o<blb?c<_<Slc
;c8o<blb?b<_<SlS;c8o8blb;`068Rl01R8O8BlR7b4_4QlQ7`<A7`0=41lA7a4O4@l@7a4?41l13a0O
00l@7`0?40l00`0?00?oo`0?ool06_oo000Cool00`0?ool03`1I00l00ooo00ooo`0Tool00`0?ool0
3`0:00l01@0O00l03`0?01l00`0?03807`4?00l03`0O0@l07`4?01l13a0O0@l07`4?41l13a0O0@l@
7`4?41l13a0O0@l@7`4?41l13a0O0@l@7`4?41l13a0O0@l@7`4?41l13`0O0@l07`4?01l13`0O00l0
7`4?0P0?00D07`0?00l03`0O00<03`0301l03`0?00P03`03ool03ooo02Goo`0=00ooo`4?01l13`0O
0@l@7`4?41l13a4O0@l0114O00TA;a4O4BlB7a4_4QlQ;a8_8Bl0128_00lS;b8o8RlR?b<_<SlS;c8o
8clc?b<o<clS?c<o8cl00c<o00lS?c<o8clc?b<o<SlS?c<o8blb?b<_<SlS;b8o8bl01B8_00HB;b4_
4QlQ;a8O4Bl64Al03P4O41l17a0O0@l07`4?01l13`0O0@l07ooo00lKool001?oo`0300ooo`0?05T0
3`03ool03ooo02Coo`0300ooo`0?00/03`0540l03`0?00l@3`0300l0;A0?00l03`0?40l03a0?00l@
3`0?40l03a0?00l@3`4?40l03a0?0@l@3`0?40l13a0?00l@3`4?40l03a0?0@l@3`0?40l03a0?00l@
3`0?40l03a0?00l@3`0300l01A0?00l03`0?40l00`0?00<@3`0?00l02`0?00?oo`0?ool09Ooo0180
3ooo40l03a0?00l@3`0?41l13a0?0@l@7`4?41lA3a4O4@l44Al03B4O4AlQ;a8O8BlB7b4_8QlQ;b8O
8RlR7b4_00<R;`0=<RlR;b8_8Rlb;b8_<RlR;c8_8Rlb;b8_<Rl00b8_00<b;b8_8Rl0128_00XR7b4_
8QlQ;a8O8BlB7b4_4QlQ7`HA7`0A4@l@7a4?41l13a0O0@l@7`4?40l03a0?00l@3`0?ool03`0Kool0
01?oo`0300ooo`0?05T03`03ool03ooo02Coo`0300ooo`0?00d03`050@l03`0?00l13`0200l0;P0O
0@l03`4?01l13`0?0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O0@l07`4?01l13`0O
0@l07`4?01l13`0O0@l07`4?01l13`0?0@l07`4?0P0?00<07`4?00l00P0?00D13`0?00l03`4?00/0
3`03ool03ooo02Goo`0C00ooo`0?01l13`0?0@l07`4?41l13a0O0@lA7`4?4Al17a4O0Al00a4O00dB
7a4_4QlQ;a8O8BlB;b8_4RlR;a8_8RlB;`048Rl03R8o8blR;b<_8SlS;b8_8blR?b<_8RlS;b8o8bl3
8Rl00b<_8RlR;`038Rl02Q8_8RlB;b4_4QlQ;a8O8BlB7a4_0Q4O00l17a4O0AlA7`4O41l17a0O0@l0
7`4?01l13`0O0@l00P0?00<07ooo00l06ooo000Cool00`0?ool03`1I00l00ooo00ooo`0Tool00`0?
ool03`0E00l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<03`0940l03`0?00l@3`0?40l03a0?
00<03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00<@3`0?00l05@0?00?oo`0?ool09Ooo
01D03ooo00l03a0?00l@3`0?40l03a0O0@l@7`4?41l13a0O4@l@7a4?41l01a4O02DQ7a4O8BlB7b4_
4QlQ;a8O8BlR7b4_8QlQ;b8O8BlR7b4_8RlQ;b8O8BlR;b4_8QlQ;b8O8BlB7b4_8QlQ;a8O8BlA7b4_
4AlQ7`074Al04A0O4Al@7a4?41lA3a0O0@l@7`0?41l03a0?00l@3`0?40l00`0?00?oo`0?ool06_oo
000Cool00`0?ool03`1I00l00ooo00ooo`0Tool00`0?ool03`0>00l01@0O00l03`0?01l00`0?00H0
7`4?00l03`0O0@l200l07P0O0@l07`0?01l13`0O00l07`4?01l03`0O0@l07`0?01l13`0O00l07`4?
01l03`0O0@l07`0?01l13`803`0501l13`0?00l07`0300l01@0O00l03`0?01l03P0?00?oo`0?ool0
9Ooo00<03ooo00l00P0?01007`4?01l13`0O0@l@7`4?41l13a4O0@lA7`4O4Al17`@A7`0D4BlB7a4_
4QlA;a8O8BlB7b4_4QlR;a8O8BlB;b8_4RlR;a8_8RlB;`<R;`0F4RlR;a8_8RlB;b8_4RlR;a8_8BlB
;b4_4QlQ;a8O8BlB7a4_4QlA;a4O4Bl24Al04P4O4Al17a4O0@l@7`4O41l13a0O0@l@7`4?01l13`0O
00l07`803`03ool03ooo01[oo`004ooo00<03ooo00l0F@0?00?oo`0?ool09?oo00<03ooo00l04`0?
00D@3`0?00l03a0?00<03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?
00<03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00<@3`0?00l04`0?00?oo`0?ool09Ooo
00<03ooo40l00`0?01@@3`0?40l03a0?00l@3`4?40l13a0O0@l@7a4?41lA3a0O4@lA7a4?114O024Q
7a4O4AlA7b4O4AlQ7a8O8AlA7b4_4QlQ7a4O8BlB7b4O4AlQ;a8O8AlA7b4_4QlQ7a4O8AlA7b4O4AlQ
7a4O8Al00Q4O01HA3a4O4AlA7a4?41lA3a0O4@l@7a4?41l13a0O00l@7`4?40l03a0?00l@3`<03`04
40l03ooo00lKool000goo`0400oooooo00l2ool00`0?ool03`1I00l00ooo00ooo`0Nool0100?oooo
o`0?0_oo00<03ooo00l04@0?00D13`0?00l03`4?00<03`050@l03`0?01l13`0200l01P0O0@l03`0?
01l13`803`0601l13`0?00l07`4?0P0?00H07`4?00l03`0O0@l200l00`0O0@l03`0200l01@4?00l0
3`0?0@l00`0?00<13`0?00l04@0?00?oo`0?ool07_oo00@03oooool03`?oo`0G00ooo`0?00l13`0?
0@l07`4?01l13`0O0@l@7`4?41l13a4O0@lA7`4O4Al17`034Al00`4O4AlA7`024Al07Q4_4QlA7a8O
4BlB7a4_4QlA;a8O8BlB7a4_4QlQ;a8O4BlB7b4_4QlA;a8O8BlB7a4_4QlA;a8O4BlB7`DA7`0G0AlA
7a4O4Al17a4O0AlA7`4?41l13a0O0@l07`4?01l13`0O0@l03`4?01l13`0300l00ooo00ooo`0Jool0
00_oo`<03`07ool03ooo00ooo`0?ool0FP0?00?oo`0?ool07?oo0`0?00Ooo`0?ool03ooo00ooo`0Z
00l01A0?00l03`0?40l0:`0?00?oo`0?ool07?oo0`0?00Coo`0?ool03`;oo`0300ooo`0?00D03`0E
40l03`0?00l@3`0?41l13a0?00l@7`4?41l13a0O0@l@7a4?41lA3a0O00<A7`0541lA7a4O4Al@7`0G
4Al06A0O4AlA7a4?41lA3a0O4@l@7a4?41l13a0O0@l@7`4?40l03a0O00l@3`0?40l03a0?00L03`03
ool03ooo01[oo`002ooo00X03ooo00ooo`0?ool03ooo00oooeX03`03ool03ooo01coo`0:00ooo`0?
ool03ooo00ooo`0?oolG00l01@0O00l03`0?01l00`0?00D07`0?00l03`0O00<03`0601l13`0?00l0
7`4?0P0?00D07`4?00l03`0O00<03`0501l03`0?00l07`0300l01@0O00l03`0?01l05P0?00?oo`0?
ool07?oo00L03ooo00ooo`0?ool03`02ool00`0?ool03`0200l0600O0@l03`0?01l13`0O0@l07`4?
41l13a0O0@l@7`4?41l17a4O0Al@7`4O4Al17``A7`054BlA7a4O4AlA;`034Al01A4_4AlA7a4O4Bl0
2Q4O01L17a4O0AlA7`4O41l17a4O0@l@7`4?41l13`0O0@l@7`4?01l13`0O00l07`4?00803`0501l0
3`0?ool03`0Kool000coo`803`05ool03ooo00ooo`1L00l00ooo00ooo`0Mool200l01ooo00ooo`0?
ool03ooo01`03`0540l03`0?00l@3`0300l01A0?00l03`0?40l00`0?00D@3`0?00l03a0?00<03`05
40l03`0?00l@3`0300l00a0?00l03`0K00l00ooo00ooo`0Mool200l01?oo00ooo`0?0_oo00<03ooo
00l00`0?02D@3`0?00l03a0?00l@3`0?40l03a0?0@l@3`0?41l13a0O0@l@7`4?41lA3a0O0@l@7a4?
41lA3a0O4@lA7a4?41lA3a4O4@l@7`024Al01Q4?41lA7a4O4@l@7`8A7`0N4@l@7a4?4AlA3a0O4@l@
7a4?41lA3a0O0@l@7a4?41l13a0O0@l@7`4?40l03a0?00l@3`0?40l03a0?0`0?00<@3`0?00l01@0?
6ooo000=ool0100?ooooo`0?0_oo00<03ooo00l0F@0?00?oo`0?ool07_oo00@03oooool03`;oo`03
00ooo`0?01T03`050@l03`0?00l13`0300l01@4?00l03`0?0@l00`0?00D13`0?00l03`4?00<03`05
0@l03`0?00l13`0300l01@4?00l03`0?0@l06`0?00?oo`0?ool07_oo00@03oooool03`?oo`0300oo
o`0?00D03`0S0@l03`0?01l13`0?0@l07`4?01l13`0O0@l@7`4?41l13a4O0@l@7`4O4Al13a4O0AlA
7`4O4Al17a4O0AlA7`4O4Al17`034Al09`4O4AlA7a4O0AlA7`4O4Al17a4O0AlA7`4O4Al17a4O0@l@
7`4O4Al13a0O0@lA7`4?41l13a0O0@l07`4?01l13`0O0@l03`4?01l13`0700l00ooo00ooo`0Jool0
01?oo`0300ooo`0?05T03`03ool03ooo02Coo`0300ooo`0?05T03`03ool03ooo02Goo`0300ooo`0?
00D03`0540l03`0?00l@3`0300l06A0?00l@7`4?40l03a0O0@l@7`4?41l13a0O4@l@7`4?41lA3a0O
4@l@7a4O41lA3a0O008A7`064@l@7a4O4AlA3a0O0Q4O01hA3a0O4Al@7a4?41lA7a0O4@l@7a4?41l1
3a0O4@l@7`4?41l13a0O0@l@3`0?41l03a0?00l@3`0?40l300l00a0?00l03`0500l00ooo00ooo`0J
ool001?oo`0300ooo`0?01Goo`0300oooooo01?oo`0300oooooo01?oo`0300oooooo01;oo`0500oo
ooooool03`0Uool00`0?ool03`03ool01@0?oooooooo00l01?oo00D03oooooooo`0?00Coo`0500oo
ooooool03`03ool00`0?ooooo`02ool01@0?oooooooo00l00ooo00<03oooool00_oo00D03ooooooo
o`0?00Coo`0500ooooooool03`03ool00`0?ooooo`02ool01@0?oooooooo00l00ooo00<03oooool0
0_oo00D03oooooooo`0?00?oo`0300oooooo02Coo`803aGoo`0300oooooo01?oo`0300oooooo01?o
o`0300oooooo01?oo`0500ooooooool03`0Kool001?ooeh03bGooeh03bKooeh03a_oo`00ooooU?oo
003ooonDool003ooo`0300oooooo00;oo`0300oooooo07_oo`0300oooooo00;oo`0300oooooo07_o
o`0300oooooo00;oo`0300oooooo04Koo`00?_oo00<03oooool01?oo00<03oooool0NOoo00<03ooo
ool01?oo00<03oooool0NOoo00<03oooool01?oo00<03oooool0AOoo000nool00`0?ool03`0200l2
ool00`0?ooooo`1iool00`0?ool03`0200l2ool00`0?ooooo`1iool0100?ool03`0?0ooo00<03ooo
ool0AOoo000mool01@0?oooooooo00l01?oo00<03oooool0Mooo00@03oooool03`Goo`0300oooooo
07Ooo`0300oooooo00;oo`0500ooooooool03`16ool003koo`0400oooooo00l3ool00`0?ooooo`1i
ool0100?ooooo`0?0ooo00<03oooool0NOoo00@03oooool03`?oo`0300oooooo04Goo`00?_oo00@0
3oooool03`?oo`0300oooooo07Woo`0500ooo`0?ool03`02ool00`0?ooooo`1iool01@0?oooooooo
00l00_oo00<03oooool0AOoo000oool300l2ool00`0?ooooo`1kool01P0?ool03`0?ool03ggoo`<0
3`;oo`0300oooooo04Koo`003Ooo00<03oooool00ooo0P0?1?oo0P0?M?oo00<03oooool00ooo0P0?
1Ooo0P0?MOoo00<03oooool00ooo0P0?1?oo0P0?L_oo000>ool00`0?ooooo`02ool00`0?ooooo`04
ool00`0?ooooo`1cool00`0?ooooo`02ool00`0?ooooo`05ool00`0?ooooo`1dool00`0?ooooo`02
ool00`0?ooooo`04ool00`0?ooooo`1`ool000koo`0300oooooo00;oo`0500ooo`0?ool03`02ool0
0`0?ooooo`1cool00`0?ooooo`02ool01P0?ooooo`0?ool03`;oo`0300oooooo07Coo`0300oooooo
00;oo`0500ooo`0?ool03`02ool00`0?ooooo`1`ool000goo`0300ooo`0?00?oo`0400ooo`0?00l3
ool00`0?ooooo`1bool00`0?ool03`03ool00`0?ooooo`0200l3ool00`0?ooooo`1cool00`0?ool0
3`03ool0100?ool03`0?0ooo00<03oooool0L?oo000=ool00`0?ool03`03ool0100?ooooo`0?0ooo
00<03oooool0L_oo00<03ooo00l00ooo00D03oooooooo`0?00?oo`0300oooooo07?oo`0300ooo`0?
00?oo`0400oooooo00l3ool00`0?ooooo`1`ool000goo`0300ooo`0?00?oo`0400ooo`0?00l3ool0
0`0?ooooo`1bool00`0?ool03`03ool00`0?ooooo`0200l3ool00`0?ooooo`1cool00`0?ool03`03
ool0100?ool03`0?0ooo00<03oooool0L?oo000Cool200l4ool200mjool200l5ool200mkool200l4
ool200mbool00?oooiCoo`00ooooU?oo003ooonDool00?oooiCoo`00\
\>"],
  ImageRangeCache->{{{0, 401.3125}, {124.3125, 0}} -> {-0.889798, -0.713681, 
  0.132919, 0.132919}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"NeXT 3.0",
ScreenRectangle->{{0, 957}, {0, 768}},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Automatic,
WindowSize->{520, 600},
WindowMargins->{{Automatic, 146}, {Automatic, -1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"NeXTAutomaticEncoding",
Magnification->1.25
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 92, 2, 122, "Title"],
Cell[1826, 55, 55, 1, 31, "Input"],
Cell[1884, 58, 87, 2, 64, "Section"],
Cell[1974, 62, 85, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[2084, 68, 89, 2, 64, "Section"],
Cell[2176, 72, 2606, 49, 1176, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4819, 126, 97, 2, 64, "Section"],
Cell[4919, 130, 117, 3, 74, "Input"],
Cell[5039, 135, 219, 5, 104, "Input"],
Cell[5261, 142, 140, 3, 65, "Input"],
Cell[5404, 147, 77, 2, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5518, 154, 95, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[5638, 160, 96, 2, 54, "Subsection"],
Cell[5737, 164, 192, 5, 74, "Input"],
Cell[5932, 171, 232, 5, 107, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6201, 181, 94, 2, 54, "Subsection"],
Cell[6298, 185, 99, 2, 55, "Input"],
Cell[6400, 189, 134, 3, 48, "Input"],
Cell[6537, 194, 332, 7, 159, "Input"],
Cell[6872, 203, 332, 7, 159, "Input"],
Cell[7207, 212, 114, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[7346, 219, 123, 2, 51, "Subsubsection"],

Cell[CellGroupData[{
Cell[7494, 225, 439, 9, 133, "Input"],
Cell[7936, 236, 28942, 1289, 149, 22648, 1207, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36927, 1531, 123, 2, 51, "Subsubsection"],

Cell[CellGroupData[{
Cell[37075, 1537, 430, 9, 150, "Input"],
Cell[37508, 1548, 26369, 1231, 146, 22342, 1177, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63926, 2785, 116, 2, 51, "Subsubsection"],

Cell[CellGroupData[{
Cell[64067, 2791, 250, 6, 101, "Input"],
Cell[64320, 2799, 43699, 1095, 148, 16172, 751, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108056, 3899, 250, 6, 101, "Input"],
Cell[108309, 3907, 43526, 1093, 147, 16172, 751, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[151896, 5007, 94, 2, 54, "Subsection"],
Cell[151993, 5011, 122, 3, 48, "Input"],
Cell[152118, 5016, 102, 2, 31, "Input"],
Cell[152223, 5020, 422, 9, 116, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[152682, 5034, 109, 2, 54, "Subsection"],
Cell[152794, 5038, 113, 2, 55, "Input"],
Cell[152910, 5042, 81, 2, 44, "Input"],

Cell[CellGroupData[{
Cell[153016, 5048, 479, 10, 188, "Input"],
Cell[153498, 5060, 100403, 4437, 150, 82353, 4210, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[253916, 9500, 258, 6, 132, "Input"],

Cell[CellGroupData[{
Cell[254199, 9510, 111, 2, 51, "Subsubsection"],

Cell[CellGroupData[{
Cell[254335, 9516, 248, 6, 99, "Input"],
Cell[254586, 9524, 44633, 1106, 148, 16208, 751, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[299268, 10636, 111, 2, 51, "Subsubsection"],

Cell[CellGroupData[{
Cell[299404, 10642, 248, 6, 99, "Input"],
Cell[299655, 10650, 44897, 1110, 148, 16208, 751, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[344625, 11768, 86, 2, 64, "Section"],
Cell[344714, 11772, 51, 1, 31, "Input"],
Cell[344768, 11775, 171, 4, 67, "Input"],
Cell[344942, 11781, 182, 3, 48, "Input"],

Cell[CellGroupData[{
Cell[345149, 11788, 84, 2, 54, "Subsection"],
Cell[345236, 11792, 419, 9, 189, "Input"],
Cell[345658, 11803, 276, 6, 116, "Input"],
Cell[345937, 11811, 239, 5, 115, "Input"],
Cell[346179, 11818, 155, 4, 65, "Input"],

Cell[CellGroupData[{
Cell[346359, 11826, 116, 2, 51, "Subsubsection"],
Cell[346478, 11830, 380, 8, 186, "Input"],

Cell[CellGroupData[{
Cell[346883, 11842, 270, 6, 48, "Input"],
Cell[347156, 11850, 85470, 2760, 136, 50185, 2320, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[432663, 14615, 257, 6, 205, "Input"],
Cell[432923, 14623, 476, 12, 82, "Output"]
}, Open  ]],
Cell[433414, 14638, 380, 8, 186, "Input"],

Cell[CellGroupData[{
Cell[433819, 14650, 270, 6, 48, "Input"],
Cell[434092, 14658, 83432, 2735, 136, 50185, 2320, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[517539, 17396, 381, 8, 186, "Input"],

Cell[CellGroupData[{
Cell[517945, 17408, 274, 6, 48, "Input"],
Cell[518222, 17416, 83043, 2730, 123, 50185, 2320, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[601326, 20153, 94, 2, 54, "Subsection"],
Cell[601423, 20157, 267, 6, 116, "Input"],
Cell[601693, 20165, 341, 7, 178, "Input"],
Cell[602037, 20174, 266, 6, 115, "Input"],
Cell[602306, 20182, 155, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[602498, 20191, 109, 2, 54, "Subsection"],
Cell[602610, 20195, 90, 2, 31, "Input"],
Cell[602703, 20199, 182, 5, 111, "Input"],
Cell[602888, 20206, 137, 3, 79, "Input"],
Cell[603028, 20211, 397, 8, 191, "Input"],

Cell[CellGroupData[{
Cell[603450, 20223, 274, 6, 48, "Input"],
Cell[603727, 20231, 85889, 2556, 136, 36139, 1936, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[689653, 22792, 251, 6, 167, "Input"],
Cell[689907, 22800, 473, 12, 82, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[690441, 22819, 101, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[690567, 22825, 94, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[690686, 22831, 265, 6, 156, "Input"],
Cell[690954, 22839, 28718, 1053, 114, 16215, 893, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[719721, 23898, 89, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[719835, 23904, 281, 6, 173, "Input"],
Cell[720119, 23912, 29241, 1089, 114, 16205, 922, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[749409, 25007, 30, 0, 54, "Subsection"],
Cell[749442, 25009, 86299, 2872, 136, 25271, 2113, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

