(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    101794,       2948]*)
(*NotebookOutlinePosition[    102735,       2980]*)
(*  CellTagsIndexPosition[    102691,       2976]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["V-SHAPED CANTILEVERS"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Remove["\<Global`*\>"]\)], "Input"],

Cell[TextData["Highlights"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Abstract"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Introduction"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Off[General::"\<spell\>", General::"\<spell1\>"]; \)\), 
    \(\(Needs["\<Graphics`Arrow`\>"]; \)\), 
    \(tera = 10\^12; micro = 1\/10\^6; \), 
    \(giga = 10\^9; nano = 1\/10\^9; \), 
    \(mega = 10\^6; pico = 1\/10\^12; \), 
    \(kilo = 10\^3; femto = 1\/10\^15; \), 
    \(milli = 1\/10.\^3; atto = 1\/10\^18; \), 
    \(\(NSub
       = {c \[Rule] 2.99792458\ 10\^8, e \[Rule] 1.6021773\/10\^19, 
        h \[Rule] 6.6260755\/10.\^34, hbar \[Rule] 1.05457\/10.\^34, 
        K \[Rule] 1.380658\/10\^23, me \[Rule] 9.109389\/10\^31, 
        mu0 \[Rule] \(4.\ \[Pi]\)\/10\^7, eps0 \[Rule] 8.85419\/10\^12}; \)\),
   
    \(ESi = 0.179\ tera; rhoSi = 2330; nuSi = 0.28; \), 
    \(ESiO2 = 0.06\ tera; rhoSiO2 = 2200; nuSiO2 = 0.3; \), 
    \(ESi3N4 = 0.15\ tera; rhoSi3N4 = 3100; nuSi3N4 = 0.24; \), 
    \(EAu = 0.08\ tera; rhoAu = 19300; nuAu = 0.42; \), 
    \(ENi = 0.207\ tera; rhoNi = 8900; nuNi = 0.41; \), 
    \(EW = 0.345\ tera; rhoW = 19300; nuW = 0.28; \), 
    \(EPt = 0.17\ tera; rhoPt = 21400; nuPt = 0.39; \), 
    \(EIr = 0.52\ tera; rhoIr = 22500; nuIr = 0.3; \), 
    \(EHOPG = 0.2\ tera; rhoHOPG = 2250; nuHOPG = 0.3; \), 
    \(EPol = 0.001\ tera; rhoPol = 1000; nuPol = 0.3; \), 
    \(\(xx = 0.8; \)\), 
    \(\(EPtIr = xx\ 0.8\ EPt + \((1 - xx)\)\ EIr; \)\), 
    \(\(rhoPtIr = xx\ rhoPt + \((1 - xx)\)\ rhoIr; \)\), 
    \(\(nuPtIr = 0.3; \)\), 
    \(\(opt
       = {PlotRange \[Rule] All, AxesOrigin \[Rule] {0, 0}, 
        Frame \[Rule] True, GridLines \[Rule] Automatic, 
        DefaultFont \[Rule] {"\<Times-Roman\>", 8}, 
        PlotStyle 
          \[Rule] {Dashing[{.0001}], Dashing[{.0200}], Dashing[{.0500}], 
            Dashing[{.0200}], Dashing[{.0200}], Dashing[{.0001}]}}; \)\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Operating Conditions"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.47619 0.007007 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.02381 0.007007 0.477324 0.287295 MathSubStart
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.02381 0.952381 0.014715 0.952381 [
[(\\(a\\))] .5 .61803 0 -2 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
0 .61803 m
1 .61803 L
s
P
[(\\(a\\))] .5 .61803 0 -2 Mshowa
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.02381 0.014715 0.97619 0.603319 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.4884 0.014715 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.36569 .26193 m
.85409 .26193 L
.85409 .28547 L
.36569 .28547 L
.36569 .60332 L
.36569 .25016 L
.02381 .25016 L
.02381 .60332 L
.36569 .60332 L
s
.80525 .26193 m
.82967 .1913 L
.85409 .26193 L
s
.02381 .01472 m
.85409 .01472 L
.85409 .07358 L
.65873 .07358 L
.65873 .10301 L
.56105 .10301 L
.56105 .07358 L
.02381 .07358 L
.02381 .01472 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(sample)] .51221 .04415 0 0 Mshowa
P
p
/Times-Roman findfont 8 scalefont setfont
[(L)] .60989 .4856 0 0 Mshowa
P
.41502 .4856 m
.36618 .4856 L
.3906 .47971 L
.3906 .49148 L
.36618 .4856 L
s
.80281 .4856 m
.85165 .4856 L
.82723 .47971 L
.82723 .49148 L
.85165 .4856 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(d)] .46337 .39731 0 0 Mshowa
P
.46337 .19718 m
.46337 .25604 L
.45849 .22661 L
.46825 .22661 L
.46337 .25604 L
s
.46337 .35022 m
.46337 .29136 L
.45849 .32079 L
.46825 .32079 L
.46337 .29136 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(x)] .97619 .1913 0 0 Mshowa
P
.90293 .1913 m
.95177 .1913 L
.92735 .18541 L
.92735 .19718 L
.95177 .1913 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(z)] .90293 .2737 0 0 Mshowa
P
.90293 .1913 m
.90293 .25016 L
.89805 .22073 L
.90781 .22073 L
.90293 .25016 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(base)] .19475 .42674 0 0 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.007007 0.97619 0.287295 MathSubStart
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.02381 0.952381 0.014715 0.952381 [
[(\\(b\\))] .5 .61803 0 -2 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
0 .61803 m
1 .61803 L
s
P
[(\\(b\\))] .5 .61803 0 -2 Mshowa
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.02381 0.014715 0.97619 0.603319 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02381 0.560224 0.014715 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.30392 .01472 m
.86415 .30902 L
.30392 .60332 L
.30392 .07358 L
.64006 .25604 L
.64006 .36199 L
.30392 .54446 L
.30392 .60332 L
.30392 .01472 L
.02381 .01472 L
.02381 .60332 L
.30392 .60332 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(L)] .58403 .03237 0 0 Mshowa
P
.3605 .03237 m
.30448 .03237 L
.33249 .02649 L
.33249 .03826 L
.30448 .03237 L
s
.80532 .03237 m
.86134 .03237 L
.83333 .02649 L
.83333 .03826 L
.86134 .03237 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(B)] .27591 .4856 0 0 Mshowa
P
.27591 .53857 m
.27591 .59743 L
.27031 .568 L
.28151 .568 L
.27591 .59743 L
s
.27591 .07946 m
.27591 .0206 L
.27031 .05003 L
.28151 .05003 L
.27591 .0206 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(L1)] .41597 .30902 0 0 Mshowa
P
.36555 .30902 m
.30952 .30902 L
.33754 .30313 L
.33754 .3149 L
.30952 .30902 L
s
.57843 .30902 m
.63445 .30902 L
.60644 .30313 L
.60644 .3149 L
.63445 .30902 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(w)] .58403 .54446 0 0 Mshowa
P
.58403 .33845 m
.58403 .39731 L
.57843 .36788 L
.58964 .36788 L
.58403 .39731 L
s
.58403 .51503 m
.58403 .45617 L
.57843 .4856 L
.58964 .4856 L
.58403 .45617 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(x)] .97619 .30902 0 0 Mshowa
P
.89216 .30902 m
.94818 .30902 L
.92017 .30313 L
.92017 .3149 L
.94818 .30902 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(y)] .89216 .41497 0 0 Mshowa
P
.89216 .30902 m
.89216 .36788 L
.88655 .33845 L
.89776 .33845 L
.89216 .36788 L
s
p
/Times-Roman findfont 8 scalefont setfont
[(base)] .16387 .30902 0 0 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 82},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0000IQ000`40O003h00OogooGgoo003oOomO
Ool00?mooemoo`0057ooR@008gooR@005Goo000DOol00`00Oomoo`25Ool00`00Oomoo`0QOol00`00
Oomoo`25Ool00`00Oomoo`0COol001Aoo`03001oogoo08Eoo`03001oogoo025oo`03001oogoo08Eo
o`03001oogoo01=oo`0057oo00<007ooOol0QGoo00<007ooOol08Goo00<007ooOol0QGoo00<007oo
Ool04goo000DOol00`00Oomoo`03Oom]000EOol00`00Oomoo`0QOol00`00Oomoo`03OolV001LOol0
0`00Oomoo`0COol001Aoo`03001oogoo00=oo`03001oogoo03moo`03001oogoo02Moo`03001oogoo
01=oo`03001oogoo025oo`03001oogoo00=oo`03001oogoo01ioo`05001oogoo001oo`03000MOol5
000NOol3000FOol00`00Oomoo`0COol001Aoo`03001oogoo00=oo`03001oogoo035oo`80009oo`<0
0007Ool007oo001oo`00Ool00P000Woo00@007oo0000029oo`03001oogoo01=oo`03001oogoo025o
o`03001oogoo00=oo`03001oogoo01ioo`03001oogoo00T001Yoo`03001oogoo01aoo`P001Aoo`03
001oogoo01=oo`0057oo00<007ooOol00goo00<007ooOol0<Woo0P0000=oo`0000000Woo00X007oo
001oo`00Ool007oo001oo`8002Aoo`03001oogoo01=oo`03001oogoo025oo`03001oogoo00=oo`03
001oogoo01eoo`<00004Ool007ooOol200000goo0000000KOol00`00Oomoo`0OOol2000GOol00`00
Oomoo`0COol001Aoo`03001oogoo00=oo`03001oogoo035oo`03001oogoo009oo`0=001oogoo001o
o`00Ool007oo001oo`00Ool01@008Goo00<007ooOol04goo00<007ooOol08Goo00<007ooOol00goo
00<007ooOol07Goo0`0000=oo`00Ool01Woo0P006Goo00<007ooOol0>7oo00<007ooOol04goo000D
Ool00`00Oomoo`03Ool00`00Oomoo`0bOol40003Ool500000goo00000002Ool01000Ool000008Woo
00<007ooOol04goo00<007ooOol08Goo00<007ooOol00goo00<007ooOol07Woo00@007ooOol000Uo
o`8001Moo`03001oogoo03Qoo`03001oogoo01=oo`0057oo00<007ooOol00goo00<007ooOol0@goo
00<007ooOol08goo00<007ooOol04goo00<007ooOol08Goo00<007ooOol00goo00<007ooOol07Woo
00@007ooOol000]oo`03001oogoo01=oo`<003Uoo`03001oogoo01=oo`0057oo00<007ooOol00goo
A`0037oo6P005Goo00<007ooOol08Goo00<007ooOol00goo00<007ooOol07Woo00<007ooOol00P00
2goo0P00Cgoo00<007ooOol04goo000DOol00`00Oomoo`19Ool00`00Oomoo`0:Ool00`00Oomoo`0/
Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0NOol01@00Oomoo`00Ool00P002goo0P00
CGoo00<007ooOol04goo000DOol00`00Oomoo`19Ool00`00Oomoo`0:Ool00`00Oomoo`0/Ool00`00
Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0QOol01000Oomoogoo0P002goo0P00Bgoo00<007oo
Ool04goo000DOol00`00Oomoo`19Ool00`00Oomoo`0:Ool00`00Oomoo`0/Ool00`00Oomoo`0QOol0
0`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0:Ool20019Ool00`00Oomo
o`0COol001Aoo`03001oogoo04Uoo`h002ioo`03001oogoo025oo`03001oogoo00=oo`03001oogoo
025oo`03001oogoo00Aoo`8000aoo`8004Moo`03001oogoo01=oo`0057oo00<007ooOol0QGoo00<0
07ooOol08Goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol01Woo0P0037oo0P00AGoo00<0
07ooOol04goo000DOol00`00Oomoo`25Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0Q
Ool00`00Oomoo`08Ool2000<Ool20013Ool00`00Oomoo`0COol001Aoo`03001oogoo08Eoo`03001o
ogoo025oo`03001oogoo00=oo`03001oogoo025oo`03001oogoo00Yoo`8000aoo`80045oo`03001o
ogoo01=oo`0057oo00<007ooOol0QGoo00<007ooOol08Goo00<007ooOol00goo00<007ooOol08Goo
00<007ooOol037oo0P0037oo0P00?goo00<007ooOol04goo000DOol00`00Oomoo`25Ool00`00Oomo
o`0QOol00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0>Ool00`00Oomoo`0;Ool2000mOol0
0`00Oomoo`0COol001Aoo`03001oogoo08Eoo`03001oogoo025oo`03001oogoo00=oo`03001oogoo
025oo`03001oogoo00moo`8000eoo`8003]oo`03001oogoo01=oo`0057oo00<007ooOol0QGoo00<0
07ooOol08Goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol04Goo0P003Goo0P00>Goo00<0
07ooOol04goo000DOol00`00Oomoo`25Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0Q
Ool00`00Oomoo`0COol2000=Ool00`00Oomoo`0fOol00`00Oomoo`0COol001Aoo`03001oogoo08Eo
o`03001oogoo025oo`03001oogoo00=oo`03001oogoo025oo`03001oogoo01Eoo`8000aoo`8003Io
o`03001oogoo01=oo`0057oo00<007ooOol0QGoo00<007ooOol08Goo00<007ooOol00goo00<007oo
Ool08Goo00<007ooOol05goo0P0037oo0P00=7oo00<007ooOol04goo000DOol00`00Oomoo`1iOol2
0002Ool40004Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0IOol0
0`00Oomoo`0;Ool2000bOol00`00Oomoo`0COol001Aoo`03001oogoo03aoo`03001oogoo02eoo`03
001oogoo00Ioo`P00003Ool0000000Eoo`03001oogoo025oo`03001oogoo00=oo`03001oogoo025o
o`03001oogoo01Yoo`8000eoo`80031oo`03001oogoo01=oo`0057oo00<007ooOol0?7oo00<007oo
Ool0;Goo00<007ooOol01Woo00<007ooOol01Woo0`0017oo00<007ooOol08Goo00<007ooOol00goo
00<007ooOol08Goo00<007ooOol077oo0P003Goo0P00;Woo00<007ooOol04goo000DOol00`00Oomo
o`0lOol00`00Oomoo`0/Ool00`00Ool00007Ool00`00Oomoo`05Ool40004Ool00`00Oomoo`0QOol0
0`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0NOol2000=Ool2000/Ool00`00Oomoo`0COol0
01Aoo`03001oogoo03aoo`03001oogoo02aoo`03001oo`0000Moo`8000ioo`03001oogoo025oo`03
001oogoo00=oo`03001oogoo025oo`03001oogoo021oo`8000eoo`8002Yoo`03001oogoo01=oo`00
57oo00<007ooOol0?7oo0P00;Goo00<007oo00001goo0P003Woo00<007ooOol08Goo00<007ooOol0
0goo00<007ooOol08Goo00<007ooOol08Woo0P003Goo0P00:7oo00<007ooOol04goo000DOol00`00
Oomoo`0lOol2000/Ool01@00Oomoogoo00001Woo0P003Woo00<007ooOol08Goo00<007ooOol00goo
00<007ooOol08Goo00<007ooOol097oo00<007ooOol037oo0P009Woo00<007ooOol04goo000DOol0
0`00Oomoo`0lOol2000/Ool01@00Oomoogoo00001Woo00<007ooOol03Goo00<007ooOol08Goo00<0
07ooOol00goo00<007ooOol08Goo00<007ooOol09Goo0P003Woo0P0097oo00<007ooOol04goo000D
Ool00`00Oomoo`03Ool]000<Ool00`00Oomoo`0[Ool01@00Oomoogoo00001Woo00<007ooOol03Goo
00<007ooOol08Goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol09goo0P003Woo0P008Woo
00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`0:Ool00`00Oomo
o`0ZOol00`00Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomo
o`0QOol00`00Oomoo`0YOol00`00Oomoo`0=Ool2000POol00`00Oomoo`0COol001Aoo`03001oogoo
00=oo`03001oogoo02Uood4000Aoo`@000eoo`03001oogoo025oo`03001oogoo00=oo`03001oogoo
025oo`03001oogoo02Uoo`03001oogoo00moo`03001oogoo01eoo`03001oogoo01=oo`0057oo00<0
07ooOol00goo00<007ooOol0:Goo00<007ooOol0?Goo00<007ooOol00goo00<007ooOol03Goo00<0
07ooOol08Goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol0:Goo00<007ooOol047oo0P00
7Goo00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`0mOol00`00
Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0QOol00`00
Oomoo`0YOol00`00Oomoo`0BOol2000KOol00`00Oomoo`0COol001Aoo`03001oogoo00=oo`03001o
ogoo02Uood4000Aoo`@000eoo`03001oogoo025oo`03001oogoo00=oo`03001oogoo025oo`03001o
ogoo02Uoo`03001oogoo01Aoo`8001Uoo`03001oogoo01=oo`0057oo00<007ooOol00goo00<007oo
Ool0:Goo00<007ooOol02Woo00<007ooOol0AWoo00<007ooOol08Goo00<007ooOol00goo00<007oo
Ool08Goo00<007ooOol0:Goo00<007ooOol05Woo0P005goo00<007ooOol04goo000DOol00`00Oomo
o`03Ool00`00Oomoo`0YOol00`00Oomoo`0:Ool00`00Oomoo`16Ool00`00Oomoo`0QOol00`00Oomo
o`03Ool00`00Oomoo`09Ool20002Ool50002Ool2000;Ool00`00Oomoo`030005Ool8000EOol20002
Ool00`00Oomoo`0HOol20008Ool20003Ool40004Ool00`00Oomoo`0COol001Aoo`03001oogoo00=o
o`03001oogoo02Uoo`03001oogoo00Yoo`8004Moo`03001oogoo025oo`03001oogoo00=oo`03001o
ogoo00Uoo`04001oo`00Ool20002Ool3000=Ool90003Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool9
000KOol20003Ool80002Ool20005Ool00`00Oomoo`0COol001Aoo`03001oogoo00=oo`03001oogoo
02Uoo`03001oogoo00Yoo`8004Moo`03001oogoo025oo`03001oogoo00=oo`03001oogoo00Uoo`03
001oo`00009oo`03001oo`00009oo`@000Yoo`04001oogooOol20006Ool00`00Oomoo`02Ool00`00
Oomoo`0DOol20002Ool00`00Oomoo`0GOol20005Ool01000Oomoogoo0P0017oo0`0017oo00<007oo
Ool04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`0:Ool00`00Oomoo`16Ool0
0`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`09Ool200000goo00000003Ool200000goo0000
000;Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`0EOol20007Ool0
0`00Oomoo`06Ool40004Ool00`00Oomoo`0COol001Aoo`03001oogoo00=oo`03001oogoo02Uoo`03
001oogoo00Yoo`03001oogoo04Ioo`03001oogoo025oo`03001oogoo00=oo`03001oogoo00Uoo`03
001oogoo01Eoo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo01Qoo`03001oogoo01=oo`80
00Uoo`03001oogoo00ioo`03001oogoo01=oo`0057oo00<007ooOol00goo00<007ooOol0:Goo00<0
07ooOol02Woo00<007ooOol0AWoo00<007ooOol08Goo00<007ooOol00goo00<007ooOol02Goo00<0
07ooOol05Goo00<007ooOol027oo0`000Woo0P004goo00<007ooOol017oo00<007ooOol04Goo0P00
2Woo0`003goo00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`0:
Ool00`00Oomoo`16Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0R
Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool2000<Ool3000?Ool00`00Oomoo`0COol001Aoo`03001o
ogoo00=oo`03001oogoo02Uoo`03001oogoo05=oo`03001oogoo025oo`03001oogoo00=oo`03001o
ogoo025oo`03001oogoo029oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00aoo`<000mo
o`03001oogoo01=oo`0057oo00<007ooOol00goo00<007ooOol0:Goo00<007ooOol0Dgoo00<007oo
Ool08Goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol08Woo00<007ooOol00goo0P003Woo
0P0047oo00<007ooOol03Woo00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0YOol0
0`00Oomoo`1COol00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0QOol3
0002Ool2000>Ool2000BOol00`00Oomoo`0>Ool00`00Oomoo`0COol001Aoo`03001oogoo00=oo`03
001oogoo02Uoo`03001oogoo05=oo`03001oogoo025oo`03001oogoo00=oo`03001oogoo025oo`03
001oogoo025oo`D000ioo`8002Eoo`03001oogoo01=oo`0057oo00<007ooOol00goo00<007ooOol0
:Goo00<007ooOol02Goo0P00B7oo00<007ooOol08Goo00<007ooOol00goo00<007ooOol08Goo00<0
07ooOol08Woo0P003Woo0P009goo00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0Y
Ool00`00Oomoo`08Ool00`00Ool00018Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0Q
Ool00`00Oomoo`0QOol2000=Ool2000FOol2000AOol00`00Oomoo`0COol001Aoo`03001oogoo00=o
o`03001oogoo02Uoo`03001oogoo00Qoo`03001oo`0004Qoo`03001oogoo025oo`03001oogoo00=o
o`03001oogoo025oo`03001oogoo01moo`8000eoo`8001Uoo`03001oogoo00moo`03001oogoo01=o
o`0057oo00<007ooOol00goo00<007ooOol0:Goo00<007ooOol02Goo0P00B7oo00<007ooOol08Goo
00<007ooOol00goo00<007ooOol08Goo00<007ooOol07Goo0P003Goo0P0077oo00<007ooOol03Woo
00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0=Ool20002Ool50002Ool2000?Ool0
0`00Oomoo`0:Ool00`00Oomoo`16Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0QOol0
0`00Oomoo`0KOol2000=Ool2000MOol2000@Ool00`00Oomoo`0COol001Aoo`03001oogoo00=oo`03
001oogoo00eoo`04001oo`00Ool20002Ool3000AOol00`00Oomoo`0:Ool00`00Oomoo`16Ool00`00
Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0IOol2000=Ool2000OOol3000?
Ool00`00Oomoo`0COol001Aoo`03001oogoo00=oo`03001oogoo00eoo`03001oo`00009oo`03001o
o`00009oo`@000ioo`03001oogoo05=oo`03001oogoo025oo`03001oogoo00=oo`03001oogoo025o
o`03001oogoo01Qoo`03001oogoo00]oo`80021oo`@000moo`03001oogoo01=oo`0057oo00<007oo
Ool00goo00<007ooOol03Goo0P0000=oo`0000000goo0P0000=oo`0000003goo00<007ooOol0Dgoo
00<007ooOol08Goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol05Woo0P0037oo0P00=Goo
00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0IOol00`00Oomo
o`1COol00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0DOol2000<Ool2
000gOol00`00Oomoo`0COol001Aoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo01Uoo`03
001oogoo05=oo`03001oogoo025oo`03001oogoo00=oo`03001oogoo025oo`03001oogoo019oo`80
00eoo`8003Qoo`03001oogoo01=oo`0057oo00<007ooOol00goo00<007ooOol0:Goo00<007ooOol0
Dgoo00<007ooOol08Goo00<007ooOol00goo00<007ooOol08Goo00<007ooOol047oo0P003Goo0P00
00=oo`00Ool0=goo00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomo
o`1COol00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`0>Ool2000=Ool2
0003Ool00`00Oomoo`0fOol00`00Oomoo`0COol001Aoo`03001oogoo00=oo`03001oogoo02Uoo`03
001oo`00008001Uoo`D001Yoo`8001Moo`03001oogoo025oo`03001oogoo00=oo`03001oogoo01]o
o`<000=oo`03001oogoo00eoo`03001oogoo00]oo`8000Aoo`<003Moo`03001oogoo01=oo`0057oo
00<007ooOol00goo00<007ooOol0:Goo20005goo00<007ooOol05goo20005Goo00<007ooOol08Goo
00<007ooOol00goo00<007ooOol077oo00<007oo00000Woo00<007ooOol02goo0P0037oo0P001Woo
0`00=goo00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`02000J
Ool00`00Oomoo`0KOol2000GOol00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0LOol00`00
Ool00002Ool00`00Oomoo`09Ool2000<Ool20009Ool00`00Oomoo`0fOol00`00Oomoo`0COol001Ao
o`03001oogoo00=oo`03001oogoo02Uoo`03001oogoo01aoo`03001oogoo03Aoo`03001oogoo025o
o`03001oogoo00=oo`03001oogoo01aoo`8000=oo`03001oogoo00Moo`8000aoo`8000]oo`03001o
ogoo03Ioo`03001oogoo01=oo`0057oo00<007ooOol00goo00<007ooOol0:Goo00<007ooOol077oo
00<007ooOol0=7oo00<007ooOol08Goo00<007ooOol00goo00<007ooOol077oo00<007oo00000Woo
00<007ooOol01Goo0P0037oo0P003Goo00<007ooOol0=Woo00<007ooOol04goo000DOol00`00Oomo
o`03Ool00`00Oomoo`0YOol00`00Oomoo`0KOol3000eOol00`00Oomoo`0QOol00`00Oomoo`03Ool0
0`00Oomoo`0KOol30003Ool00`00Oomoo`03Ool2000<Ool2000?Ool00`00Oomoo`0fOol00`00Oomo
o`0COol001Aoo`03001oogoo00=oo`03001oogoo02Uoo`03001oogoo05=oo`03001oogoo025oo`03
001oogoo00=oo`03001oogoo025oo`03001oogoo009oo`03001oogoo00Yoo`8004Yoo`03001oogoo
01=oo`0057oo00<007ooOol00goo00<007ooOol0:Goo00<007ooOol0Dgoo00<007ooOol08Goo00<0
07ooOol00goo00<007ooOol08Goo00<007ooOol00P002goo0P00C7oo00<007ooOol04goo000DOol0
0`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`1COol00`00Oomoo`0QOol00`00Oomoo`03Ool0
0`00Oomoo`0NOol00`00Oomoo`03000;Ool2000DOol00`00Ool0000gOol00`00Oomoo`0COol001Ao
o`03001oogoo00=oo`03001oogoo02Uoo`03001oogoo05=oo`03001oogoo025oo`03001oogoo00=o
o`03001oogoo01ioo`04001oogoo000;Ool2000EOol01@00Ool007oo0000=Woo00<007ooOol04goo
000DOol00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`1COol00`00Oomoo`0QOol00`00Oomo
o`03Ool00`00Oomoo`0NOol01000Oomoo`002Woo00<007ooOol05Goo00<007oo00000Woo00<007oo
Ool0<goo00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`1COol0
0`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0NOol01000Oomoo`0027oo0P005goo100000=o
o`000000=Goo00<007ooOol04goo000DOol00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`1C
Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0MOol300000goo001oo`05Ool2001EOol0
0`00Oomoo`0COol001Aoo`03001oogoo00=oo`03001oogoo02Uoo`03001oogoo05=oo`03001oogoo
025oo`03001oogoo00=oo`03001oogoo01eoo`<00003Ool007oo00=oo`8005Moo`03001oogoo01=o
o`0057oo00<007ooOol00goo00<007ooOol0:Goo00<007ooOol0Dgoo00<007ooOol08Goo00<007oo
Ool00goo00<007ooOol07Woo00@007ooOol0009oo`8005Uoo`03001oogoo01=oo`0057oo00<007oo
Ool00goo00<007ooOol0:Goo00<007ooOol0Dgoo00<007ooOol08Goo00<007ooOol00goo00<007oo
Ool07Woo00<007ooOol00`00Fgoo00<007ooOol04goo000DOol00`00Oomoo`03Ool]001EOol00`00
Oomoo`0QOol00`00Oomoo`03OolU001MOol00`00Oomoo`0COol001Aoo`03001oogoo08Eoo`03001o
ogoo025oo`03001oogoo08Eoo`03001oogoo01=oo`0057oo00<007ooOol0QGoo00<007ooOol08Goo
00<007ooOol0QGoo00<007ooOol04goo000DOol00`00Oomoo`25Ool00`00Oomoo`0QOol00`00Oomo
o`25Ool00`00Oomoo`0COol001AoohT002=oohT001Eoo`00ogooGgoo003oOomOOol00?mooemoo`00
ogooGgoo003oOomOOol005Eoo`03001oogoo009oo`03001oogoo0:=oo`03001oogoo00=oo`03001o
ogoo05Eoo`00EGoo00<007ooOol01000Y7oo00<007ooOol00P0000=oo`000000EWoo001DOol01000
Oomoogoo0P0000=oo`00Ool0XWoo00T007ooOomoo`00Ool007oo0000EWoo001DOol00`00Oomoo`02
Ool00`00Ool0002SOol02@00Oomoogoo001oo`00Ool0001FOol005Aoo`03001oogoo0080009oo`03
001oogoo0:5oo`04001oogooOol20002Ool00`00Oomoo`1DOol005Eoo`03001oogoo009oo`03001o
ogoo0:=oo`04001oogoo0002Ool00`00Oomoo`1EOol005Eoo`03001oogoo009oo`03001oogoo0:=o
o`04001oogoo0002Ool00`00Oomoo`1EOol00?mooemoo`00ogooGgoo0000\
\>"],
  ImageRangeCache->{{{0, 349}, {101.5, 0}} -> {-0.0625362, -0.0147178, 
  0.00761129, 0.00761129}, {{10.25, 166.625}, {99.0625, 2.375}} -> {-0.17877,
   -0.0352121, 0.00959392, 0.00959392}, {{23.25, 153.562}, {96.875, 16.375}}
   -> {-0.4147, -0.0853255, 0.0196493, 0.0163042}, {{182.312, 338.688}, {
  99.0625, 2.375}} -> {-1.49937, -0.0352121, 0.00959392, 0.00959392}, {{
  195.312, 325.625}, {96.875, 16.375}} -> {-2.7195, -0.0853255, 0.0171302, 
  0.0163042}}],

Cell[BoxData[
    \(\(geo
       = {rho \[Rule] rhoSi, Em \[Rule] ESi, L \[Rule] 190\ micro, 
        L1 \[Rule] 87.5\ micro, B \[Rule] 165\ micro, w \[Rule] 33.3\ micro, 
        d \[Rule] 0.6\ micro, del \[Rule] 7.1\ micro, 
        htip \[Rule] 3.5\ micro, Fx \[Rule] 1\ nano, Fz \[Rule] 1\ nano}; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Spring Constant in the $z$ Direction"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["General Solution"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[My, I1, I2]; \)\), 
    \(\(Mz[x_] := \((L - x)\)\ Fz; \)\), 
    \(\(I1[x_] := \(2\ w\ d\^3\)\/12; \)\), 
    \(\(I2[x_] := 1\/12\ \((1 - x\/L)\)\ B\ d\^3; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[d2Z1, d2Z2]; \)\), 
    \(\(d2Z1[x_] := Mz[x]\/\(Em\ I1[x]\); \)\), 
    \(\(d2Z2[x_] := Mz[x]\/\(Em\ I2[x]\); \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[d1Z1, d1Z2]; \)\), 
    \(d1Z1[x1_] := \[Integral]\_0\%x1 d2Z1[x] \[DifferentialD]x; \n
    d1Z2[x1_]\  := \ 
      Integrate[d2Z2[x]\ , {x, L1, x1}, \ GenerateConditions -> False]\  + \n
        \ \ \ \ \ \ \ \ \ \ \ \ \ d1Z1[L1]; \n\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Z1, Z2]; \)\), 
    \(\(Z1[x2_] := \[Integral]\_0\%x2 d1Z1[x1] \[DifferentialD]x1; \)\), 
    \(\(Z2[x2_] := \[Integral]\_L1\%x2 d1Z2[x1] \[DifferentialD]x1 + Z1[L1]; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(kz = Re[Fz\/Z2[L - del]]; \)\), 
    \(\(ZMax = 1\/kz; \)\), 
    \(\(ktheta = d1Z2[L - del]\/Fz; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Print["\<kz     = \>", N[kz /. geo], "\< N/m\>"]\), 
    \(Print["\<Z Max  = \>", N[ZMax /. geo], "\< nm/nN\>"]\), 
    \(Print["\<ktheta = \>", N[\(ktheta\ nano\)\/milli /. geo], 
      "\< mrad/nN\>"]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("kz     = "\[InvisibleSpace]0.0981858570344851955`
        \[InvisibleSpace]" N/m"\),
      SequenceForm[ "kz     = ", 0.0981858570344852, " N/m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("Z Max  = "\[InvisibleSpace]10.1847662199330435`
        \[InvisibleSpace]" nm/nN"\),
      SequenceForm[ "Z Max  = ", 10.18476621993304398, " nm/nN"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("ktheta = "\[InvisibleSpace]0.0937305449176957949`
        \[InvisibleSpace]" mrad/nN"\),
      SequenceForm[ "ktheta = ", 0.09373054491769579, " mrad/nN"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Special Cases"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["V-Shaped Cantilever with a Triangular Recess"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[kz1, ZMax, ktheta]; \)\), 
    \(\(kz1 = Fz\/Z2[L]; \)\), 
    \(\(ZMax = 1\/kz1; \)\), 
    \(\(ktheta = d1Z2[L]\/Fz; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Print["\<kz1    = \>", 
      Simplify[kz1 /. L1 \[Rule] L\ \((1 - \(2\ w\)\/B)\)]]\), 
    \(Print["\<ZMax   = \>", 
      Simplify[ZMax /. L1 \[Rule] L\ \((1 - \(2\ w\)\/B)\)]]\), 
    \(Print["\<ktheta = \>", 
      Simplify[ktheta /. L1 \[Rule] L\ \((1 - \(2\ w\)\/B)\)]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("kz1    = "\[InvisibleSpace]\(B\^3\ d\^3\ Em\ w\)\/\(2\ L\^3\ \((
            B\^3 + 4\ w\^3)\)\)\),
      SequenceForm[ "kz1    = ", 
        Times[ 
          Rational[ 1, 2], 
          Power[ B, 3], 
          Power[ d, 3], Em, 
          Power[ L, -3], w, 
          Power[ 
            Plus[ 
              Power[ B, 3], 
              Times[ 4, 
                Power[ w, 3]]], -1]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("ZMax   = "\[InvisibleSpace]\(2\ L\^3\ \((B\^3 + 4\ w\^3)
            \)\)\/\(B\^3\ d\^3\ Em\ w\)\),
      SequenceForm[ "ZMax   = ", 
        Times[ 2, 
          Power[ B, -3], 
          Power[ d, -3], 
          Power[ Em, -1], 
          Power[ L, 3], 
          Power[ w, -1], 
          Plus[ 
            Power[ B, 3], 
            Times[ 4, 
              Power[ w, 3]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("ktheta = "\[InvisibleSpace]\(3\ L\^2\ \((B\^2 + 4\ w\^2)
            \)\)\/\(B\^2\ d\^3\ Em\ w\)\),
      SequenceForm[ "ktheta = ", 
        Times[ 3, 
          Power[ B, -2], 
          Power[ d, -3], 
          Power[ Em, -1], 
          Power[ L, 2], 
          Power[ w, -1], 
          Plus[ 
            Power[ B, 2], 
            Times[ 4, 
              Power[ w, 2]]]]],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["V-Shaped Cantilever without a Recess"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Print["\<kz1    = \>", Simplify[kz1 /. L1 \[Rule] 0]]\), 
    \(Print["\<ZMax   = \>", Simplify[ZMax /. L1 \[Rule] 0]]\), 
    \(Print["\<ktheta = \>", Simplify[ktheta /. L1 \[Rule] 0]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("kz1    = "\[InvisibleSpace]\(B\ d\^3\ Em\)\/\(6\ L\^3\)\),
      SequenceForm[ "kz1    = ", 
        Times[ 
          Rational[ 1, 6], B, 
          Power[ d, 3], Em, 
          Power[ L, -3]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("ZMax   = "\[InvisibleSpace]\(6\ L\^3\)\/\(B\ d\^3\ Em\)\),
      SequenceForm[ "ZMax   = ", 
        Times[ 6, 
          Power[ B, -1], 
          Power[ d, -3], 
          Power[ Em, -1], 
          Power[ L, 3]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("ktheta = "\[InvisibleSpace]\(12\ L\^2\)\/\(B\ d\^3\ Em\)\),
      SequenceForm[ "ktheta = ", 
        Times[ 12, 
          Power[ B, -1], 
          Power[ d, -3], 
          Power[ Em, -1], 
          Power[ L, 2]]],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Trapezoidal Cantilever without a Recess"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = \(1 - B1\/B\)\/L; \)\), 
    \(\(g = 
      m\ L - \(m\^2\ L\^2\)\/\(2\ \((1 - m\ L)\)\) + 
        \((1 - m\ L)\)\ Log[1 - m\ L]; \)\), 
    \(\(kz2 = Simplify[\(Em\ B\ d\^3\ m\^3\)\/\(12\ g\ \((m\ L - 1)\)\)]; 
    \)\), 
    \(Print["\<kz2 = \>", kz2]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("kz2 = "\[InvisibleSpace]\(\((B - B1)\)\^3\ d\^3\ Em\)\/\(6\ L\^3\ \((
            B\^2 - 4\ B\ B1 + 3\ B1\^2 - 2\ B1\^2\ Log[B1\/B])\)\)\),
      SequenceForm[ "kz2 = ", 
        Times[ 
          Rational[ 1, 6], 
          Power[ 
            Plus[ B, 
              Times[ -1, B1]], 3], 
          Power[ d, 3], Em, 
          Power[ L, -3], 
          Power[ 
            Plus[ 
              Power[ B, 2], 
              Times[ -4, B, B1], 
              Times[ 3, 
                Power[ B1, 2]], 
              Times[ -2, 
                Power[ B1, 2], 
                Log[ 
                  Times[ 
                    Power[ B, -1], B1]]]], -1]]],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Spring Constant in the $x$ Direction"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["General Solution"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Mx]; \)\), 
    \(\(Mx[x_] := htip\ Fx; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[d2Z1, d2Z2, d1Z1, d1Z2, Z1, Z2]; \)\), 
    \(\(d2Z1[x_] := Mx[x]\/\(Em\ I1[x]\); \)\), 
    \(\(d2Z2[x_] := Mx[x]\/\(Em\ I2[x]\); \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(d1Z1[x1_] := \[Integral]\_0\%x1 d2Z1[x] \[DifferentialD]x; \)\), 
    \(\(d1Z2[x1_] := 
      \[Integral]\_L1\%x1 d2Z2[x] \[DifferentialD]x + d1Z1[L1]; \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Z1[x2_] := \[Integral]\_0\%x2 d1Z1[x1] \[DifferentialD]x1; \)\), 
    \(\(Z2[x2_] := \[Integral]\_L1\%x2 d1Z2[x1] \[DifferentialD]x1 + Z1[L1]; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[kx, ZMax, ktheta]; \)\), 
    \(\(kx = Re[Fx\/Z2[L - del]]; \)\), 
    \(\(ZMax = 1\/kx; \)\), 
    \(\(ktheta = d1Z2[L - del]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Print["\<kx     = \>", Re[N[kx /. geo]], "\< N/m\>"]\), 
    \(Print["\<Z Max  = \>", Re[N[ZMax /. geo]], "\< nm/nN\>"]\), 
    \(Print["\<ktheta = \>", Re[N[ktheta\/milli /. geo]], "\< mrad/nN\>"]\)}],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("kx     = "\[InvisibleSpace]3.39889456517885868`
        \[InvisibleSpace]" N/m"\),
      SequenceForm[ "kx     = ", 3.39889456517885868, " N/m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("Z Max  = "\[InvisibleSpace]0.294213304009145524`
        \[InvisibleSpace]" nm/nN"\),
      SequenceForm[ "Z Max  = ", 0.29421330400914552, " nm/nN"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("ktheta = "\[InvisibleSpace]0.00476670467644926176`
        \[InvisibleSpace]" mrad/nN"\),
      SequenceForm[ "ktheta = ", 0.00476670467644926, " mrad/nN"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Special Cases"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["V-Shaped Cantilever with a Triangular Recess"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[kx1, ZMax, ktheta]; \)\), 
    \(\(kx1 = Fx\/Z2[L]; \)\), 
    \(\(ZMax = 1\/kx1; \)\), 
    \(\(ktheta = d1Z2[L - del]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Print["\<kx1      = \>", 
      Simplify[kx1 /. L1 \[Rule] L\ \((1 - \(2\ w\)\/B)\)]]\), 
    \(Print["\<ZMax     = \>", 
      Simplify[ZMax /. L1 \[Rule] L\ \((1 - \(2\ w\)\/B)\)]]\), 
    \(Print["\<ktheta = \>", 
      Simplify[ktheta /. L1 \[Rule] L\ \((1 - \(2\ w\)\/B)\)]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("kx1      = "\[InvisibleSpace]\(B\^2\ d\^3\ Em\ w
            \)\/\(3\ B\^2\ htip\ L\^2 + 12\ htip\ L\^2\ w\^2\)\),
      SequenceForm[ "kx1      = ", 
        Times[ 
          Power[ B, 2], 
          Power[ d, 3], Em, w, 
          Power[ 
            Plus[ 
              Times[ 3, 
                Power[ B, 2], htip, 
                Power[ L, 2]], 
              Times[ 12, htip, 
                Power[ L, 2], 
                Power[ w, 2]]], -1]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("ZMax     = "\[InvisibleSpace]\(3\ htip\ L\^2\ \((B\^2 + 4\ w\^2)
            \)\)\/\(B\^2\ d\^3\ Em\ w\)\),
      SequenceForm[ "ZMax     = ", 
        Times[ 3, 
          Power[ B, -2], 
          Power[ d, -3], 
          Power[ Em, -1], htip, 
          Power[ L, 2], 
          Power[ w, -1], 
          Plus[ 
            Power[ B, 2], 
            Times[ 4, 
              Power[ w, 2]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("ktheta = "\[InvisibleSpace]\(6\ Fx\ htip\ L\ \((
            B - 2\ w - 2\ w\ Log[\(-del\)] + 
              2\ w\ Log[\(-\(\(2\ L\ w\)\/B\)\)])\)\)\/\(B\ d\^3\ Em\ w\)\),
      SequenceForm[ "ktheta = ", 
        Times[ 6, 
          Power[ B, -1], 
          Power[ d, -3], 
          Power[ Em, -1], Fx, htip, L, 
          Power[ w, -1], 
          Plus[ B, 
            Times[ -2, w], 
            Times[ -2, w, 
              Log[ 
                Times[ -1, del]]], 
            Times[ 2, w, 
              Log[ 
                Times[ -2, 
                  Power[ B, -1], L, w]]]]]],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["V-Shaped Cantilever without a Recess"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Print["\<kx2    = \>", Simplify[kx1 /. L1 \[Rule] 0]]\), 
    \(Print["\<ZMax   = \>", Simplify[ZMax /. L1 \[Rule] 0]]\), 
    \(Print["\<ktheta = \>", Simplify[ktheta /. L1 \[Rule] 0]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("kx2    = "\[InvisibleSpace]\(B\ d\^3\ Em\)\/\(12\ htip\ L\^2\)\),
      SequenceForm[ "kx2    = ", 
        Times[ 
          Rational[ 1, 12], B, 
          Power[ d, 3], Em, 
          Power[ htip, -1], 
          Power[ L, -2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("ZMax   = "\[InvisibleSpace]\(12\ htip\ L\^2\)\/\(B\ d\^3\ Em\)\),
      SequenceForm[ "ZMax   = ", 
        Times[ 12, 
          Power[ B, -1], 
          Power[ d, -3], 
          Power[ Em, -1], htip, 
          Power[ L, 2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("ktheta = "\[InvisibleSpace]\(12\ Fx\ htip\ L\ \((
            \(-Log[\(-del\)]\) + Log[\(-L\)])\)\)\/\(B\ d\^3\ Em\)\),
      SequenceForm[ "ktheta = ", 
        Times[ 12, 
          Power[ B, -1], 
          Power[ d, -3], 
          Power[ Em, -1], Fx, htip, L, 
          Plus[ 
            Times[ -1, 
              Log[ 
                Times[ -1, del]]], 
            Log[ 
              Times[ -1, L]]]]],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Resonance Frequencies"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(a = 
      Table[Em\ \((
              \[Integral]\_0\%L1
                    \( 2\/12\ w\ d\^3\ \[PartialD]\_{x, 2}x\^\(n + 1\)\ 
                      \[PartialD]\_{x, 2}x\^\(m + 1\)\) \[DifferentialD]x + 
                \[Integral]\_L1\%L
                    \( 1\/12\ B\ d\^3\ \((1 - x\/L)\)\ 
                      \[PartialD]\_{x, 2}x\^\(n + 1\)\ 
                      \[PartialD]\_{x, 2}x\^\(m + 1\)\) \[DifferentialD]x)
              \), {n, 1, 3}, {m, 1, 3}] /. geo; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(b = 
      Table[rho\ 
            \((\[Integral]\_0\%L1\( 2\ w\ d\ x\^\(n + 1\)\ x\^\(m + 1\)\) 
                    \[DifferentialD]x + 
                \[Integral]\_L1\%L
                    \( B\ d\ \((1 - x\/L)\)\ x\^\(n + 1\)\ x\^\(m + 1\)\) 
                    \[DifferentialD]x)\), {n, 1, 3}, {m, 1, 3}] /. geo; \)\)],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ddt = NRoots[Det[a - ww\ b] == 0, ww]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Print["\<    L = \>", N[L\/micro] /. geo, "\< um\>"]\), 
    \(Print["\<   L1 = \>", L1\/micro /. geo, "\< um\>"]\), 
    \(Print["\<    B = \>", B\/micro /. geo, "\< um\>"]\), 
    \(Print["\<    w = \>", w\/micro /. geo, "\< um\>"]\), 
    \(Print["\<    d = \>", d\/micro /. geo, "\< um\>"]\), 
    \(Print["\<  del = \>", del\/micro /. geo, "\< um\>"]\), 
    \(Print["\< htip = \>", htip\/micro /. geo, "\< um\>"]\), 
    \(Print["\<   kz = \>", N[kz /. geo], "\< N/m\>"]\), 
    \(Print["\<   kx = \>", N[kx /. geo], "\< N/m\>"]\), 
    \(Print["\<   f1 = \>", 
      N[\@ddt\[LeftDoubleBracket]1, 2\[RightDoubleBracket]\/\(\((2\ \[Pi])\)\ 
            kilo\)], "\< KHz\>"]\), 
    \(Print["\<   f2 = \>", 
      N[\@ddt\[LeftDoubleBracket]2, 2\[RightDoubleBracket]\/\(\((2\ \[Pi])\)\ 
            kilo\)], "\< KHz\>"]\), 
    \(Print["\<   f3 = \>", 
      N[\@ddt\[LeftDoubleBracket]3, 2\[RightDoubleBracket]\/\(\((2\ \[Pi])\)\ 
            kilo\)], "\< KHz\>"]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("    L = "\[InvisibleSpace]190.`\[InvisibleSpace]" um"\),
      SequenceForm[ "    L = ", 190.0, " um"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("   L1 = "\[InvisibleSpace]87.5`\[InvisibleSpace]" um"\),
      SequenceForm[ "   L1 = ", 87.5, " um"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("    B = "\[InvisibleSpace]165\[InvisibleSpace]" um"\),
      SequenceForm[ "    B = ", 165, " um"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("    w = "\[InvisibleSpace]33.2999999999999962`
        \[InvisibleSpace]" um"\),
      SequenceForm[ "    w = ", 33.29999999999999716, " um"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("    d = "\[InvisibleSpace]0.6`\[InvisibleSpace]" um"\),
      SequenceForm[ "    d = ", 0.6, " um"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("  del = "\[InvisibleSpace]7.09999999999999964`
        \[InvisibleSpace]" um"\),
      SequenceForm[ "  del = ", 7.09999999999999964, " um"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(" htip = "\[InvisibleSpace]3.5`\[InvisibleSpace]" um"\),
      SequenceForm[ " htip = ", 3.5, " um"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("   kz = "\[InvisibleSpace]0.0981858570344851955`
        \[InvisibleSpace]" N/m"\),
      SequenceForm[ "   kz = ", 0.0981858570344852, " N/m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("   kx = "\[InvisibleSpace]3.39889456517885868`
        \[InvisibleSpace]" N/m"\),
      SequenceForm[ "   kx = ", 3.39889456517885868, " N/m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("   f1 = "\[InvisibleSpace]34.5606327842417337`
        \[InvisibleSpace]" KHz"\),
      SequenceForm[ "   f1 = ", 34.56063278424173291, " KHz"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("   f2 = "\[InvisibleSpace]196.277504905443826`
        \[InvisibleSpace]" KHz"\),
      SequenceForm[ "   f2 = ", 196.2775049054438341, " KHz"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("   f3 = "\[InvisibleSpace]708.117750556945857`
        \[InvisibleSpace]" KHz"\),
      SequenceForm[ "   f3 = ", 708.11775055694579351, " KHz"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Characteristic Functions"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m1 = a - ddt\[LeftDoubleBracket]1, 2\[RightDoubleBracket]\ b /. geo; 
    \)\), 
    \(\(m2 = a - ddt\[LeftDoubleBracket]2, 2\[RightDoubleBracket]\ b /. geo; 
    \)\), 
    \(\(m3 = a - ddt\[LeftDoubleBracket]3, 2\[RightDoubleBracket]\ b /. geo; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(bv1 = NullSpace[m1] /. geo; \)\), 
    \(\(bv2 = NullSpace[m2] /. geo; \)\), 
    \(\(bv3 = NullSpace[m3] /. geo; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[poly1, poly2, poly3]; \)\), 
    \(\(poly1[x_] := 
      bv1\[LeftDoubleBracket]1, 1\[RightDoubleBracket]\ x\^2 + 
        bv1\[LeftDoubleBracket]1, 2\[RightDoubleBracket]\ x\^3 + 
        bv1\[LeftDoubleBracket]1, 3\[RightDoubleBracket]\ x\^4; \)\), 
    \(\(poly2[x_] := 
      bv2\[LeftDoubleBracket]1, 1\[RightDoubleBracket]\ x\^2 + 
        bv2\[LeftDoubleBracket]1, 2\[RightDoubleBracket]\ x\^3 + 
        bv2\[LeftDoubleBracket]1, 3\[RightDoubleBracket]\ x\^4; \)\), 
    \(\(poly3[x_] := 
      bv3\[LeftDoubleBracket]1, 1\[RightDoubleBracket]\ x\^2 + 
        bv3\[LeftDoubleBracket]1, 2\[RightDoubleBracket]\ x\^3 + 
        bv3\[LeftDoubleBracket]1, 3\[RightDoubleBracket]\ x\^4; \)\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig4x2 = 
      Plot[{10\^14\ poly1[x\ micro], 10\^15\ poly2[x\ micro], 
          10\^15\ poly3[x\ micro]}, {x, 0, L\/micro /. geo}, 
        FrameLabel \[Rule] {"\<x in um\>", "\<Z in a.u.\>"}, Evaluate[opt]]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times-Roman findfont 8  scalefont  setfont
% Scaling calculations
0.023809 0.005013 0.454312 1.288614 [
[.02381 -0.0125 -4 -12 ]
[.02381 -0.0125 4 0 ]
[.14912 -0.0125 -6 -12 ]
[.14912 -0.0125 6 0 ]
[.27444 -0.0125 -6 -12 ]
[.27444 -0.0125 6 0 ]
[.39975 -0.0125 -6 -12 ]
[.39975 -0.0125 6 0 ]
[.52506 -0.0125 -8 -12 ]
[.52506 -0.0125 8 0 ]
[.65038 -0.0125 -8 -12 ]
[.65038 -0.0125 8 0 ]
[.77569 -0.0125 -8 -12 ]
[.77569 -0.0125 8 0 ]
[.901 -0.0125 -8 -12 ]
[.901 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14.5 -24 ]
[.5 -0.0125 14.5 -12 ]
[-0.0125 .06773 -20 -6 ]
[-0.0125 .06773 0 6 ]
[-0.0125 .19659 -20 -6 ]
[-0.0125 .19659 0 6 ]
[-0.0125 .32545 -20 -6 ]
[-0.0125 .32545 0 6 ]
[-0.0125 .45431 -8 -6 ]
[-0.0125 .45431 0 6 ]
[-0.0125 .58317 -14 -6 ]
[-0.0125 .58317 0 6 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -32 -15.5 ]
[-0.01875 .30902 -20 15.5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.14912 0 m
.14912 .61803 L
s
.27444 0 m
.27444 .61803 L
s
.39975 0 m
.39975 .61803 L
s
.52506 0 m
.52506 .61803 L
s
.65038 0 m
.65038 .61803 L
s
.77569 0 m
.77569 .61803 L
s
.901 0 m
.901 .61803 L
s
0 .06773 m
1 .06773 L
s
0 .19659 m
1 .19659 L
s
0 .32545 m
1 .32545 L
s
0 .45431 m
1 .45431 L
s
0 .58317 m
1 .58317 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.14912 0 m
.14912 .00625 L
s
gsave
.14912 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.27444 0 m
.27444 .00625 L
s
gsave
.27444 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.39975 0 m
.39975 .00625 L
s
gsave
.39975 -0.0125 -67 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(75) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.52506 0 m
.52506 .00625 L
s
gsave
.52506 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.65038 0 m
.65038 .00625 L
s
gsave
.65038 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(125) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77569 0 m
.77569 .00625 L
s
gsave
.77569 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(150) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.901 0 m
.901 .00625 L
s
gsave
.901 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(175) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.04887 0 m
.04887 .00375 L
s
.07393 0 m
.07393 .00375 L
s
.099 0 m
.099 .00375 L
s
.12406 0 m
.12406 .00375 L
s
.17419 0 m
.17419 .00375 L
s
.19925 0 m
.19925 .00375 L
s
.22431 0 m
.22431 .00375 L
s
.24937 0 m
.24937 .00375 L
s
.2995 0 m
.2995 .00375 L
s
.32456 0 m
.32456 .00375 L
s
.34962 0 m
.34962 .00375 L
s
.37469 0 m
.37469 .00375 L
s
.42481 0 m
.42481 .00375 L
s
.44987 0 m
.44987 .00375 L
s
.47494 0 m
.47494 .00375 L
s
.5 0 m
.5 .00375 L
s
.55013 0 m
.55013 .00375 L
s
.57519 0 m
.57519 .00375 L
s
.60025 0 m
.60025 .00375 L
s
.62531 0 m
.62531 .00375 L
s
.67544 0 m
.67544 .00375 L
s
.7005 0 m
.7005 .00375 L
s
.72556 0 m
.72556 .00375 L
s
.75063 0 m
.75063 .00375 L
s
.80075 0 m
.80075 .00375 L
s
.82581 0 m
.82581 .00375 L
s
.85088 0 m
.85088 .00375 L
s
.87594 0 m
.87594 .00375 L
s
.92607 0 m
.92607 .00375 L
s
.95113 0 m
.95113 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75.5 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 13.000000 moveto
(in) show
77.187500 13.000000 moveto
(um) show
87.375000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .06773 m
.00625 .06773 L
s
gsave
-0.0125 .06773 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .19659 m
.00625 .19659 L
s
gsave
-0.0125 .19659 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .32545 m
.00625 .32545 L
s
gsave
-0.0125 .32545 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
68.500000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .45431 m
.00625 .45431 L
s
gsave
-0.0125 .45431 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .58317 m
.00625 .58317 L
s
gsave
-0.0125 .58317 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .0935 m
.00375 .0935 L
s
0 .11927 m
.00375 .11927 L
s
0 .14504 m
.00375 .14504 L
s
0 .17082 m
.00375 .17082 L
s
0 .22236 m
.00375 .22236 L
s
0 .24813 m
.00375 .24813 L
s
0 .27391 m
.00375 .27391 L
s
0 .29968 m
.00375 .29968 L
s
0 .35122 m
.00375 .35122 L
s
0 .37699 m
.00375 .37699 L
s
0 .40277 m
.00375 .40277 L
s
0 .42854 m
.00375 .42854 L
s
0 .48008 m
.00375 .48008 L
s
0 .50586 m
.00375 .50586 L
s
0 .53163 m
.00375 .53163 L
s
0 .5574 m
.00375 .5574 L
s
0 .04196 m
.00375 .04196 L
s
0 .01618 m
.00375 .01618 L
s
0 .60895 m
.00375 .60895 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -102.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
76.5 10 translate
90 rotate
-76.5 -10 translate
0 20 translate 1 -1 scale
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
69.875000 13.000000 moveto
(in) show
78.062500 13.000000 moveto
(a) show
81.562500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
83.562500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
87.562500 13.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
89.562500 13.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.14912 .61178 m
.14912 .61803 L
s
.27444 .61178 m
.27444 .61803 L
s
.39975 .61178 m
.39975 .61803 L
s
.52506 .61178 m
.52506 .61803 L
s
.65038 .61178 m
.65038 .61803 L
s
.77569 .61178 m
.77569 .61803 L
s
.901 .61178 m
.901 .61803 L
s
.125 Mabswid
.04887 .61428 m
.04887 .61803 L
s
.07393 .61428 m
.07393 .61803 L
s
.099 .61428 m
.099 .61803 L
s
.12406 .61428 m
.12406 .61803 L
s
.17419 .61428 m
.17419 .61803 L
s
.19925 .61428 m
.19925 .61803 L
s
.22431 .61428 m
.22431 .61803 L
s
.24937 .61428 m
.24937 .61803 L
s
.2995 .61428 m
.2995 .61803 L
s
.32456 .61428 m
.32456 .61803 L
s
.34962 .61428 m
.34962 .61803 L
s
.37469 .61428 m
.37469 .61803 L
s
.42481 .61428 m
.42481 .61803 L
s
.44987 .61428 m
.44987 .61803 L
s
.47494 .61428 m
.47494 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55013 .61428 m
.55013 .61803 L
s
.57519 .61428 m
.57519 .61803 L
s
.60025 .61428 m
.60025 .61803 L
s
.62531 .61428 m
.62531 .61803 L
s
.67544 .61428 m
.67544 .61803 L
s
.7005 .61428 m
.7005 .61803 L
s
.72556 .61428 m
.72556 .61803 L
s
.75063 .61428 m
.75063 .61803 L
s
.80075 .61428 m
.80075 .61803 L
s
.82581 .61428 m
.82581 .61803 L
s
.85088 .61428 m
.85088 .61803 L
s
.87594 .61428 m
.87594 .61803 L
s
.92607 .61428 m
.92607 .61803 L
s
.95113 .61428 m
.95113 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06773 m
1 .06773 L
s
.99375 .19659 m
1 .19659 L
s
.99375 .32545 m
1 .32545 L
s
.99375 .45431 m
1 .45431 L
s
.99375 .58317 m
1 .58317 L
s
.125 Mabswid
.99625 .0935 m
1 .0935 L
s
.99625 .11927 m
1 .11927 L
s
.99625 .14504 m
1 .14504 L
s
.99625 .17082 m
1 .17082 L
s
.99625 .22236 m
1 .22236 L
s
.99625 .24813 m
1 .24813 L
s
.99625 .27391 m
1 .27391 L
s
.99625 .29968 m
1 .29968 L
s
.99625 .35122 m
1 .35122 L
s
.99625 .37699 m
1 .37699 L
s
.99625 .40277 m
1 .40277 L
s
.99625 .42854 m
1 .42854 L
s
.99625 .48008 m
1 .48008 L
s
.99625 .50586 m
1 .50586 L
s
.99625 .53163 m
1 .53163 L
s
.99625 .5574 m
1 .5574 L
s
.99625 .04196 m
1 .04196 L
s
.99625 .01618 m
1 .01618 L
s
.99625 .60895 m
1 .60895 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .45431 m
1 .45431 L
s
.5 Mabswid
[ .0001 ] 0 setdash
.02381 .45431 m
.02499 .45431 L
.02605 .45431 L
.02729 .4543 L
.02846 .45429 L
.03053 .45427 L
.03279 .45423 L
.03527 .45418 L
.0379 .45411 L
.04262 .45396 L
.05205 .45353 L
.06244 .45285 L
.07293 .45198 L
.0842 .45081 L
.10458 .44814 L
.1458 .44066 L
.18551 .43104 L
.22371 .41976 L
.26435 .40582 L
.30348 .39069 L
.34506 .37302 L
.38513 .35462 L
.42368 .33582 L
.46468 .3148 L
.50417 .29372 L
.54214 .2728 L
.58257 .24995 L
.62148 .2275 L
.66284 .20326 L
.70268 .17963 L
.74101 .15671 L
.78179 .13219 L
.82106 .1085 L
.85881 .08569 L
.89901 .06138 L
.9377 .03798 L
.97619 .01472 L
s
[ .02 ] 0 setdash
.02381 .45431 m
.02499 .45431 L
.02605 .45432 L
.02729 .45433 L
.02846 .45435 L
.03053 .45439 L
.03279 .45446 L
.03527 .45455 L
.0379 .45466 L
.04262 .45493 L
.05205 .45568 L
.06244 .45681 L
.0842 .4601 L
.10458 .46415 L
.14335 .47378 L
.18458 .48569 L
.22428 .49765 L
.26248 .50864 L
.30312 .51888 L
.34225 .52658 L
.36366 .52966 L
.37347 .53078 L
.38383 .53173 L
.39341 .53242 L
.39884 .53271 L
.40391 .53293 L
.40631 .53301 L
.40858 .53308 L
.41064 .53313 L
.41283 .53317 L
.41396 .53318 L
.41521 .5332 L
.41634 .53321 L
.41741 .53322 L
.41866 .53322 L
.4198 .53322 L
.42106 .53322 L
.42169 .53322 L
.42239 .53321 L
.42371 .5332 L
.42492 .53319 L
.42626 .53317 L
.42767 .53315 L
.43005 .5331 L
.43266 .53302 L
.43748 .53284 L
.442 .53262 L
.4521 .53195 L
.46295 .53093 L
.47308 .52971 L
Mistroke
.48412 .52808 L
.50422 .52428 L
.52393 .5195 L
.54492 .51326 L
.58656 .49739 L
.62667 .4778 L
.66528 .45519 L
.70633 .42745 L
.74587 .39761 L
.7839 .36658 L
.82437 .33174 L
.86333 .29724 L
.90475 .26056 L
.94464 .22633 L
.97619 .20085 L
Mfstroke
[ .05 ] 0 setdash
.02381 .45431 m
.02499 .45431 L
.02605 .45432 L
.02729 .45432 L
.02846 .45433 L
.03053 .45435 L
.03279 .45437 L
.03527 .45441 L
.0379 .45446 L
.04262 .45456 L
.05205 .45486 L
.06244 .4553 L
.0842 .45655 L
.10458 .45801 L
.14335 .46122 L
.18458 .46467 L
.20517 .46623 L
.22428 .46749 L
.24395 .46857 L
.26248 .46935 L
.27234 .46966 L
.27752 .46979 L
.283 .46991 L
.28762 .46998 L
.29007 .47002 L
.29269 .47005 L
.2951 .47007 L
.2973 .47009 L
.29836 .47009 L
.29951 .4701 L
.30053 .4701 L
.30161 .47011 L
.30282 .47011 L
.30394 .47011 L
.30514 .47011 L
.30646 .47011 L
.3076 .47011 L
.30881 .47011 L
.30996 .4701 L
.31101 .4701 L
.31357 .47008 L
.31634 .47005 L
.32138 .46999 L
.32669 .4699 L
.33231 .46978 L
.34239 .46948 L
.35183 .46912 L
.36196 .46865 L
.38028 .46756 L
.40145 .46594 L
Mistroke
.42155 .46407 L
.4598 .45972 L
.5005 .45423 L
.53968 .44854 L
.58131 .44265 L
.60222 .43999 L
.62143 .43786 L
.64022 .43614 L
.64979 .43544 L
.66003 .43484 L
.66533 .4346 L
.67033 .43441 L
.67483 .43428 L
.67737 .43423 L
.67971 .43418 L
.68076 .43417 L
.6819 .43415 L
.68288 .43414 L
.68395 .43414 L
.68513 .43413 L
.68638 .43412 L
.68754 .43412 L
.68861 .43413 L
.68985 .43413 L
.69101 .43414 L
.69205 .43415 L
.69318 .43416 L
.69572 .4342 L
.69806 .43424 L
.70275 .43438 L
.70778 .43458 L
.71253 .43482 L
.71686 .4351 L
.72746 .43597 L
.73751 .4371 L
.7574 .44023 L
.77581 .44431 L
.79445 .44976 L
.81504 .45747 L
.83599 .46734 L
.85522 .47838 L
.89387 .50707 L
.93346 .54676 L
.97154 .5964 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.9375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000ga000`40l00?003`ooooJOoo003ooomY
ool00?ooofWoo`00ooooJOoo002jool00`0?ool03`03ool01P0?ooooo`0?ool03`Coo`803`06ool0
3ooo00ooo`0?U_oo002kool00`0?ooooo`02ool01P0?ooooo`0?ool03`?oo`0900ooo`0?ool03ooo
00ooo`0?09Koo`00^ooo00<03oooool00_oo00H03oooool03ooo00l3ool02@0?ool03ooo00ooo`0?
ool03`2Fool00;[oo`0300ooo`0?00?oo`0300oooooo00803`Coo`0400ooo`0?ool200l00ooo00oo
o`2Fool00?ooofWoo`00`?oo00<03oooool0YOoo003ooomYool00?ooofWoo`00ooooJOoo003ooomY
ool00?ooofWoo`00ooooJOoo000`ool00`0?ooooo`0Qool300l00ooo00l03`0Rool200l3ool00`0?
ooooo`0Pool00`0?ooooo`0200lPool300l2ool01@0?oooooooo00l07Ooo0`0?00Goo`0?00l03ooo
00803akoo`<03`03ool03`0?00?oo`0300oooooo01_oo`<03`;oo`0300oooooo00803aooo`00;ooo
00<03ooo00l08_oo00<03oooool00ooo00<03oooool08Ooo00D03ooo00ooo`0?027oo`0300oooooo
00;oo`0300oooooo01koo`0:00oooooo00ooo`0?ool03ooo00lMool0100?ooooo`0?1Ooo00<03ooo
ool07?oo00<03oooool00_oo00D03ooo00ooo`0?01goo`0500ooooooool03`04ool00`0?ooooo`0L
ool002ooo`0300ooo`0?02?oo`0300oooooo00803b;oo`803`;oo`0300ooo`0?02;oo`0400ooo`0?
00lQool02P0?ooooo`0?ool03ooo00ooo`0?7Ooo00D03oooooooo`0?00;oo`803aooo`0300oooooo
00803`;oo`0300ooo`0?01goo`0300oooooo00;oo`0400ooo`0?00lOool002ooo`0300ooo`0?02;o
o`0500ooo`0?ool03`0Sool01`0?oooooooo00ooo`0?02;oo`0300ooo`0?02;oo`0:00oooooo00oo
o`0?ool03ooo00lMool0200?ooooo`0?ool03ooo00lPool0100?ooooo`0?0ooo00<03ooo00l07Ooo
00<03oooool00_oo00<03ooo00l08?oo000`ool00`0?ooooo`0Rool200l01?oo00l03`0?8Ooo0`0?
0_oo00<03oooool07ooo0`0?00Coo`0?00l03aooo`803`?oo`0500ooooooool03`0Mool200l3ool2
00l01?oo00l03`0?7Ooo0P0?0_oo0`0?0_oo00<03oooool06ooo0P0?0_oo0`0?00Coo`0?00l03ako
o`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo003ooomYool00?ooofWoo`00ooooJOoo000Y
oooo00lm00l3ool002Woo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo
00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo
00Goo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo
00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo
00Goo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo
00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo
00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo
00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo
00Goo`0300oooooo00Goo`0300oooooo007oo`00:Ooo00<03oooool01Ooo00<03oooool09?oo00<0
3oooool09?oo00<03oooool09Ooo00<03oooool09?oo00<03oooool09Ooo00<03oooool09?oo00<0
3oooool09Ooo00<03oooool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0T
ool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0U
ool00`2?ooooo`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oo
oooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`0307oo
oooo01coo`0300oooooo007oo`00:Ooo0P0?;Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Sooo
ool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool04ooo0P0?1_oo
0P0?0ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool0
0`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Aool300l8ool00`0?oooo
o`01ool002Woo`0300oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`03
07oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo013oo`803`[oo`0300oooooo
007oo`00:Ooo00<03oooool0;?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0
Soooool09Ooo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool03_oo0`0?2ooo00<03oooool0
0Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1o
ooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0<ool300l=ool00`0?ooooo`01
ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oo
oooo02Goo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo00_oo`803`ooo`0300oooooo007o
o`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Oooo
ool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool02Ooo0`0?4?oo00<03oooool00Ooo
000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?oooo
o`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`07ool300lBool00`0?ooooo`01ool0
02Woo`803bgoo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`03
07oooooo02Coo`0308oooooo02Goo`0308oooooo00Koo`803a?oo`803`?oo`00:Ooo00<03oooool0
;?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool0
9?oo00<0Ooooool09Ooo00<0Ooooool01?oo0`0?5Ooo00<03oooool00Ooo000Yool00`0?ooooo`0/
ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0T
ool00`2?ooooo`0Uool00`2?ooooo`02ool300lGool00`0?ooooo`01ool002Woo`0300oooooo02co
o`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Co
o`0307oooooo02Goo`0407ooooooool200lIool00`0?ooooo`01ool002Woo`0300oooooo02coo`03
07oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`03
08oooooo02Goo`0308ooo`0?00803a[oo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Sooo
ool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Oooo
ool09Ooo0`0?7?oo00<03oooool00Ooo000Jool01@0?ooooo`0?ool00P0?2?oo00<03oooool0;?oo
00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo
00<0Soooool09?oo0P0?7_oo00<03oooool00Ooo000Iool00`0?ool03`05ool00`0?ooooo`05ool0
0`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Uool0
0`2?ooooo`0Tool00`1oooooo`0Rool300l00`1oooooo`0Lool00`0?ooooo`01ool001Goo`<03`04
ool03ooo00l4ool00`0?ooooo`06ool300l0o`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`00
5@1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`0300l07`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?00<03`?oo`00
6Ooo00<03ooo00l01Ooo00<03oooool01Ooo00<03oooool0;?oo00<0Soooool09?oo00<0Ooooool0
9Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool07ooo0P0?1?oo00<0
Ooooool07?oo00<03oooool00Ooo000Jool00`0?ooooo`02ool200l8ool00`0?ooooo`0/ool00`1o
ooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?
ooooo`0Mool300l5ool00`2?ooooo`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`0308oo
oooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oo
oooo01_oo`<03`Ooo`0307oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Oooo
ool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Sooo
ool06_oo0P0?2Ooo00<0Soooool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`2?oooo
o`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1ooooo
o`0Hool300l:ool00`1oooooo`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`0307oooooo
02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo
01Koo`<03`coo`0308oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool0
9?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool0
5Ooo0P0?3_oo00<0Ooooool07?oo00<03oooool00Ooo000Yool200l]ool00`1oooooo`0Tool00`2?
ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Cool300l?
ool00`2?ooooo`0Kool200l3ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo02Go
o`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo01;oo`803a7oo`0307oo
oooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo
00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool04?oo0P0?4ooo00<0Sooo
ool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Uool0
0`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0>ool300lDool00`1ooooo
o`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`03
08oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo00goo`803aKoo`0308oooooo
01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0
Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool02ooo0`0?5ooo00<0Ooooool0
7?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?
ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`09ool300lIool00`2?ooooo`0L
ool00`0?ooooo`01ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo02Goo`0307oo
oooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo00Soo`803a_oo`0307oooooo01co
o`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Sooo
ool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool01_oo0`0?7?oo00<0Soooool07?oo
00<03oooool00Ooo000Yool200l]ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool0
0`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`04ool300lNool00`1oooooo`0Kool200l3ool0
02Woo`0300oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo
02Goo`0307oooooo02Coo`0308oooooo00?oo`803b3oo`0308oooooo01coo`0300oooooo007oo`00
:Ooo00<03oooool0;?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool0
9Ooo00<0Soooool09?oo00@0Ooooooooo`<03b7oo`0307oooooo01coo`0300oooooo007oo`00:Ooo
00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool09Ooo
00<0Ooooool09?oo00<0Sooo00l00P0?8ooo00<0Soooool07?oo00<03oooool00Ooo000Yool00`0?
ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?
ooooo`0Tool00`1o00l03`0Uool00`1oooooo`0Lool00`0?ooooo`01ool002Woo`0300oooooo02co
o`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02?o
o`<03bKoo`0308oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool09?oo
00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool08Ooo0`0?00<0Ooooool0
9Ooo00<0Ooooool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?
ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Pool200l2ool00`2?ooooo`0U
ool00`2?ooooo`0Lool00`0?ooooo`01ool002Woo`803bgoo`0308oooooo02Coo`0307oooooo02Go
o`0307oooooo02Coo`0308oooooo02Goo`0308oooooo01koo`<03`?oo`0307oooooo02Goo`0307oo
oooo01_oo`803`?oo`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Sooo
ool09?oo00<0Ooooool09Ooo00<0Ooooool07?oo0`0?1Ooo00<0Soooool09Ooo00<0Soooool07?oo
00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1ooooo
o`0Tool00`2?ooooo`0Uool00`2?ooooo`0Kool200l7ool00`1oooooo`0Uool00`1oooooo`0Lool0
0`0?ooooo`01ool002Woo`0300oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo
02Coo`0307oooooo02Goo`0307oooooo01Woo`<03`Soo`0308oooooo02Goo`0308oooooo01coo`03
00oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool0
9?oo00<0Soooool09Ooo00<0Soooool05ooo0`0?2_oo00<0Ooooool09Ooo00<0Ooooool07?oo00<0
3oooool00Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0T
ool00`1oooooo`0Uool00`1oooooo`0Fool200l<ool00`2?ooooo`0Uool00`2?ooooo`0Lool00`0?
ooooo`01ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Co
o`0308oooooo02Goo`0308oooooo01Coo`<03`goo`0307oooooo02Goo`0307oooooo01coo`0300oo
oooo007oo`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo
00<0Ooooool09Ooo00<0Ooooool04_oo0`0?3ooo00<0Soooool09Ooo00<0Soooool07?oo00<03ooo
ool00Ooo000Yool200l]ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?oooo
o`0Uool00`2?ooooo`0Aool200lAool00`1oooooo`0Uool00`1oooooo`0Kool200l3ool002Woo`03
00oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`03
07oooooo00ooo`<03a;oo`0308oooooo02Goo`0308oooooo01coo`0300oooooo007oo`00:Ooo00<0
3oooool0;?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0
Soooool03Ooo0`0?5?oo00<0Ooooool09Ooo00<0Ooooool07?oo00<03oooool00Ooo000Yool00`0?
ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1o
ooooo`0<ool200lFool00`2?ooooo`0Uool00`2?ooooo`0Lool00`0?ooooo`01ool002Woo`0300oo
oooo02coo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oo
oooo00[oo`<03aOoo`0307oooooo02Goo`0307oooooo01coo`0300oooooo007oo`006_oo00D03ooo
ool03ooo00<03`Ooo`0300oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Co
o`0307oooooo02Goo`0307oooooo00Soo`<03aWoo`0308oooooo02Goo`0308oooooo01coo`0300oo
oooo007oo`006Ooo00<03ooo00l00ooo00<03oooool01ooo00<03oooool0;?oo00<0Soooool09?oo
00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool01ooo0P0?6ooo00<0Oooo
ool09Ooo00<0Ooooool07?oo00<03oooool00Ooo000Eool300l01?oo00ooo`0?1?oo00<03oooool0
1_oo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool0
9Ooo00<0Ooooool01Ooo0`0?7?oo00<0Soooool09Ooo00<0Soooool07?oo00<03oooool00Ooo000I
ool00`0?ool03`03ool00`0?ool03`07ool300l0d02?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0
S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o0`0?06<0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l00`0?0ooo000J
ool00`0?ooooo`03ool200l7ool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?
ooooo`0Tool00`1oooooo`0Uool0101ooooooooo0`0?8?oo00<0Soooool09Ooo00<0Soooool07?oo
00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1ooooo
o`0Tool00`2?ooooo`0Uool00`2?ooooo`0200lRool00`1oooooo`0Uool00`1oooooo`0Lool00`0?
ooooo`01ool002Woo`0300oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Co
o`0307oooooo02Goo`0407l03`0?00lSool00`2?ooooo`0Uool00`2?ooooo`0Bool00`0?ooooo`07
ool00`0?ooooo`01ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo02Goo`0307oo
oooo02Coo`0308oooooo02Coo`<03bGoo`0307oooooo02Goo`0307oooooo017oo`0300oooooo00So
o`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Sooo
ool09?oo00<0Ooooool08ooo0P0?00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool03ooo0P0?
2ooo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1o
ooooo`0Tool00`2?ooooo`0Qool300l00ooo08ooo`0Uool00`1oooooo`0Uool00`1oooooo`0>ool0
0`0?ooooo`0;ool00`0?ooooo`01ool002Woo`0300oooooo02coo`0307oooooo02Coo`0308oooooo
02Goo`0308oooooo02Coo`0307oooooo01ooo`<03`?oo`0307oooooo02Coo`0308oooooo02Goo`03
08oooooo00goo`0300oooooo00coo`0300oooooo007oo`00:Ooo0P0?;Ooo00<0Soooool09?oo00<0
Ooooool09Ooo00<0Ooooool09?oo00<0Soooool07_oo0P0?1Ooo00<0Soooool09?oo00<0Ooooool0
9Ooo00<0Ooooool06ooo0P0?0ooo000Yool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0U
ool00`2?ooooo`0Tool00`1oooooo`0Lool300l6ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?
ooooo`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo02Go
o`0307oooooo02Coo`0308oooooo01[oo`<03`Soo`0308oooooo02Coo`0307oooooo02Goo`0307oo
oooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo
00<0Soooool09?oo00<0Ooooool06?oo0`0?2_oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Sooo
ool02?oo00<03oooool04Ooo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool0
0`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Gool200l<ool00`2?ooooo`0Tool00`1ooooo
o`0Uool00`1oooooo`07ool00`0?ooooo`0Bool00`0?ooooo`01ool002Woo`0300oooooo02coo`03
07oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo01Goo`<03`goo`0307oooooo
02Coo`0308oooooo02Goo`0308oooooo00Koo`0300oooooo01?oo`0300oooooo007oo`00:Ooo00<0
3oooool0;?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool04ooo0`0?
3ooo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool01Ooo00<03oooool05?oo00<03oooool0
0Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1o
ooooo`0Aool300lAool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`04ool00`0?ooooo`0E
ool00`0?ooooo`01ool002Woo`803bgoo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Co
o`0308oooooo013oo`803a?oo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo01_oo`803`?o
o`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Oooo
ool03_oo0`0?5?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool07?oo00<03oooool00Ooo
000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?oooo
o`0<ool300lFool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Lool00`0?ooooo`01ool0
02Woo`0300oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo
00[oo`<03aSoo`0307oooooo02Coo`0308oooooo02Goo`0308ooo`0?01coo`0300oooooo007oo`00
:Ooo00<03oooool0;?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool0
2Ooo0P0?6_oo00<0Soooool09?oo00<0Ooooool09Ooo00<0O`0?ool07?oo00<03oooool00Ooo000Y
ool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`07
ool300lKool00`1oooooo`0Tool00`2?ooooo`0Uool00`0?ooooo`0Lool00`0?ooooo`01ool000Oo
o`803`?oo`0300oooooo01[oo`0300oooooo02coo`0308oooooo02Coo`0307oooooo02Goo`0307oo
oooo02Coo`0308oooooo00Goo`<03agoo`0308oooooo02Coo`0307oooooo02?oo`803`0307oooooo
01coo`0300oooooo007oo`001ooo00@03oooooooo`803acoo`0300oooooo02coo`0307oooooo02Co
o`0308oooooo02Goo`0308oooooo02Coo`0307oooooo00?oo`<03aooo`0307oooooo02Coo`0308oo
oooo02;oo`0400oooooo08lNool00`0?ooooo`01ool000Ooo`0600ooo`0?00ooo`0?7?oo0P0?;Ooo
00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool00_oo0P0?8Ooo00<0Sooo
ool09?oo00<0Ooooool09Ooo00<0Ooooool06ooo0P0?0ooo0007ool200l3ool00`0?ooooo`0Jool0
0`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0300lR
ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Lool00`0?ooooo`01ool000Ooo`0400oo
ooooool200lLool00`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool0
102?00l03`0?9?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool07?oo00<03oooool00Ooo
000Yool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Sool300lVool0
0`1oooooo`0Tool00`2?ooooo`0Mool00`0?ooooo`05ool00`2?ooooo`0Lool00`0?ooooo`01ool0
02Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo027oo`<03`0308oo
oooo02Goo`0308oooooo02Coo`0307oooooo01goo`0300oooooo00Goo`0307oooooo01coo`0300oo
oooo007oo`002_oo00<03ooo00l07?oo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo
00<0Soooool07ooo0`0?0_oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool07?oo00<03ooo
ool01_oo00<0Soooool07?oo00<03oooool00Ooo0007ool00`0?ool03`0300lLool00`0?ooooo`0/
ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Nool200l4ool00`2?ooooo`0Uool00`2?
ooooo`0Tool00`1oooooo`0Jool200l9ool00`1oooooo`0Lool00`0?ooooo`01ool000Woo`@03aco
o`0300oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo01coo`<03`Goo`0307oo
oooo02Goo`0307oooooo02Coo`0308oooooo01Woo`0300oooooo00Woo`0308oooooo01coo`0300oo
oooo007oo`002Ooo00@03oooool03acoo`803bgoo`0308oooooo02Coo`0307oooooo02Goo`0307oo
oooo01[oo`<03`Ooo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo01Woo`0300oooooo00Wo
o`0307oooooo01_oo`803`?oo`002Ooo00<03oooool07Ooo00<03oooool0;?oo00<0Ooooool09?oo
00<0Soooool09Ooo00<0Soooool06?oo0`0?2Ooo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Sooo
ool09Ooo00<0Soooool07?oo00<03oooool00Ooo000:ool300lLool00`0?ooooo`0/ool00`2?oooo
o`0Tool00`1oooooo`0Uool00`1oooooo`0Fool300l;ool00`2?ooooo`0Uool00`2?ooooo`0Tool0
0`1oooooo`0Uool00`1oooooo`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`0307oooooo
02Coo`0308oooooo02Goo`0308oooooo01Coo`<03`goo`0307oooooo02Goo`0307oooooo02Coo`03
08oooooo02Goo`0308oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool0
9?oo00<0Ooooool09Ooo00<0Ooooool04_oo0`0?3ooo00<0Soooool09Ooo00<0Soooool09?oo00<0
Ooooool05?oo00<03oooool03_oo00<0Ooooool07?oo00<03oooool00Ooo0009ool00`0?ool03`0M
ool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Aool200lAool00`1o
ooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Cool00`0?ooooo`0?ool00`2?ooooo`0Lool00`0?
ooooo`01ool000Woo`803`03ool03ooo00coo`0500oooooo00ooo`0300l7ool00`0?ooooo`0/ool0
0`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0?ool200lCool00`2?ooooo`0Uool00`2?oooo
o`0Tool00`1oooooo`0Aool200lBool00`1oooooo`0Lool00`0?ooooo`01ool000[oo`<03`coo`03
00ooo`0?00Coo`0300oooooo00Koo`0300oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`03
08oooooo00goo`<03aCoo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo013oo`0300oooooo
01;oo`0308oooooo01coo`0300oooooo007oo`003?oo00<03oooool01_oo0`0?00Coo`0?ool03`Co
o`0300oooooo00Koo`<03`2908l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`0300l0ZP2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l03`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l300l3ool001Woo`0300ooo`0?00Co
o`0300oooooo00Koo`0300oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo00Wo
o`<03aSoo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo01coo`0300oo
oooo007oo`003?oo00<03oooool02ooo00<03oooool00_oo0P0?2?oo00<03oooool0;?oo00<0Sooo
ool09?oo00<0Ooooool09Ooo00<0Ooooool01ooo0`0?6_oo00<0Soooool09Ooo00<0Soooool09?oo
00<0Ooooool09Ooo00<0Ooooool07?oo00<03oooool00Ooo0009ool300lMool00`0?ooooo`0/ool0
0`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`05ool300lLool00`1oooooo`0Uool00`1ooooo
o`0Tool00`2?ooooo`0Uool00`2?ooooo`0Lool00`0?ooooo`01ool000coo`0300oooooo01[oo`03
00oooooo02coo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo00?oo`<03akoo`0308oooooo
02Goo`0308oooooo02Coo`0307oooooo00_oo`0300oooooo01Ooo`0307oooooo01coo`0300oooooo
007oo`002Ooo100?7?oo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00@0Sooooooo
o`<03b3oo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo00Woo`803a[oo`0308oooooo01co
o`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Oooo
00l00P0?8_oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool02?oo00<03oooool06_oo00<0
Ooooool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0U
ool300lTool00`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`07ool00`0?ooooo`0Kool00`2?
ooooo`0Lool00`0?ooooo`01ool000coo`0300oooooo01[oo`0300oooooo02coo`0308oooooo02Co
o`0307oooooo02?oo`<03bKoo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo00Koo`0300oo
oooo01coo`0307oooooo01coo`0300oooooo007oo`00:Ooo0P0?;Ooo00<0Ooooool09?oo00<0Sooo
ool08Ooo0`0?00?oo`2?ool09Ooo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0
Soooool06ooo0P0?0ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Nool300l4
ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0L
ool00`0?ooooo`01ool002Woo`0300oooooo02coo`0307oooooo02Coo`0308oooooo01coo`<03`Ko
o`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo01co
o`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool09?oo00<0Ooooool06_oo0`0?2?oo
00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00D0Ooooooooo`0?02?oo`0307oooooo
01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool06?oo0`0?
2_oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00@0Soooool03bCoo`0308oooooo
01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool09?oo00<0Ooooool05_oo0`0?
3?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Oooo00l09Ooo00<0Ooooool0
7?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Cool400l>
ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?00ooo`0Uool00`2?ooooo`0L
ool00`0?ooooo`01ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo017oo`<03a7o
o`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02?oo`803bOoo`0307oooooo01coo`0300oo
oooo007oo`00:Ooo0P0?;Ooo00<0Ooooool09?oo00<0Soooool03ooo0`0?4ooo00<0Soooool09?oo
00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool06ooo0P0?0ooo000Yool0
0`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0<ool400lEool00`1oooooo`0Tool00`2?oooo
o`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Lool00`0?ooooo`01ool002Woo`03
00oooooo02coo`0307oooooo02Coo`0308oooooo00[oo`<03aSoo`0308oooooo02Coo`0307oooooo
02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo01coo`0300oooooo007oo`00:Ooo00<0
3oooool0;?oo00<0Soooool09?oo00<0Ooooool02?oo0`0?6_oo00<0Ooooool09?oo00<0Soooool0
9Ooo00<0Soooool07_oo00<03oooool00ooo00<0Ooooool09Ooo00<0Ooooool07?oo00<03oooool0
0Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`05ool400lLool00`2?ooooo`0T
ool00`1oooooo`0Uool00`1oooooo`0Mool00`0?ooooo`04ool00`2?ooooo`0Uool00`2?ooooo`0L
ool00`0?ooooo`01ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo00?oo`<03aoo
o`0307oooooo02Coo`0308oooooo02Goo`0308oooooo01coo`0300oooooo00Goo`0307oooooo02Go
o`0307oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Sooo
ool0100?8Ooo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool06ooo00<03oooool01_oo00<0
Soooool09Ooo00<0Soooool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0T
ool400lTool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Iool200l9ool00`1oooooo`0U
ool00`1oooooo`0Lool00`0?ooooo`01ool002Woo`803bgoo`0307oooooo02;oo`<03bOoo`0308oo
oooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo01_oo`803`?o
o`00:Ooo00<03oooool0;?oo00<0Soooool07ooo100?00?oo`1oool09_oo00<0Ooooool09?oo00<0
Soooool09Ooo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool07?oo00<03oooool00Ooo000Y
ool00`0?ooooo`0/ool00`1oooooo`0Lool400l4ool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1o
ooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Lool00`0?ooooo`01ool002Wo
o`0300oooooo02coo`0308oooooo01Woo`@03`Ooo`0307oooooo02Goo`0307oooooo02Coo`0308oo
oooo02Goo`0308oooooo01Coo`0300oooooo00goo`0307oooooo02Goo`0307oooooo01coo`0300oo
oooo007oo`00:Ooo00<03oooool0;?oo00<0Ooooool05_oo100?2_oo00<0Soooool09Ooo00<0Sooo
ool09?oo00<0Ooooool09Ooo00<0Ooooool04ooo00<03oooool03_oo00<0Soooool09Ooo00<0Sooo
ool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0Cool400l=ool00`1ooooo
o`0Uool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Bool00`0?ooooo`0?ool00`1ooooo
o`0Uool00`1oooooo`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`0307oooooo013oo`@0
3a3oo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo013oo`803a;oo`03
08oooooo02Goo`0308oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool0
3?oo1@0?4ooo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool03ooo00<0
3oooool04_oo00<0Ooooool09Ooo00<0Ooooool07?oo00<03oooool00Ooo000Yool200l]ool00`1o
ooooo`09ool400lGool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0T
ool00`2?ooooo`0Uool00`2?ooooo`0Kool200l3ool002Woo`0300oooooo02coo`0308oooooo00Go
o`D03a[oo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oo
oooo02Goo`0307oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00@0Ooooooooo`D0
3akoo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo023oo``03`Koo`0300oooooo00Koo`D0
3`coo`0308oooooo02Goo`0308oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo1@0?
8_oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool07?oo100?1Ooo00<0Soooool02Ooo00<0
3oooool03?oo1P0?1_oo00<0Ooooool09Ooo00<0Ooooool07?oo00<03oooool00Ooo000Yool00`0?
ooooo`0Wool600lVool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`07
ool200lEool500l00ooo08ooo`0Vool00`2?ooooo`0Lool00`0?ooooo`01ool0027oo`0300oooooo
00Goo`0300oooooo027oo`L03`Coo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`03
08oooooo00Ooo`H03aSoo`0308oooooo00Koo`0300oooooo01_oo`0307oooooo02Goo`0307oooooo
01coo`0300oooooo007oo`008?oo00<03ooo00l01_oo00<03oooool06ooo1`0?2_oo00<0Ooooool0
9?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool01`0?7_oo00<0Ooooool01Ooo00<03ooo
ool07?oo00<0Soooool09Ooo00<0Soooool07?oo00<03oooool00Ooo000Pool00`0?ool03`06ool0
0`0?ooooo`0Aool;00l@ool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Sool400lUool0
0`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Lool00`0?ooooo`01ool0023oo`0300ooo`0?
00Koool03cd03`?oo`008Ooo00<03oooool01Ooo00<03oooool04Ooo1@0?5_oo00<0Soooool09?oo
00<0Ooooool09Ooo00<0Ooooool04_oo0`0?3ooo00<0Soooool09Ooo00@0Soooool03b?oo`0307oo
oooo00[oo`0300oooooo01Soo`0307oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool05_oo
0P0?3?oo2`0?9?oo00<0Soooool09Ooo00<0Soooool02Ooo2@0?4_oo00<0Ooooool09Ooo00<0O`0?
00l09?oo00<0Soooool02ooo0P0?6?oo00<0Soooool07?oo00<03oooool00Ooo000Yool00`0?oooo
o`0Nool200l<ool00`2?ooooo`0600lNool00`1oooooo`0Uool00`1oooooo`04ool500lKool00`2?
ooooo`0Tool200lVool00`1oooooo`0=ool200lFool00`1oooooo`0Lool00`0?ooooo`01ool002Wo
o`0300oooooo023oo`D03`Ooo`0307oooooo01Coo`P03`Soo`0308oooooo01Woo`D03`Ooo`0308oo
oooo02Coo`0307oooooo02;oo`803`03ool0Oooo02Goo`0308oooooo00ooo`803aCoo`0308oooooo
01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool07?oo2@0?3ooo3@0?2ooo00<0
Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool04Ooo0P0?4_oo00<0Ooooool0
7?oo00<03oooool00Ooo000Yool00`0?ooooo`0Zool200l00`1oooooo`0Tool00`2?ooooo`0Uool0
0`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Cool200l@ool00`2?oooo
o`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`<03bCoo`0307oooooo02Goo`0307oooooo
02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo01Goo`803`koo`0307oooooo01coo`03
00oooooo007oo`00:Ooo0P0?;Ooo00<0Ooooool00P0?8_oo00<0Soooool09Ooo00<0Soooool09?oo
00<0Ooooool06ooo0`0?1ooo00<0Ooooool09?oo00<0Soooool05_oo0P0?3Ooo00<0Soooool06ooo
0P0?0ooo000Yool00`0?ooooo`0/ool00`2?ooooo`07ool00`0?ooooo`0Jool00`1oooooo`0Uool0
0`1oooooo`0Tool00`2?ooooo`0Iool200l:ool00`2?ooooo`0Tool00`1oooooo`0Hool00`0?oooo
o`0:ool00`1oooooo`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`0307oooooo00Ooo`@0
3aWoo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo01Ooo`803`coo`0307oooooo02Coo`03
08oooooo02Goo`0308oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool0
2ooo0`0?5_oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0
Ooooool09Ooo00<0Ooooool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0T
ool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0U
ool00`2?ooooo`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`0308oooooo01?oo`803`oo
o`0307oooooo02Goo`0307oooooo02Coo`0308oooooo017oo`0300oooooo017oo`0308oooooo02Co
o`0307oooooo02Goo`0307oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Oooo
ool05Ooo0`0?3?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool03ooo0`0?4ooo00<0Oooo
ool09?oo00<0Soooool09Ooo00<0Soooool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool0
0`2?ooooo`0Hool200l:ool00`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0<ool300lFool0
0`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Lool00`0?ooooo`01ool002Woo`803bgoo`03
07oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`03
08oooooo02Goo`0308oooooo01_oo`803`?oo`00:Ooo00<03oooool0;?oo00<0Soooool07ooo100?
00?oo`1oool09_oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool09Ooo
00<0Ooooool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0Sool300lVool0
0`2?ooooo`0Tool00`1oooooo`04ool300lNool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?oooo
o`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo02Goo`03
07oooooo02Coo`0408ooooooool400lPool00`2?ooooo`0Tool00`1oooooo`0Tool200lNool00`0?
ooooo`01ool002Woo`0300oooooo02coo`0307oooooo02Coo`0308oooooo00Coo`@03agoo`0308oo
oooo02Coo`0407oooooo00lTool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?00ooo`0Lool00`0?
ooooo`01ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo00Soo`<03a[oo`0307oo
oooo023oo`803`;oo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`0307ooo`0?01co
o`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool04?oo0P0?4ooo
00<0Soooool07?oo100?1?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00@0Sooo
ool03a_oo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Soooool09?oo00<0Ooooool04_oo
1P0?3Ooo00<0Ooooool06ooo00<03oooool01_oo00<0Soooool09Ooo00<0Soooool09?oo00<0Oooo
ool09Ooo00D0Ooooooooo`0?01[oo`0300oooooo007oo`00:Ooo0P0?;Ooo00<0Ooooool09?oo00<0
Soooool07Ooo1@0?0ooo00<0Soooool03_oo1`0?3ooo00<0Ooooool09Ooo00<0Ooooool09?oo00<0
Soooool09Ooo00<0Soooool00_oo00<03oooool05_oo0P0?0ooo000Yool00`0?ooooo`0/ool00`2?
ooooo`0Tool00`1oooooo`0Rool200l00ooo07ooo`02ool800lKool00`2?ooooo`0Uool00`2?oooo
o`0Tool00`1oooooo`0Uool00`1oooooo`03ool00`0?ooooo`0Fool00`0?ooooo`01ool002Woo`03
00oooooo02coo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`03
07oooooo02Coo`0308oooooo02Goo`0308oooooo00Coo`0300oooooo01Goo`0300oooooo007oo`00
:Ooo00<03oooool0;?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool0
9Ooo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool01Ooo00<03oooool05?oo00<03oooool0
0Ooo000Yool00`0?ooooo`0/ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1o
ooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`06ool00`0?ooooo`0Cool00`0?
ooooo`01ool002Woo`0300oooooo02coo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Co
o`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo00Ooo`0300oooooo01;o
o`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Sooo
ool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool01ooo00<03ooo
ool04_oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool00`1oooooo`0Uool0
0`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Lool0
0`0?ooooo`01ool002Woo`803bgoo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`03
07oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo01_oo`803`?oo`00:Ooo00<0
3oooool0;?oo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0
Soooool09?oo00<0Ooooool09Ooo00<0Ooooool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/
ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0T
ool00`2?ooooo`0Uool00`2?ooooo`0Lool00`0?ooooo`01ool002Woo`0300oooooo02coo`0308oo
oooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oo
oooo02Goo`0307oooooo01coo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0Ooooool09?oo
00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo
00<0Soooool07?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool00`1ooooo
o`0Uool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1ooooo
o`0Lool00`0?ooooo`01ool001_oo`0500oooooo00ooo`0300l6ool00`0?ooooo`0/ool00`1ooooo
o`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?oooo
o`0Uool00`2?ooooo`0Lool00`0?ooooo`01ool001[oo`0300ooo`0?00Coo`0300oooooo00Goo`03
00oooooo02coo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`03
08oooooo02Coo`0307oooooo02Goo`0307oooooo01coo`0300oooooo007oo`006_oo00<03ooo00l0
1?oo00<03oooool01Ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool0
9?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool07?oo00<03oooool0
0Ooo000Jool00`0?ool03`04ool00`0?ooooo`05ool300l0o`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0
O`2?07l0S`00=`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?07l0S`1o08l0O`2?
00<03`?oo`006ooo00<03oooool00_oo0P0?1ooo00<03oooool0;?oo00<0Ooooool09?oo00<0Sooo
ool09Ooo00<0Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Sooo
ool04Ooo00<03oooool02?oo00<03oooool00Ooo000Yool00`0?ooooo`0/ool00`2?ooooo`0Tool0
0`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool0
0`1oooooo`0Aool00`0?ooooo`08ool00`0?ooooo`01ool002Woo`0300oooooo02coo`0307oooooo
02Coo`0308oooooo02Goo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo
02Goo`0308oooooo01;oo`0300oooooo00Ooo`0300oooooo007oo`00:Ooo00<03oooool0;?oo00<0
Soooool09?oo00<0Ooooool09Ooo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0
Ooooool09Ooo00<0Ooooool04ooo00<03oooool01_oo00<03oooool00Ooo000Yool00`0?ooooo`0/
ool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0T
ool00`2?ooooo`0Uool00`2?ooooo`0Dool00`0?ooooo`05ool00`0?ooooo`01ool002Woo`0300oo
oooo02coo`0308oooooo02Coo`0307oooooo02Goo`0307oooooo02Coo`0308oooooo02Goo`0308oo
oooo02Coo`0307oooooo02Goo`0307oooooo01Coo`0300oooooo00Goo`0300oooooo007oo`00:Ooo
00<03oooool0;?oo00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool09?oo00<0Ooooool09Ooo
00<0Ooooool09?oo00<0Soooool09Ooo00<0Soooool07?oo00<03oooool00Ooo000Yool200l]ool0
0`2?ooooo`0Tool00`1oooooo`0Uool00`1oooooo`0Tool00`2?ooooo`0Uool00`2?ooooo`0Tool0
0`1oooooo`0Uool00`1oooooo`0Kool200l3ool002Woo`0300oooooo00Goo`0300oooooo00Coo`03
00oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`03
00oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`03
00oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`03
00oooooo00Goo`0300oooooo00Goo`0300oooooo00Coo`0300oooooo00Goo`0300oooooo00Goo`03
00oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`03
00oooooo00Coo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`03
00oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo00Coo`03
00oooooo00Goo`0300oooooo00Goo`0300oooooo00Goo`0300oooooo007oo`00:Oooo`0??@0?0ooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-31.11364, -0.418993, 
  0.792566, 0.003083}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"NeXT 3.0",
ScreenRectangle->{{0, 957}, {0, 768}},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Automatic,
WindowSize->{673, 575},
WindowMargins->{{129, Automatic}, {Automatic, 11}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"NeXTAutomaticEncoding",
Magnification->1.25
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 95, 2, 122, "Title"],
Cell[1829, 55, 55, 1, 31, "Input"],
Cell[1887, 58, 87, 2, 64, "Section"],
Cell[1977, 62, 85, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[2087, 68, 89, 2, 64, "Section"],
Cell[2179, 72, 1790, 36, 717, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4006, 113, 97, 2, 64, "Section"],
Cell[4106, 117, 20425, 593, 113, 5301, 401, "GraphicsData", 
"PostScript", "Graphics"],
Cell[24534, 712, 347, 7, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24918, 724, 113, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[25056, 730, 96, 2, 54, "Subsection"],
Cell[25155, 734, 228, 5, 140, "Input"],
Cell[25386, 741, 182, 4, 128, "Input"],
Cell[25571, 747, 303, 6, 142, "Input"],
Cell[25877, 755, 243, 5, 115, "Input"],
Cell[26123, 762, 163, 4, 149, "Input"],

Cell[CellGroupData[{
Cell[26311, 770, 263, 5, 91, "Input"],
Cell[26577, 777, 226, 5, 27, "Print"],
Cell[26806, 784, 230, 5, 27, "Print"],
Cell[27039, 791, 235, 5, 27, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27323, 802, 93, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[27441, 808, 127, 2, 51, "Subsubsection"],
Cell[27571, 812, 190, 5, 169, "Input"],

Cell[CellGroupData[{
Cell[27786, 821, 336, 7, 146, "Input"],
Cell[28125, 830, 470, 15, 48, "Print"],
Cell[28598, 847, 461, 15, 46, "Print"],
Cell[29062, 864, 461, 15, 46, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29572, 885, 119, 2, 51, "Subsubsection"],

Cell[CellGroupData[{
Cell[29716, 891, 246, 4, 65, "Input"],
Cell[29965, 897, 275, 8, 45, "Print"],
Cell[30243, 907, 296, 9, 45, "Print"],
Cell[30542, 918, 298, 9, 45, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30889, 933, 122, 2, 51, "Subsubsection"],

Cell[CellGroupData[{
Cell[31036, 939, 321, 8, 193, "Input"],
Cell[31360, 949, 739, 23, 55, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32172, 980, 113, 2, 64, "Section"],

Cell[CellGroupData[{
Cell[32310, 986, 96, 2, 54, "Subsection"],
Cell[32409, 990, 111, 3, 48, "Input"],
Cell[32523, 995, 202, 4, 128, "Input"],
Cell[32728, 1001, 220, 5, 95, "Input"],
Cell[32951, 1008, 213, 4, 95, "Input"],
Cell[33167, 1014, 199, 5, 142, "Input"],

Cell[CellGroupData[{
Cell[33391, 1023, 261, 5, 91, "Input"],
Cell[33655, 1030, 225, 5, 27, "Print"],
Cell[33883, 1037, 230, 5, 27, "Print"],
Cell[34116, 1044, 236, 5, 27, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34401, 1055, 93, 2, 54, "Subsection"],

Cell[CellGroupData[{
Cell[34519, 1061, 127, 2, 51, "Subsubsection"],
Cell[34649, 1065, 192, 5, 142, "Input"],

Cell[CellGroupData[{
Cell[34866, 1074, 340, 7, 146, "Input"],
Cell[35209, 1083, 536, 16, 48, "Print"],
Cell[35748, 1101, 477, 15, 46, "Print"],
Cell[36228, 1118, 672, 20, 51, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36949, 1144, 119, 2, 51, "Subsubsection"],

Cell[CellGroupData[{
Cell[37093, 1150, 246, 4, 65, "Input"],
Cell[37342, 1156, 312, 9, 48, "Print"],
Cell[37657, 1167, 310, 9, 45, "Print"],
Cell[37970, 1178, 493, 15, 44, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38536, 1201, 98, 2, 64, "Section"],
Cell[38637, 1205, 541, 11, 158, "Input"],
Cell[39181, 1218, 387, 9, 105, "Input"],
Cell[39571, 1229, 102, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[39698, 1235, 1030, 19, 561, "Input"],
Cell[40731, 1256, 183, 4, 27, "Print"],
Cell[40917, 1262, 182, 4, 27, "Print"],
Cell[41102, 1268, 179, 4, 27, "Print"],
Cell[41284, 1274, 222, 5, 27, "Print"],
Cell[41509, 1281, 180, 4, 27, "Print"],
Cell[41692, 1287, 221, 5, 27, "Print"],
Cell[41916, 1294, 180, 4, 27, "Print"],
Cell[42099, 1300, 224, 5, 27, "Print"],
Cell[42326, 1307, 223, 5, 27, "Print"],
Cell[42552, 1314, 224, 5, 27, "Print"],
Cell[42779, 1321, 224, 5, 27, "Print"],
Cell[43006, 1328, 225, 5, 27, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[43280, 1339, 101, 2, 64, "Section"],
Cell[43384, 1343, 317, 7, 65, "Input"],
Cell[43704, 1352, 179, 4, 65, "Input"],
Cell[43886, 1358, 765, 15, 90, "Input"],

Cell[CellGroupData[{
Cell[44676, 1377, 280, 6, 106, "Input"],
Cell[44959, 1385, 56795, 1558, 233, 18882, 1085, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

